@@ -1,29 +1,42 @@
 <?php
 /*********************************************************************************
- * The contents of this file are subject to the TimeTrex Public License Version
- * 1.1.0 ("License"); You may not use this file except in compliance with the
- * License. You may obtain a copy of the License at http://www.TimeTrex.com/TPL
- * Software distributed under the License is distributed on an "AS IS" basis,
- * WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the License
- * for the specific language governing rights and limitations under the
- * License.
+ * TimeTrex is a Payroll and Time Management program developed by
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
  *
- * All copies of the Covered Code must include on each user interface screen:
- *    (i) the "Powered by TimeTrex" logo and
- *    (ii) the TimeTrex copyright notice
- * in the same form as they appear in the distribution.  See full license for
- * requirements.
+ * This program is free software; you can redistribute it and/or modify it under
+ * the terms of the GNU Affero General Public License version 3 as published by
+ * the Free Software Foundation with the addition of the following permission
+ * added to Section 15 as permitted in Section 7(a): FOR ANY PART OF THE COVERED
+ * WORK IN WHICH THE COPYRIGHT IS OWNED BY TIMETREX, TIMETREX DISCLAIMS THE
+ * WARRANTY OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
  *
- * The Original Code is: TimeTrex Open Source
- * The Initial Developer of the Original Code is TimeTrex Payroll Services
- * Portions created by TimeTrex are Copyright (C) 2004-2007 TimeTrex Payroll Services;
- * All Rights Reserved.
+ * This program is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+ * FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
+ * details.
  *
+ * You should have received a copy of the GNU Affero General Public License along
+ * with this program; if not, see http://www.gnu.org/licenses or write to the Free
+ * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+ * 02110-1301 USA.
+ *
+ * You can contact TimeTrex headquarters at Unit 22 - 2475 Dobbin Rd. Suite
+ * #292 Westbank, BC V4T 2E9, Canada or at email address info@timetrex.com.
+ *
+ * The interactive user interfaces in modified source and object code versions
+ * of this program must display Appropriate Legal Notices, as required under
+ * Section 5 of the GNU Affero General Public License version 3.
+ *
+ * In accordance with Section 7(b) of the GNU Affero General Public License
+ * version 3, these Appropriate Legal Notices must retain the display of the
+ * "Powered by TimeTrex" logo. If the display of the logo is not reasonably
+ * feasible for technical reasons, the Appropriate Legal Notices must display
+ * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2158 $
- * $Id: CompanyFactory.class.php 2158 2008-09-15 23:26:15Z ipso $
- * $Date: 2008-09-15 16:26:15 -0700 (Mon, 15 Sep 2008) $
+ * $Revision: 3021 $
+ * $Id: CompanyFactory.class.php 3021 2009-11-11 23:33:03Z ipso $
+ * $Date: 2009-11-11 15:33:03 -0800 (Wed, 11 Nov 2009) $
  */
 
 /**
@@ -33,8 +46,8 @@ class CompanyFactory extends Factory {
 	protected $table = 'company';
 	protected $pk_sequence_name = 'company_id_seq'; //PK Sequence name
 
-	protected $address_validator_regex = '/^[a-zA-Z0-9-,_\/\.\'#\ |\x7F-\xFF|\x{4E00}-\x{9FFF}]{1,250}$/iu';
-	protected $city_validator_regex = '/^[a-zA-Z0-9-\.\ |\x7F-\xFF|\x{4E00}-\x{9FFF}]{1,250}$/iu';
+	protected $address_validator_regex = '/^[a-zA-Z0-9-,_\/\.\'#\ |\x{0080}-\x{FFFF}]{1,250}$/iu';
+	protected $city_validator_regex = '/^[a-zA-Z0-9-\.\ |\x{0080}-\x{FFFF}]{1,250}$/iu';
 
 	function _getFactoryOptions( $name ) {
 
@@ -312,12 +325,12 @@ class CompanyFactory extends Factory {
 														'MB' => TTi18n::gettext('Manitoba'),
 														'QC' => TTi18n::gettext('Quebec'),
 														'ON' => TTi18n::gettext('Ontario'),
-														'NF' => TTi18n::gettext('NewFoundLand'),
+														'NL' => TTi18n::gettext('NewFoundLand'),
 														'NB' => TTi18n::gettext('New Brunswick'),
 														'NS' => TTi18n::gettext('Nova Scotia'),
 														'PE' => TTi18n::gettext('Prince Edward Island'),
 														'NT' => TTi18n::gettext('Northwest Territories'),
-														'YU' => TTi18n::gettext('Yukon'),
+														'YT' => TTi18n::gettext('Yukon'),
 														'NU' => TTi18n::gettext('Nunavut')
 														),
 										'US' => array(
@@ -390,14 +403,14 @@ class CompanyFactory extends Factory {
 										'AW' => array( '00' => '--'),
 										'AU' => array(
 														'00' => '--',
-														'ACT'	=> 'Australian Capital Territory',
-														'NSW'	=> 'New South Wales',
-														'NT'	=> 'Northern Territory',
-														'QLD'	=> 'Queensland',
-														'SA'	=> 'South Australia',
-														'TAS'	=> 'Tasmania',
-														'VIC'	=> 'Victoria',
-														'WA'	=> 'Western Australia',
+														'ACT'	=> TTi18n::gettext('Australian Capital Territory'),
+														'NSW'	=> TTi18n::gettext('New South Wales'),
+														'NT'	=> TTi18n::gettext('Northern Territory'),
+														'QLD'	=> TTi18n::gettext('Queensland'),
+														'SA'	=> TTi18n::gettext('South Australia'),
+														'TAS'	=> TTi18n::gettext('Tasmania'),
+														'VIC'	=> TTi18n::gettext('Victoria'),
+														'WA'	=> TTi18n::gettext('Western Australia'),
 													),
 										'AT' => array( '00' => '--'),
 										'AZ' => array( '00' => '--'),
@@ -406,17 +419,17 @@ class CompanyFactory extends Factory {
 										'BD' => array( '00' => '--'),
 										'BB' => array(
 														'00' => '--',
-														'M' => 'St. Michael',
-														'X' => 'Christ Church',
-														'G' => 'St. George',
-														'J' => 'St. John',
-														'P' => 'St. Philip',
-														'O' => 'St. Joseph',
-														'L' => 'St. Lucy',
-														'S' => 'St. James',
-														'T' => 'St. Thomas',
-														'A' => 'St. Andrew',
-														'E' => 'St. Peter'
+														'M' => TTi18n::gettext('St. Michael'),
+														'X' => TTi18n::gettext('Christ Church'),
+														'G' => TTi18n::gettext('St. George'),
+														'J' => TTi18n::gettext('St. John'),
+														'P' => TTi18n::gettext('St. Philip'),
+														'O' => TTi18n::gettext('St. Joseph'),
+														'L' => TTi18n::gettext('St. Lucy'),
+														'S' => TTi18n::gettext('St. James'),
+														'T' => TTi18n::gettext('St. Thomas'),
+														'A' => TTi18n::gettext('St. Andrew'),
+														'E' => TTi18n::gettext('St. Peter')
 													),
 										'BY' => array( '00' => '--'),
 										'BE' => array( '00' => '--'),
@@ -446,39 +459,39 @@ class CompanyFactory extends Factory {
 										'CC' => array( '00' => '--'),
 										'CO' => array(
 														'00' => '--',
-														'AM' => 'Amazonas',
-														'AN' => 'Antioquia',
-														'AR' => 'Arauca',
-														'AT' => 'Atlantico',
-														'BL' => 'Bolivar',
-														'BY' => 'Boyaca',
-														'CL' => 'Caldas',
-														'CQ' => 'Caqueta',
-														'CS' => 'Casanare',
-														'CA' => 'Cauca',
-														'CE' => 'Cesar',
-														'CH' => 'Choco',
-														'CO' => 'Cordoba',
-														'CU' => 'Cundinamarca',
-														'DC' => 'Distrito Capital',
-														'GN' => 'Guainia',
-														'GV' => 'Guaviare',
-														'HU' => 'Huila',
-														'LG' => 'La Guajira',
-														'MA' => 'Magdalena',
-														'ME' => 'Meta',
-														'NA' => 'Nariño',
-														'NS' => 'Norte de Santander',
-														'PU' => 'Putumayo',
-														'QD' => 'Quindio',
-														'RI' => 'Risaralda',
-														'SA' => 'San Andres y Providencia',
-														'ST' => 'Santander',
-														'SU' => 'Sucre',
-														'TO' => 'Tolima',
-														'VC' => 'Valle del Cauca',
-														'VP' => 'Vaupes',
-														'VD' => 'Vichada',
+														'AM' => TTi18n::gettext('Amazonas'),
+														'AN' => TTi18n::gettext('Antioquia'),
+														'AR' => TTi18n::gettext('Arauca'),
+														'AT' => TTi18n::gettext('Atlantico'),
+														'BL' => TTi18n::gettext('Bolivar'),
+														'BY' => TTi18n::gettext('Boyaca'),
+														'CL' => TTi18n::gettext('Caldas'),
+														'CQ' => TTi18n::gettext('Caqueta'),
+														'CS' => TTi18n::gettext('Casanare'),
+														'CA' => TTi18n::gettext('Cauca'),
+														'CE' => TTi18n::gettext('Cesar'),
+														'CH' => TTi18n::gettext('Choco'),
+														'CO' => TTi18n::gettext('Cordoba'),
+														'CU' => TTi18n::gettext('Cundinamarca'),
+														'DC' => TTi18n::gettext('Distrito Capital'),
+														'GN' => TTi18n::gettext('Guainia'),
+														'GV' => TTi18n::gettext('Guaviare'),
+														'HU' => TTi18n::gettext('Huila'),
+														'LG' => TTi18n::gettext('La Guajira'),
+														'MA' => TTi18n::gettext('Magdalena'),
+														'ME' => TTi18n::gettext('Meta'),
+														'NA' => TTi18n::gettext('Nariño'),
+														'NS' => TTi18n::gettext('Norte de Santander'),
+														'PU' => TTi18n::gettext('Putumayo'),
+														'QD' => TTi18n::gettext('Quindio'),
+														'RI' => TTi18n::gettext('Risaralda'),
+														'SA' => TTi18n::gettext('San Andres y Providencia'),
+														'ST' => TTi18n::gettext('Santander'),
+														'SU' => TTi18n::gettext('Sucre'),
+														'TO' => TTi18n::gettext('Tolima'),
+														'VC' => TTi18n::gettext('Valle del Cauca'),
+														'VP' => TTi18n::gettext('Vaupes'),
+														'VD' => TTi18n::gettext('Vichada'),
 														),
 										'KM' => array( '00' => '--'),
 										'CG' => array( '00' => '--'),
@@ -486,13 +499,13 @@ class CompanyFactory extends Factory {
 										'CK' => array( '00' => '--'),
 										'CR' => array(
 														'00' => '--',
-														'AL' => 'Alajuela',
-														'CA' => 'Cartago',
-														'GU' => 'Guanacaste',
-														'HE' => 'Heredia',
-														'LI' => 'Limon',
-														'PU' => 'Puntarenas',
-														'SJ' => 'San Jose',
+														'AL' => TTi18n::gettext('Alajuela'),
+														'CA' => TTi18n::gettext('Cartago'),
+														'GU' => TTi18n::gettext('Guanacaste'),
+														'HE' => TTi18n::gettext('Heredia'),
+														'LI' => TTi18n::gettext('Limon'),
+														'PU' => TTi18n::gettext('Puntarenas'),
+														'SJ' => TTi18n::gettext('San Jose'),
 														),
 										'CI' => array( '00' => '--'),
 										'HR' => array( '00' => '--'),
@@ -507,20 +520,20 @@ class CompanyFactory extends Factory {
 										'EG' => array( '00' => '--'),
 										'SV' => array(
 														'00' => '--',
-														'AH' => 'Ahuachapan',
-														'CA' => 'Cabañas',
-														'CH' => 'Chalatenango',
-														'CU' => 'Cuscatlan',
-														'LI' => 'La Libertad',
-														'PA' => 'La Paz',
-														'UN' => 'La Union',
-														'MO' => 'Morazan',
-														'SM' => 'San Miguel',
-														'SS' => 'San Salvador',
-														'SA' => 'Santa Ana',
-														'SV' => 'San Vicente',
-														'SO' => 'Sonsonate',
-														'US' => 'Usulatan'
+														'AH' => TTi18n::gettext('Ahuachapan'),
+														'CA' => TTi18n::gettext('Cabañas'),
+														'CH' => TTi18n::gettext('Chalatenango'),
+														'CU' => TTi18n::gettext('Cuscatlan'),
+														'LI' => TTi18n::gettext('La Libertad'),
+														'PA' => TTi18n::gettext('La Paz'),
+														'UN' => TTi18n::gettext('La Union'),
+														'MO' => TTi18n::gettext('Morazan'),
+														'SM' => TTi18n::gettext('San Miguel'),
+														'SS' => TTi18n::gettext('San Salvador'),
+														'SA' => TTi18n::gettext('Santa Ana'),
+														'SV' => TTi18n::gettext('San Vicente'),
+														'SO' => TTi18n::gettext('Sonsonate'),
+														'US' => TTi18n::gettext('Usulatan')
 														),
 										'GQ' => array( '00' => '--'),
 										'ER' => array( '00' => '--'),
@@ -547,28 +560,28 @@ class CompanyFactory extends Factory {
 										'GU' => array( '00' => '--'),
 										'GT' => array(
 														'00' => '--',
-														'AV' => 'Alta Verapaz',
-														'BV' => 'Baja Verapaz',
-														'GT' => 'Chimaltenango',
-														'CQ' => 'Chiquimula',
-														'PR' => 'El Progreso',
-														'ES' => 'Escuintla',
-														'GU' => 'Guatemala',
-														'HU' => 'Huehuetenango',
-														'IZ' => 'Izaqbal',
-														'JA' => 'Jalapa',
-														'JU' => 'Jutiapa',
-														'PE' => 'Peten',
-														'QZ' => 'Quetzaltenango',
-														'QC' => 'Quiche',
-														'RE' => 'Retalhuleu',
-														'SA' => 'Sacatepequez',
-														'SM' => 'San Marcos',
-														'SR' => 'Santa Rosa',
-														'SO' => 'Solola',
-														'SU' => 'Suchitepequez',
-														'TO' => 'Totonicapan',
-														'ZA' => 'Zacapa'
+														'AV' => TTi18n::gettext('Alta Verapaz'),
+														'BV' => TTi18n::gettext('Baja Verapaz'),
+														'GT' => TTi18n::gettext('Chimaltenango'),
+														'CQ' => TTi18n::gettext('Chiquimula'),
+														'PR' => TTi18n::gettext('El Progreso'),
+														'ES' => TTi18n::gettext('Escuintla'),
+														'GU' => TTi18n::gettext('Guatemala'),
+														'HU' => TTi18n::gettext('Huehuetenango'),
+														'IZ' => TTi18n::gettext('Izaqbal'),
+														'JA' => TTi18n::gettext('Jalapa'),
+														'JU' => TTi18n::gettext('Jutiapa'),
+														'PE' => TTi18n::gettext('Peten'),
+														'QZ' => TTi18n::gettext('Quetzaltenango'),
+														'QC' => TTi18n::gettext('Quiche'),
+														'RE' => TTi18n::gettext('Retalhuleu'),
+														'SA' => TTi18n::gettext('Sacatepequez'),
+														'SM' => TTi18n::gettext('San Marcos'),
+														'SR' => TTi18n::gettext('Santa Rosa'),
+														'SO' => TTi18n::gettext('Solola'),
+														'SU' => TTi18n::gettext('Suchitepequez'),
+														'TO' => TTi18n::gettext('Totonicapan'),
+														'ZA' => TTi18n::gettext('Zacapa')
 														),
 										'GN' => array( '00' => '--'),
 										'GW' => array( '00' => '--'),
@@ -578,30 +591,99 @@ class CompanyFactory extends Factory {
 										'VA' => array( '00' => '--'),
 										'HN' => array(
 														'00' => '--',
-														'AT' => 'Atlantida',
-														'CH' => 'Choluteca',
-														'CL' => 'Colon',
-														'CM' => 'Comayagua',
-														'CP' => 'Copan',
-														'CR' => 'Cortes',
-														'EP' => 'El Paraiso',
-														'FM' => 'Francisco Morazan',
-														'GD' => 'Gracias a Dios',
-														'IN' => 'Intibuca',
-														'IB' => 'Islas de la Bahia',
-														'LP' => 'La Paz',
-														'LE' => 'Lempira',
-														'OC' => 'Ocotepeque',
-														'OL' => 'Olancho',
-														'SB' => 'Santa Barbara',
-														'VA' => 'Valle',
-														'YO' => 'Yoro'
+														'AT' => TTi18n::gettext('Atlantida'),
+														'CH' => TTi18n::gettext('Choluteca'),
+														'CL' => TTi18n::gettext('Colon'),
+														'CM' => TTi18n::gettext('Comayagua'),
+														'CP' => TTi18n::gettext('Copan'),
+														'CR' => TTi18n::gettext('Cortes'),
+														'EP' => TTi18n::gettext('El Paraiso'),
+														'FM' => TTi18n::gettext('Francisco Morazan'),
+														'GD' => TTi18n::gettext('Gracias a Dios'),
+														'IN' => TTi18n::gettext('Intibuca'),
+														'IB' => TTi18n::gettext('Islas de la Bahia'),
+														'LP' => TTi18n::gettext('La Paz'),
+														'LE' => TTi18n::gettext('Lempira'),
+														'OC' => TTi18n::gettext('Ocotepeque'),
+														'OL' => TTi18n::gettext('Olancho'),
+														'SB' => TTi18n::gettext('Santa Barbara'),
+														'VA' => TTi18n::gettext('Valle'),
+														'YO' => TTi18n::gettext('Yoro'),
 														),
 										'HK' => array( '00' => '--'),
 										'HU' => array( '00' => '--'),
 										'IS' => array( '00' => '--'),
-										'IN' => array( '00' => '--'),
-										'ID' => array( '00' => '--'),
+										'IN' => array(
+														'00' => '--',
+														'AN' => TTi18n::gettext('Andaman and Nicobar Islands'),
+														'AP' => TTi18n::gettext('Andhra Pradesh'),
+														'AR' => TTi18n::gettext('Arunachal Pradesh'),
+														'AS' => TTi18n::gettext('Assam'),
+														'BR' => TTi18n::gettext('Bihar'),
+														'CH' => TTi18n::gettext('Chandigarh'),
+														'CT' => TTi18n::gettext('Chhattisgarh'),
+														'DN' => TTi18n::gettext('Dadra and Nagar Haveli'),
+														'DD' => TTi18n::gettext('Daman and Diu'),
+														'DL' => TTi18n::gettext('Delhi'),
+														'GA' => TTi18n::gettext('Goa'),
+														'GJ' => TTi18n::gettext('Gujarat'),
+														'HR' => TTi18n::gettext('Haryana'),
+														'HP' => TTi18n::gettext('Himachal Pradesh'),
+														'JK' => TTi18n::gettext('Jammu and Kashmir'),
+														'JH' => TTi18n::gettext('Jharkhand'),
+														'KA' => TTi18n::gettext('Karnataka'),
+														'KL' => TTi18n::gettext('Kerala'),
+														'LD' => TTi18n::gettext('Lakshadweep'),
+														'MP' => TTi18n::gettext('Madhya Pradesh'),
+														'MH' => TTi18n::gettext('Maharashtra'),
+														'MN' => TTi18n::gettext('Manipur'),
+														'ML' => TTi18n::gettext('Meghalaya'),
+														'MZ' => TTi18n::gettext('Mizoram'),
+														'NL' => TTi18n::gettext('Nagaland'),
+														'OR' => TTi18n::gettext('Orissa'),
+														'PY' => TTi18n::gettext('Pondicherry'),
+														'PB' => TTi18n::gettext('Punjab'),
+														'RJ' => TTi18n::gettext('Rajasthan'),
+														'SK' => TTi18n::gettext('Sikkim'),
+														'TN' => TTi18n::gettext('Tamil Nadu'),
+														'TR' => TTi18n::gettext('Tripura'),
+														'UP' => TTi18n::gettext('Uttar Pradesh'),
+														'UL' => TTi18n::gettext('Uttarakhand'),
+														'WB' => TTi18n::gettext('West Bengal'),
+														),
+										'ID' => array(
+														'00' => '--',
+														'BA' => TTi18n::gettext('Bali'),
+														'BB' => TTi18n::gettext('Bangka-Belitung'),
+														'BT' => TTi18n::gettext('Banten'),
+														'BE' => TTi18n::gettext('Bengkulu'),
+														'JT' => TTi18n::gettext('Central Java'),
+														'KT' => TTi18n::gettext('Central Kalimantan'),
+														'ST' => TTi18n::gettext('Central Sulawesi'),
+														'JI' => TTi18n::gettext('East Java'),
+														'KI' => TTi18n::gettext('East Kalimantan'),
+														'NT' => TTi18n::gettext('East Nusa Tenggara'),
+														'GO' => TTi18n::gettext('Gorontalo'),
+														'JA' => TTi18n::gettext('Jambi'),
+														'JK' => TTi18n::gettext('Jakarta'),
+														'LA' => TTi18n::gettext('Lampung'),
+														'MA' => TTi18n::gettext('Maluku'),
+														'MU' => TTi18n::gettext('North Maluku'),
+														'SA' => TTi18n::gettext('North Sulawesi'),
+														'SU' => TTi18n::gettext('North Sumatra'),
+														'RI' => TTi18n::gettext('Riau'),
+														'KR' => TTi18n::gettext('Riau Islands'),
+														'SS' => TTi18n::gettext('South Sumatra'),
+														'SN' => TTi18n::gettext('South Sulawesi'),
+														'KS' => TTi18n::gettext('South Kalimantan'),
+														'SG' => TTi18n::gettext('Southeast Sulawesi'),
+														'JB' => TTi18n::gettext('West Java'),
+														'KB' => TTi18n::gettext('West Kalimantan'),
+														'NB' => TTi18n::gettext('West Nusa Tenggara'),
+														'SR' => TTi18n::gettext('West Sulawesi'),
+														'SB' => TTi18n::gettext('West Sumatra'),
+														'YO' => TTi18n::gettext('Yogyakarta'),
+														),
 										'IR' => array( '00' => '--'),
 										'IQ' => array( '00' => '--'),
 										'IE' => array( '00' => '--'),
@@ -641,38 +723,38 @@ class CompanyFactory extends Factory {
 										'YT' => array( '00' => '--'),
 										'MX' => array(
 														'00' => '--',
-														'AG' => 'Aguascalientes',
-														'BN' => 'Baja California',
-														'BS' => 'Baja California Sur',
-														'CM' => 'Campeche',
-														'CP' => 'Chiapas',
-														'CP' => 'Chihuahua',
-														'CA' => 'Coahuila',
-														'CL' => 'Colima',
-														'DF' => 'Distrito Federal',
-														'DU' => 'Durango',
-														'GJ' => 'Guanajuato',
-														'GR' => 'Guerrero',
-														'HI' => 'Hidalgo',
-														'JA' => 'Jalisco',
-														'MX' => 'Mexico',
-														'MC' => 'Michoacan',
-														'MR' => 'Morelos',
-														'NA' => 'Niyarit',
-														'NL' => 'Nuevo Leon',
-														'OA' => 'Oaxaca',
-														'PU' => 'Puebla',
-														'QE' => 'Queretaro',
-														'QR' => 'Quintana Roo',
-														'SL' => 'San Luis Potosi',
-														'SI' => 'Sinaloa',
-														'SO' => 'Sonora',
-														'TB' => 'Tabasco',
-														'TM' => 'Tamaulipas',
-														'TL' => 'Tlaxcala',
-														'VE' => 'Veracruz-Llave',
-														'YU' => 'Yucatan',
-														'ZA' => 'Zacatecas'
+														'AG' => TTi18n::gettext('Aguascalientes'),
+														'BN' => TTi18n::gettext('Baja California'),
+														'BS' => TTi18n::gettext('Baja California Sur'),
+														'CM' => TTi18n::gettext('Campeche'),
+														'CP' => TTi18n::gettext('Chiapas'),
+														'CP' => TTi18n::gettext('Chihuahua'),
+														'CA' => TTi18n::gettext('Coahuila'),
+														'CL' => TTi18n::gettext('Colima'),
+														'DF' => TTi18n::gettext('Distrito Federal'),
+														'DU' => TTi18n::gettext('Durango'),
+														'GJ' => TTi18n::gettext('Guanajuato'),
+														'GR' => TTi18n::gettext('Guerrero'),
+														'HI' => TTi18n::gettext('Hidalgo'),
+														'JA' => TTi18n::gettext('Jalisco'),
+														'MX' => TTi18n::gettext('Mexico'),
+														'MC' => TTi18n::gettext('Michoacan'),
+														'MR' => TTi18n::gettext('Morelos'),
+														'NA' => TTi18n::gettext('Niyarit'),
+														'NL' => TTi18n::gettext('Nuevo Leon'),
+														'OA' => TTi18n::gettext('Oaxaca'),
+														'PU' => TTi18n::gettext('Puebla'),
+														'QE' => TTi18n::gettext('Queretaro'),
+														'QR' => TTi18n::gettext('Quintana Roo'),
+														'SL' => TTi18n::gettext('San Luis Potosi'),
+														'SI' => TTi18n::gettext('Sinaloa'),
+														'SO' => TTi18n::gettext('Sonora'),
+														'TB' => TTi18n::gettext('Tabasco'),
+														'TM' => TTi18n::gettext('Tamaulipas'),
+														'TL' => TTi18n::gettext('Tlaxcala'),
+														'VE' => TTi18n::gettext('Veracruz-Llave'),
+														'YU' => TTi18n::gettext('Yucatan'),
+														'ZA' => TTi18n::gettext('Zacatecas'),
 														),
 										'FM' => array( '00' => '--'),
 										'MD' => array( '00' => '--'),
@@ -691,23 +773,23 @@ class CompanyFactory extends Factory {
 										'NZ' => array( '00' => '--'),
 										'NI' => array(
 														'00' => '--',
-														'BO' => 'Boaco',
-														'CA' => 'Carazo',
-														'CI' => 'Chinandega',
-														'CO' => 'Chontales',
-														'ES' => 'Esteli',
-														'GR' => 'Granada',
-														'JI' => 'Jinotega',
-														'LE' => 'Leon',
-														'MD' => 'Madriz',
-														'MN' => 'Managua',
-														'MS' => 'Masaya',
-														'MT' => 'Matagalpa',
-														'NS' => 'Nueva Segovia',
-														'SJ' => 'Rio San Juan',
-														'RI' => 'Rivas',
-														'AN' => 'Region Autonoma Atlantico Norte',
-														'AS' => 'Region Autonoma Atlantico Sur'
+														'BO' => TTi18n::gettext('Boaco'),
+														'CA' => TTi18n::gettext('Carazo'),
+														'CI' => TTi18n::gettext('Chinandega'),
+														'CO' => TTi18n::gettext('Chontales'),
+														'ES' => TTi18n::gettext('Esteli'),
+														'GR' => TTi18n::gettext('Granada'),
+														'JI' => TTi18n::gettext('Jinotega'),
+														'LE' => TTi18n::gettext('Leon'),
+														'MD' => TTi18n::gettext('Madriz'),
+														'MN' => TTi18n::gettext('Managua'),
+														'MS' => TTi18n::gettext('Masaya'),
+														'MT' => TTi18n::gettext('Matagalpa'),
+														'NS' => TTi18n::gettext('Nueva Segovia'),
+														'SJ' => TTi18n::gettext('Rio San Juan'),
+														'RI' => TTi18n::gettext('Rivas'),
+														'AN' => TTi18n::gettext('Region Autonoma Atlantico Norte'),
+														'AS' => TTi18n::gettext('Region Autonoma Atlantico Sur'),
 														),
 										'NE' => array( '00' => '--'),
 										'NG' => array( '00' => '--'),
@@ -721,16 +803,16 @@ class CompanyFactory extends Factory {
 										'PS' => array( '00' => '--'),
 										'PA' => array(
 														'00' => '--',
-														'BC' => 'Bocas del Toro',
-														'CH' => 'Chiriqui',
-														'CC' => 'Cocle',
-														'CL' => 'Colon',
-														'DR' => 'Darien',
-														'HE' => 'Herrera',
-														'LS' => 'Los Santos',
-														'PN' => 'Panama',
-														'SB' => 'San Blas',
-														'VR' => 'Veraguas'
+														'BC' => TTi18n::gettext('Bocas del Toro'),
+														'CH' => TTi18n::gettext('Chiriqui'),
+														'CC' => TTi18n::gettext('Cocle'),
+														'CL' => TTi18n::gettext('Colon'),
+														'DR' => TTi18n::gettext('Darien'),
+														'HE' => TTi18n::gettext('Herrera'),
+														'LS' => TTi18n::gettext('Los Santos'),
+														'PN' => TTi18n::gettext('Panama'),
+														'SB' => TTi18n::gettext('San Blas'),
+														'VR' => TTi18n::gettext('Veraguas'),
 														),
 										'PG' => array( '00' => '--'),
 										'PY' => array( '00' => '--'),
@@ -765,15 +847,15 @@ class CompanyFactory extends Factory {
 										'SO' => array( '00' => '--'),
 										'ZA' => array(
 														'00' => '--',
-														'MP' => 'Mpumalanga',
-														'GP' => 'Gauteng',
-														'NW' => 'North West',
-														'LP' => 'Limpopo',
-														'FS' => 'Free State',
-														'WC' => 'Western Cape',
-														'ZN' => 'Kwa-Zulu Natal',
-														'EC' => 'Eastern Cape',
-														'NC' => 'Northern Cape'
+														'MP' => TTi18n::gettext('Mpumalanga'),
+														'GP' => TTi18n::gettext('Gauteng'),
+														'NW' => TTi18n::gettext('North West'),
+														'LP' => TTi18n::gettext('Limpopo'),
+														'FS' => TTi18n::gettext('Free State'),
+														'WC' => TTi18n::gettext('Western Cape'),
+														'ZN' => TTi18n::gettext('Kwa-Zulu Natal'),
+														'EC' => TTi18n::gettext('Eastern Cape'),
+														'NC' => TTi18n::gettext('Northern Cape'),
 														),
 										'GS' => array( '00' => '--'),
 										'ES' => array( '00' => '--'),
