@@ -1,29 +1,42 @@
 <?php
 /*********************************************************************************
- * The contents of this file are subject to the TimeTrex Public License Version
- * 1.1.0 ("License"); You may not use this file except in compliance with the
- * License. You may obtain a copy of the License at http://www.TimeTrex.com/TPL
- * Software distributed under the License is distributed on an "AS IS" basis,
- * WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the License
- * for the specific language governing rights and limitations under the
- * License.
+ * TimeTrex is a Payroll and Time Management program developed by
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
  *
- * All copies of the Covered Code must include on each user interface screen:
- *    (i) the "Powered by TimeTrex" logo and
- *    (ii) the TimeTrex copyright notice
- * in the same form as they appear in the distribution.  See full license for
- * requirements.
+ * This program is free software; you can redistribute it and/or modify it under
+ * the terms of the GNU Affero General Public License version 3 as published by
+ * the Free Software Foundation with the addition of the following permission
+ * added to Section 15 as permitted in Section 7(a): FOR ANY PART OF THE COVERED
+ * WORK IN WHICH THE COPYRIGHT IS OWNED BY TIMETREX, TIMETREX DISCLAIMS THE
+ * WARRANTY OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
  *
- * The Original Code is: TimeTrex Open Source
- * The Initial Developer of the Original Code is TimeTrex Payroll Services
- * Portions created by TimeTrex are Copyright (C) 2004-2007 TimeTrex Payroll Services;
- * All Rights Reserved.
+ * This program is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+ * FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
+ * details.
  *
+ * You should have received a copy of the GNU Affero General Public License along
+ * with this program; if not, see http://www.gnu.org/licenses or write to the Free
+ * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+ * 02110-1301 USA.
+ *
+ * You can contact TimeTrex headquarters at Unit 22 - 2475 Dobbin Rd. Suite
+ * #292 Westbank, BC V4T 2E9, Canada or at email address info@timetrex.com.
+ *
+ * The interactive user interfaces in modified source and object code versions
+ * of this program must display Appropriate Legal Notices, as required under
+ * Section 5 of the GNU Affero General Public License version 3.
+ *
+ * In accordance with Section 7(b) of the GNU Affero General Public License
+ * version 3, these Appropriate Legal Notices must retain the display of the
+ * "Powered by TimeTrex" logo. If the display of the logo is not reasonably
+ * feasible for technical reasons, the Appropriate Legal Notices must display
+ * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2158 $
- * $Id: AJAX_Server.class.php 2158 2008-09-15 23:26:15Z ipso $
- * $Date: 2008-09-15 16:26:15 -0700 (Mon, 15 Sep 2008) $
+ * $Revision: 3143 $
+ * $Id: AJAX_Server.class.php 3143 2009-12-02 17:21:41Z ipso $
+ * $Date: 2009-12-02 09:21:41 -0800 (Wed, 02 Dec 2009) $
  */
 
 /**
@@ -155,7 +168,7 @@ class AJAX_Server {
 		$uwf->setType( $wage_type_id );
 		$uwf->setWage( $wage );
 		$uwf->setWeeklyTime( TTDate::parseTimeUnit($weekly_hours) );
-		$hourly_rate = $uwf->getHourlyRate();
+		$hourly_rate = $uwf->calcHourlyRate();
 
 		return $hourly_rate;
 	}
@@ -217,41 +230,23 @@ class AJAX_Server {
 	}
 
 	function getJobItemOptions( $job_id, $include_disabled = TRUE ) {
+		//Don't check for current company as this needs to work when we are not fully authenticated.
+		/*
 		global $current_company;
 
 		if ( !is_object($current_company) ) {
 			return FALSE;
 		}
+		*/
 
-		Debug::text('Job ID: '. $job_id .' Company ID: '. $current_company->getId() .' Include Disabled: '. (int)$include_disabled, __FILE__, __LINE__, __METHOD__, 10);
+		Debug::text('Job ID: '. $job_id .' Include Disabled: '. (int)$include_disabled, __FILE__, __LINE__, __METHOD__, 10);
 
-		$jlf = new JobListFactory();
-		$jlf->getByIdAndCompanyId( $job_id, $current_company->getId() );
-		if ( $jlf->getRecordCount() > 0 ) {
-			//Get all job items
-			$jilf = new JobItemListFactory();
-			$jilf->getByCompanyId( $current_company->getId() );
-			$job_item_options = $jilf->getArrayByListFactory( $jilf, TRUE, $include_disabled );
-
-			$j_obj = $jlf->getCurrent();
-			if ( $j_obj->getItemAllowAll() == TRUE ) {
+		$jilf = new JobItemListFactory();
+		//$jilf->getByCompanyIdAndJobId( $current_company->getId(), $job_id );
+		$jilf->getByJobId( $job_id );
+		$job_item_options = $jilf->getArrayByListFactory( $jilf, TRUE, $include_disabled );
+		if ( $job_item_options != FALSE AND is_array($job_item_options) ) {
 				return $job_item_options;
-			} else {
-				$restricted_job_items = $j_obj->getItem();
-
-				if ( is_array($restricted_job_items) ) {
-					if ( isset($job_item_options[0]) ) {
-						$retarr[0] = $job_item_options[0];
-					}
-					foreach( $restricted_job_items as $job_item_id ) {
-						if ( isset($job_item_options[$job_item_id]) ) {
-							$retarr[$job_item_id] = $job_item_options[$job_item_id];
-						}
-					}
-
-					return $retarr;
-				}
-			}
 		}
 
 		Debug::text('Returning FALSE!', __FILE__, __LINE__, __METHOD__, 10);
