@@ -1,29 +1,42 @@
 <?php
 /*********************************************************************************
- * The contents of this file are subject to the TimeTrex Public License Version
- * 1.1.0 ("License"); You may not use this file except in compliance with the
- * License. You may obtain a copy of the License at http://www.TimeTrex.com/TPL
- * Software distributed under the License is distributed on an "AS IS" basis,
- * WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the License
- * for the specific language governing rights and limitations under the
- * License.
+ * TimeTrex is a Payroll and Time Management program developed by
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
  *
- * All copies of the Covered Code must include on each user interface screen:
- *    (i) the "Powered by TimeTrex" logo and
- *    (ii) the TimeTrex copyright notice
- * in the same form as they appear in the distribution.  See full license for
- * requirements.
+ * This program is free software; you can redistribute it and/or modify it under
+ * the terms of the GNU Affero General Public License version 3 as published by
+ * the Free Software Foundation with the addition of the following permission
+ * added to Section 15 as permitted in Section 7(a): FOR ANY PART OF THE COVERED
+ * WORK IN WHICH THE COPYRIGHT IS OWNED BY TIMETREX, TIMETREX DISCLAIMS THE
+ * WARRANTY OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
  *
- * The Original Code is: TimeTrex Open Source
- * The Initial Developer of the Original Code is TimeTrex Payroll Services
- * Portions created by TimeTrex are Copyright (C) 2004-2007 TimeTrex Payroll Services;
- * All Rights Reserved.
+ * This program is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+ * FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
+ * details.
  *
+ * You should have received a copy of the GNU Affero General Public License along
+ * with this program; if not, see http://www.gnu.org/licenses or write to the Free
+ * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+ * 02110-1301 USA.
+ *
+ * You can contact TimeTrex headquarters at Unit 22 - 2475 Dobbin Rd. Suite
+ * #292 Westbank, BC V4T 2E9, Canada or at email address info@timetrex.com.
+ *
+ * The interactive user interfaces in modified source and object code versions
+ * of this program must display Appropriate Legal Notices, as required under
+ * Section 5 of the GNU Affero General Public License version 3.
+ *
+ * In accordance with Section 7(b) of the GNU Affero General Public License
+ * version 3, these Appropriate Legal Notices must retain the display of the
+ * "Powered by TimeTrex" logo. If the display of the logo is not reasonably
+ * feasible for technical reasons, the Appropriate Legal Notices must display
+ * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2237 $
- * $Id: ExceptionFactory.class.php 2237 2008-11-11 18:18:20Z ipso $
- * $Date: 2008-11-11 10:18:20 -0800 (Tue, 11 Nov 2008) $
+ * $Revision: 3199 $
+ * $Id: ExceptionFactory.class.php 3199 2009-12-20 23:37:45Z ipso $
+ * $Date: 2009-12-20 15:37:45 -0800 (Sun, 20 Dec 2009) $
  */
 
 /**
@@ -299,17 +312,9 @@ class ExceptionFactory extends Factory {
 				//Make sure supervisor email notifcations are enabled
 				if ( $ep_obj->getEmailNotification() == 20 OR $ep_obj->getEmailNotification() == 100 ) {
 					//Find supervisor
-
-					//Find proper hierarchy to use for this object
-					$hotlf = new HierarchyObjectTypeListFactory();
-					$control_id = $hotlf->getByCompanyIdAndObjectTypeId( $u_obj->getCompany(), 80 )->getCurrent()->getHierarchyControl();
-					Debug::Text(' Hierarchy Control ID: '. $control_id , __FILE__, __LINE__, __METHOD__,10);
-
-					if ( is_numeric( $control_id ) ) {
-						$hlf = new HierarchyListFactory();
-						$node_data = $hlf->getByHierarchyControlIdAndUserId( $control_id, $u_obj->getId() );
-						$parent_user_id = $node_data['parent_id'];
-
+					$hlf = new HierarchyListFactory();
+					$parent_user_id = $hlf->getHierarchyParentByCompanyIdAndUserIdAndObjectTypeID( $u_obj->getCompany(), $u_obj->getId(), 80 );
+					if ( $parent_user_id != FALSE ) {
 						$ulf = new UserListFactory();
 						$ulf->getById( $parent_user_id );
 						if ( $ulf->getRecordCount() > 0 ) {
@@ -329,7 +334,7 @@ class ExceptionFactory extends Factory {
 							}
 						}
 					} else {
-						Debug::Text(' No Hierarchy Control Found, skipping email to supervisor.', __FILE__, __LINE__, __METHOD__,10);
+						Debug::Text(' No Hierarchy Parent Found, skipping email to supervisor.', __FILE__, __LINE__, __METHOD__,10);
 					}
 				}
 
@@ -379,7 +384,7 @@ class ExceptionFactory extends Factory {
 			return FALSE;
 		}
 
-		$from = 'DoNotReply@'.Misc::getHostName();
+		$from = 'DoNotReply@'.Misc::getHostName( FALSE );
 
 		$to = array_shift( $email_to_arr );
 		Debug::Text('To: '. $to, __FILE__, __LINE__, __METHOD__,10);
@@ -417,11 +422,6 @@ class ExceptionFactory extends Factory {
 							NULL,
 							);
 
-		//For some reason the EOL defaults to \r\n, which seems to screw with Amavis
-		if ( !defined('MAIL_MIMEPART_CRLF') ) {
-			define('MAIL_MIMEPART_CRLF', "\n");
-		}
-
 		$subject = str_replace( $search_arr, $replace_arr, $exception_email_subject );
 		Debug::Text('Subject: '. $subject, __FILE__, __LINE__, __METHOD__,10);
 
@@ -433,28 +433,22 @@ class ExceptionFactory extends Factory {
 							'Return-Path' => $to,
 							'Errors-To' => $to,
 						 );
-		Debug::Arr($headers, 'Headers: ', __FILE__, __LINE__, __METHOD__,10);
 
 		$body = '<pre>'.str_replace( $search_arr, $replace_arr, $exception_email_body ).'</pre>';
 		Debug::Text('Body: '. $body, __FILE__, __LINE__, __METHOD__,10);
 
-		require_once('Mail.php');
-		require_once('Mail/mime.php');
+		$mail = new TTMail();
+		$mail->setTo( $to );
+		$mail->setHeaders( $headers );
 
-		$mime = @new Mail_Mime();
-		@$mime->setHTMLBody($body);
+		@$mail->getMIMEObject()->setHTMLBody($body);
 
-		@$body = $mime->get();
-		@$headers = $mime->headers($headers);
+		$mail->setBody( $mail->getMIMEObject()->get( $mail->default_mime_config ) );
+		$retval = $mail->Send();
 
-		$mail = &Mail::factory('mail');
-		if ( PRODUCTION == TRUE AND DEMO_MODE == FALSE ) {
-			if ( $mail->send($to, $headers, $body) == TRUE ) {
-				TTLog::addEntry( $this->getId(), 500,  TTi18n::getText('Email Exception to').': '. $to .' Bcc: '. $headers['Bcc'], NULL, $this->getTable() );
-				return TRUE;
-			}
-		} else {
-			Debug::Text(' Not sending email, production mode not enabled...', __FILE__, __LINE__, __METHOD__,10);
+		if ( $retval == TRUE ) {
+			TTLog::addEntry( $this->getId(), 500,  TTi18n::getText('Email Exception to').': '. $to .' Bcc: '. $headers['Bcc'], NULL, $this->getTable() );
+			return TRUE;
 		}
 
 		return TRUE;
