@@ -1,29 +1,42 @@
 <?php
 /*********************************************************************************
- * The contents of this file are subject to the TimeTrex Public License Version
- * 1.1.0 ("License"); You may not use this file except in compliance with the
- * License. You may obtain a copy of the License at http://www.TimeTrex.com/TPL
- * Software distributed under the License is distributed on an "AS IS" basis,
- * WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the License
- * for the specific language governing rights and limitations under the
- * License.
+ * TimeTrex is a Payroll and Time Management program developed by
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
  *
- * All copies of the Covered Code must include on each user interface screen:
- *    (i) the "Powered by TimeTrex" logo and
- *    (ii) the TimeTrex copyright notice
- * in the same form as they appear in the distribution.  See full license for
- * requirements.
+ * This program is free software; you can redistribute it and/or modify it under
+ * the terms of the GNU Affero General Public License version 3 as published by
+ * the Free Software Foundation with the addition of the following permission
+ * added to Section 15 as permitted in Section 7(a): FOR ANY PART OF THE COVERED
+ * WORK IN WHICH THE COPYRIGHT IS OWNED BY TIMETREX, TIMETREX DISCLAIMS THE
+ * WARRANTY OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
  *
- * The Original Code is: TimeTrex Open Source
- * The Initial Developer of the Original Code is TimeTrex Payroll Services
- * Portions created by TimeTrex are Copyright (C) 2004-2007 TimeTrex Payroll Services;
- * All Rights Reserved.
+ * This program is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+ * FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
+ * details.
  *
+ * You should have received a copy of the GNU Affero General Public License along
+ * with this program; if not, see http://www.gnu.org/licenses or write to the Free
+ * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+ * 02110-1301 USA.
+ *
+ * You can contact TimeTrex headquarters at Unit 22 - 2475 Dobbin Rd. Suite
+ * #292 Westbank, BC V4T 2E9, Canada or at email address info@timetrex.com.
+ *
+ * The interactive user interfaces in modified source and object code versions
+ * of this program must display Appropriate Legal Notices, as required under
+ * Section 5 of the GNU Affero General Public License version 3.
+ *
+ * In accordance with Section 7(b) of the GNU Affero General Public License
+ * version 3, these Appropriate Legal Notices must retain the display of the
+ * "Powered by TimeTrex" logo. If the display of the logo is not reasonably
+ * feasible for technical reasons, the Appropriate Legal Notices must display
+ * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2426 $
- * $Id: Factory.class.php 2426 2009-02-18 22:39:19Z ipso $
- * $Date: 2009-02-18 14:39:19 -0800 (Wed, 18 Feb 2009) $
+ * $Revision: 3021 $
+ * $Id: Factory.class.php 3021 2009-11-11 23:33:03Z ipso $
+ * $Date: 2009-11-11 15:33:03 -0800 (Wed, 11 Nov 2009) $
  */
 
 /**
@@ -139,17 +152,53 @@ abstract class Factory {
 	}
 
 	//Determines if the data is new data, or updated data.
-	function isNew() {
+	function isNew( $force_lookup = FALSE ) {
 		//Debug::Arr( $this->getId() ,'getId: ', __FILE__, __LINE__, __METHOD__,10);
 		if ( $this->getId() === FALSE ) {
 			//New Data
 			return TRUE;
+		} elseif ( $force_lookup == TRUE ) {
+			//See if we can find the ID to determine if the record needs to be inserted or update.
+			$ph = array( 'id' => $this->getID() );
+			$query = 'select id from '. $this->getTable() .' where id = ?';
+			$retval = $this->db->GetOne($query, $ph);
+			if ( $retval === FALSE ) {
+				return TRUE;
+			}
 		}
 
 		//Not new data
 		return FALSE;
 	}
 
+	//Determines if we were called by a save function or not.
+	//This is useful for determining if we are just validating or actually saving data. Problem is its too late to throw any new validation errors.
+	function isSave() {
+		$stack = debug_backtrace();
+
+		if ( is_array($stack) ) {
+			//Loop through and if we find a Save function call return TRUE.
+			//Not sure if this will work in some more complex cases though.
+			foreach( $stack as $data ) {
+				if ( $data['function'] == 'Save' ) {
+					return TRUE;
+				}
+			}
+		}
+
+		return FALSE;
+	}
+
+	//Returns the calling function name
+	function getCallerFunction() {
+		$stack = debug_backtrace();
+		if ( isset($stack[1]) ) {
+			return $statc[1]['function'];
+		}
+
+		return FALSE;
+	}
+
 	function getLabelId() {
 		//Gets the ID used in validator labels. If no ID, uses "-1";
 		if ( $this->getId() == FALSE ) {
@@ -210,7 +259,7 @@ abstract class Factory {
 	function setCreatedDate($epoch = NULL) {
 		$epoch = trim($epoch);
 
-		if ($epoch == NULL) {
+		if ( $epoch == NULL OR $epoch == '' OR $epoch == 0 ) {
 			$epoch = TTDate::getTime();
 		}
 
@@ -248,7 +297,7 @@ abstract class Factory {
 
 		$ulf = new UserListFactory();
 
-		if ( $this->Validator->isResultSetWithRows(	'updated_by',
+		if ( $this->Validator->isResultSetWithRows(	'created_by',
 													$ulf->getByID($id),
 													TTi18n::gettext('Incorrect User')
 													) ) {
@@ -271,7 +320,7 @@ abstract class Factory {
 	function setUpdatedDate($epoch = NULL) {
 		$epoch = trim($epoch);
 
-		if ($epoch == NULL) {
+		if ( $epoch == NULL OR $epoch == '' OR $epoch == 0 ) {
 			$epoch = TTDate::getTime();
 		}
 
@@ -335,7 +384,7 @@ abstract class Factory {
 	function setDeletedDate($epoch = NULL) {
 		$epoch = trim($epoch);
 
-		if ($epoch == NULL) {
+		if ( $epoch == NULL OR $epoch == '' OR $epoch == 0 ) {
 			$epoch = TTDate::getTime();
 		}
 
@@ -386,6 +435,68 @@ abstract class Factory {
 		return FALSE;
 	}
 
+	function setCreatedAndUpdatedColumns( $data ) {
+		//Update array in-place.
+		if ( isset($data['created_by']) AND is_numeric($data['created_by']) AND $data['created_by'] > 0 ) {
+			$this->setCreatedBy( $data['created_by'] );
+		}
+		if ( isset($data['created_by_id']) AND is_numeric($data['created_by_id']) AND $data['created_by_id'] > 0 ) {
+			$this->setCreatedBy( $data['created_by_id'] );
+		}
+		if ( isset($data['created_date']) AND $data['created_date'] != FALSE ) {
+			$this->setCreatedDate( TTDate::parseDateTime( $data['created_date'] ) );
+		}
+
+		if ( isset($data['updated_by']) AND is_numeric($data['updated_by']) AND $data['updated_by'] > 0 ) {
+			$this->setUpdatedBy( $data['updated_by'] );
+		}
+		if ( isset($data['updated_by_id']) AND is_numeric($data['updated_by_id']) AND $data['updated_by_id'] > 0 ) {
+			$this->setUpdatedBy( $data['updated_by_id'] );
+		}
+		if ( isset($data['updated_date']) AND $data['created_date'] != FALSE ) {
+			$this->setUpdatedDate( TTDate::parseDateTime( $data['updated_date'] ) );
+		}
+
+		return TRUE;
+	}
+	function getCreatedAndUpdatedColumns( &$data, $include_columns = NULL ) {
+		//Update array in-place.
+		if ( $include_columns == NULL OR ( isset($include_columns['created_by_id']) AND $include_columns['created_by_id'] == TRUE) ) {
+			$data['created_by_id'] = $this->getCreatedBy();
+		}
+		if ( $include_columns == NULL OR ( isset($include_columns['created_by']) AND $include_columns['created_by'] == TRUE) ) {
+			$data['created_by'] = Misc::getFullName( $this->getColumn('created_by_first_name'), $this->getColumn('created_by_middle_name'), $this->getColumn('created_by_last_name') );
+		}
+		if ( $include_columns == NULL OR ( isset($include_columns['created_date']) AND $include_columns['created_date'] == TRUE) ) {
+			$data['created_date'] = TTDate::getAPIDate( 'DATE+TIME', $this->getCreatedDate() );
+		}
+		if ( $include_columns == NULL OR ( isset($include_columns['updated_by_id']) AND $include_columns['updated_by_id'] == TRUE) ) {
+			$data['updated_by_id'] = $this->getUpdatedBy();
+		}
+		if ( $include_columns == NULL OR ( isset($include_columns['updated_by']) AND $include_columns['updated_by'] == TRUE) ) {
+			$data['updated_by'] = Misc::getFullName( $this->getColumn('updated_by_first_name'), $this->getColumn('updated_by_middle_name'), $this->getColumn('updated_by_last_name') );
+		}
+		if ( $include_columns == NULL OR ( isset($include_columns['updated_date']) AND $include_columns['updated_date'] == TRUE) ) {
+			$data['updated_date'] = TTDate::getAPIDate( 'DATE+TIME', $this->getUpdatedDate() );
+		}
+
+		return TRUE;
+	}
+
+	function getPermissionColumns( &$data, $object_id, $created_by_id, $permission_children_ids ) {
+		$permission = new Permission();
+
+		$data['is_owner'] = $permission->isOwner( $created_by_id, $object_id );
+
+		if ( is_array($permission_children_ids) ) {
+			$data['is_child'] = $permission->isChild( $object_id, $permission_children_ids );
+		} else {
+			$data['is_child'] = FALSE;
+		}
+
+		return TRUE;
+	}
+
 	function getOptions($name, $parent = NULL) {
 		if ( $parent == NULL OR $parent == '') {
 			return $this->_getFactoryOptions( $name );
@@ -398,11 +509,17 @@ abstract class Factory {
 
 		return FALSE;
 	}
-
 	protected function _getFactoryOptions( $name ) {
 		return FALSE;
 	}
 
+	function getVariableToFunctionMap( $data = NULL ) {
+		return $this->_getVariableToFunctionMap( $data );
+	}
+	protected function _getVariableToFunctionMap( $data ) {
+		return FALSE;
+	}
+
 	function getRecordCount() {
 		if ( isset($this->rs) ) {
 			return $this->rs->RecordCount();
@@ -411,6 +528,14 @@ abstract class Factory {
 		return FALSE;
 	}
 
+	function getCurrentRow( $offset = 1 ) {
+		if ( isset($this->rs) AND isset($this->rs->_currentRow) ) {
+			return $this->rs->_currentRow+(int)$offset;
+		}
+
+		return FALSE;
+	}
+
 	private function getRecordSetColumnList($rs) {
 		if (is_object($rs)) {
 			for ($i=0, $max=$rs->FieldCount(); $i < $max; $i++) {
@@ -430,9 +555,9 @@ abstract class Factory {
 				return '\''.implode('\',\'',$array).'\'';
 			} elseif ( is_array($array) ) {
 				//Return NULL, because this is an empty array.
-				return "NULL";
+				return 'NULL';
 			} elseif ( $array == '' ) {
-				return "NULL";
+				return 'NULL';
 			}
 
 			//Just a single ID, return it.
@@ -483,11 +608,81 @@ abstract class Factory {
 		}
 	}
 
+	//This function takes plain input from the user and creates a SQL statement for filtering
+	//based on a date range.
+	// Supported Syntax:
+	//					>=01-Jan-09
+	//					<=01-Jan-09
+	//					<01-Jan-09
+	//					>01-Jan-09
+	//					>01-Jan-09 & <10-Jan-09
+	//
+	function getDateRangeSQL( $str, $column, $use_epoch = TRUE ) {
+
+		if ( $str == '' ) {
+			return FALSE;
+		}
+
+		if ( $column == '' ) {
+			return FALSE;
+		}
+
+		$operators = array(
+						   '>',
+						   '<',
+						   '>=',
+						   '<=',
+						   '=',
+						   );
+
+		$operations = FALSE;
+
+		//Parse input, separate any subqueries first.
+		$split_str = explode( '&', $str, 2 ); //Limit sub-queries
+		if ( is_array($split_str) ) {
+			foreach( $split_str as $tmp_str ) {
+				$tmp_str = trim($tmp_str);
+
+				$date = (int)TTDate::parseDateTime( str_replace( $operators, '', $tmp_str ) );
+				//Debug::text(' Parsed Date: '. $tmp_str .' To: '. TTDate::getDate('DATE+TIME', $date) .' ('. $date .')', __FILE__, __LINE__, __METHOD__,10);
+
+				if ( $date != 0 ) {
+					preg_match('/^>=|>|<=|</i', $tmp_str, $operator );
+
+					//Debug::Arr($operator, ' Operator: ', __FILE__, __LINE__, __METHOD__,10);
+					if ( isset($operator[0]) AND in_array( $operator[0], $operators) ) {
+						if ( $operator[0] == '<=' ) {
+							$date = TTDate::getEndDayEpoch( $date );
+						} elseif ( $operator[0] == '>' ) {
+							$date = TTDate::getEndDayEpoch( $date );
+						}
+
+						$operations[] = $column .' '. $operator[0] .' '. $date;
+					} else {
+						//Debug::text(' No operator specified... Using a 24hr period', __FILE__, __LINE__, __METHOD__,10);
+						$operations[] = $column .' >= '. TTDate::getBeginDayEpoch( $date );
+						$operations[] = $column .' <= '. TTDate::getEndDayEpoch( $date );
+					}
+				}
+			}
+		}
+
+		//Debug::Arr($operations, ' Operations: ', __FILE__, __LINE__, __METHOD__,10);
+		if ( is_array($operations) ) {
+			$retval = ' ( '. implode(' AND ', $operations ) .' )';
+			Debug::text(' Query parts: '. $retval, __FILE__, __LINE__, __METHOD__,10);
+
+			return $retval;
+		}
+
+		return FALSE;
+	}
+
 	//Parses out the exact column name, without any aliases, or = signs in it.
 	private function parseColumnName($column) {
 		$column = trim($column);
 
-		if (strstr($column, '=') ) {
+		if ( strstr($column, '=') ) {
 			$tmp_column = explode('=', $column);
 			$retval = trim($tmp_column[0]);
 			unset($tmp_column);
@@ -495,11 +690,12 @@ abstract class Factory {
 			$retval = $column;
 		}
 
-		if (strstr($retval, '.') ) {
+		if ( strstr($retval, '.') ) {
 			$tmp_column = explode('.', $retval);
 			$retval = $tmp_column[1];
 			unset($tmp_column);
 		}
+		//Debug::Text('Column: '. $column .' RetVal: '. $retval, __FILE__, __LINE__, __METHOD__,10);
 
 		return $retval;
 	}
@@ -537,9 +733,68 @@ abstract class Factory {
 		return FALSE;
 	}
 
-	protected function getSortSQL($array, $strict = TRUE, $additional_fields = NULL) {
+	protected function getColumnsFromAliases( $columns, $aliases ) {
+		// Columns is the original column array.
+		//
+		// Aliases is an array of search => replace key/value pairs.
+		//
+		// This is used so the frontend can sort by the column name (ie: type) and it can be converted to type_id for the SQL query.
+		if ( is_array($columns) AND is_array( $aliases ) ) {
+			$columns = $this->convertFlexArray( $columns );
 
+			//Debug::Arr($columns, 'Columns before: ', __FILE__, __LINE__, __METHOD__,10);
+
+			foreach( $columns as $column => $sort_order ) {
+				if ( isset($aliases[$column]) AND !isset($columns[$aliases[$column]]) ) {
+					$retarr[$aliases[$column]] = $sort_order;
+				} else {
+					$retarr[$column] = $sort_order;
+				}
+
+			}
+			//Debug::Arr($retarr, 'Columns after: ', __FILE__, __LINE__, __METHOD__,10);
+
+			if ( isset($retarr) ) {
+				return $retarr;
+			}
+		}
+
+		return $columns;
+	}
+
+	protected function convertFlexArray( $array ) {
+		//Flex doesn't appear to be consistent on the order the fields are placed into an assoc array, so
+		//handle this type of array too:
+		// array(
+		//		0 => array('first_name' => 'asc')
+		//		1 => array('last_name' => 'desc')
+		//		)
+
+		if ( isset($array[0]) AND is_array($array[0]) ) {
+			Debug::text('Found Flex Sort Array, converting to proper format...', __FILE__, __LINE__, __METHOD__,10);
+
+			//Debug::Arr($array, 'Before conversion...', __FILE__, __LINE__, __METHOD__,10);
+
+			$new_arr = array();
+			foreach( $array as $tmp_order => $tmp_arr ) {
+				if ( is_array($tmp_arr) ) {
+					foreach( $tmp_arr as $tmp_column => $tmp_order ) {
+						$new_arr[$tmp_column] = $tmp_order;
+					}
+				}
+			}
+			$array = $new_arr;
+			unset($tmp_key, $tmp_arr, $tmp_order, $tmp_column, $new_arr);
+			//Debug::Arr($array, 'Converted format...', __FILE__, __LINE__, __METHOD__,10);
+		}
+
+		return $array;
+	}
+
+	protected function getSortSQL($array, $strict = TRUE, $additional_fields = NULL) {
 		if ( is_array($array) ) {
+			$array = $this->convertFlexArray( $array );
+
 			$alt_order_options = array( 1 => 'asc', -1 => 'desc');
 			$order_options = array('asc', 'desc');
 
@@ -564,17 +819,30 @@ abstract class Factory {
 					}
 				}
 
-				if ( $strict == FALSE OR ( ( in_array($column, $fields) OR in_array($orig_column, $fields) ) AND in_array( strtolower($order), $order_options) ) ) {
-					$sql_chunks[] = $orig_column.' '.$order;
+				if ( $strict == FALSE
+						OR ( 	(
+									in_array($column, $fields)
+									OR
+									in_array($orig_column, $fields)
+								)
+								AND in_array( strtolower($order), $order_options)
+							)
+						) {
+					//Make sure ';' does not appear in the resulting order string, to help prevent attacks in non-strict mode.
+					if ( $strict == TRUE OR ( $strict == FALSE AND strpos( $orig_column, ';') === FALSE AND strpos( $order, ';') === FALSE ) ) {
+						$sql_chunks[] = $orig_column.' '.$order;
+					} else {
+						Debug::text('ERROR: Found ";" in SQL order string: '. $orig_column .' Order: '. $order, __FILE__, __LINE__, __METHOD__,10);
+					}
 				} else {
 					Debug::text('Invalid Sort Column/Order: '. $column .' Order: '. $order, __FILE__, __LINE__, __METHOD__,10);
 				}
 			}
 
 			if ( isset($sql_chunks) ) {
-				$sql = implode(",", $sql_chunks);
+				$sql = implode(',', $sql_chunks);
 
-				return ' order by '.$sql;
+				return ' order by '. $this->db->escape( $sql );
 			}
 		}
 
@@ -603,9 +871,9 @@ abstract class Factory {
 		return FALSE;
 	}
 
-	private function getEmptyRecordSet($id = NULL) {
+	public function getEmptyRecordSet($id = NULL) {
 		global $profiler;
-		$profiler->startTimer( "getEmptyRecordSet()");
+		$profiler->startTimer( 'getEmptyRecordSet()' );
 
 		if ($id == NULL) {
 			$id = -1;
@@ -619,10 +887,29 @@ abstract class Factory {
 			$column_str = '*'; //Get empty RS with all columns.
 		}
 
-		$query = 'select '. $column_str .' from '. $this->table .' where id = '. (int)$id;
-		//Debug::text('Query: '. $query , __FILE__, __LINE__, __METHOD__,9);
-
 		try {
+/*
+			//Cache_Lite fails when caching this query.
+			$query = 'select '. $column_str .' from '. $this->table .' where id = '. (int)$id;
+			//Debug::text('Query: '. $query , __FILE__, __LINE__, __METHOD__,9);
+
+			if ( $id == -1 ) {
+				$cache_id = md5($this->getTable().$column_str.$id);
+
+				$rs = $this->getCache($cache_id);
+				if ( $rs === FALSE ) {
+					$rs = $this->db->Execute($query);
+
+					$this->saveCache($rs, $cache_id);
+				}
+			} else {
+				$rs = $this->db->Execute($query);
+			}
+			Debug::Arr($rs, 'getEmptyRecordSet() RS:' , __FILE__, __LINE__, __METHOD__,9);
+*/
+			$query = 'select '. $column_str .' from '. $this->table .' where id = '. (int)$id;
+			//Debug::text('Query: '. $query , __FILE__, __LINE__, __METHOD__,9);
+
 			if ( $id == -1 ) {
 				$rs = $this->db->CacheExecute(86400, $query);
 			} else {
@@ -632,12 +919,12 @@ abstract class Factory {
 			throw new DBError($e);
 		}
 
-		$profiler->stopTimer( "getEmptyRecordSet()");
+		$profiler->stopTimer( 'getEmptyRecordSet()' );
 		return $rs;
 	}
 
 	private function getUpdateQuery($data = NULL) {
-		Debug::text('Update' , __FILE__, __LINE__, __METHOD__,9);
+		//Debug::text('Update' , __FILE__, __LINE__, __METHOD__,9);
 
 		//
 		// If the table has timestamp columns without timezone set
@@ -715,7 +1002,9 @@ abstract class Factory {
 			throw new DBError($e);
 		}
 
-		$query = $this->db->GetInsertSQL($rs, $this->data);
+		//Use table name instead of recordset, especially when using CacheLite for caching empty recordsets.
+		//$query = $this->db->GetInsertSQL($rs, $this->data);
+		$query = $this->db->GetInsertSQL($this->getTable(), $this->data);
 
 		//Debug::text('Insert Query: '. $query, __FILE__, __LINE__, __METHOD__, 9);
 
@@ -748,21 +1037,12 @@ abstract class Factory {
 	}
 
 	function getNextInsertId() {
-		/*
-		if ( isset($this->next_insert_id) AND is_numeric($this->next_insert_id) ) {
-			return $this->next_insert_id;
-		} else {
-			$this->next_insert_id = $this->db->GenID( $this->pk_sequence_name );
-		}
-
-		return $this->next_insert_id;
-		*/
 		return $this->db->GenID( $this->pk_sequence_name );
 	}
 
 	//Determines to insert or update, and does it.
 	//Have this handle created, createdby, updated, updatedby.
-	function Save($reset_data = TRUE) {
+	function Save($reset_data = TRUE, $force_lookup = FALSE) {
 		$this->StartTransaction();
 
 		//Run Pre-Save function
@@ -781,7 +1061,7 @@ abstract class Factory {
 		}
 
 		//Should we insert, or update?
-		if ( $this->isNew() ) {
+		if ( $this->isNew( $force_lookup ) ) {
 			//Insert
 			$time = TTDate::getTime();
 
@@ -795,12 +1075,14 @@ abstract class Factory {
 
 			unset($time);
 
-			//Append insert ID to data array.
-			//$insert_id = $this->db->GenID( $this->pk_sequence_name );
-			$insert_id = $this->getNextInsertId();
+			$insert_id = $this->getID();
+			if ( $insert_id == FALSE ) {
+				//Append insert ID to data array.
+				$insert_id = $this->getNextInsertId();
 
-			Debug::text('Insert ID: '. $insert_id , __FILE__, __LINE__, __METHOD__, 9);
-			$this->setId($insert_id);
+				Debug::text('Insert ID: '. $insert_id , __FILE__, __LINE__, __METHOD__, 9);
+				$this->setId($insert_id);
+			}
 
 			try {
 				//$query = $this->getInsertQuery($this->data);
@@ -815,7 +1097,6 @@ abstract class Factory {
 			Debug::text(' Updating...' , __FILE__, __LINE__, __METHOD__,10);
 
 			//Update
-			//$query = $this->getUpdateQuery($this->data);
 			$query = $this->getUpdateQuery(); //Don't pass data, too slow
 
 			//Debug::Arr($this->data, 'Save(): Query: ', __FILE__, __LINE__, __METHOD__,10);
@@ -831,7 +1112,7 @@ abstract class Factory {
 		//Debug::text('Save(): Query: '. $query , __FILE__, __LINE__, __METHOD__,10);
 		//Debug::Arr($query, 'Save(): Query: ', __FILE__, __LINE__, __METHOD__,10);
 
-		if ( $query != '' OR $query === TRUE) {
+		if ( $query != '' OR $query === TRUE ) {
 
 			if ( is_string($query) AND $query != '' ) {
 				try {
