@@ -1,29 +1,42 @@
 <?php
 /*********************************************************************************
- * The contents of this file are subject to the TimeTrex Public License Version
- * 1.1.0 ("License"); You may not use this file except in compliance with the
- * License. You may obtain a copy of the License at http://www.TimeTrex.com/TPL
- * Software distributed under the License is distributed on an "AS IS" basis,
- * WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the License
- * for the specific language governing rights and limitations under the
- * License.
+ * TimeTrex is a Payroll and Time Management program developed by
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
  *
- * All copies of the Covered Code must include on each user interface screen:
- *    (i) the "Powered by TimeTrex" logo and
- *    (ii) the TimeTrex copyright notice
- * in the same form as they appear in the distribution.  See full license for
- * requirements.
+ * This program is free software; you can redistribute it and/or modify it under
+ * the terms of the GNU Affero General Public License version 3 as published by
+ * the Free Software Foundation with the addition of the following permission
+ * added to Section 15 as permitted in Section 7(a): FOR ANY PART OF THE COVERED
+ * WORK IN WHICH THE COPYRIGHT IS OWNED BY TIMETREX, TIMETREX DISCLAIMS THE
+ * WARRANTY OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
  *
- * The Original Code is: TimeTrex Open Source
- * The Initial Developer of the Original Code is TimeTrex Payroll Services
- * Portions created by TimeTrex are Copyright (C) 2004-2007 TimeTrex Payroll Services;
- * All Rights Reserved.
+ * This program is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+ * FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
+ * details.
  *
+ * You should have received a copy of the GNU Affero General Public License along
+ * with this program; if not, see http://www.gnu.org/licenses or write to the Free
+ * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+ * 02110-1301 USA.
+ *
+ * You can contact TimeTrex headquarters at Unit 22 - 2475 Dobbin Rd. Suite
+ * #292 Westbank, BC V4T 2E9, Canada or at email address info@timetrex.com.
+ *
+ * The interactive user interfaces in modified source and object code versions
+ * of this program must display Appropriate Legal Notices, as required under
+ * Section 5 of the GNU Affero General Public License version 3.
+ *
+ * In accordance with Section 7(b) of the GNU Affero General Public License
+ * version 3, these Appropriate Legal Notices must retain the display of the
+ * "Powered by TimeTrex" logo. If the display of the logo is not reasonably
+ * feasible for technical reasons, the Appropriate Legal Notices must display
+ * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2308 $
- * $Id: Misc.class.php 2308 2008-12-22 23:06:24Z ipso $
- * $Date: 2008-12-22 15:06:24 -0800 (Mon, 22 Dec 2008) $
+ * $Revision: 3143 $
+ * $Id: Misc.class.php 3143 2009-12-02 17:21:41Z ipso $
+ * $Date: 2009-12-02 09:21:41 -0800 (Wed, 02 Dec 2009) $
  */
 
 /**
@@ -94,6 +107,9 @@ class Misc {
 					if ( !isset($totals[$sum_key]) ) {
 						$totals[$sum_key] = 0;
 					}
+					if ( !is_numeric( $sum_value )) {
+						$sum_value = 0;
+					}
 					$totals[$sum_key] += $sum_value;
 					//Debug::text(' Sum: '. $totals[$sum_key] .' Key: '. $sum_key .' This Value: '. $sum_value, __FILE__, __LINE__, __METHOD__,10);
 				}
@@ -204,7 +220,7 @@ class Misc {
 	static function arrayIntersectByKey( $keys, $options ) {
 		if ( is_array($keys) and is_array($options) ) {
 			foreach( $keys as $key ) {
-				if ( isset($options[$key]) ) {
+				if ( isset($options[$key]) AND $key !== FALSE ) { //Ignore boolean FALSE, so the Root group isn't always selected.
 					$retarr[$key] = $options[$key];
 				}
 			}
@@ -219,6 +235,33 @@ class Misc {
 		return NULL;
 	}
 
+	/*
+		When passed an associative array from a ListFactory, ie:
+		array( 	0 => array( <...Data ..> ),
+				1 => array( <...Data ..> ),
+				2 => array( <...Data ..> ),
+				... )
+		this function will return an associative array of only the key=>value
+		pairs that intersect across all rows.
+
+	*/
+	static function arrayIntersectByRow( $rows ) {
+		if ( !is_array($rows) ) {
+			return FALSE;
+		}
+
+		if ( count($rows) < 2 ) {
+			return FALSE;
+		}
+
+		$retval = FALSE;
+		if ( isset($rows[0]) ) {
+			$retval = call_user_func_array( 'array_intersect_assoc', $rows );
+			Debug::Arr($retval, 'Intersected/Common Data', __FILE__, __LINE__, __METHOD__, 10);
+		}
+
+		return $retval;
+	}
 	/*
 		Returns all the output_key => output_value pairs where
 		the input_keys are not present in output array keys.
@@ -227,7 +270,7 @@ class Misc {
 	static function arrayDiffByKey( $keys, $options ) {
 		if ( is_array($keys) and is_array($options) ) {
 			foreach( $options as $key => $value ) {
-				if ( !in_array($key, $keys) ) {
+				if ( !in_array($key, $keys, TRUE) ) { //Use strict we ignore boolean FALSE, so the Root group isn't always selected.
 					$retarr[$key] = $options[$key];
 				}
 			}
@@ -312,6 +355,21 @@ class Misc {
 		return TRUE;
 	}
 
+	static function removeTrailingZeros( $value, $minimum_decimals = 2 ) {
+		//Remove trailing zeros after the decimal, leave a minimum of X though.
+		if ( strpos( $value, '.') !== FALSE ) {
+			$trimmed_value = rtrim( $value, 0);
+
+			$tmp_minimum_decimals = strlen( (int)strrev($trimmed_value) );
+			if ( $tmp_minimum_decimals > $minimum_decimals ) {
+				$minimum_decimals = $tmp_minimum_decimals;
+			}
+			return number_format( $value, $minimum_decimals );
+		}
+
+		return $value;
+	}
+
 	static function MoneyFormat($value, $pretty = TRUE) {
 
 		if ( $pretty == TRUE ) {
@@ -341,15 +399,29 @@ class Misc {
 	}
 
 	static function getBeforeDecimal($float) {
-		$float_array = split("\.", $float);
+		$float = Misc::MoneyFormat( $float, FALSE );
 
-		return $float_array[0];
+		$float_array = split('\.', $float);
+
+		if ( isset($float_array[0]) ) {
+			return $float_array[0];
+		}
+
+		return FALSE;
 	}
 
-	static function getAfterDecimal($float) {
-		$float_array = split("\.", $float);
+	static function getAfterDecimal($float, $format_number = TRUE ) {
+		if ( $format_number == TRUE ) {
+			$float = Misc::MoneyFormat( $float, FALSE );
+		}
 
-		return $float_array[1];
+		$float_array = split('\.', $float);
+
+		if ( isset($float_array[1]) ) {
+			return str_pad($float_array[1],2,'0');
+		}
+
+		return FALSE;
 	}
 
 	static function calculatePercent( $current, $maximum, $precision = 0 ) {
@@ -708,24 +780,41 @@ class Misc {
 		return $retarr;
 	}
 
-	static function getHostName() {
+	static function getHostName( $include_port = TRUE ) {
 		global $config_vars;
 
-		if ( isset($config_vars['other']['hostname']) AND $config_vars['other']['hostname'] != '' ) {
+		$server_port = NULL;
+		if ( isset( $_SERVER['SERVER_PORT'] ) ) {
+			$server_port = ':'.$_SERVER['SERVER_PORT'];
+		}
+
+		if ( DEPLOYMENT_ON_DEMAND == TRUE AND isset($config_vars['other']['hostname']) AND $config_vars['other']['hostname'] != '' ) {
 			$server_domain = $config_vars['other']['hostname'];
-		} elseif ( isset( $_SERVER['SERVER_NAME'] ) ) {
-			$server_domain = $_SERVER['SERVER_NAME'];
-		} elseif ( isset( $_SERVER['HOSTNAME'] ) ) {
-			$server_domain = $_SERVER['HOSTNAME'];
 		} else {
-			$server_domain = 'localhost';
+			//Try server hostname/servername first, than fallback on .ini hostname setting.
+			if ( isset( $_SERVER['HTTP_HOST'] ) ) { //Use HTTP_HOST instead of SERVER_NAME first so it includes any custom ports.
+				$server_domain = $_SERVER['HTTP_HOST'];
+			} elseif ( isset( $_SERVER['SERVER_NAME'] ) ) {
+				$server_domain = $_SERVER['SERVER_NAME'].$server_port;
+			} elseif ( isset( $_SERVER['HOSTNAME'] ) ) {
+				$server_domain = $_SERVER['HOSTNAME'].$server_port;
+			} elseif ( isset($config_vars['other']['hostname']) AND $config_vars['other']['hostname'] != '' ) {
+				$server_domain = $config_vars['other']['hostname'];
+			} else {
+				$server_domain = 'localhost'.$server_port;
+			}
+		}
+
+		if ( $include_port == FALSE ) {
+			//strip off port, important for sending emails.
+			$server_domain = str_replace( $server_port, '', $server_domain );
 		}
 
 		return $server_domain;
 	}
 
 	//Accepts a search_str and key=>val array that it searches through, to return the array key of the closest match.
-	function findClosestMatch( $search_str, $search_arr, $minimum_percent_match = 0, $return_all_matches = FALSE ) {
+	static function findClosestMatch( $search_str, $search_arr, $minimum_percent_match = 0, $return_all_matches = FALSE ) {
 		if ( $search_str == '' ) {
 			return FALSE;
 		}
@@ -757,7 +846,7 @@ class Misc {
 	}
 
 	//Converts a number between 0 and 25 to the corresponding letter.
-	function NumberToLetter( $number ) {
+	static function NumberToLetter( $number ) {
 		if ( $number > 25 ) {
 			return FALSE;
 		}
@@ -765,7 +854,7 @@ class Misc {
 		return chr($number+65);
 	}
 
-	function issetOr( &$var, $default = NULL ) {
+	static function issetOr( &$var, $default = NULL ) {
 		if ( isset($var) ) {
 			return $var;
 		}
@@ -773,6 +862,23 @@ class Misc {
 		return $default;
 	}
 
+	static function getFullName($first_name, $middle_name, $last_name, $reverse = FALSE, $include_middle = TRUE) {
+		if ( $first_name != '' AND $last_name != '' ) {
+			if ( $reverse === TRUE ) {
+				$retval = $last_name .', '. $first_name;
+				if ( $include_middle == TRUE AND $middle_name != '' ) {
+					$retval .= ' '.$middle_name[0].'.'; //Use just the middle initial.
+				}
+			} else {
+				$retval = $first_name .' '. $last_name;
+			}
+
+			return $retval;
+		}
+
+		return FALSE;
+	}
+
 	//Caller ID numbers can come in in all sorts of forms:
 	// 2505551234
 	// 12505551234
@@ -788,5 +894,58 @@ class Misc {
 		return $retval;
 	}
 
+	static function generateCopyName( $name, $strict = FALSE ) {
+		$name = str_replace( TTi18n::getText('Copy of'), '', $name );
+
+		if ( $strict === TRUE ) {
+			return TTi18n::getText('Copy of').' '. $name;
+		} else {
+			return TTi18n::getText('Copy of').' '. $name .' ['. rand(1,99) .']';
+		}
+	}
+
+	static function getFileList( $start_dir, $regex_filter = NULL, $recurse = FALSE ) {
+		$files = array();
+		if ( is_dir($start_dir) AND is_readable( $start_dir ) ) {
+			$fh = opendir($start_dir);
+			while ( ($file = readdir($fh)) !== FALSE ) {
+				# loop through the files, skipping . and .., and recursing if necessary
+				if ( strcmp($file, '.') == 0 OR strcmp($file, '..' ) == 0 ) {
+					continue;
+				}
+
+				$filepath = $start_dir . DIRECTORY_SEPARATOR . $file;
+				if ( is_dir($filepath) AND $recurse == TRUE ) {
+					Debug::Text(' Recursing into dir: '. $filepath , __FILE__, __LINE__, __METHOD__, 10);
+
+					$tmp_files = self::getFileList($filepath, $regex_filter, TRUE );
+					if ( $tmp_files != FALSE AND is_array($tmp_files) ) {
+						$files = array_merge( $files, $tmp_files );
+					}
+					unset($tmp_files);
+				} elseif ( !is_dir( $filepath ) ) {
+					if ( $regex_filter == '*' OR preg_match( '/'.$regex_filter.'/i', $file) == 1 ) {
+						//Debug::Text(' Match: Dir: '. $start_dir .' File: '. $filepath , __FILE__, __LINE__, __METHOD__, 10);
+						if ( is_readable($filepath) ) {
+							array_push($files, $filepath);
+						} else {
+							Debug::Text(' Matching file is not read/writable: '. $filepath , __FILE__, __LINE__, __METHOD__, 10);
+						}
+					} else {
+						//Debug::Text(' NO Match: Dir: '. $start_dir .' File: '. $filepath , __FILE__, __LINE__, __METHOD__, 10);
+					}
+				}
+			}
+			closedir($fh);
+			sort($files);
+		} else {
+			# false if the function was called with an invalid non-directory argument
+			$files = FALSE;
+		}
+
+		//Debug::Arr( $files, 'Matching files: ', __FILE__, __LINE__, __METHOD__, 10);
+		return $files;
+	}
+
 }
 ?>
\ No newline at end of file
