@@ -1,29 +1,42 @@
 <?php
 /*********************************************************************************
- * The contents of this file are subject to the TimeTrex Public License Version
- * 1.1.0 ("License"); You may not use this file except in compliance with the
- * License. You may obtain a copy of the License at http://www.TimeTrex.com/TPL
- * Software distributed under the License is distributed on an "AS IS" basis,
- * WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the License
- * for the specific language governing rights and limitations under the
- * License.
+ * TimeTrex is a Payroll and Time Management program developed by
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
  *
- * All copies of the Covered Code must include on each user interface screen:
- *    (i) the "Powered by TimeTrex" logo and
- *    (ii) the TimeTrex copyright notice
- * in the same form as they appear in the distribution.  See full license for
- * requirements.
+ * This program is free software; you can redistribute it and/or modify it under
+ * the terms of the GNU Affero General Public License version 3 as published by
+ * the Free Software Foundation with the addition of the following permission
+ * added to Section 15 as permitted in Section 7(a): FOR ANY PART OF THE COVERED
+ * WORK IN WHICH THE COPYRIGHT IS OWNED BY TIMETREX, TIMETREX DISCLAIMS THE
+ * WARRANTY OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
  *
- * The Original Code is: TimeTrex Open Source
- * The Initial Developer of the Original Code is TimeTrex Payroll Services
- * Portions created by TimeTrex are Copyright (C) 2004-2007 TimeTrex Payroll Services;
- * All Rights Reserved.
+ * This program is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+ * FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
+ * details.
  *
+ * You should have received a copy of the GNU Affero General Public License along
+ * with this program; if not, see http://www.gnu.org/licenses or write to the Free
+ * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+ * 02110-1301 USA.
+ *
+ * You can contact TimeTrex headquarters at Unit 22 - 2475 Dobbin Rd. Suite
+ * #292 Westbank, BC V4T 2E9, Canada or at email address info@timetrex.com.
+ *
+ * The interactive user interfaces in modified source and object code versions
+ * of this program must display Appropriate Legal Notices, as required under
+ * Section 5 of the GNU Affero General Public License version 3.
+ *
+ * In accordance with Section 7(b) of the GNU Affero General Public License
+ * version 3, these Appropriate Legal Notices must retain the display of the
+ * "Powered by TimeTrex" logo. If the display of the logo is not reasonably
+ * feasible for technical reasons, the Appropriate Legal Notices must display
+ * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2426 $
- * $Id: Permission.class.php 2426 2009-02-18 22:39:19Z ipso $
- * $Date: 2009-02-18 14:39:19 -0800 (Wed, 18 Feb 2009) $
+ * $Revision: 2838 $
+ * $Id: Permission.class.php 2838 2009-09-18 20:57:41Z ipso $
+ * $Date: 2009-09-18 13:57:41 -0700 (Fri, 18 Sep 2009) $
  */
 
 /**
@@ -63,7 +76,7 @@ class Permission {
 		//Use Cache_Lite class once we need performance.
 		if ( $user_id == NULL OR $user_id == '') {
 			global $current_user;
-			if ( isset($current_user) ) {
+			if ( is_object( $current_user ) ) {
 				$user_id = $current_user->getId();
 			} else {
 				return FALSE;
@@ -110,7 +123,11 @@ class Permission {
 		Debug::Text('Permission Query!' , __FILE__, __LINE__, __METHOD__,9);
 		if ( $user_id == NULL OR $user_id == '') {
 			global $current_user;
-			$user_id = $current_user->getId();
+			if ( is_object( $current_user ) ) {
+				$user_id = $current_user->getId();
+			} else {
+				return FALSE;
+			}
 		}
 
 		if ( $company_id == NULL OR $company_id == '') {
@@ -127,7 +144,11 @@ class Permission {
 	function isOwner( $object_created_by, $object_assigned_to = NULL, $current_user_id = NULL ) {
 		if ( $current_user_id == NULL OR $current_user_id == '') {
 			global $current_user;
-			$current_user_id = $current_user->getId();
+			if ( is_object( $current_user ) ) {
+				$current_user_id = $current_user->getId();
+			} else {
+				return FALSE;
+			}
 		}
 
 		if ( ($object_created_by != '' AND $object_created_by == $current_user_id)
