@@ -1,29 +1,42 @@
 <?php
 /*********************************************************************************
- * The contents of this file are subject to the TimeTrex Public License Version
- * 1.1.0 ("License"); You may not use this file except in compliance with the
- * License. You may obtain a copy of the License at http://www.TimeTrex.com/TPL
- * Software distributed under the License is distributed on an "AS IS" basis,
- * WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the License
- * for the specific language governing rights and limitations under the
- * License.
+ * TimeTrex is a Payroll and Time Management program developed by
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
  *
- * All copies of the Covered Code must include on each user interface screen:
- *    (i) the "Powered by TimeTrex" logo and
- *    (ii) the TimeTrex copyright notice
- * in the same form as they appear in the distribution.  See full license for
- * requirements.
+ * This program is free software; you can redistribute it and/or modify it under
+ * the terms of the GNU Affero General Public License version 3 as published by
+ * the Free Software Foundation with the addition of the following permission
+ * added to Section 15 as permitted in Section 7(a): FOR ANY PART OF THE COVERED
+ * WORK IN WHICH THE COPYRIGHT IS OWNED BY TIMETREX, TIMETREX DISCLAIMS THE
+ * WARRANTY OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
  *
- * The Original Code is: TimeTrex Open Source
- * The Initial Developer of the Original Code is TimeTrex Payroll Services
- * Portions created by TimeTrex are Copyright (C) 2004-2007 TimeTrex Payroll Services;
- * All Rights Reserved.
+ * This program is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+ * FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
+ * details.
  *
+ * You should have received a copy of the GNU Affero General Public License along
+ * with this program; if not, see http://www.gnu.org/licenses or write to the Free
+ * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+ * 02110-1301 USA.
+ *
+ * You can contact TimeTrex headquarters at Unit 22 - 2475 Dobbin Rd. Suite
+ * #292 Westbank, BC V4T 2E9, Canada or at email address info@timetrex.com.
+ *
+ * The interactive user interfaces in modified source and object code versions
+ * of this program must display Appropriate Legal Notices, as required under
+ * Section 5 of the GNU Affero General Public License version 3.
+ *
+ * In accordance with Section 7(b) of the GNU Affero General Public License
+ * version 3, these Appropriate Legal Notices must retain the display of the
+ * "Powered by TimeTrex" logo. If the display of the logo is not reasonably
+ * feasible for technical reasons, the Appropriate Legal Notices must display
+ * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2308 $
- * $Id: PermissionFactory.class.php 2308 2008-12-22 23:06:24Z ipso $
- * $Date: 2008-12-22 15:06:24 -0800 (Mon, 22 Dec 2008) $
+ * $Revision: 2816 $
+ * $Id: PermissionFactory.class.php 2816 2009-09-14 23:03:18Z ipso $
+ * $Date: 2009-09-14 16:03:18 -0700 (Mon, 14 Sep 2009) $
  */
 
 /**
@@ -119,6 +132,7 @@ class PermissionFactory extends Factory {
 															'policy_group',
 															'schedule_policy',
 															'meal_policy',
+															'break_policy',
 															'over_time_policy',
 															'premium_policy',
 															'accrual_policy',
@@ -191,6 +205,7 @@ class PermissionFactory extends Factory {
 										'policy_group' => TTi18n::gettext('Policy Group'),
 										'schedule_policy' => TTi18n::gettext('Schedule Policies'),
 										'meal_policy' => TTi18n::gettext('Meal Policies'),
+										'break_policy' => TTi18n::gettext('Break Policies'),
 										'over_time_policy' => TTi18n::gettext('Overtime Policies'),
 										'premium_policy' => TTi18n::gettext('Premium Policies'),
 										'accrual_policy' => TTi18n::gettext('Accrual Policies'),
@@ -244,6 +259,7 @@ class PermissionFactory extends Factory {
 																'edit_permission_group' => TTi18n::gettext('Edit Permission Group'),
 																'edit_pay_period_schedule' => TTi18n::gettext('Edit Pay Period Schedule'),
 																'edit_policy_group' => TTi18n::gettext('Edit Policy Group'),
+																'edit_hierarchy' => TTi18n::gettext('Edit Hierarchy'),
 																'enroll' => TTi18n::gettext('Enroll Employees'),
 																'enroll_child' => TTi18n::gettext('Enroll Subordinate'),
 																'timeclock_admin' => TTi18n::gettext('TimeClock Administrator'),
@@ -504,6 +520,17 @@ class PermissionFactory extends Factory {
 																'delete' => TTi18n::gettext('Delete'),
 																//'undelete' => TTi18n::gettext('Un-Delete')
 															),
+											'break_policy' => 	array(
+																'enabled' => TTi18n::gettext('Enabled'),
+																'view_own' => TTi18n::gettext('View Own'),
+																'view' => TTi18n::gettext('View'),
+																'add' => TTi18n::gettext('Add'),
+																'edit_own' => TTi18n::gettext('Edit Own'),
+																'edit' => TTi18n::gettext('Edit'),
+																'delete_own' => TTi18n::gettext('Delete Own'),
+																'delete' => TTi18n::gettext('Delete'),
+																//'undelete' => TTi18n::gettext('Un-Delete')
+															),
 											'absence_policy' => 	array(
 																'enabled' => TTi18n::gettext('Enabled'),
 																'view_own' => TTi18n::gettext('View Own'),
@@ -758,8 +785,9 @@ class PermissionFactory extends Factory {
 															),
 											'job_report' => 		array(
 																'enabled' => TTi18n::gettext('Enabled'),
-																'view_job_analysis' => TTi18n::gettext('View Job Analysis'),
 																'view_job_summary' => TTi18n::gettext('View Job Summary'),
+																'view_job_analysis' => TTi18n::gettext('View Job Analysis'),
+																'view_job_payroll_analysis' => TTi18n::gettext('View Job Payroll Analysis'),
 																'view_job_barcode' => TTi18n::gettext('View Job Barcode')
 															),
 											'invoice_config' => 	array(
@@ -897,10 +925,7 @@ class PermissionFactory extends Factory {
 
 	function getCompany() {
 		$company_id = $this->getPermissionControlObject()->getCompany();
-		/*
-		global $current_company;
-		$company_id = $current_company->getId();
-		*/
+
 		return $company_id;
 	}
 
@@ -1089,6 +1114,13 @@ class PermissionFactory extends Factory {
 																'edit' => TRUE,
 																'delete' => TRUE,
 															),
+											'break_policy' => 	array(
+																'enabled' => TRUE,
+																'view' => TRUE,
+																'add' => TRUE,
+																'edit' => TRUE,
+																'delete' => TRUE,
+															),
 											'over_time_policy' => 	array(
 																'enabled' => TRUE,
 																'view' => TRUE,
@@ -1359,7 +1391,7 @@ class PermissionFactory extends Factory {
 					Debug::Text('NOT Applying Invoice Permissions for Payroll Admin Preset', __FILE__, __LINE__, __METHOD__,10);
 				}
 			case 20:
-				//Supervisor, can see all schedules and shifts, and can do authorizations
+				//Supervisor (All Employees), can see all schedules and shifts, and can do authorizations
 				$preset_permissions_20 = array(
 											'user' => 	array(
 																'view' => TRUE,
@@ -1436,7 +1468,7 @@ class PermissionFactory extends Factory {
 					Debug::Text('NOT Applying Job Permissions for Supervisor Preset', __FILE__, __LINE__, __METHOD__,10);
 				}
 			case 18:
-				//Supervisor, can see all schedules and shifts, and can do authorizations
+				//Supervisor (Suborindates Only), can see all schedules and shifts, and can do authorizations
 				$preset_permissions_18 = array(
 											'user' => 	array(
 																'view_child' => TRUE,
@@ -1446,6 +1478,7 @@ class PermissionFactory extends Factory {
 																'delete_child' => TRUE,
 																'edit_pay_period_schedule' => TRUE,
 																'edit_policy_group' => TRUE,
+																'edit_hierarchy' => TRUE,
 															),
 											'user_preference' => 	array(
 																'edit_child' => TRUE,
@@ -1532,8 +1565,9 @@ class PermissionFactory extends Factory {
 															),
 											'job_report' => array(
 																'enabled' => TRUE,
-																'view_job_analysis' => TRUE,
 																'view_job_summary' => TRUE,
+																'view_job_analysis' => TRUE,
+																'view_job_payroll_analysis' => TRUE,
 																'view_job_barcode' => TRUE
 															),
 													);
