@@ -1,29 +1,42 @@
 <?php
 /*********************************************************************************
- * The contents of this file are subject to the TimeTrex Public License Version
- * 1.1.0 ("License"); You may not use this file except in compliance with the
- * License. You may obtain a copy of the License at http://www.TimeTrex.com/TPL
- * Software distributed under the License is distributed on an "AS IS" basis,
- * WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the License
- * for the specific language governing rights and limitations under the
- * License.
+ * TimeTrex is a Payroll and Time Management program developed by
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
  *
- * All copies of the Covered Code must include on each user interface screen:
- *    (i) the "Powered by TimeTrex" logo and
- *    (ii) the TimeTrex copyright notice
- * in the same form as they appear in the distribution.  See full license for
- * requirements.
+ * This program is free software; you can redistribute it and/or modify it under
+ * the terms of the GNU Affero General Public License version 3 as published by
+ * the Free Software Foundation with the addition of the following permission
+ * added to Section 15 as permitted in Section 7(a): FOR ANY PART OF THE COVERED
+ * WORK IN WHICH THE COPYRIGHT IS OWNED BY TIMETREX, TIMETREX DISCLAIMS THE
+ * WARRANTY OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
  *
- * The Original Code is: TimeTrex Open Source
- * The Initial Developer of the Original Code is TimeTrex Payroll Services
- * Portions created by TimeTrex are Copyright (C) 2004-2007 TimeTrex Payroll Services;
- * All Rights Reserved.
+ * This program is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+ * FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
+ * details.
  *
+ * You should have received a copy of the GNU Affero General Public License along
+ * with this program; if not, see http://www.gnu.org/licenses or write to the Free
+ * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+ * 02110-1301 USA.
+ *
+ * You can contact TimeTrex headquarters at Unit 22 - 2475 Dobbin Rd. Suite
+ * #292 Westbank, BC V4T 2E9, Canada or at email address info@timetrex.com.
+ *
+ * The interactive user interfaces in modified source and object code versions
+ * of this program must display Appropriate Legal Notices, as required under
+ * Section 5 of the GNU Affero General Public License version 3.
+ *
+ * In accordance with Section 7(b) of the GNU Affero General Public License
+ * version 3, these Appropriate Legal Notices must retain the display of the
+ * "Powered by TimeTrex" logo. If the display of the logo is not reasonably
+ * feasible for technical reasons, the Appropriate Legal Notices must display
+ * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2453 $
- * $Id: TTDate.class.php 2453 2009-03-20 16:34:04Z ipso $
- * $Date: 2009-03-20 09:34:04 -0700 (Fri, 20 Mar 2009) $
+ * $Revision: 3199 $
+ * $Id: TTDate.class.php 3199 2009-12-20 23:37:45Z ipso $
+ * $Date: 2009-12-20 15:37:45 -0800 (Sun, 20 Dec 2009) $
  */
 
 /**
@@ -33,7 +46,7 @@ class TTDate {
 	static protected $time_zone = 'GMT';
 	static protected $date_format = 'd-M-y';
 	static protected $time_format = 'g:i A T';
-	static protected $time_unit_format = 30; //Minutes
+	static protected $time_unit_format = 20; //Hours
 
 	static protected $month_arr = array(
 										'jan' => 1,
@@ -65,8 +78,8 @@ class TTDate {
 
 	static $month_of_year_arr = NULL;
 
-	private function __construct() {
-		this::setTimeZone();
+	function __construct() {
+		self::setTimeZone();
 	}
 
 	private function _get_month_short_names() {
@@ -103,8 +116,8 @@ class TTDate {
 			if ( isset($config_vars['other']['system_timezone']) ) {
 				$time_zone = $config_vars['other']['system_timezone'];
 			} else {
-				//$time_zone = 'GMT';
-				$time_zone = date('e');
+				//$time_zone = date('e'); //Newer versions of PHP return System/Localtime which is invalid, so force to GMT instead
+				$time_zone = 'GMT';
 			}
 		}
 
@@ -118,6 +131,7 @@ class TTDate {
 
 			self::$time_zone = $time_zone;
 
+			@date_default_timezone_set( $time_zone );
 			putenv('TZ='.$time_zone);
 
 			global $db;
@@ -133,6 +147,7 @@ class TTDate {
 			//If we don't do this then looping over users and setting timezones, if a user
 			//doesn't have a timezone set, it will cause them to use the previous users timezone.
 			//This way they at least use UTC and hopefully the issue will stand out more.
+			//date_default_timezone_set( '' );
 			putenv('TZ=');
 		}
 
@@ -185,6 +200,30 @@ class TTDate {
 		return date('Z');
 	}
 
+	public static function convertTimeZone( $epoch, $timezone ) {
+		if ( $timezone == '' ) {
+			return $epoch;
+		}
+
+		$old_timezone_offset = TTDate::getTimeZoneOffset();
+
+		try {
+			//Use PEAR Date class to convert timezones instead of PHP v5.2 date object so we can still use older PHP versions for distros like CentOS.
+			require_once('Date.php');
+
+			$d = new Date( date('r', $epoch ) );
+			$tz = new Date_TimeZone( $timezone );
+
+			$new_timezone_offset = ( $tz->getOffset( $d ) / 1000 );
+
+			return $epoch - ( $old_timezone_offset - $new_timezone_offset );
+		} catch (Exception $e) {
+			return $epoch;
+		}
+
+		return $epoch;
+	}
+
 	function convertSecondsToHMS( $seconds, $include_seconds = FALSE ) {
 		if ( $seconds < 0 ) {
 			$negative_number = TRUE;
@@ -290,9 +329,7 @@ class TTDate {
 			$time_unit_format = self::$time_unit_format;
 		}
 
-		//var_dump($seconds);
 		if ( empty($seconds) ) {
-			//echo "Empty Seconds<br>\n";
 			switch ($time_unit_format) {
 				case 10: //hh:mm
 					$retval = '00:00';
@@ -300,68 +337,37 @@ class TTDate {
 				case 12: //hh:mm:ss
 					$retval = '00:00:00';
 					break;
-				case 20: //hours
+				case 20: //hours with 2 decimal places
 					$retval = '0.00';
 					break;
-				case 22: //hours
+				case 22: //hours with 3 decimal places
 					$retval = '0.000';
 					break;
-				case 20: //minus
+				case 30: //minutes
 					$retval = 0;
 					break;
 			}
-
 		} else {
-
 			switch ($time_unit_format) {
 				case 10: //hh:mm
 					$retval = self::convertSecondsToHMS( $seconds );
-					/*
-					//Debug::text('Seconds: '. $seconds, __FILE__, __LINE__, __METHOD__, 10);
-					if ( $seconds < 0 ) {
-						$negative_number = TRUE;
-					}
-					$seconds = abs($seconds);
-
-					$hours = number_format( floor($seconds / 3600), 0 );
-					$minutes = number_format( ($seconds % 3600) / 60, 0);
-
-					if ( $minutes == 60 ) {
-						$hours++;
-						$minutes = 0;
-					}
-
-					if ( isset( $negative_number ) ) {
-						$negative = '-';
-					} else {
-						$negative = '';
-					}
-					$minutes = abs($minutes);
-
-					//Debug::text('Hours: '. $hours, __FILE__, __LINE__, __METHOD__, 10);
-					//Debug::text('Minutes: '. $minutes, __FILE__, __LINE__, __METHOD__, 10);
-
-					$retval = $negative.str_pad($hours,2,0,STR_PAD_LEFT).':'.str_pad($minutes,2,0,STR_PAD_LEFT);
-					*/
 					break;
 				case 12: //hh:mm:ss
 					$retval = self::convertSecondsToHMS( $seconds, TRUE );
 					break;
-				case 20: //hours
+				case 20: //hours with 2 decimal places
 					$retval = number_format( $seconds / 3600, 2);
 					break;
-				case 22: //hours [Precise]
+				case 22: //hours with 3 decimal places
 					$retval = number_format( $seconds / 3600, 3);
 					break;
 				case 30: //minutes
 					$retval = number_format( $seconds / 60, 0);
 					break;
 			}
-
 		}
 
 		if ( isset($retval) ) {
-			//var_dump($retval);
 			return $retval;
 		}
 
@@ -385,48 +391,51 @@ class TTDate {
 									);
 		$str = trim($str);
 		$orig_str = $str;
-		Debug::text('String: '. $str .' Date Format: '. self::$date_format, __FILE__, __LINE__, __METHOD__, 10);
 
+		if ( $str == '' ) {
+			Debug::text('No date to parse! String: '. $str .' Date Format: '. self::$date_format, __FILE__, __LINE__, __METHOD__, 10);
+			return FALSE;
+		}
+
+		//Debug::text('String: '. $str .' Date Format: '. self::$date_format, __FILE__, __LINE__, __METHOD__, 10);
 		if ( !is_numeric($str) AND in_array( self::$date_format, $custom_parse_formats) ) {
-			Debug::text('Custom Parse Format detected!', __FILE__, __LINE__, __METHOD__, 10);
+			//Debug::text('  Custom Parse Format detected!', __FILE__, __LINE__, __METHOD__, 10);
 			//Match to: Year, Month, Day
 			$textual_month = FALSE;
 			switch (self::$date_format) {
 				case 'M-d-y':
 				case 'M-d-Y':
-					Debug::text('Parsing format: M-d-y', __FILE__, __LINE__, __METHOD__, 10);
+					//Debug::text('  Parsing format: M-d-y', __FILE__, __LINE__, __METHOD__, 10);
 					$date_pattern = '/([A-Za-z]{3})\-([0-9]{1,2})\-([0-9]{2,4})/';
 					$match_arr = array( 'year' => 3, 'month' => 1, 'day' => 2 );
 					$textual_month = TRUE;
 					break;
 				case 'm-d-y':
 				case 'm-d-Y':
-					Debug::text('Parsing format: m-d-y', __FILE__, __LINE__, __METHOD__, 10);
+					//Debug::text('  Parsing format: m-d-y', __FILE__, __LINE__, __METHOD__, 10);
 					$date_pattern = '/([0-9]{1,2})\-([0-9]{1,2})\-([0-9]{2,4})/';
 					$match_arr = array( 'year' => 3, 'month' => 1, 'day' => 2 );
 					break;
 				case 'm/d/y':
 				case 'm/d/Y':
-					Debug::text('Parsing format: m/d/y', __FILE__, __LINE__, __METHOD__, 10);
+					//Debug::text('  Parsing format: m/d/y', __FILE__, __LINE__, __METHOD__, 10);
 					$date_pattern = '/([0-9]{1,2})\/([0-9]{1,2})\/([0-9]{2,4})/';
 					$match_arr = array( 'year' => 3, 'month' => 1, 'day' => 2 );
 					break;
 				case 'd/m/y':
 				case 'd/m/Y':
-					Debug::text('Parsing format: d/m/y', __FILE__, __LINE__, __METHOD__, 10);
+					//Debug::text('  Parsing format: d/m/y', __FILE__, __LINE__, __METHOD__, 10);
 					$date_pattern = '/([0-9]{1,2})\/([0-9]{1,2})\/([0-9]{2,4})/';
 					$match_arr = array( 'year' => 3, 'month' => 2, 'day' => 1 );
-
 					break;
 				case 'd-m-y':
 				case 'd-m-Y':
-					Debug::text('Parsing format: d-m-y', __FILE__, __LINE__, __METHOD__, 10);
+					//Debug::text('  Parsing format: d-m-y', __FILE__, __LINE__, __METHOD__, 10);
 					$date_pattern = '/([0-9]{1,2})\-([0-9]{1,2})\-([0-9]{2,4})/';
 					$match_arr = array( 'year' => 3, 'month' => 2, 'day' => 1 );
-
 					break;
 				default:
-					Debug::text('NO pattern match!', __FILE__, __LINE__, __METHOD__, 10);
+					//Debug::text('  NO pattern match!', __FILE__, __LINE__, __METHOD__, 10);
 					break;
 			}
 
@@ -436,7 +445,7 @@ class TTDate {
 				//var_dump($date_matches);
 
 				if ( $date_result != 0 ) {
-					Debug::text('Custom Date Match Success!', __FILE__, __LINE__, __METHOD__, 10);
+					//Debug::text('  Custom Date Match Success!', __FILE__, __LINE__, __METHOD__, 10);
 
 					$date_arr = array(
 										'year' => $date_matches[$match_arr['year']],
@@ -457,31 +466,28 @@ class TTDate {
 					//; preg_match('/[a-z]/', $date_arr['month']) != 0
 					if ( $textual_month == TRUE) {
 						$numeric_month = self::$month_arr[strtolower($date_arr['month'])];
-						Debug::text('Numeric Month: '. $numeric_month, __FILE__, __LINE__, __METHOD__, 10);
+						Debug::text('  Numeric Month: '. $numeric_month, __FILE__, __LINE__, __METHOD__, 10);
 						$date_arr['month'] = $numeric_month;
 						unset($numeric_month);
 					}
 
 					$tmp_date = $date_arr['year'].'-'.$date_arr['month'].'-'.$date_arr['day'];
-					Debug::text('Tmp Date: '. $tmp_date, __FILE__, __LINE__, __METHOD__, 10);
+					//Debug::text('  Tmp Date: '. $tmp_date, __FILE__, __LINE__, __METHOD__, 10);
 
 					//Replace the date pattern with NULL leaving only time left to append to the end of the string.
 					$time_result = preg_replace( $date_pattern, '', $str );
 					$formatted_date = $tmp_date .' '. $time_result;
 				} else {
-					Debug::text('Custom Date Match Failed... Falling back to strtotime', __FILE__, __LINE__, __METHOD__, 10);
+					Debug::text('  Custom Date Match Failed... Falling back to strtotime', __FILE__, __LINE__, __METHOD__, 10);
 				}
-
 			}
-
-
 		}
 
 		if ( !isset($formatted_date) ) {
-			Debug::text('NO Custom Parse Format detected!', __FILE__, __LINE__, __METHOD__, 10);
+			//Debug::text('  NO Custom Parse Format detected!', __FILE__, __LINE__, __METHOD__, 10);
 			$formatted_date = $str;
 		}
-		Debug::text('Parsing Date: '. $formatted_date , __FILE__, __LINE__, __METHOD__, 10);
+		//Debug::text('  Parsing Date: '. $formatted_date , __FILE__, __LINE__, __METHOD__, 10);
 
 		if ( is_numeric( $formatted_date ) ) {
 			$epoch = (int)$formatted_date;
@@ -491,11 +497,11 @@ class TTDate {
 
 			//Parse failed.
 			if ( $epoch == $formatted_date ) {
-				Debug::text('Parsing Date Failed! Returning FALSE! ', __FILE__, __LINE__, __METHOD__, 10);
+				Debug::text('  Parsing Date Failed! Returning FALSE! ', __FILE__, __LINE__, __METHOD__, 10);
 				$epoch = FALSE;
 			}
 
-			Debug::text('Parsed Date: '. TTDate::getDate('DATE+TIME', $epoch) , __FILE__, __LINE__, __METHOD__, 10);
+			//Debug::text('  Parsed Date: '. TTDate::getDate('DATE+TIME', $epoch) , __FILE__, __LINE__, __METHOD__, 10);
 		}
 
 		return $epoch;
@@ -506,6 +512,13 @@ class TTDate {
 
 		return date( $format, $epoch);
 	}
+	public static function getISOTimeStamp( $epoch ) {
+		return date( 'r', $epoch);
+	}
+
+	public static function getAPIDate( $format = 'DATE+TIME', $epoch ) {
+		return self::getDate( $format, $epoch );
+	}
 
 	public static function getDBTimeStamp( $epoch, $include_time_zone = TRUE ) {
 		$format = 'Y-m-d H:i:s';
@@ -553,9 +566,8 @@ class TTDate {
 			return NULL;
 		}
 
-		//debug_print_backtrace();
 		//Debug::text('Epoch: '. $epoch, __FILE__, __LINE__, __METHOD__, 10);
-		//This seems to support pre 1790 dates..
+		//This seems to support pre 1970 dates..
 		return date($format, $epoch);
 
 		//Support pre 1970 dates?
@@ -631,8 +643,12 @@ class TTDate {
 		}
 	}
 
+	public static function getDayOfYear( $epoch ) {
+		return date('z', $epoch);
+	}
+
 	public static function getDayOfWeekByInt($int, $translation = TRUE ) {
-		self::getDayOfWeekArray( TRUE );
+		self::getDayOfWeekArray( $translation );
 
 		if ( isset(self::$day_of_week_arr[$int]) ) {
 			return self::$day_of_week_arr[$int];
@@ -663,6 +679,14 @@ class TTDate {
 
 	}
 
+	public static function doesRangeSpanMidnight( $start_epoch, $end_epoch ) {
+		if ( self::getDayOfYear( $start_epoch ) != self::getDayOfYear( $end_epoch ) ) {
+			return TRUE; //Range spans midnight.
+		}
+
+		return FALSE;
+	}
+
 	public static function doesRangeSpanDST( $start_epoch, $end_epoch ) {
 		Debug::text('Start Epoch: '. TTDate::getDate('DATE+TIME', $start_epoch) .'  End Epoch: '. TTDate::getDate('DATE+TIME', $end_epoch), __FILE__, __LINE__, __METHOD__, 10);
 		$dst_epochs = self::getDSTEpoch($start_epoch);
@@ -765,6 +789,14 @@ class TTDate {
 		return date('t', $epoch);
 	}
 
+	public static function getDaysInYear($epoch = NULL ) {
+		if ($epoch == NULL) {
+			$epoch = TTDate::getTime();
+		}
+
+		return date('z', $epoch);
+	}
+
 	public static function snapTime($epoch, $snap_to_epoch, $snap_type) {
 		Debug::text('Epoch: '. $epoch .' ('.TTDate::getDate('DATE+TIME', $epoch).') Snap Epoch: '. $snap_to_epoch .' ('.TTDate::getDate('DATE+TIME', $snap_to_epoch).') Snap Type: '. $snap_type, __FILE__, __LINE__, __METHOD__, 10);
 
@@ -1163,6 +1195,29 @@ class TTDate {
 		return TTDate::getBeginDayEpoch( $retval );
 	}
 
+	public static function getDateOfNextYear( $anchor_epoch ) {
+		//Anchor Epoch is the anchor date to start searching from.
+		//Day of year epoch is the epoch we use to extract the day of the year from.
+		Debug::text('-------- ', __FILE__, __LINE__, __METHOD__,10);
+		Debug::text('Anchor Epoch: '. TTDate::getDate('DATE+TIME', $anchor_epoch), __FILE__, __LINE__, __METHOD__,10);
+
+		if ( $anchor_epoch == '' ) {
+			return FALSE;
+		}
+
+		$retval = mktime( 	date('H', $anchor_epoch ),
+							date('i', $anchor_epoch ),
+							date('s', $anchor_epoch ),
+							date('m', $anchor_epoch ),
+							date('j', $anchor_epoch ),
+							date('Y', $anchor_epoch )+1
+							);
+
+		Debug::text('Retval: '. TTDate::getDate('DATE+TIME', $retval), __FILE__, __LINE__, __METHOD__,10);
+		return $retval;
+
+	}
+
 	public static function getLastHireDateAnniversary($hire_date) {
 		Debug::Text('Hire Date: '. $hire_date .' - '. TTDate::getDate('DATE+TIME', $hire_date) , __FILE__, __LINE__, __METHOD__,10);
 
@@ -1214,6 +1269,8 @@ class TTDate {
 
 		$retval = self::getEndDayEpoch( self::getMiddleDayEpoch( self::getBeginWeekEpoch( self::getMiddleDayEpoch($epoch), $start_day_of_week ) ) + (86400*6) );
 
+		Debug::text(' Epoch: '. TTDate::getDate('DATE+TIME', $epoch) .' Retval: '. TTDate::getDate('DATE+TIME', $retval) .' Start Day of Week: '. $start_day_of_week, __FILE__, __LINE__, __METHOD__,10);
+
 		return $retval;
 	}
 
@@ -1223,27 +1280,20 @@ class TTDate {
 			$epoch = self::getTime();
 		}
 
-		$raw_week = (int)date('W', $epoch);
-		if ( $start_day_of_week == 1 ) {
-			//Start day of week is set to Monday, so it matches PHP.
-			$retval = $raw_week;
+		if ( $start_day_of_week == 1 ) { //PHP starts weeks on Monday.
+			return date('W', $epoch);
 		} else {
-			$epoch_dow = date('w', $epoch);
-
-			//Get day of week for Jan 1st of this year.
-			$jan_1st_dow = TTDate::getDayOfWeek( mktime( 12,0,0, TTDate::getMonth( $epoch ), 1, TTDate::getYear( $epoch ) ) );
-
-			if ( $start_day_of_week == $epoch_dow ) {
-				$dow_diff = 1;
+			if ( $start_day_of_week == 0 ) {
+				return date('W', strtotime('+1 day', $epoch ) );
 			} else {
-				$dow_diff = $start_day_of_week*-1;
+				$day_of_week = TTDate::getDayOfWeek( $epoch, 1); //Monday
+
+				$offset = $start_day_of_week - 1;
+				//Debug::text(' Offset: '. $offset .' Day Of Week: '. $day_of_week .' Start Day Of Week: '. $start_day_of_week, __FILE__, __LINE__, __METHOD__,10);
+
+				return date('W', strtotime('-'. $offset .' day', $epoch ) );
 			}
-
-			$retval = (int)date('W', mktime( 12,0,0, TTDate::getMonth( $epoch ), TTDate::getDayOfMonth( $epoch ) + $dow_diff, TTDate::getYear( $epoch ) ) );
-
 		}
-
-		return $retval;
 	}
 
 	public static function getYear($epoch = NULL) {
@@ -1559,18 +1609,45 @@ class TTDate {
 		return FALSE;
 	}
 
-	public static function getTimeLockedDate($time_epoch, $date_epoch) {
-		$epoch = mktime( 	date('H', $time_epoch ),
-							date('i', $time_epoch ),
-							date('s', $time_epoch ),
-							date('m', $date_epoch ),
-							date('j', $date_epoch ),
-							date('Y', $date_epoch )
-							);
-		return $epoch;
+	public static function calculateTimeOnEachDayBetweenRange( $start_epoch, $end_epoch ) {
+		if ( TTDate::doesRangeSpanMidnight( $start_epoch, $end_epoch ) == TRUE ) {
+			$total_before_first_midnight = (TTDate::getEndDayEpoch( $start_epoch )+1)-$start_epoch;
+			if ( $total_before_first_midnight > 0 ) {
+				$retval[TTDate::getBeginDayEpoch($start_epoch)] = $total_before_first_midnight;
+			}
 
+			$loop_start = TTDate::getEndDayEpoch( $start_epoch )+1;
+			$loop_end = TTDate::getBeginDayEpoch( $end_epoch );
+			for( $x=$loop_start; $x < $loop_end; $x+=86400 ) {
+				$retval[TTDate::getBeginDayEpoch($x)] = 86400;
+			}
+
+			$total_after_last_midnight = ($end_epoch-TTDate::getBeginDayEpoch( $end_epoch ));
+			if ( $total_after_last_midnight > 0 ) {
+				$retval[TTDate::getBeginDayEpoch($end_epoch)] = $total_after_last_midnight;
+			}
+		} else {
+			$retval = array( TTDate::getBeginDayEpoch($start_epoch) => ($end_epoch - $start_epoch) );
+		}
+
+		return $retval;
 	}
 
+	public static function getTimeLockedDate($time_epoch, $date_epoch) {
+		$time_arr = getdate($time_epoch);
+		$date_arr = getdate($date_epoch);
+
+		$epoch = mktime( 	$time_arr['hours'],
+							$time_arr['minutes'],
+							$time_arr['seconds'],
+							$date_arr['mon'],
+							$date_arr['mday'],
+							$date_arr['year']
+							);
+		unset($time_arr, $date_arr);
+
+		return $epoch;
+	}
 
 	// Function to return "13 mins ago" text from a given time.
 	public static function getHumanTimeSince($epoch) {
@@ -1631,7 +1708,6 @@ class TTDate {
 			Debug::text(' Returning False', __FILE__, __LINE__, __METHOD__,10);
             return FALSE;
         }
-
 	}
 
 	//Runs strtotime over a string, but if it happens to be an epoch, strtotime
