@@ -1,29 +1,42 @@
 <?php
 /*********************************************************************************
- * The contents of this file are subject to the TimeTrex Public License Version
- * 1.1.0 ("License"); You may not use this file except in compliance with the
- * License. You may obtain a copy of the License at http://www.TimeTrex.com/TPL
- * Software distributed under the License is distributed on an "AS IS" basis,
- * WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the License
- * for the specific language governing rights and limitations under the
- * License.
+ * TimeTrex is a Payroll and Time Management program developed by
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
  *
- * All copies of the Covered Code must include on each user interface screen:
- *    (i) the "Powered by TimeTrex" logo and
- *    (ii) the TimeTrex copyright notice
- * in the same form as they appear in the distribution.  See full license for
- * requirements.
+ * This program is free software; you can redistribute it and/or modify it under
+ * the terms of the GNU Affero General Public License version 3 as published by
+ * the Free Software Foundation with the addition of the following permission
+ * added to Section 15 as permitted in Section 7(a): FOR ANY PART OF THE COVERED
+ * WORK IN WHICH THE COPYRIGHT IS OWNED BY TIMETREX, TIMETREX DISCLAIMS THE
+ * WARRANTY OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
  *
- * The Original Code is: TimeTrex Open Source
- * The Initial Developer of the Original Code is TimeTrex Payroll Services
- * Portions created by TimeTrex are Copyright (C) 2004-2007 TimeTrex Payroll Services;
- * All Rights Reserved.
+ * This program is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+ * FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
+ * details.
  *
+ * You should have received a copy of the GNU Affero General Public License along
+ * with this program; if not, see http://www.gnu.org/licenses or write to the Free
+ * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+ * 02110-1301 USA.
+ *
+ * You can contact TimeTrex headquarters at Unit 22 - 2475 Dobbin Rd. Suite
+ * #292 Westbank, BC V4T 2E9, Canada or at email address info@timetrex.com.
+ *
+ * The interactive user interfaces in modified source and object code versions
+ * of this program must display Appropriate Legal Notices, as required under
+ * Section 5 of the GNU Affero General Public License version 3.
+ *
+ * In accordance with Section 7(b) of the GNU Affero General Public License
+ * version 3, these Appropriate Legal Notices must retain the display of the
+ * "Powered by TimeTrex" logo. If the display of the logo is not reasonably
+ * feasible for technical reasons, the Appropriate Legal Notices must display
+ * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2396 $
- * $Id: UserDateTotalListFactory.class.php 2396 2009-01-27 19:04:45Z ipso $
- * $Date: 2009-01-27 11:04:45 -0800 (Tue, 27 Jan 2009) $
+ * $Revision: 2858 $
+ * $Id: UserDateTotalListFactory.class.php 2858 2009-09-29 18:12:05Z ipso $
+ * $Date: 2009-09-29 11:12:05 -0700 (Tue, 29 Sep 2009) $
  */
 
 /**
@@ -624,6 +637,27 @@ class UserDateTotalListFactory extends UserDateTotalFactory implements IteratorA
 		return $this;
 	}
 
+	function getByPunchControlId($punch_control_id) {
+		if ( $punch_control_id == '' ) {
+			return FALSE;
+		}
+
+		$ph = array(
+					'punch_control_id' => $punch_control_id,
+					);
+
+		$query = '
+					select 	*
+					from	'. $this->getTable() .'
+					where punch_control_id = ?
+						AND deleted = 0
+					';
+
+		$this->rs = $this->db->Execute($query, $ph);
+
+		return $this;
+	}
+
 	function getByUserDateIdAndPunchControlId($user_date_id, $punch_control_id) {
 		if ( $user_date_id == '' ) {
 			return FALSE;
@@ -671,7 +705,7 @@ class UserDateTotalListFactory extends UserDateTotalFactory implements IteratorA
 					LEFT JOIN '. $pcf->getTable() .' as b ON a.punch_control_id = b.id
 					LEFT JOIN '. $apf->getTable() .' as c ON a.absence_policy_id = c.id
 					where 	a.user_date_id = ?
-						AND ( a.status_id in (20,30) OR ( a.status_id = 10 AND a.type_id = 100 ) )
+						AND ( a.status_id in (20,30) OR ( a.status_id = 10 AND a.type_id in ( 100, 110 ) ) )
 						AND ( c.type_id IS NULL OR c.type_id in ( 10, 12 ) )
 						AND ( a.deleted = 0 AND (b.deleted=0 OR b.deleted is NULL) )
 				';
@@ -968,7 +1002,7 @@ class UserDateTotalListFactory extends UserDateTotalFactory implements IteratorA
 						c.company_id = ?
 						AND	b.user_id = ?
 						AND a.status_id = ?
-						AND a.type_id not in (40,100)
+						AND a.type_id not in (40,100,110)
 						AND b.date_stamp >= ?
 						AND b.date_stamp <= ?
 						AND ( a.deleted = 0 AND b.deleted = 0 )
@@ -1035,7 +1069,7 @@ class UserDateTotalListFactory extends UserDateTotalFactory implements IteratorA
 						AND a.status_id in ('. $this->getListSQL($status, $ph) .')
 						AND a.type_id in ('. $this->getListSQL($type, $ph) .')
 						AND ( a.deleted = 0 AND b.deleted = 0 )
-					ORDER BY b.date_stamp asc, a.status_id asc, a.type_id asc, d.type_id desc
+					ORDER BY b.date_stamp asc, a.status_id asc, a.type_id asc, d.type_id desc, a.total_time asc
 					';
 
 		$this->rs = $this->db->Execute($query, $ph);
@@ -1100,7 +1134,7 @@ class UserDateTotalListFactory extends UserDateTotalFactory implements IteratorA
 					where
 						c.company_id = ?
 						AND	b.user_id = ?
-						AND a.type_id not in (10,40,100)
+						AND a.type_id not in (10,40,100,110)
 						AND b.date_stamp >= ?
 						AND b.date_stamp <= ?
 						AND a.status_id in ('. $this->getListSQL($status, $ph) .')
@@ -1297,6 +1331,43 @@ class UserDateTotalListFactory extends UserDateTotalFactory implements IteratorA
 		return $total;
 	}
 
+	function getDaysWorkedByUserIDAndUserDateIDs( $user_id, $user_date_ids ) {
+		if ( $user_id == '' ) {
+			return FALSE;
+		}
+
+		if ( $user_date_ids == '' ) {
+			return FALSE;
+		}
+
+		$udf = new UserDateFactory();
+
+		$ph = array(
+					'user_id' => $user_id,
+					);
+
+		//Include only paid absences.
+		$query = '
+					select 	count(distinct(a.user_date_id))
+					from	'. $this->getTable() .' as a,
+							'. $udf->getTable() .' as b
+					where 	a.user_date_id = b.id
+						AND b.user_id = ?
+						AND a.user_date_id in ('. $this->getListSQL($user_date_ids, $ph) .')
+						AND a.status_id = 20
+						AND a.total_time > 0
+						AND ( a.deleted = 0 AND b.deleted=0 )
+				';
+
+		$total = $this->db->GetOne($query, $ph);
+
+		if ($total === FALSE ) {
+			$total = 0;
+		}
+		Debug::text('Total: '. $total, __FILE__, __LINE__, __METHOD__, 10);
+
+		return $total;
+	}
 
 	/*
 
@@ -1360,7 +1431,7 @@ class UserDateTotalListFactory extends UserDateTotalFactory implements IteratorA
 					where 	a.user_date_id = b.id
 						AND b.user_id = ?
 						AND b.pay_period_id = ?
-						AND ( a.status_id = 20 OR ( a.status_id = 10 AND a.type_id = 100 ) )
+						AND ( a.status_id = 20 OR ( a.status_id = 10 AND a.type_id in ( 100, 110 ) ) )
 						AND ( a.deleted = 0 AND b.deleted=0 )
 				';
 
@@ -1401,7 +1472,7 @@ class UserDateTotalListFactory extends UserDateTotalFactory implements IteratorA
 						AND b.user_id = ?
 						AND b.pay_period_id = ?
 						AND a.status_id = 10
-						AND a.type_id not in ( 10, 40, 100 )
+						AND a.type_id not in ( 10, 40, 100, 110 )
 						AND ( a.deleted = 0 AND b.deleted=0 )
 					group by a.type_id, a.over_time_policy_id
 					order by a.type_id, a.over_time_policy_id
@@ -1560,6 +1631,54 @@ class UserDateTotalListFactory extends UserDateTotalFactory implements IteratorA
 		return $this;
 	}
 
+	function getByMealPolicyId($meal_policy_id, $where = NULL, $order = NULL) {
+		if ( $meal_policy_id == '') {
+			return FALSE;
+		}
+
+		$ph = array(
+					'meal_policy_id' => $meal_policy_id,
+					);
+
+		$query = '
+					select 	*
+					from	'. $this->getTable() .'
+					where	meal_policy_id = ?
+						AND deleted = 0
+					LIMIT 1
+				';
+		$query .= $this->getWhereSQL( $where );
+		$query .= $this->getSortSQL( $order );
+
+		$this->rs = $this->db->Execute($query, $ph);
+
+		return $this;
+	}
+
+	function getByBreakPolicyId($break_policy_id, $where = NULL, $order = NULL) {
+		if ( $break_policy_id == '') {
+			return FALSE;
+		}
+
+		$ph = array(
+					'break_policy_id' => $break_policy_id,
+					);
+
+		$query = '
+					select 	*
+					from	'. $this->getTable() .'
+					where	break_policy_id = ?
+						AND deleted = 0
+					LIMIT 1
+				';
+		$query .= $this->getWhereSQL( $where );
+		$query .= $this->getSortSQL( $order );
+
+		$this->rs = $this->db->Execute($query, $ph);
+
+		return $this;
+	}
+
 	function getByPremiumTimePolicyId($premium_policy_id, $where = NULL, $order = NULL) {
 		if ( $premium_policy_id == '') {
 			return FALSE;
@@ -1663,6 +1782,9 @@ class UserDateTotalListFactory extends UserDateTotalFactory implements IteratorA
 
 		$udf = new UserDateFactory();
 		$uwf = new UserWageFactory();
+		$otpf = new OverTimePolicyFactory();
+		$apf = new AbsencePolicyFactory();
+		$ppf = new PremiumPolicyFactory();
 
 		$ph = array();
 
@@ -1677,9 +1799,19 @@ class UserDateTotalListFactory extends UserDateTotalFactory implements IteratorA
 							a.job_item_id as job_item_id,
 							a.status_id as status_id,
 							a.type_id as type_id,
+
 							a.over_time_policy_id as over_time_policy_id,
+							n.id as over_time_policy_wage_id,
+							n.effective_date as over_time_policy_wage_effective_date,
+
 							a.absence_policy_id as absence_policy_id,
+							p.id as absence_policy_wage_id,
+							p.effective_date as absence_policy_wage_effective_date,
+
 							a.premium_policy_id as premium_policy_id,
+							r.id as premium_policy_wage_id,
+							r.effective_date as premium_policy_wage_effective_date,
+
 							z.id as user_wage_id,
 							z.effective_date as user_wage_effective_date,
 							sum(total_time) as total_time,
@@ -1688,6 +1820,34 @@ class UserDateTotalListFactory extends UserDateTotalFactory implements IteratorA
 							sum(bad_quantity) as bad_quantity
 					from	'. $this->getTable() .' as a
 					LEFT JOIN '. $udf->getTable() .' as b ON a.user_date_id = b.id
+
+					LEFT JOIN '. $otpf->getTable() .' as m ON a.over_time_policy_id = m.id
+					LEFT JOIN '. $uwf->getTable() .' as n ON n.id = (select n.id
+																		from '. $uwf->getTable() .' as n
+																		where n.user_id = b.user_id
+																			and n.wage_group_id = m.wage_group_id
+																			and n.effective_date <= b.date_stamp
+																			and n.deleted = 0
+																			order by n.effective_date desc limit 1)
+
+					LEFT JOIN '. $apf->getTable() .' as o ON a.absence_policy_id = o.id
+					LEFT JOIN '. $uwf->getTable() .' as p ON p.id = (select p.id
+																		from '. $uwf->getTable() .' as p
+																		where p.user_id = b.user_id
+																			and p.wage_group_id = o.wage_group_id
+																			and p.effective_date <= b.date_stamp
+																			and p.deleted = 0
+																			order by p.effective_date desc limit 1)
+
+					LEFT JOIN '. $ppf->getTable() .' as q ON a.premium_policy_id = q.id
+					LEFT JOIN '. $uwf->getTable() .' as r ON r.id = (select r.id
+																		from '. $uwf->getTable() .' as r
+																		where r.user_id = b.user_id
+																			and r.wage_group_id = q.wage_group_id
+																			and r.effective_date <= b.date_stamp
+																			and r.deleted = 0
+																			order by r.effective_date desc limit 1)
+
 					LEFT JOIN '. $uwf->getTable() .' as z ON z.id = (select z.id
 																		from '. $uwf->getTable() .' as z
 																		where z.user_id = b.user_id
@@ -1698,8 +1858,7 @@ class UserDateTotalListFactory extends UserDateTotalFactory implements IteratorA
 						a.job_id in ('. $this->getListSQL($job_ids, $ph) .')
 						AND a.status_id in (10)
 						AND ( a.deleted = 0 AND b.deleted = 0 )
-					group by b.user_id,user_wage_id, user_wage_effective_date, a.status_id, a.type_id, a.branch_id, a.department_id, a.job_id, a.job_item_id, a.over_time_policy_id, a.absence_policy_id, a.premium_policy_id order by a.job_id asc
-
+					group by b.user_id,user_wage_id, user_wage_effective_date, over_time_policy_wage_id, over_time_policy_wage_effective_date, absence_policy_wage_id, absence_policy_wage_effective_date, premium_policy_wage_id, premium_policy_wage_effective_date, a.status_id, a.type_id, a.branch_id, a.department_id, a.job_id, a.job_item_id, a.over_time_policy_id, a.absence_policy_id, a.premium_policy_id order by a.job_id asc
 				';
 		//$query .= $this->getSortSQL( $order, FALSE );
 
@@ -1729,6 +1888,9 @@ class UserDateTotalListFactory extends UserDateTotalFactory implements IteratorA
 
 		$udf = new UserDateFactory();
 		$uwf = new UserWageFactory();
+		$otpf = new OverTimePolicyFactory();
+		$apf = new AbsencePolicyFactory();
+		$ppf = new PremiumPolicyFactory();
 
 		$ph = array(
 					'user_id' => $user_id,
@@ -1737,35 +1899,6 @@ class UserDateTotalListFactory extends UserDateTotalFactory implements IteratorA
 					);
 
 /*
-		$query = '
-					select 	a.status_id as status_id,
-							a.type_id as type_id,
-							a.over_time_policy_id as over_time_policy_id,
-							a.absence_policy_id as absence_policy_id,
-							a.premium_policy_id as premium_policy_id,
-							(select z.id
-									from user_wage as z
-									where z.user_id = b.user_id
-										and z.effective_date <= b.date_stamp
-										and z.deleted = 0
-										order by z.effective_date desc limit 1) as user_wage_id,
-							sum(total_Time) as total_time
-					from	'. $this->getTable() .' as a,
-							'. $udf->getTable() .' as b
-					where 	a.user_date_id = b.id
-						AND b.user_id = '. $user_id .'
-						AND b.pay_period_id = '. $pay_period_id .'
-						AND b.date_stamp <= '. $this->db->BindTimeStamp( $end_date ) .'
-						AND a.status_id in (10,30)
-						AND ( a.deleted = 0 AND b.deleted = 0)
-					group by user_wage_id, a.status_id, a.type_id, a.over_time_policy_id, a.absence_policy_id, a.premium_policy_id
-					order by a.status_id desc, a.type_id asc
-				';
-
-*/
-		//Order dock hours first, so it can be deducted from regular time.
-		//Order newest wage changes first too. This is VERY important for calculating pro-rate amounts.
-		$query = '
 					select 	a.status_id as status_id,
 							a.type_id as type_id,
 							a.over_time_policy_id as over_time_policy_id,
@@ -1790,6 +1923,73 @@ class UserDateTotalListFactory extends UserDateTotalFactory implements IteratorA
 						AND ( a.deleted = 0 AND b.deleted = 0)
 					group by user_wage_id, user_wage_effective_date, a.status_id, a.type_id, a.over_time_policy_id, a.absence_policy_id, a.premium_policy_id
 					order by a.status_id desc, a.type_id asc, user_wage_effective_date desc
+*/
+		//Order dock hours first, so it can be deducted from regular time.
+		//Order newest wage changes first too. This is VERY important for calculating pro-rate amounts.
+		$query = '
+					select 	a.status_id as status_id,
+							a.type_id as type_id,
+
+							a.over_time_policy_id as over_time_policy_id,
+							n.id as over_time_policy_wage_id,
+							n.effective_date as over_time_policy_wage_effective_date,
+
+							a.absence_policy_id as absence_policy_id,
+							p.id as absence_policy_wage_id,
+							p.effective_date as absence_policy_wage_effective_date,
+
+							a.premium_policy_id as premium_policy_id,
+							r.id as premium_policy_wage_id,
+							r.effective_date as premium_policy_wage_effective_date,
+
+							z.id as user_wage_id,
+							z.effective_date as user_wage_effective_date,
+							sum(total_Time) as total_time
+					from	'. $this->getTable() .' as a
+					LEFT JOIN '. $udf->getTable() .' as b ON a.user_date_id = b.id
+
+					LEFT JOIN '. $otpf->getTable() .' as m ON a.over_time_policy_id = m.id
+					LEFT JOIN '. $uwf->getTable() .' as n ON n.id = (select n.id
+																		from '. $uwf->getTable() .' as n
+																		where n.user_id = b.user_id
+																			and n.wage_group_id = m.wage_group_id
+																			and n.effective_date <= b.date_stamp
+																			and n.deleted = 0
+																			order by n.effective_date desc limit 1)
+
+					LEFT JOIN '. $apf->getTable() .' as o ON a.absence_policy_id = o.id
+					LEFT JOIN '. $uwf->getTable() .' as p ON p.id = (select p.id
+																		from '. $uwf->getTable() .' as p
+																		where p.user_id = b.user_id
+																			and p.wage_group_id = o.wage_group_id
+																			and p.effective_date <= b.date_stamp
+																			and p.deleted = 0
+																			order by p.effective_date desc limit 1)
+
+					LEFT JOIN '. $ppf->getTable() .' as q ON a.premium_policy_id = q.id
+					LEFT JOIN '. $uwf->getTable() .' as r ON r.id = (select r.id
+																		from '. $uwf->getTable() .' as r
+																		where r.user_id = b.user_id
+																			and r.wage_group_id = q.wage_group_id
+																			and r.effective_date <= b.date_stamp
+																			and r.deleted = 0
+																			order by r.effective_date desc limit 1)
+
+					LEFT JOIN '. $uwf->getTable() .' as z ON z.id = (select z.id
+																		from '. $uwf->getTable() .' as z
+																		where z.user_id = b.user_id
+																			and z.wage_group_id = 0
+																			and z.effective_date <= b.date_stamp
+																			and z.deleted = 0
+																			order by z.effective_date desc limit 1)
+					where
+						b.user_id = ?
+						AND b.pay_period_id = ?
+						AND b.date_stamp <= ?
+						AND a.status_id in (10,30)
+						AND ( a.deleted = 0 AND b.deleted = 0)
+					group by user_wage_id, user_wage_effective_date, over_time_policy_wage_id, over_time_policy_wage_effective_date, absence_policy_wage_id, absence_policy_wage_effective_date, premium_policy_wage_id, premium_policy_wage_effective_date, a.status_id, a.type_id, a.over_time_policy_id, a.absence_policy_id, a.premium_policy_id
+					order by a.status_id desc, a.type_id asc, user_wage_effective_date desc, over_time_policy_wage_effective_date desc, absence_policy_wage_effective_date desc, premium_policy_wage_effective_date desc
 				';
 
 		$this->rs = $this->db->Execute($query, $ph);
@@ -1879,9 +2079,13 @@ class UserDateTotalListFactory extends UserDateTotalFactory implements IteratorA
 		if ( isset($filter_data['user_ids']) ) {
 			$filter_data['user_id'] = $filter_data['user_ids'];
 		}
+		if ( isset($filter_data['job_ids']) ) {
+			$filter_data['job_id'] = $filter_data['job_ids'];
+		}
 
 		$ulf = new UserListFactory();
 		$udf = new UserDateFactory();
+		$ppf = new PayPeriodFactory();
 
 		$ph = array();
 
@@ -1895,15 +2099,20 @@ class UserDateTotalListFactory extends UserDateTotalFactory implements IteratorA
 							a.status_id as status_id,
 							a.type_id as type_id,
 							b.pay_period_id as pay_period_id,
+							a.branch_id as branch_id,
+							a.department_id as department_id,
+							a.job_id as job_id,
+							a.job_item_id as job_item_id,
 							a.over_time_policy_id as over_time_policy_id,
 							a.absence_policy_id as absence_policy_id,
 							a.premium_policy_id as premium_policy_id,
 							sum(a.total_time) as total_time,
 							sum(a.actual_total_Time) as actual_total_time,
 							count( distinct(CASE WHEN a.status_id = 20 AND a.type_id = 10 AND a.total_time > 0 THEN a.user_date_id ELSE NULL END) ) as worked_days
-					from	'. $this->getTable() .' as a,
-							'. $udf->getTable() .' as b
-					where 	a.user_date_id = b.id
+					from	'. $this->getTable() .' as a
+					LEFT JOIN '. $udf->getTable() .' as b ON a.user_date_id = b.id
+					LEFT JOIN '. $ppf->getTable() .' as c ON b.pay_period_id = c.id
+					where 1=1
 					';
 
 					if ( isset($filter_data['user_id']) AND isset($filter_data['user_id'][0]) AND !in_array(-1, (array)$filter_data['user_id']) ) {
@@ -1913,6 +2122,14 @@ class UserDateTotalListFactory extends UserDateTotalFactory implements IteratorA
 					if ( isset($filter_data['pay_period_ids']) AND isset($filter_data['pay_period_ids'][0]) AND !in_array(-1, (array)$filter_data['pay_period_ids']) ) {
 						$query .= 	' AND b.pay_period_id in ('. $this->getListSQL($filter_data['pay_period_ids'], $ph) .') ';
 					}
+					if ( isset($filter_data['transaction_start_date']) AND trim($filter_data['transaction_start_date']) != '' ) {
+						$ph[] = $this->db->BindTimeStamp( strtolower(trim($filter_data['transaction_start_date'])) );
+						$query  .=	' AND c.transaction_date >= ?';
+					}
+					if ( isset($filter_data['transaction_end_date']) AND trim($filter_data['transaction_end_date']) != '' ) {
+						$ph[] = $this->db->BindTimeStamp( strtolower(trim($filter_data['transaction_end_date'])) );
+						$query  .=	' AND c.transaction_date <= ?';
+					}
 
 					if ( isset($filter_data['start_date']) AND trim($filter_data['start_date']) != '' ) {
 						$ph[] = $this->db->BindDate($filter_data['start_date']);
@@ -1923,11 +2140,18 @@ class UserDateTotalListFactory extends UserDateTotalFactory implements IteratorA
 						$query  .=	' AND b.date_stamp <= ?';
 					}
 
+					if ( isset($filter_data['job_id']) AND isset($filter_data['job_id'][0]) AND !in_array(-1, (array)$filter_data['job_id']) ) {
+						$query  .=	' AND a.job_id in ('. $this->getListSQL($filter_data['job_id'], $ph) .') ';
+					}
+					if ( isset($filter_data['job_item_id']) AND isset($filter_data['job_item_id'][0]) AND !in_array(-1, (array)$filter_data['job_item_id']) ) {
+						$query  .=	' AND a.job_item_id in ('. $this->getListSQL($filter_data['job_item_id'], $ph) .') ';
+					}
+
 		$ph[] = $company_id;
 		$query .= '
 						AND a.status_id in (10,20,30)
 						AND ( a.deleted = 0 AND b.deleted = 0)
-					group by b.user_id, b.pay_period_id, a.status_id, a.type_id, a.over_time_policy_id, a.absence_policy_id, a.premium_policy_id
+					group by b.user_id, b.pay_period_id, a.branch_id, a.department_id, a.job_id, a.job_item_id, a.status_id, a.type_id, a.over_time_policy_id, a.absence_policy_id, a.premium_policy_id
 					) as tmp ON z.id = tmp.user_id
 				WHERE z.company_id = ? ';
 
@@ -2054,6 +2278,9 @@ class UserDateTotalListFactory extends UserDateTotalFactory implements IteratorA
 		$uwf = new UserWageFactory();
 		$pcf = new PunchControlFactory();
 		$pf = new PunchFactory();
+		$otpf = new OverTimePolicyFactory();
+		$apf = new AbsencePolicyFactory();
+		$ppf = new PremiumPolicyFactory();
 
 		$ph = array();
 
@@ -2072,9 +2299,19 @@ class UserDateTotalListFactory extends UserDateTotalFactory implements IteratorA
 							a.department_id as department_id,
 							a.status_id as status_id,
 							a.type_id as type_id,
+
 							a.over_time_policy_id as over_time_policy_id,
+							n.id as over_time_policy_wage_id,
+							n.effective_date as over_time_policy_wage_effective_date,
+
 							a.absence_policy_id as absence_policy_id,
+							p.id as absence_policy_wage_id,
+							p.effective_date as absence_policy_wage_effective_date,
+
 							a.premium_policy_id as premium_policy_id,
+							r.id as premium_policy_wage_id,
+							r.effective_date as premium_policy_wage_effective_date,
+
 							z.id as user_wage_id,
 							z.effective_date as user_wage_effective_date,
 							tmp2.min_punch_time_stamp as min_punch_time_stamp,
@@ -2083,6 +2320,34 @@ class UserDateTotalListFactory extends UserDateTotalFactory implements IteratorA
 							sum(actual_total_Time) as actual_total_time
 					from	'. $this->getTable() .' as a
 					LEFT JOIN '. $udf->getTable() .' as b ON a.user_date_id = b.id
+
+					LEFT JOIN '. $otpf->getTable() .' as m ON a.over_time_policy_id = m.id
+					LEFT JOIN '. $uwf->getTable() .' as n ON n.id = (select n.id
+																		from '. $uwf->getTable() .' as n
+																		where n.user_id = b.user_id
+																			and n.wage_group_id = m.wage_group_id
+																			and n.effective_date <= b.date_stamp
+																			and n.deleted = 0
+																			order by n.effective_date desc limit 1)
+
+					LEFT JOIN '. $apf->getTable() .' as o ON a.absence_policy_id = o.id
+					LEFT JOIN '. $uwf->getTable() .' as p ON p.id = (select p.id
+																		from '. $uwf->getTable() .' as p
+																		where p.user_id = b.user_id
+																			and p.wage_group_id = o.wage_group_id
+																			and p.effective_date <= b.date_stamp
+																			and p.deleted = 0
+																			order by p.effective_date desc limit 1)
+
+					LEFT JOIN '. $ppf->getTable() .' as q ON a.premium_policy_id = q.id
+					LEFT JOIN '. $uwf->getTable() .' as r ON r.id = (select r.id
+																		from '. $uwf->getTable() .' as r
+																		where r.user_id = b.user_id
+																			and r.wage_group_id = q.wage_group_id
+																			and r.effective_date <= b.date_stamp
+																			and r.deleted = 0
+																			order by r.effective_date desc limit 1)
+
 					LEFT JOIN '. $uwf->getTable() .' as z ON z.id = (select z.id
 																		from '. $uwf->getTable() .' as z
 																		where z.user_id = b.user_id
@@ -2145,13 +2410,10 @@ class UserDateTotalListFactory extends UserDateTotalFactory implements IteratorA
 		$query .= '
 						AND a.status_id in (10,20,30)
 						AND ( a.deleted = 0 AND b.deleted = 0 )
-					group by b.user_id, b.pay_period_id, a.branch_id, a.department_id, b.date_stamp, user_wage_id, user_wage_effective_date, a.status_id, a.type_id, a.over_time_policy_id, a.absence_policy_id, a.premium_policy_id, tmp2.min_punch_time_stamp, tmp2.max_punch_time_stamp
+					group by b.user_id, b.pay_period_id, a.branch_id, a.department_id, b.date_stamp, user_wage_id, user_wage_effective_date, over_time_policy_wage_id, over_time_policy_wage_effective_date, absence_policy_wage_id, absence_policy_wage_effective_date, premium_policy_wage_id, premium_policy_wage_effective_date, a.status_id, a.type_id, a.over_time_policy_id, a.absence_policy_id, a.premium_policy_id, tmp2.min_punch_time_stamp, tmp2.max_punch_time_stamp
 					) as tmp ON z.id = tmp.user_id
 				WHERE z.company_id = ? ';
-/*
-				$ph[] = $company_id;
-				$query .= ' AND z.company_id = ? ';
-*/
+
 		if ( isset($filter_data['user_id']) AND isset($filter_data['user_id'][0]) AND !in_array(-1, (array)$filter_data['user_id']) ) {
 			$query  .=	' AND z.id in ('. $this->getListSQL($filter_data['user_id'], $ph) .') ';
 		}
@@ -2192,6 +2454,9 @@ class UserDateTotalListFactory extends UserDateTotalFactory implements IteratorA
 		$ulf = new UserListFactory();
 		$udf = new UserDateFactory();
 		$uwf = new UserWageFactory();
+		$otpf = new OverTimePolicyFactory();
+		$apf = new AbsencePolicyFactory();
+		$ppf = new PremiumPolicyFactory();
 
 		$ph = array(
 					'start_date' => $this->db->BindDate( $start_date ),
@@ -2208,15 +2473,53 @@ class UserDateTotalListFactory extends UserDateTotalFactory implements IteratorA
 							b.date_stamp as date_stamp,
 							a.status_id as status_id,
 							a.type_id as type_id,
+
 							a.over_time_policy_id as over_time_policy_id,
+							n.id as over_time_policy_wage_id,
+							n.effective_date as over_time_policy_wage_effective_date,
+
 							a.absence_policy_id as absence_policy_id,
+							p.id as absence_policy_wage_id,
+							p.effective_date as absence_policy_wage_effective_date,
+
 							a.premium_policy_id as premium_policy_id,
+							r.id as premium_policy_wage_id,
+							r.effective_date as premium_policy_wage_effective_date,
+
 							z.id as user_wage_id,
 							z.effective_date as user_wage_effective_date,
 							sum(total_Time) as total_time,
 							sum(actual_total_Time) as actual_total_time
 					from	'. $this->getTable() .' as a
 					LEFT JOIN '. $udf->getTable() .' as b ON a.user_date_id = b.id
+
+					LEFT JOIN '. $otpf->getTable() .' as m ON a.over_time_policy_id = m.id
+					LEFT JOIN '. $uwf->getTable() .' as n ON n.id = (select n.id
+																		from '. $uwf->getTable() .' as n
+																		where n.user_id = b.user_id
+																			and n.wage_group_id = m.wage_group_id
+																			and n.effective_date <= b.date_stamp
+																			and n.deleted = 0
+																			order by n.effective_date desc limit 1)
+
+					LEFT JOIN '. $apf->getTable() .' as o ON a.absence_policy_id = o.id
+					LEFT JOIN '. $uwf->getTable() .' as p ON p.id = (select p.id
+																		from '. $uwf->getTable() .' as p
+																		where p.user_id = b.user_id
+																			and p.wage_group_id = o.wage_group_id
+																			and p.effective_date <= b.date_stamp
+																			and p.deleted = 0
+																			order by p.effective_date desc limit 1)
+
+					LEFT JOIN '. $ppf->getTable() .' as q ON a.premium_policy_id = q.id
+					LEFT JOIN '. $uwf->getTable() .' as r ON r.id = (select r.id
+																		from '. $uwf->getTable() .' as r
+																		where r.user_id = b.user_id
+																			and r.wage_group_id = q.wage_group_id
+																			and r.effective_date <= b.date_stamp
+																			and r.deleted = 0
+																			order by r.effective_date desc limit 1)
+
 					LEFT JOIN '. $uwf->getTable() .' as z ON z.id = (select z.id
 																		from '. $uwf->getTable() .' as z
 																		where z.user_id = b.user_id
@@ -2229,7 +2532,7 @@ class UserDateTotalListFactory extends UserDateTotalFactory implements IteratorA
 						AND b.user_id in ('. $this->getListSQL($user_ids, $ph) .')
 						AND a.status_id in (10,30)
 						AND ( a.deleted = 0 AND b.deleted = 0)
-					group by b.user_id, b.date_stamp, user_wage_id, user_wage_effective_date, a.status_id, a.type_id, a.over_time_policy_id, a.absence_policy_id, a.premium_policy_id
+					group by b.user_id, b.date_stamp, user_wage_id, user_wage_effective_date, over_time_policy_wage_id, over_time_policy_wage_effective_date, absence_policy_wage_id, absence_policy_wage_effective_date, premium_policy_wage_id, premium_policy_wage_effective_date, a.status_id, a.type_id, a.over_time_policy_id, a.absence_policy_id, a.premium_policy_id
 					) as tmp ON z.id = tmp.user_id
 				WHERE z.id in ('. $this->getListSQL($user_ids, $ph) .')
 					AND z.deleted = 0
@@ -2272,6 +2575,9 @@ class UserDateTotalListFactory extends UserDateTotalFactory implements IteratorA
 		$ulf = new UserListFactory();
 		$udf = new UserDateFactory();
 		$uwf = new UserWageFactory();
+		$otpf = new OverTimePolicyFactory();
+		$apf = new AbsencePolicyFactory();
+		$ppf = new PremiumPolicyFactory();
 
 		$ph = array(
 					'start_date' => $this->db->BindDate( $start_date ),
@@ -2287,9 +2593,19 @@ class UserDateTotalListFactory extends UserDateTotalFactory implements IteratorA
 							a.department_id as department_id,
 							a.job_id as job_id,
 							a.job_item_id as job_item_id,
+
 							a.over_time_policy_id as over_time_policy_id,
+							n.id as over_time_policy_wage_id,
+							n.effective_date as over_time_policy_wage_effective_date,
+
 							a.absence_policy_id as absence_policy_id,
+							p.id as absence_policy_wage_id,
+							p.effective_date as absence_policy_wage_effective_date,
+
 							a.premium_policy_id as premium_policy_id,
+							r.id as premium_policy_wage_id,
+							r.effective_date as premium_policy_wage_effective_date,
+
 							z.id as user_wage_id,
 							z.effective_date as user_wage_effective_date,
 							sum(total_time) as total_time,
@@ -2298,6 +2614,34 @@ class UserDateTotalListFactory extends UserDateTotalFactory implements IteratorA
 							sum(bad_quantity) as bad_quantity
 					from	'. $this->getTable() .' as a
 					LEFT JOIN '. $udf->getTable() .' as b ON a.user_date_id = b.id
+
+					LEFT JOIN '. $otpf->getTable() .' as m ON a.over_time_policy_id = m.id
+					LEFT JOIN '. $uwf->getTable() .' as n ON n.id = (select n.id
+																		from '. $uwf->getTable() .' as n
+																		where n.user_id = b.user_id
+																			and n.wage_group_id = m.wage_group_id
+																			and n.effective_date <= b.date_stamp
+																			and n.deleted = 0
+																			order by n.effective_date desc limit 1)
+
+					LEFT JOIN '. $apf->getTable() .' as o ON a.absence_policy_id = o.id
+					LEFT JOIN '. $uwf->getTable() .' as p ON p.id = (select p.id
+																		from '. $uwf->getTable() .' as p
+																		where p.user_id = b.user_id
+																			and p.wage_group_id = o.wage_group_id
+																			and p.effective_date <= b.date_stamp
+																			and p.deleted = 0
+																			order by p.effective_date desc limit 1)
+
+					LEFT JOIN '. $ppf->getTable() .' as q ON a.premium_policy_id = q.id
+					LEFT JOIN '. $uwf->getTable() .' as r ON r.id = (select r.id
+																		from '. $uwf->getTable() .' as r
+																		where r.user_id = b.user_id
+																			and r.wage_group_id = q.wage_group_id
+																			and r.effective_date <= b.date_stamp
+																			and r.deleted = 0
+																			order by r.effective_date desc limit 1)
+
 					LEFT JOIN '. $uwf->getTable() .' as z ON z.id = (select z.id
 																		from '. $uwf->getTable() .' as z
 																		where z.user_id = b.user_id
@@ -2310,7 +2654,7 @@ class UserDateTotalListFactory extends UserDateTotalFactory implements IteratorA
 						AND a.job_id in ('. $this->getListSQL($job_ids, $ph) .')
 						AND a.status_id in (10,20,30)
 						AND ( a.deleted = 0 AND b.deleted = 0)
-					group by b.user_id,user_wage_id, user_wage_effective_date, a.status_id, a.type_id, a.branch_id, a.department_id, a.job_id, a.job_item_id, a.over_time_policy_id, a.absence_policy_id, a.premium_policy_id
+					group by b.user_id,user_wage_id, user_wage_effective_date, over_time_policy_wage_id, over_time_policy_wage_effective_date, absence_policy_wage_id, absence_policy_wage_effective_date, premium_policy_wage_id, premium_policy_wage_effective_date, a.status_id, a.type_id, a.branch_id, a.department_id, a.job_id, a.job_item_id, a.over_time_policy_id, a.absence_policy_id, a.premium_policy_id
 					order by a.job_id asc
 				';
 
@@ -2361,6 +2705,9 @@ class UserDateTotalListFactory extends UserDateTotalFactory implements IteratorA
 		$ulf = new UserListFactory();
 		$udf = new UserDateFactory();
 		$uwf = new UserWageFactory();
+		$otpf = new OverTimePolicyFactory();
+		$apf = new AbsencePolicyFactory();
+		$ppf = new PremiumPolicyFactory();
 
 		$ph = array(
 					'start_date' => $this->db->BindDate( $start_date ),
@@ -2376,9 +2723,19 @@ class UserDateTotalListFactory extends UserDateTotalFactory implements IteratorA
 							a.department_id as department_id,
 							a.job_id as job_id,
 							a.job_item_id as job_item_id,
+
 							a.over_time_policy_id as over_time_policy_id,
+							n.id as over_time_policy_wage_id,
+							n.effective_date as over_time_policy_wage_effective_date,
+
 							a.absence_policy_id as absence_policy_id,
+							p.id as absence_policy_wage_id,
+							p.effective_date as absence_policy_wage_effective_date,
+
 							a.premium_policy_id as premium_policy_id,
+							r.id as premium_policy_wage_id,
+							r.effective_date as premium_policy_wage_effective_date,
+
 							z.id as user_wage_id,
 							z.effective_date as user_wage_effective_date,
 							sum(total_time) as total_time,
@@ -2387,6 +2744,34 @@ class UserDateTotalListFactory extends UserDateTotalFactory implements IteratorA
 							sum(bad_quantity) as bad_quantity
 					from	'. $this->getTable() .' as a
 					LEFT JOIN '. $udf->getTable() .' as b ON a.user_date_id = b.id
+
+					LEFT JOIN '. $otpf->getTable() .' as m ON a.over_time_policy_id = m.id
+					LEFT JOIN '. $uwf->getTable() .' as n ON n.id = (select n.id
+																		from '. $uwf->getTable() .' as n
+																		where n.user_id = b.user_id
+																			and n.wage_group_id = m.wage_group_id
+																			and n.effective_date <= b.date_stamp
+																			and n.deleted = 0
+																			order by n.effective_date desc limit 1)
+
+					LEFT JOIN '. $apf->getTable() .' as o ON a.absence_policy_id = o.id
+					LEFT JOIN '. $uwf->getTable() .' as p ON p.id = (select p.id
+																		from '. $uwf->getTable() .' as p
+																		where p.user_id = b.user_id
+																			and p.wage_group_id = o.wage_group_id
+																			and p.effective_date <= b.date_stamp
+																			and p.deleted = 0
+																			order by p.effective_date desc limit 1)
+
+					LEFT JOIN '. $ppf->getTable() .' as q ON a.premium_policy_id = q.id
+					LEFT JOIN '. $uwf->getTable() .' as r ON r.id = (select r.id
+																		from '. $uwf->getTable() .' as r
+																		where r.user_id = b.user_id
+																			and r.wage_group_id = q.wage_group_id
+																			and r.effective_date <= b.date_stamp
+																			and r.deleted = 0
+																			order by r.effective_date desc limit 1)
+
 					LEFT JOIN '. $uwf->getTable() .' as z ON z.id = (select z.id
 																		from '. $uwf->getTable() .' as z
 																		where z.user_id = b.user_id
@@ -2409,7 +2794,7 @@ class UserDateTotalListFactory extends UserDateTotalFactory implements IteratorA
 		$query .= '
 						AND a.status_id in (10,20,30)
 						AND ( a.deleted = 0 AND b.deleted = 0)
-					group by b.user_id,user_wage_id, user_wage_effective_date, a.status_id, a.type_id, a.branch_id, a.department_id, a.job_id, a.job_item_id, a.over_time_policy_id, a.absence_policy_id, a.premium_policy_id
+					group by b.user_id,user_wage_id, user_wage_effective_date, over_time_policy_wage_id, over_time_policy_wage_effective_date, absence_policy_wage_id, absence_policy_wage_effective_date, premium_policy_wage_id, premium_policy_wage_effective_date, a.status_id, a.type_id, a.branch_id, a.department_id, a.job_id, a.job_item_id, a.over_time_policy_id, a.absence_policy_id, a.premium_policy_id
 				';
 
 		$query .= $this->getSortSQL( $order, FALSE );
