@@ -1,29 +1,42 @@
 <?php
 /*********************************************************************************
- * The contents of this file are subject to the TimeTrex Public License Version
- * 1.1.0 ("License"); You may not use this file except in compliance with the
- * License. You may obtain a copy of the License at http://www.TimeTrex.com/TPL
- * Software distributed under the License is distributed on an "AS IS" basis,
- * WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the License
- * for the specific language governing rights and limitations under the
- * License.
+ * TimeTrex is a Payroll and Time Management program developed by
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
  *
- * All copies of the Covered Code must include on each user interface screen:
- *    (i) the "Powered by TimeTrex" logo and
- *    (ii) the TimeTrex copyright notice
- * in the same form as they appear in the distribution.  See full license for
- * requirements.
+ * This program is free software; you can redistribute it and/or modify it under
+ * the terms of the GNU Affero General Public License version 3 as published by
+ * the Free Software Foundation with the addition of the following permission
+ * added to Section 15 as permitted in Section 7(a): FOR ANY PART OF THE COVERED
+ * WORK IN WHICH THE COPYRIGHT IS OWNED BY TIMETREX, TIMETREX DISCLAIMS THE
+ * WARRANTY OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
  *
- * The Original Code is: TimeTrex Open Source
- * The Initial Developer of the Original Code is TimeTrex Payroll Services
- * Portions created by TimeTrex are Copyright (C) 2004-2007 TimeTrex Payroll Services;
- * All Rights Reserved.
+ * This program is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+ * FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
+ * details.
  *
+ * You should have received a copy of the GNU Affero General Public License along
+ * with this program; if not, see http://www.gnu.org/licenses or write to the Free
+ * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+ * 02110-1301 USA.
+ *
+ * You can contact TimeTrex headquarters at Unit 22 - 2475 Dobbin Rd. Suite
+ * #292 Westbank, BC V4T 2E9, Canada or at email address info@timetrex.com.
+ *
+ * The interactive user interfaces in modified source and object code versions
+ * of this program must display Appropriate Legal Notices, as required under
+ * Section 5 of the GNU Affero General Public License version 3.
+ *
+ * In accordance with Section 7(b) of the GNU Affero General Public License
+ * version 3, these Appropriate Legal Notices must retain the display of the
+ * "Powered by TimeTrex" logo. If the display of the logo is not reasonably
+ * feasible for technical reasons, the Appropriate Legal Notices must display
+ * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2158 $
- * $Id: RecurringHolidayFactory.class.php 2158 2008-09-15 23:26:15Z ipso $
- * $Date: 2008-09-15 16:26:15 -0700 (Mon, 15 Sep 2008) $
+ * $Revision: 2707 $
+ * $Id: RecurringHolidayFactory.class.php 2707 2009-08-06 22:48:08Z ipso $
+ * $Date: 2009-08-06 15:48:08 -0700 (Thu, 06 Aug 2009) $
  */
 
 /**
@@ -51,8 +64,8 @@ class RecurringHolidayFactory extends Factory {
 			case 'type':
 				$retval = array(
 										10 => TTi18n::gettext('Static'),
-										20 => TTi18n::gettext('Dynamic - Week Interval'),
-										30 => TTi18n::gettext('Dynamic - Pivot Day')
+										20 => TTi18n::gettext('Dynamic: Week Interval'),
+										30 => TTi18n::gettext('Dynamic: Pivot Day')
 									);
 				break;
 			case 'week_interval':
@@ -73,12 +86,54 @@ class RecurringHolidayFactory extends Factory {
 										40 => TTi18n::gettext('On or After'),
 									);
 				break;
+			case 'columns':
+				$retval = array(
+										'-1010-name' => TTi18n::gettext('Name'),
+										'-1020-next_date' => TTi18n::gettext('Next Date'),
 
+										'-2000-created_by' => TTi18n::gettext('Created By'),
+										'-2010-created_date' => TTi18n::gettext('Created Date'),
+										'-2020-updated_by' => TTi18n::gettext('Updated By'),
+										'-2030-updated_date' => TTi18n::gettext('Updated Date'),
+							);
+				break;
+			case 'default_display_columns': //Columns that are displayed by default.
+				$retval = array(
+								'name',
+								'next_date',
+								);
+				break;
+			case 'unique_columns': //Columns that are unique, and disabled for mass editing.
+				$retval = array(
+								'name',
+								);
+				break;
+			case 'linked_columns': //Columns that are linked together, mainly for Mass Edit, if one changes, they all must.
+				$retval = array(
+								);
+				break;
 		}
 
 		return $retval;
 	}
 
+	function _getVariableToFunctionMap() {
+		$variable_function_map = array(
+										'id' => 'ID',
+										'company_id' => 'Company',
+										'special_day' => 'SpecialDay',
+										'type_id' => 'Type',
+										'pivot_day_direction_id' => 'PivotDayDirection',
+										'name' => 'Name',
+										'week_interval' => 'WeekInterval',
+										'day_of_week' => 'DayOfWeek',
+										'day_of_month' => 'DayOfMonth',
+										'month_int' => 'Month',
+										'next_date' => 'NextDate',
+										'deleted' => 'Deleted',
+										);
+		return $variable_function_map;
+	}
 
 	function getCompanyObject() {
 		if ( is_object($this->company_obj) ) {
@@ -118,8 +173,8 @@ class RecurringHolidayFactory extends Factory {
 	}
 
 	function getSpecialDay() {
-		if ( isset($this->data['easter']) ) {
-			return $this->data['easter'];
+		if ( isset($this->data['special_day']) ) {
+			return $this->data['special_day'];
 		}
 
 		return FALSE;
@@ -127,17 +182,12 @@ class RecurringHolidayFactory extends Factory {
 	function setSpecialDay($value) {
 		$value = trim($value);
 
-		$key = Option::getByValue($value, $this->getOptions('special_day') );
-		if ($key !== FALSE) {
-			$value = $key;
-		}
-
 		if ( $this->Validator->inArrayKey(	'special_day',
 											$value,
 											TTi18n::gettext('Incorrect Special Day'),
 											$this->getOptions('special_day')) ) {
 
-			$this->data['easter'] = $value;
+			$this->data['special_day'] = $value;
 
 			return FALSE;
 		}
@@ -183,12 +233,9 @@ class RecurringHolidayFactory extends Factory {
 	function setPivotDayDirection($value) {
 		$value = trim($value);
 
-		$key = Option::getByValue($value, $this->getOptions('pivot_day_direction') );
-		if ($key !== FALSE) {
-			$value = $key;
-		}
-
-		if ( $this->Validator->inArrayKey(	'pivot_day_direction',
+		if ( 	$value == 0
+				OR
+				$this->Validator->inArrayKey(	'pivot_day_direction',
 											$value,
 											TTi18n::gettext('Incorrect Pivot Day Direction'),
 											$this->getOptions('pivot_day_direction')) ) {
@@ -248,16 +295,7 @@ class RecurringHolidayFactory extends Factory {
 
 		return FALSE;
 	}
-/*
-	function getEaster() {
-		return $this->fromBool( $this->data['easter'] );
-	}
-	function setEaster($bool) {
-		$this->data['easter'] = $this->toBool($bool);
-
-		return true;
-	}
-*/
+	
 	function getWeekInterval() {
 		if ( isset($this->data['week_interval']) ) {
 			return (int)$this->data['week_interval'];
@@ -366,16 +404,21 @@ class RecurringHolidayFactory extends Factory {
 
 		if ( $this->getSpecialDay() == 1 OR $this->getSpecialDay() == 5) {
 			Debug::text('Easter Sunday Date...', __FILE__, __LINE__, __METHOD__, 10);
-			$easter_epoch = easter_date(date('Y', $epoch));
+
+			//Use easter_days() instead, as easter_date returns incorrect values for some timezones/years (2010 and US/Eastern on Windows)
+			//$easter_epoch = easter_date(date('Y', $epoch));
+			$easter_epoch = mktime( 12, 0, 0, 3, ( 21+easter_days( date('Y', $epoch) ) ), date('Y', $epoch) );
 
 			//Fix "cross-year" bug.
 			if ( $easter_epoch < $epoch ) {
-				$easter_epoch = easter_date(date('Y', $epoch)+1);
+				//$easter_epoch = easter_date(date('Y', $epoch)+1);
+				$easter_epoch = mktime( 12, 0, 0, 3, ( 21+easter_days( (date('Y', $epoch)+1) ) ), ( date('Y', $epoch)+1 ) );
 			}
 
 			if ( $this->getSpecialDay() == 1 ) {
 				Debug::text('Good Friday Date...', __FILE__, __LINE__, __METHOD__, 10);
-				$holiday_epoch = mktime(12,0,0,date('n',$easter_epoch),date('j',$easter_epoch) - 2, date('Y', $easter_epoch));
+				//$holiday_epoch = mktime(12,0,0,date('n',$easter_epoch),date('j',$easter_epoch) - 2, date('Y', $easter_epoch));
+				$holiday_epoch = $easter_epoch-(2*86400);
 			} else {
 				$holiday_epoch = $easter_epoch;
 			}
@@ -1617,6 +1660,60 @@ class RecurringHolidayFactory extends Factory {
 		return TRUE;
 	}
 
+	function setObjectFromArray( $data ) {
+		if ( is_array( $data ) ) {
+			$variable_function_map = $this->getVariableToFunctionMap();
+			foreach( $variable_function_map as $key => $function ) {
+				if ( isset($data[$key]) ) {
+
+					$function = 'set'.$function;
+					switch( $key ) {
+						default:
+							if ( method_exists( $this, $function ) ) {
+								$this->$function( $data[$key] );
+							}
+							break;
+					}
+				}
+			}
+
+			$this->setCreatedAndUpdatedColumns( $data );
+
+			return TRUE;
+		}
+
+		return FALSE;
+	}
+
+	function getObjectAsArray( $include_columns = NULL ) {
+		$variable_function_map = $this->getVariableToFunctionMap();
+		if ( is_array( $variable_function_map ) ) {
+			foreach( $variable_function_map as $variable => $function_stub ) {
+				if ( $include_columns == NULL OR ( isset($include_columns[$variable]) AND $include_columns[$variable] == TRUE ) ) {
+
+					$function = 'get'.$function_stub;
+					switch( $variable ) {
+						case 'status':
+							$function = 'get'.$variable;
+							if ( method_exists( $this, $function ) ) {
+								$data[$variable] = Option::getByKey( $this->$function(), $this->getOptions( $variable ) );
+							}
+							break;
+						default:
+							if ( method_exists( $this, $function ) ) {
+								$data[$variable] = $this->$function();
+							}
+							break;
+					}
+
+				}
+			}
+			$this->getCreatedAndUpdatedColumns( &$data, $include_columns );
+		}
+
+		return $data;
+	}
+
 	function addLog( $log_action ) {
 		return TTLog::addEntry( $this->getId(), $log_action,  TTi18n::getText('Recurring Holiday'), NULL, $this->getTable() );
 	}
