@@ -1,29 +1,42 @@
 <?php
 /*********************************************************************************
- * The contents of this file are subject to the TimeTrex Public License Version
- * 1.1.0 ("License"); You may not use this file except in compliance with the
- * License. You may obtain a copy of the License at http://www.TimeTrex.com/TPL
- * Software distributed under the License is distributed on an "AS IS" basis,
- * WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the License
- * for the specific language governing rights and limitations under the
- * License.
+ * TimeTrex is a Payroll and Time Management program developed by
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
  *
- * All copies of the Covered Code must include on each user interface screen:
- *    (i) the "Powered by TimeTrex" logo and
- *    (ii) the TimeTrex copyright notice
- * in the same form as they appear in the distribution.  See full license for
- * requirements.
+ * This program is free software; you can redistribute it and/or modify it under
+ * the terms of the GNU Affero General Public License version 3 as published by
+ * the Free Software Foundation with the addition of the following permission
+ * added to Section 15 as permitted in Section 7(a): FOR ANY PART OF THE COVERED
+ * WORK IN WHICH THE COPYRIGHT IS OWNED BY TIMETREX, TIMETREX DISCLAIMS THE
+ * WARRANTY OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
  *
- * The Original Code is: TimeTrex Open Source
- * The Initial Developer of the Original Code is TimeTrex Payroll Services
- * Portions created by TimeTrex are Copyright (C) 2004-2007 TimeTrex Payroll Services;
- * All Rights Reserved.
+ * This program is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+ * FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
+ * details.
  *
+ * You should have received a copy of the GNU Affero General Public License along
+ * with this program; if not, see http://www.gnu.org/licenses or write to the Free
+ * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+ * 02110-1301 USA.
+ *
+ * You can contact TimeTrex headquarters at Unit 22 - 2475 Dobbin Rd. Suite
+ * #292 Westbank, BC V4T 2E9, Canada or at email address info@timetrex.com.
+ *
+ * The interactive user interfaces in modified source and object code versions
+ * of this program must display Appropriate Legal Notices, as required under
+ * Section 5 of the GNU Affero General Public License version 3.
+ *
+ * In accordance with Section 7(b) of the GNU Affero General Public License
+ * version 3, these Appropriate Legal Notices must retain the display of the
+ * "Powered by TimeTrex" logo. If the display of the logo is not reasonably
+ * feasible for technical reasons, the Appropriate Legal Notices must display
+ * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2237 $
- * $Id: Install.class.php 2237 2008-11-11 18:18:20Z ipso $
- * $Date: 2008-11-11 10:18:20 -0800 (Tue, 11 Nov 2008) $
+ * $Revision: 3021 $
+ * $Id: Install.class.php 3021 2009-11-11 23:33:03Z ipso $
+ * $Date: 2009-11-11 15:33:03 -0800 (Wed, 11 Nov 2009) $
  */
 
 /**
@@ -140,7 +153,7 @@ class Install {
 	}
 
 	function setDatabaseConnection( $db ) {
-		if ( is_object($db) AND is_resource($db->_connectionID) ) {
+		if ( is_object($db) AND ( is_resource($db->_connectionID) OR is_object($db->_connectionID) ) ) {
 			$this->temp_db = $db;
 			return TRUE;
 		}
@@ -148,7 +161,7 @@ class Install {
 		return FALSE;
 	}
 	function getDatabaseConnection() {
-		if ( isset($this->temp_db) AND is_resource($this->temp_db->_connectionID) ) {
+		if ( isset($this->temp_db) AND ( is_resource($this->temp_db->_connectionID) OR is_object($this->temp_db->_connectionID)  ) ) {
 			return $this->temp_db;
 		}
 
@@ -168,7 +181,8 @@ class Install {
 				$db->debug=TRUE;
 			}
 
-			if ( is_resource($db->_connectionID) ) {
+			//MySQLi extension uses an object, not a resource.
+			if ( is_resource($db->_connectionID) OR is_object($db->_connectionID) ) {
 				$this->setDatabaseConnection( $db );
 
 				//$this->temp_db = $db;
@@ -480,7 +494,7 @@ class Install {
 		Debug::text('Comparing with Version: '. $php_version, __FILE__, __LINE__, __METHOD__,9);
 
 		$min_version = '5.0.0';
-		$max_version = '5.2.99';
+		$max_version = '5.3.99';
 
 		$unsupported_versions = array('');
 
@@ -596,11 +610,11 @@ class Install {
 			// changes all date columns to timestamp columns and breaks TimeTrex.
 			$retval['enterprisedb'] = 'EnterpriseDB (DISABLE edb_redwood_date)';
 		}
-		if ( function_exists('mysql_connect') ) {
-			$retval['mysqlt'] = 'MySQL (w/InnoDB)';
-		}
 		if ( function_exists('mysqli_real_connect') ) {
-			$retval['mysqli'] = 'MySQLi (v4.1.3+ w/InnoDB)';
+			$retval['mysqli'] = 'MySQLi (v5.0.48+ w/InnoDB)';
+		}
+		if ( function_exists('mysql_connect') ) {
+			$retval['mysqlt'] = 'MySQL (Legacy Driver w/InnoDB)';
 		}
 
 		return $retval;
@@ -857,18 +871,16 @@ class Install {
 	}
 
 	function checkCleanCacheDirectory() {
-		$raw_cache_files = scandir( $this->config_vars['cache']['dir'] );
+		if ( DEPLOYMENT_ON_DEMAND == FALSE ) {
+			$raw_cache_files = scandir( $this->config_vars['cache']['dir'] );
 
-		if ( is_array($raw_cache_files) AND count($raw_cache_files) > 0 ) {
-			foreach( $raw_cache_files as $cache_file ) {
-				if ( $cache_file != '.' AND $cache_file != '..' ) {
-					$cache_files[] = $cache_file;
+			if ( is_array($raw_cache_files) AND count($raw_cache_files) > 0 ) {
+				foreach( $raw_cache_files as $cache_file ) {
+					if ( $cache_file != '.' AND $cache_file != '..' AND stristr( $cache_file, '.lock') === FALSE ) {
+						return 1;
+					}
 				}
 			}
-
-			if ( isset($cache_files) AND is_array($cache_files) AND count($cache_files) > 0 ) {
-				return 1;
-			}
 		}
 
 		return 0;
@@ -968,13 +980,6 @@ class Install {
 		$retarr[$this->checkPEAR()]++;
 
 		//PEAR modules are bundled as of v1.2.0
-		/*
-		$retarr[$this->checkPEARHTML_Progress()]++;
-		$retarr[$this->checkPEARHTTP_Download()]++;
-		$retarr[$this->checkPEARHTML_AJAX()]++;
-		$retarr[$this->checkPEARMail()]++;
-		$retarr[$this->checkPEARMail_Mime()]++;
-		*/
 		if ( $post_install_requirements_only == FALSE ) {
 			$retarr[$this->checkWritableConfigFile()]++;
 			$retarr[$this->checkWritableCacheDirectory()]++;
@@ -988,12 +993,6 @@ class Install {
 		$retarr[$this->checkPHPMagicQuotesGPC()]++;
 
 		if ( $this->getTTProductEdition() == TT_PRODUCT_PROFESSIONAL ) {
-			/*
-			$retarr[$this->checkPEARValidate()]++;
-			$retarr[$this->checkPEARValidate_Finance()]++;
-			$retarr[$this->checkPEARValidate_Finance_CreditCard()]++;
-			$retarr[$this->checkPEARNET_Curl()]++;
-			*/
 			$retarr[$this->checkMCRYPT()]++;
 		}
 
@@ -1003,7 +1002,7 @@ class Install {
 			return 1;
 		} elseif ( $retarr[2] > 0 ) {
 			return 2;
-		} elseif ( $retarr[1] > 0 ) {
+		} else {
 			return 0;
 		}
 	}
@@ -1057,25 +1056,6 @@ class Install {
 			$retarr[] = 'PEAR';
 		}
 
-		/*
-		//PEAR modules are bundled as of v1.2.0
-		if ( $fail_all == TRUE OR $this->checkPEARHTML_Progress() != 0 ) {
-			$retarr[] = 'PEARHTML_Progress';
-		}
-		if ( $fail_all == TRUE OR $this->checkPEARHTTP_Download() != 0 ) {
-			$retarr[] = 'PEARHTTP_Download';
-		}
-		if ( $fail_all == TRUE OR $this->checkPEARHTML_AJAX() != 0 ) {
-			$retarr[] = 'PEARHTML_AJAX';
-		}
-		if ( $fail_all == TRUE OR $this->checkPEARMail() != 0 ) {
-			$retarr[] = 'PEARMail';
-		}
-		if ( $fail_all == TRUE OR $this->checkPEARMail_Mime() != 0 ) {
-			$retarr[] = 'PEARMail_Mime';
-		}
-		*/
-
 		if ( $post_install_requirements_only == FALSE ) {
 			if ( $fail_all == TRUE OR $this->checkWritableConfigFile() != 0 ) {
 				$retarr[] = 'WConfigFile';
