@@ -1,29 +1,42 @@
 <?php
 /*********************************************************************************
- * The contents of this file are subject to the TimeTrex Public License Version
- * 1.1.0 ("License"); You may not use this file except in compliance with the
- * License. You may obtain a copy of the License at http://www.TimeTrex.com/TPL
- * Software distributed under the License is distributed on an "AS IS" basis,
- * WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the License
- * for the specific language governing rights and limitations under the
- * License.
+ * TimeTrex is a Payroll and Time Management program developed by
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
  *
- * All copies of the Covered Code must include on each user interface screen:
- *    (i) the "Powered by TimeTrex" logo and
- *    (ii) the TimeTrex copyright notice
- * in the same form as they appear in the distribution.  See full license for
- * requirements.
+ * This program is free software; you can redistribute it and/or modify it under
+ * the terms of the GNU Affero General Public License version 3 as published by
+ * the Free Software Foundation with the addition of the following permission
+ * added to Section 15 as permitted in Section 7(a): FOR ANY PART OF THE COVERED
+ * WORK IN WHICH THE COPYRIGHT IS OWNED BY TIMETREX, TIMETREX DISCLAIMS THE
+ * WARRANTY OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
  *
- * The Original Code is: TimeTrex Open Source
- * The Initial Developer of the Original Code is TimeTrex Payroll Services
- * Portions created by TimeTrex are Copyright (C) 2004-2007 TimeTrex Payroll Services;
- * All Rights Reserved.
+ * This program is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+ * FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
+ * details.
  *
+ * You should have received a copy of the GNU Affero General Public License along
+ * with this program; if not, see http://www.gnu.org/licenses or write to the Free
+ * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+ * 02110-1301 USA.
+ *
+ * You can contact TimeTrex headquarters at Unit 22 - 2475 Dobbin Rd. Suite
+ * #292 Westbank, BC V4T 2E9, Canada or at email address info@timetrex.com.
+ *
+ * The interactive user interfaces in modified source and object code versions
+ * of this program must display Appropriate Legal Notices, as required under
+ * Section 5 of the GNU Affero General Public License version 3.
+ *
+ * In accordance with Section 7(b) of the GNU Affero General Public License
+ * version 3, these Appropriate Legal Notices must retain the display of the
+ * "Powered by TimeTrex" logo. If the display of the logo is not reasonably
+ * feasible for technical reasons, the Appropriate Legal Notices must display
+ * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2308 $
- * $Id: PayStubAmendmentFactory.class.php 2308 2008-12-22 23:06:24Z ipso $
- * $Date: 2008-12-22 15:06:24 -0800 (Mon, 22 Dec 2008) $
+ * $Revision: 3199 $
+ * $Id: PayStubAmendmentFactory.class.php 3199 2009-12-20 23:37:45Z ipso $
+ * $Date: 2009-12-20 15:37:45 -0800 (Sun, 20 Dec 2009) $
  */
 
 /**
@@ -224,10 +237,10 @@ class PayStubAmendmentFactory extends Factory {
 	function setEffectiveDate($epoch) {
 		$epoch = trim($epoch);
 
-		//Add 12 hours to effective date, because we won't want it to be a
-		//day boundary and have issues with pay period end date.
-		//We've fixed the pay period boundary issues I think so this is no longer needed.
-		//$epoch = TTDate::getBeginDayEpoch( $epoch ) + (43200-1);
+		//Adjust effective date, because we won't want it to be a
+		//day boundary and have issues with pay period start/end dates.
+		//Although with employees in timezones that differ from the pay period timezones, there can still be issues.
+		$epoch = TTDate::getMiddleDayEpoch( $epoch );
 
 		if 	(	$this->Validator->isDate(		'effective_date',
 												$epoch,
@@ -318,7 +331,8 @@ class PayStubAmendmentFactory extends Factory {
 														) ) {
 			Debug::text('Setting Rate to: '. $value, __FILE__, __LINE__, __METHOD__,10);
 			//Must round to 2 decimals otherwise discreptancy can occur when generating pay stubs.
-			$this->data['rate'] = Misc::MoneyFormat( $value, FALSE );
+			//$this->data['rate'] = Misc::MoneyFormat( $value, FALSE );
+			$this->data['rate'] = $value;
 
 			return TRUE;
 		}
@@ -346,7 +360,8 @@ class PayStubAmendmentFactory extends Factory {
 														TTi18n::gettext('Invalid Units')
 														) ) {
 			//Must round to 2 decimals otherwise discreptancy can occur when generating pay stubs.
-			$this->data['units'] = Misc::MoneyFormat( $value, FALSE );
+			//$this->data['units'] = Misc::MoneyFormat( $value, FALSE );
+			$this->data['units'] = $value;
 
 			return TRUE;
 		}
@@ -425,7 +440,7 @@ class PayStubAmendmentFactory extends Factory {
 
 		$retval = bcadd($type_amount_arr['amount'], $amount_arr['amount'] );
 
-		Debug::text('Type Amount: '. $type_amount_arr['amount'] .' Regular Amount: '. $amount_arr['amount'] .' Total: '. $retval .' YTD/Balance Amount: '. $amount_arr['ytd_amount'], __FILE__, __LINE__, __METHOD__, 10);
+		Debug::text('Type Amount: '. $type_amount_arr['amount'] .' Regular Amount: '. $amount_arr['amount'] .' Total: '. $retval, __FILE__, __LINE__, __METHOD__, 10);
 
 		return $retval;
 	}
@@ -454,7 +469,7 @@ class PayStubAmendmentFactory extends Factory {
 				unset($pay_stub_entry_account, $previous_pay_stub_amount_arr);
 
 				Debug::text('Pay Stub Amendment Total Amount: '. $ps_amendment_percent_amount .' Percent Amount: '. $this->getPercentAmount(), __FILE__, __LINE__, __METHOD__,10);
-				if ( $ps_amendment_percent_amount > 0 AND $this->getPercentAmount() > 0 ) {
+				if ( $ps_amendment_percent_amount != 0 AND $this->getPercentAmount() != 0 ) { //Allow negative values.
 					$amount = bcmul($ps_amendment_percent_amount, bcdiv($this->getPercentAmount(), 100) );
 
 					return $amount;
@@ -567,7 +582,7 @@ class PayStubAmendmentFactory extends Factory {
 												2,
 												100) ) {
 
-			$this->data['description'] = htmlentities( $text );
+			$this->data['description'] = htmlspecialchars( $text );
 
 			return TRUE;
 		}
