@@ -1,29 +1,42 @@
 <?php
 /*********************************************************************************
- * The contents of this file are subject to the TimeTrex Public License Version
- * 1.1.0 ("License"); You may not use this file except in compliance with the
- * License. You may obtain a copy of the License at http://www.TimeTrex.com/TPL
- * Software distributed under the License is distributed on an "AS IS" basis,
- * WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the License
- * for the specific language governing rights and limitations under the
- * License.
+ * TimeTrex is a Payroll and Time Management program developed by
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
  *
- * All copies of the Covered Code must include on each user interface screen:
- *    (i) the "Powered by TimeTrex" logo and
- *    (ii) the TimeTrex copyright notice
- * in the same form as they appear in the distribution.  See full license for
- * requirements.
+ * This program is free software; you can redistribute it and/or modify it under
+ * the terms of the GNU Affero General Public License version 3 as published by
+ * the Free Software Foundation with the addition of the following permission
+ * added to Section 15 as permitted in Section 7(a): FOR ANY PART OF THE COVERED
+ * WORK IN WHICH THE COPYRIGHT IS OWNED BY TIMETREX, TIMETREX DISCLAIMS THE
+ * WARRANTY OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
  *
- * The Original Code is: TimeTrex Open Source
- * The Initial Developer of the Original Code is TimeTrex Payroll Services
- * Portions created by TimeTrex are Copyright (C) 2004-2007 TimeTrex Payroll Services;
- * All Rights Reserved.
+ * This program is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+ * FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
+ * details.
  *
+ * You should have received a copy of the GNU Affero General Public License along
+ * with this program; if not, see http://www.gnu.org/licenses or write to the Free
+ * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+ * 02110-1301 USA.
+ *
+ * You can contact TimeTrex headquarters at Unit 22 - 2475 Dobbin Rd. Suite
+ * #292 Westbank, BC V4T 2E9, Canada or at email address info@timetrex.com.
+ *
+ * The interactive user interfaces in modified source and object code versions
+ * of this program must display Appropriate Legal Notices, as required under
+ * Section 5 of the GNU Affero General Public License version 3.
+ *
+ * In accordance with Section 7(b) of the GNU Affero General Public License
+ * version 3, these Appropriate Legal Notices must retain the display of the
+ * "Powered by TimeTrex" logo. If the display of the logo is not reasonably
+ * feasible for technical reasons, the Appropriate Legal Notices must display
+ * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2453 $
- * $Id: PayPeriodScheduleFactory.class.php 2453 2009-03-20 16:34:04Z ipso $
- * $Date: 2009-03-20 09:34:04 -0700 (Fri, 20 Mar 2009) $
+ * $Revision: 3199 $
+ * $Id: PayPeriodScheduleFactory.class.php 3199 2009-12-20 23:37:45Z ipso $
+ * $Date: 2009-12-20 15:37:45 -0800 (Sun, 20 Dec 2009) $
  */
 
 /**
@@ -60,15 +73,80 @@ class PayPeriodScheduleFactory extends Factory {
 											4 => TTi18n::gettext('Thursday-Wednesday'),
 											5 => TTi18n::gettext('Friday-Thursday'),
 											6 => TTi18n::gettext('Saturday-Friday'),
-
 										);
 				break;
+			case 'shift_assigned_day':
+				$retval = array(
+											10 => TTi18n::gettext('Day They Start On'),
+											20 => TTi18n::gettext('Day They End On'),
+											30 => TTi18n::gettext('Day w/Most Time Worked'),
+											40 => TTi18n::gettext('Each Day (Split at Midnight)'),
+										);
+				break;
+			case 'transaction_date_business_day':
+				$retval = array(
+											//Adjust Transaction Date To:
+											0 => TTi18n::gettext('No'),
+											1 => TTi18n::gettext('Yes - Previous Business Day'),
+											2 => TTi18n::gettext('Yes - Next Business Day'),
+											3 => TTi18n::gettext('Yes - Closest Business Day'),
+										);
+				break;
+			case 'columns':
+				$retval = array(
+										'-1010-type_id' => TTi18n::gettext('Type'),
+										'-1020-name' => TTi18n::gettext('Name'),
+										'-1030-description' => TTi18n::gettext('Description'),
+										'-1040-shift_assigned_day_id' => TTi18n::gettext('Assign Shifts To'),
+										'-1050-time_zone' => TTi18n::gettext('TimeZone'),
+										'-1060-new_day_trigger_time' => TTi18n::gettext('Minimum Time Off Between Shifts'),
+										'-1070-maximum_shift_time' => TTi18n::gettext('Maximum Shift Time'),
+
+										'-2000-created_by' => TTi18n::gettext('Created By'),
+										'-2010-created_date' => TTi18n::gettext('Created Date'),
+										'-2020-updated_by' => TTi18n::gettext('Updated By'),
+										'-2030-updated_date' => TTi18n::gettext('Updated Date'),
+							);
+				break;
+			case 'default_display_columns': //Columns that are displayed by default.
+				$retval = array(
+								'type',
+								'name',
+								'description',
+								);
+				break;
 
 		}
 
 		return $retval;
 	}
 
+	function _getVariableToFunctionMap() {
+		$variable_function_map = array(
+										'id' => 'ID',
+										'company_id' => 'Company',
+										'type_id' => 'Type',
+										'start_week_day_id' => 'StartWeekDay',
+										'shift_assigned_day_id' => 'ShiftAssignedDay',
+										'name' => 'Name',
+										'description' => 'Description',
+										'start_day_of_week' => 'StartDayOfWeek',
+										'transaction_date' => 'TransactionDate',
+										'primary_day_of_month' => 'PrimaryDayOfMonth',
+										'secondary_day_of_month' => 'SecondaryDayOfMonth',
+										'primary_transaction_day_of_month' => 'PrimaryTransactionDayOfMonth',
+										'secondary_transaction_day_of_month' => 'SecondaryTransactionDayOfMonth',
+										'transaction_date_bd' => 'TransactionDateBusinessDay',
+										'anchor_date' => 'AnchorDate',
+										'day_start_time' => 'DayStartTime',
+										'time_zone' => 'TimeZone',
+										'day_continuous_time' => 'ContinuousTime',
+										'new_day_trigger_time' => 'NewDayTriggerTime',
+										'maximum_shift_time' => 'MaximumShiftTime',
+										'deleted' => 'Deleted',
+										);
+		return $variable_function_map;
+	}
 
 	function getCompany() {
 		return $this->data['company_id'];
@@ -145,6 +223,29 @@ class PayPeriodScheduleFactory extends Factory {
 		return FALSE;
 	}
 
+	function getShiftAssignedDay() {
+		if ( isset($this->data['shift_assigned_day_id']) ) {
+			return $this->data['shift_assigned_day_id'];
+		}
+
+		return FALSE;
+	}
+	function setShiftAssignedDay($val) {
+		$val = trim($val);
+
+		if ( $this->Validator->inArrayKey(	'shift_assigned_day_id',
+											$val,
+											TTi18n::gettext('Incorrect Shift Assigned Day'),
+											$this->getOptions('shift_assigned_day')) ) {
+
+			$this->data['shift_assigned_day_id'] = $val;
+
+			return TRUE;
+		}
+
+		return FALSE;
+	}
+
 	function isUniqueName($name) {
 		$ph = array(
 					'company_id' => $this->getCompany(),
@@ -391,6 +492,28 @@ class PayPeriodScheduleFactory extends Factory {
 		return FALSE;
 	}
 
+	function getTransactionDateBusinessDay() {
+		if ( isset($this->data['transaction_date_bd']) ) {
+			return (int)$this->data['transaction_date_bd'];
+		}
+		return FALSE;
+	}
+	function setTransactionDateBusinessDay($int) {
+		$int = (int)$int;
+
+		if ( $this->Validator->inArrayKey(	'transaction_date_bd',
+											$int,
+											TTi18n::gettext('Incorrect transaction date adjustment'),
+											$this->getOptions('transaction_date_business_day') ) ) {
+
+			$this->data['transaction_date_bd'] = $int;
+
+			return TRUE;
+		}
+
+		return FALSE;
+	}
+/*
 	function getTransactionDateBusinessDay() {
 		if ( isset($this->data['transaction_date_bd']) ) {
 			return $this->fromBool( $this->data['transaction_date_bd'] );
@@ -403,7 +526,7 @@ class PayPeriodScheduleFactory extends Factory {
 
 		return true;
 	}
-
+*/
 	function getAnchorDate( $raw = FALSE ) {
 		if ( isset($this->data['anchor_date']) ) {
 			if ( $raw === TRUE ) {
@@ -562,6 +685,99 @@ class PayPeriodScheduleFactory extends Factory {
 		return FALSE;
 	}
 
+	function getAnnualPayPeriods() {
+		if ( isset($this->data['annual_pay_periods']) ) {
+			return (int)$this->data['annual_pay_periods'];
+		}
+		return FALSE;
+	}
+	function setAnnualPayPeriods($int) {
+		$int = (int)$int;
+
+		if 	(	$this->Validator->isNumeric(		'annual_pay_periods',
+													$int,
+													TTi18n::gettext('Incorrect Annual Pay Periods')) ) {
+			$this->data['annual_pay_periods'] = $int;
+
+			return TRUE;
+		}
+
+		return FALSE;
+	}
+
+	function getTimeSheetVerifyBeforeEndDate() {
+		if ( isset($this->data['timesheet_verify_before_end_date']) ) {
+			return (int)$this->data['timesheet_verify_before_end_date'];
+		}
+		return FALSE;
+	}
+	function setTimeSheetVerifyBeforeEndDate($int) {
+		$int = (int)$int;
+
+		if 	(	$this->Validator->isNumeric(		'timesheet_verify_before_end_date',
+													$int,
+													TTi18n::gettext('Incorrect value for timesheet verification before/after end date')) ) {
+			$this->data['timesheet_verify_before_end_date'] = $int;
+
+			return TRUE;
+		}
+
+		return FALSE;
+	}
+
+	function getTimeSheetVerifyBeforeTransactionDate() {
+		if ( isset($this->data['timesheet_verify_before_transaction_date']) ) {
+			return (int)$this->data['timesheet_verify_before_transaction_date'];
+		}
+		return FALSE;
+	}
+	function setTimeSheetVerifyBeforeTransactionDate($int) {
+		$int = (int)$int;
+
+		if 	(	$this->Validator->isNumeric(		'timesheet_verify_before_transaction_date',
+													$int,
+													TTi18n::gettext('Incorrect value for timesheet verification before/after transaction date')) ) {
+			$this->data['timesheet_verify_before_transaction_date'] = $int;
+
+			return TRUE;
+		}
+
+		return FALSE;
+	}
+
+	function getTimeSheetVerifyNoticeBeforeTransactionDate() {
+		if ( isset($this->data['timesheet_verify_notice_before_transaction_date']) ) {
+			return (int)$this->data['timesheet_verify_notice_before_transaction_date'];
+		}
+		return FALSE;
+	}
+	function setTimeSheetVerifyNoticeBeforeTransactionDate($int) {
+		$int = (int)$int;
+
+		if 	(	$this->Validator->isNumeric(		'timesheet_verify_notice_before_transaction_date',
+													$int,
+													TTi18n::gettext('Incorrect value for timesheet verification notice before/after transaction date')) ) {
+			$this->data['timesheet_verify_notice_before_transaction_date'] = $int;
+
+			return TRUE;
+		}
+
+		return FALSE;
+	}
+
+	function getTimeSheetVerifyNoticeEmail() {
+		if ( isset($this->data['timesheet_verify_notice_email']) ) {
+			return $this->fromBool( $this->data['timesheet_verify_notice_email'] );
+		}
+
+		return FALSE;
+	}
+	function setTimeSheetVerifyNoticeEmail($bool) {
+		$this->data['timesheet_verify_notice_email'] = $this->toBool($bool);
+
+		return true;
+	}
+
 	function getUser() {
 		$ppsulf = new PayPeriodScheduleUserListFactory();
 		$ppsulf->getByPayPeriodScheduleId( $this->getId() );
@@ -624,6 +840,67 @@ class PayPeriodScheduleFactory extends Factory {
 		return FALSE;
 	}
 
+	function getTransactionBusinessDay( $epoch ) {
+		Debug::Text('Epoch: '. TTDate::getDate('DATE+TIME', $epoch ), __FILE__, __LINE__, __METHOD__, 10);
+
+		$holiday_epochs = array();
+
+		$user_ids = $this->getUser();
+
+		if ( count($user_ids) > 0 ) {
+			$hlf = new HolidayListFactory();
+			$hlf->getByPolicyGroupUserIdAndStartDateAndEndDate( $user_ids, $epoch-(86400*14), $epoch+(86400*2) );
+			if ( $hlf->getRecordCount() > 0 ) {
+				foreach( $hlf as $h_obj ) {
+					Debug::Text('Found Holiday Epoch: '. TTDate::getDate('DATE+TIME', $h_obj->getDateStamp() ) .' Name: '. $h_obj->getName() , __FILE__, __LINE__, __METHOD__, 10);
+					$holiday_epochs[] = $h_obj->getDateStamp();
+				}
+
+				//Debug::Arr($holiday_epochs, 'Holiday Epochs: ', __FILE__, __LINE__, __METHOD__, 10);
+			}
+
+			while( TTDate::isWeekDay($epoch) == FALSE OR in_array( TTDate::getBeginDayEpoch( $epoch ), $holiday_epochs) ) {
+				Debug::text('<b>FOUND WeekDay/HOLIDAY!</b>', __FILE__, __LINE__, __METHOD__, 10);
+				switch ( $this->getTransactionDateBusinessDay() ) {
+					case 0: //No adjustment
+						break 2;
+					case 1: //Previous day
+						$epoch -= 86400;
+						break;
+					case 2: //Next day
+						$epoch += 86400;
+						break;
+					case 3: //Closest day
+						$forward_epoch = $epoch;
+						$forward_days = 0;
+						while( TTDate::isWeekDay($forward_epoch) == FALSE OR in_array( TTDate::getBeginDayEpoch( $forward_epoch ), $holiday_epochs) ) {
+							$forward_epoch += 86400;
+							$forward_days++;
+						}
+
+						$backward_epoch = $epoch;
+						$backward_days = 0;
+						while( TTDate::isWeekDay($backward_epoch) == FALSE OR in_array( TTDate::getBeginDayEpoch( $backward_epoch ), $holiday_epochs) ) {
+							$backward_epoch -= 86400;
+							$backward_days++;
+						}
+
+						if ( $backward_days <= $forward_days ) {
+							$epoch = $backward_epoch;
+						} else {
+							$epoch = $forward_epoch;
+						}
+						break;
+				}
+
+			}
+
+		}
+
+		return $epoch;
+	}
+
+/*
 	function getPreviousBusinessDay($epoch) {
 
 		Debug::Text('Epoch: '. TTDate::getDate('DATE+TIME', $epoch ), __FILE__, __LINE__, __METHOD__, 10);
@@ -653,7 +930,7 @@ class PayPeriodScheduleFactory extends Factory {
 
 		return $epoch;
 	}
-
+*/
 	function getNextPayPeriod($end_date = NULL) {
 		if ( !$this->Validator->isValid() ) {
 			return FALSE;
@@ -798,9 +1075,9 @@ class PayPeriodScheduleFactory extends Factory {
 				break;
 			case 50: //Monthly
 				$start_date = $last_pay_period_end_date+1;
-				$end_date = TTDate::getDateOfNextDayOfMonth( $start_date+86400, NULL, $this->convertLastDayOfMonth( $this->getPrimaryDayOfMonth() ) );
 
 				//Use Begin Day Epoch to nullify DST issues.
+				$end_date = TTDate::getDateOfNextDayOfMonth( TTDate::getBeginDayEpoch( $start_date+(86400+3600) ), NULL, $this->convertLastDayOfMonth( $this->getPrimaryDayOfMonth() ) );
 				$end_date = TTDate::getBeginDayEpoch( TTDate::getBeginMinuteEpoch($end_date) )-1;
 
 				$transaction_date = TTDate::getMiddleDayEpoch( TTDate::getDateOfNextDayOfMonth( $end_date, NULL, $this->convertLastDayOfMonth( $this->getPrimaryTransactionDayOfMonth() ) ) );
@@ -861,7 +1138,7 @@ class PayPeriodScheduleFactory extends Factory {
 
 		//Handle "always business day" flag for transaction dates here.
 		if ( $this->getTransactionDateBusinessDay() == TRUE ) {
-			$transaction_date = $this->getPreviousBusinessDay($transaction_date);
+			$transaction_date = $this->getTransactionBusinessDay($transaction_date);
 		}
 
 		if ( $transaction_date < $end_date ) {
@@ -910,8 +1187,6 @@ class PayPeriodScheduleFactory extends Factory {
 		Debug::text('End Date ('. $end_date.'): '. TTDate::getDate('DATE+TIME', $end_date ), __FILE__, __LINE__, __METHOD__,10);
 
 		$this->getNextPayPeriod($end_date);
-		var_dump( $this );
-		Debug::Display();
 
 		Debug::text('Next pay period starts: '. TTDate::getDate('DATE+TIME', $this->getNextStartDate() ), __FILE__, __LINE__, __METHOD__,10);
 
@@ -1069,7 +1344,7 @@ class PayPeriodScheduleFactory extends Factory {
 		return $retval;
 	}
 
-	function getAnnualPayPeriods() {
+	function calcAnnualPayPeriods() {
 		switch ( $this->getType() ) {
 			case 5:
 				//We need the annual number of pay periods calculated for manual pay period schedules if we
@@ -1117,6 +1392,224 @@ class PayPeriodScheduleFactory extends Factory {
 		return $retval;
 	}
 
+	//Returns shift data according to the pay period schedule criteria for use
+	//in determining which day punches belong to.
+	function getShiftData( $user_date_id = NULL, $user_id = NULL, $epoch = NULL, $filter = NULL, $tmp_punch_control_obj = NULL ) {
+		global $profiler;
+		$profiler->startTimer( 'PayPeriodScheduleFactory::getShiftData()' );
+
+		if ( is_numeric($user_date_id) AND $user_date_id > 0 ) {
+			$user_id = $epoch = NULL;
+		}
+
+		if ( $user_date_id == '' AND $user_id == '' AND $epoch == '' ) {
+			return FALSE;
+		}
+
+		//Debug::text('User Date ID: '. $user_date_id .' User ID: '. $user_id .' TimeStamp: '. TTDate::getDate('DATE+TIME', $epoch), __FILE__, __LINE__, __METHOD__, 10);
+		$new_shift_trigger_time = $this->getNewDayTriggerTime();
+
+		$plf = new PunchListFactory();
+		if ( $user_date_id != '' ) {
+			$plf->getByUserDateId( $user_date_id );
+		} else {
+			//Get punches by time stamp.
+			$punch_control_id = 0;
+			if ( is_object( $tmp_punch_control_obj ) ) {
+				$punch_control_id = $tmp_punch_control_obj->getId();
+			}
+			$plf->getShiftPunchesByUserIDAndEpoch( $user_id, $epoch, $punch_control_id, $this->getMaximumShiftTime() );
+			unset($punch_control_id);
+		}
+
+		Debug::text('Punch Rows: '. $plf->getRecordCount() .' UserID: '. $user_id .' Date: '. TTDate::getDate('DATE+TIME', $epoch) .'('.$epoch.') MaximumShiftTime: '. $this->getMaximumShiftTime(), __FILE__, __LINE__, __METHOD__, 10);
+
+		if ( $plf->getRecordCount() > 0 ) {
+			$shift = 0;
+			$i = 0;
+			$nearest_shift_id = 0;
+			$nearest_punch_difference = FALSE;
+			$prev_punch_obj = FALSE;
+			foreach( $plf as $p_obj ) {
+				//Debug::text('Shift: '. $shift .' Punch ID: '. $p_obj->getID() .' Punch Control ID: '. $p_obj->getPunchControlID() .' TimeStamp: '. TTDate::getDate('DATE+TIME', $p_obj->getTimeStamp() ), __FILE__, __LINE__, __METHOD__, 10);
+
+				//If we're editing a punch, we need to use the object passed to this function instead of the one
+				//from the database.
+
+				if ( $epoch == NULL ) { //If user_date_id is passed without epoch, set epoch to the first punch we find.
+					$epoch = $p_obj->getTimeStamp();
+				}
+
+				if ( isset($prev_punch_arr) AND $p_obj->getTimeStamp() > $prev_punch_arr['time_stamp'] ) {
+					$shift_data[$shift]['previous_punch_key'] = $i-1;
+					if ( $shift_data[$shift]['previous_punch_key'] < 0 ) {
+						$shift_data[$shift]['previous_punch_key'] = NULL;
+					}
+				}
+
+				//Determine if a non-saved PunchControl object was passed, and if so, match the IDs to use that instead.
+				if ( is_object($tmp_punch_control_obj) AND $p_obj->getPunchControlID() == $tmp_punch_control_obj->getId() ) {
+					Debug::text('Passed non-saved punch control object that matches, using that instead... Using ID: '. (int)$tmp_punch_control_obj->getId(), __FILE__, __LINE__, __METHOD__, 10);
+					$punch_control_obj = $tmp_punch_control_obj;
+				} else {
+					$punch_control_obj = $p_obj->getPunchControlObject();
+				}
+
+				//Can't use PunchControl object total_time because the record may not be saved yet when editing
+				//an already existing punch.
+				//When editing, simply pass the existing PunchControl object to this function so we can
+				//use it instead of the one in the database perhaps?
+				$total_time = $punch_control_obj->getTotalTime();
+/*
+				//We can't skip records with total_time == 0, because then when deleting one of the two
+				//punches in a pair, the remaining punch is ignored and causing punches to jump around between days in some cases.
+				if ( $total_time == 0 ) {
+					Debug::text('Total time is 0, skipping this punch control object...', __FILE__, __LINE__, __METHOD__, 10);
+					//continue;
+				}
+*/
+				if ( $i > 0 AND isset($shift_data[$shift]['last_out'])
+						AND ( $p_obj->getStatus() == 10 OR $p_obj->getStatus() == $prev_punch_arr['status_id'] )) {
+					Debug::text('Checking for new shift...', __FILE__, __LINE__, __METHOD__, 10);
+					//Assume that if two punches are assigned to the same punch_control_id are the same shift, even if the time between
+					//them exceeds the new_shift_trigger_time. This helps fix the bug where you could add a In punch then add a Out
+					//punch BEFORE the In punch as long as it was more than the Maximum Shift Time before the In Punch.
+					//ie: Add: In Punch 10-Dec-09 @ 8:00AM, Add: Out Punch 09-Dec-09 @ 5:00PM.
+					//Basically it just helps the validation checks to determine the error.
+					if ( $p_obj->getPunchControlID() != $shift_data[$shift]['last_out']['punch_control_id']
+							AND ($p_obj->getTimeStamp() - $shift_data[$shift]['last_out']['time_stamp']) > $new_shift_trigger_time ) {
+						$shift++;
+					}
+				}
+
+				if ( !isset($shift_data[$shift]['total_time']) ) {
+					$shift_data[$shift]['total_time'] = 0;
+				}
+
+				$punch_day_epoch = TTDate::getBeginDayEpoch( $p_obj->getTimeStamp() );
+				if ( !isset($shift_data[$shift]['total_time_per_day'][$punch_day_epoch]) ) {
+					$shift_data[$shift]['total_time_per_day'][$punch_day_epoch] = 0;
+				}
+
+				//Determine which shift is closest to the given epoch.
+				$punch_difference_from_epoch = abs($epoch-$p_obj->getTimeStamp());
+				if ( $nearest_punch_difference === FALSE OR $punch_difference_from_epoch < $nearest_punch_difference ) {
+					Debug::text('Nearest Shift Determined to be: '. $shift .' Nearest Punch Diff: '. (int)$nearest_punch_difference .' Punch Diff: '. $punch_difference_from_epoch, __FILE__, __LINE__, __METHOD__, 10);
+					$nearest_shift_id = $shift;
+					$nearest_punch_difference = $punch_difference_from_epoch;
+				}
+
+				$punch_arr = array(
+									'id' => $p_obj->getId(),
+									'punch_control_id' => $p_obj->getPunchControlId(),
+									'user_date_id' => $punch_control_obj->getUserDateID(),
+									'time_stamp' => $p_obj->getTimeStamp(),
+									'status_id' => $p_obj->getStatus(),
+									'type_id' => $p_obj->getType(),
+									);
+
+				$shift_data[$shift]['punches'][] = $punch_arr;
+				$shift_data[$shift]['punch_control_ids'][] = $p_obj->getPunchControlId();
+				if ( $punch_control_obj->getUserDateID() != FALSE ) {
+					$shift_data[$shift]['user_date_ids'][] = $punch_control_obj->getUserDateID();
+				}
+				$shift_data[$shift]['span_midnight'] = FALSE;
+				if ( !isset($shift_data[$shift]['first_in']) AND $p_obj->getStatus() == 10 ) {
+					//Debug::text('First In -- Punch ID: '. $p_obj->getID() .' Punch Control ID: '. $p_obj->getPunchControlID() .' TimeStamp: '. TTDate::getDate('DATE+TIME', $p_obj->getTimeStamp() ), __FILE__, __LINE__, __METHOD__, 10);
+
+					$shift_data[$shift]['first_in'] = $punch_arr;
+				} elseif ( $p_obj->getStatus() == 20 ) {
+					//Debug::text('Last Out -- Punch ID: '. $p_obj->getID() .' Punch Control ID: '. $p_obj->getPunchControlID() .' TimeStamp: '. TTDate::getDate('DATE+TIME', $p_obj->getTimeStamp() ), __FILE__, __LINE__, __METHOD__, 10);
+
+					$shift_data[$shift]['last_out'] = $punch_arr;
+
+					//Debug::text('Total Time: '. $total_time, __FILE__, __LINE__, __METHOD__, 10);
+					$shift_data[$shift]['total_time'] += $total_time;
+
+					//Check to see if the previous punch was on a different day then the current punch.
+					if ( isset($prev_punch_arr) AND is_array($prev_punch_arr)
+							AND ( $p_obj->getStatus() == 20 AND $prev_punch_arr['status_id'] != 20 )
+							AND TTDate::doesRangeSpanMidnight( $prev_punch_arr['time_stamp'], $p_obj->getTimeStamp() ) == TRUE ) {
+						Debug::text('Punch pair DOES span midnight', __FILE__, __LINE__, __METHOD__, 10);
+						$shift_data[$shift]['span_midnight'] = TRUE;
+
+						$total_time_for_each_day_arr = TTDate::calculateTimeOnEachDayBetweenRange( $prev_punch_arr['time_stamp'], $p_obj->getTimeStamp() );
+						if ( is_array( $total_time_for_each_day_arr ) ) {
+							foreach( $total_time_for_each_day_arr as $begin_day_epoch => $day_total_time ) {
+								if ( !isset($shift_data[$shift]['total_time_per_day'][$begin_day_epoch]) ) {
+									$shift_data[$shift]['total_time_per_day'][$begin_day_epoch] = 0;
+								}
+								$shift_data[$shift]['total_time_per_day'][$begin_day_epoch] += $day_total_time;
+							}
+						}
+						unset($total_time_for_each_day_arr,$begin_day_epoch,$day_total_time, $prev_day_total_time);
+					} else {
+						$shift_data[$shift]['total_time_per_day'][$punch_day_epoch] += $total_time;
+					}
+				}
+
+				$prev_punch_arr = $punch_arr;
+				$i++;
+			}
+
+			//Debug::Arr($shift_data, 'aShift Data:', __FILE__, __LINE__, __METHOD__, 10);
+
+			if ( isset($shift_data) ) {
+				//Loop through each shift to determine the day with the most time.
+				foreach( $shift_data as $tmp_shift_key => $tmp_shift_data ) {
+					krsort($shift_data[$tmp_shift_key]['total_time_per_day']); //Sort by day first
+					arsort($shift_data[$tmp_shift_key]['total_time_per_day']); //Sort by total time per day.
+					reset($shift_data[$tmp_shift_key]['total_time_per_day']);
+					$shift_data[$tmp_shift_key]['day_with_most_time'] = key($shift_data[$tmp_shift_key]['total_time_per_day']);
+
+					$shift_data[$tmp_shift_key]['punch_control_ids'] = array_unique( $shift_data[$tmp_shift_key]['punch_control_ids'] );
+					if ( isset($shift_data[$tmp_shift_key]['user_date_ids']) ) {
+						$shift_data[$tmp_shift_key]['user_date_ids'] = array_unique( $shift_data[$tmp_shift_key]['user_date_ids'] );
+					}
+				}
+				unset($tmp_shift_key, $tmp_shift_data);
+
+				if ( $filter == 'first_shift' ) {
+					//Only return first shift.
+					$shift_data = $shift_data[0];
+				} elseif( $filter == 'last_shift' ) {
+					//Only return last shift.
+					$shift_data = $shift_data[$shift];
+				} elseif ( $filter == 'nearest_shift' ) {
+					$shift_data = $shift_data[$nearest_shift_id];
+					//Check to make sure the nearest shift is within the new shift trigger time of EPOCH.
+					if ( isset($shift_data['first_in']['time_stamp']) ) {
+						$first_in = $shift_data['first_in']['time_stamp'];
+					} elseif ( isset($shift_data['last_out']['time_stamp']) ) {
+						$first_in = $shift_data['last_out']['time_stamp'];
+					}
+
+					if ( isset($shift_data['last_out']['time_stamp']) ) {
+						$last_out = $shift_data['last_out']['time_stamp'];
+					} elseif ( isset($shift_data['first_in']['time_stamp']) ) {
+						$last_out = $shift_data['first_in']['time_stamp'];
+					}
+
+					if ( TTDate::isTimeOverLap($epoch, $epoch, ($first_in-$new_shift_trigger_time), ($last_out+$new_shift_trigger_time) ) == FALSE ) {
+						Debug::Text('Nearest shift is outside the new shift trigger time... Epoch: '. $epoch .' First In: '. $first_in .' Last Out: '. $last_out .' New Shift Trigger: '. $new_shift_trigger_time, __FILE__, __LINE__, __METHOD__, 10);
+
+						return FALSE;
+					}
+					unset($first_in,$last_out);
+				}
+
+				$profiler->stopTimer( 'PayPeriodScheduleFactory::getShiftData()' );
+
+				//Debug::Arr($shift_data, 'bShift Data:', __FILE__, __LINE__, __METHOD__, 10);
+				return $shift_data;
+			}
+		}
+
+		$profiler->stopTimer( 'PayPeriodScheduleFactory::getShiftData()' );
+
+		return FALSE;
+	}
+
 	function getEnableInitialPayPeriods() {
 		if ( isset($this->enable_create_initial_pay_periods) ) {
 			return $this->enable_create_initial_pay_periods;
@@ -1152,6 +1645,16 @@ class PayPeriodScheduleFactory extends Factory {
 			$this->setCreateInitialPayPeriods( TRUE );
 		}
 
+		if ( $this->getShiftAssignedDay() == FALSE ) {
+			$this->setShiftAssignedDay( 10 ); //Day shifts start on
+		} elseif ( $this->getShiftAssignedDay() == 40 ) { //Split at midnight
+			$this->setNewDayTriggerTime( 0 ); //Minimum Time-off between shifts must be 0 in these cases.
+		}
+
+		if ( $this->getType() != 5 ) { //If schedule is other then manual, automatically calculate annual pay periods
+			$this->setAnnualPayPeriods( $this->calcAnnualPayPeriods() );
+		}
+
 		if ( $this->getDeleted() == TRUE ) {
 			//Delete pay periods assigned to this schedule.
 			$pplf = new PayPeriodListFactory();
@@ -1199,6 +1702,65 @@ class PayPeriodScheduleFactory extends Factory {
 		return TRUE;
 	}
 
+	//Support setting created_by,updated_by especially for importing data.
+	//Make sure data is set based on the getVariableToFunctionMap order.
+	function setObjectFromArray( $data ) {
+		if ( is_array( $data ) ) {
+			$variable_function_map = $this->getVariableToFunctionMap();
+			foreach( $variable_function_map as $key => $function ) {
+				if ( isset($data[$key]) ) {
+
+					$function = 'set'.$function;
+					switch( $key ) {
+						default:
+							if ( method_exists( $this, $function ) ) {
+								$this->$function( $data[$key] );
+							}
+							break;
+					}
+				}
+			}
+
+			$this->setCreatedAndUpdatedColumns( $data );
+
+			return TRUE;
+		}
+
+		return FALSE;
+	}
+
+
+	function getObjectAsArray( $include_columns = NULL ) {
+		$variable_function_map = $this->getVariableToFunctionMap();
+		if ( is_array( $variable_function_map ) ) {
+			foreach( $variable_function_map as $variable => $function_stub ) {
+				if ( $include_columns == NULL OR ( isset($include_columns[$variable]) AND $include_columns[$variable] == TRUE ) ) {
+
+					$function = 'get'.$function_stub;
+					switch( $variable ) {
+						case 'type':
+						case 'startweekday':
+						case 'shift_assigned_day':
+							$function = 'get'.$variable;
+							if ( method_exists( $this, $function ) ) {
+								$data[$variable] = Option::getByKey( $this->$function(), $this->getOptions( $variable ) );
+							}
+							break;
+						default:
+							if ( method_exists( $this, $function ) ) {
+								$data[$variable] = $this->$function();
+							}
+							break;
+					}
+
+				}
+			}
+			$this->getCreatedAndUpdatedColumns( &$data, $include_columns );
+		}
+
+		return $data;
+	}
+
 	function addLog( $log_action ) {
 		return TTLog::addEntry( $this->getId(), $log_action, TTi18n::getText('Pay Period Schedule'), NULL, $this->getTable() );
 	}
