@@ -1,29 +1,42 @@
 <?php
 /*********************************************************************************
- * The contents of this file are subject to the TimeTrex Public License Version
- * 1.1.0 ("License"); You may not use this file except in compliance with the
- * License. You may obtain a copy of the License at http://www.TimeTrex.com/TPL
- * Software distributed under the License is distributed on an "AS IS" basis,
- * WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the License
- * for the specific language governing rights and limitations under the
- * License.
+ * TimeTrex is a Payroll and Time Management program developed by
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
  *
- * All copies of the Covered Code must include on each user interface screen:
- *    (i) the "Powered by TimeTrex" logo and
- *    (ii) the TimeTrex copyright notice
- * in the same form as they appear in the distribution.  See full license for
- * requirements.
+ * This program is free software; you can redistribute it and/or modify it under
+ * the terms of the GNU Affero General Public License version 3 as published by
+ * the Free Software Foundation with the addition of the following permission
+ * added to Section 15 as permitted in Section 7(a): FOR ANY PART OF THE COVERED
+ * WORK IN WHICH THE COPYRIGHT IS OWNED BY TIMETREX, TIMETREX DISCLAIMS THE
+ * WARRANTY OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
  *
- * The Original Code is: TimeTrex Open Source
- * The Initial Developer of the Original Code is TimeTrex Payroll Services
- * Portions created by TimeTrex are Copyright (C) 2004-2007 TimeTrex Payroll Services;
- * All Rights Reserved.
+ * This program is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+ * FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
+ * details.
  *
+ * You should have received a copy of the GNU Affero General Public License along
+ * with this program; if not, see http://www.gnu.org/licenses or write to the Free
+ * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+ * 02110-1301 USA.
+ *
+ * You can contact TimeTrex headquarters at Unit 22 - 2475 Dobbin Rd. Suite
+ * #292 Westbank, BC V4T 2E9, Canada or at email address info@timetrex.com.
+ *
+ * The interactive user interfaces in modified source and object code versions
+ * of this program must display Appropriate Legal Notices, as required under
+ * Section 5 of the GNU Affero General Public License version 3.
+ *
+ * In accordance with Section 7(b) of the GNU Affero General Public License
+ * version 3, these Appropriate Legal Notices must retain the display of the
+ * "Powered by TimeTrex" logo. If the display of the logo is not reasonably
+ * feasible for technical reasons, the Appropriate Legal Notices must display
+ * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2237 $
- * $Id: PunchListFactory.class.php 2237 2008-11-11 18:18:20Z ipso $
- * $Date: 2008-11-11 10:18:20 -0800 (Tue, 11 Nov 2008) $
+ * $Revision: 2857 $
+ * $Id: PunchListFactory.class.php 2857 2009-09-27 09:11:28Z ipso $
+ * $Date: 2009-09-27 02:11:28 -0700 (Sun, 27 Sep 2009) $
  */
 
 /**
@@ -117,6 +130,44 @@ class PunchListFactory extends PunchFactory implements IteratorAggregate {
 		$this->rs = $this->db->Execute($query, $ph);
 	}
 
+	function getByCompanyIDAndId($company_id, $id) {
+		if ( $company_id == '' ) {
+			return FALSE;
+		}
+
+		if ( $id == '' ) {
+			return FALSE;
+		}
+
+		$uf = new UserFactory();
+		$pcf = new PunchControlFactory();
+		$udf = new UserDateFactory();
+
+		$ph = array(
+					'company_id' => $company_id,
+					);
+
+		//Status sorting MUST be desc first, otherwise transfer punches are completely out of order.
+		$query = '
+					select 	a.*
+					from	'. $this->getTable() .' as a,
+							'. $pcf->getTable() .' as b,
+							'. $udf->getTable() .' as c,
+							'. $uf->getTable() .' as d
+					where	a.punch_control_id = b.id
+						AND b.user_date_id = c.id
+						AND c.user_id = d.id
+						AND d.company_id = ?
+						AND a.id in ('. $this->getListSQL($id, $ph) .')
+						AND ( a.deleted = 0 AND b.deleted = 0 AND c.deleted = 0 )
+					ORDER BY a.time_stamp asc, a.status_id desc, a.punch_control_id asc
+					';
+
+		$this->rs = $this->db->Execute($query, $ph);
+
+		return $this;
+	}
+
 	function getByPunchControlIdAndStatusId($punch_control_id, $status_id, $where = NULL, $order = NULL) {
 		if ( $punch_control_id == '') {
 			return FALSE;
@@ -353,6 +404,97 @@ class PunchListFactory extends PunchFactory implements IteratorAggregate {
 		return $this;
 	}
 
+	function getShiftPunchesByUserIDAndEpoch( $user_id, $epoch, $punch_control_id = 0, $maximum_shift_time = NULL ) {
+		if ( $user_id == '') {
+			return FALSE;
+		}
+
+		if ( $epoch == '') {
+			return FALSE;
+		}
+
+		if ( $maximum_shift_time == '' ) {
+			$maximum_shift_time = $this->getPayPeriodMaximumShiftTime( $user_id, $maximum_shift_time );
+		}
+
+		//Make sure that we get all punches surrounding the EPOCH within the maximum shift time,
+		//We also need to take into account punch pairs, for example:
+		// Punch Pair: 10-Mar-09 @ 11:30PM -> 11-Mar-09 @ 2:30PM. If the maximum shift time ends at 11:45PM
+		// we need to include the out punch as well.
+		$start_time_stamp = ($epoch - $maximum_shift_time);
+		$end_time_stamp = ($epoch + $maximum_shift_time);
+
+		$udf = new UserDateFactory();
+		$pcf = new PunchControlFactory();
+
+		$ph = array(
+					'user_id' => $user_id,
+					'start_date_stamp' => $this->db->BindDate( $start_time_stamp ),
+					'end_date_stamp' => $this->db->BindDate( $end_time_stamp ),
+					'start_time_stamp2' => $this->db->BindTimeStamp( $start_time_stamp ),
+					'end_time_stamp2' => $this->db->BindTimeStamp( $end_time_stamp ),
+					);
+/*
+	ORIGINAL SLOW query. Moving OR into the sub-query.
+ 					select a.*
+					from '. $this->getTable() .' as a
+					where
+						(
+						a.punch_control_id = ?
+						OR
+						a.punch_control_id in (
+													select 	distinct(x.punch_control_id)
+													from 	'. $this->getTable() .' as x,
+															'. $pcf->getTable() .' as y,
+															'. $udf->getTable() .' as z
+													where	x.punch_control_id = y.id
+														AND y.user_date_id = z.id
+														AND z.user_id = ?
+														AND z.date_stamp >= ?
+														AND z.date_stamp <= ?
+														AND x.time_stamp >= ?
+														AND x.time_stamp <= ?
+														AND ( x.deleted = 0 AND y.deleted=0 AND z.deleted=0 )
+
+												)
+						)
+					AND a.deleted = 0
+					ORDER BY a.time_stamp asc, a.status_id asc
+
+*/
+		$query = '
+					select a.*
+					from '. $this->getTable() .' as a
+					where
+						(
+						a.punch_control_id in (
+													select '. (int)$punch_control_id .'
+													UNION ALL
+													select 	x.punch_control_id
+													from 	'. $this->getTable() .' as x,
+															'. $pcf->getTable() .' as y,
+															'. $udf->getTable() .' as z
+													where	x.punch_control_id = y.id
+														AND y.user_date_id = z.id
+														AND z.user_id = ?
+														AND z.date_stamp >= ?
+														AND z.date_stamp <= ?
+														AND x.time_stamp >= ?
+														AND x.time_stamp <= ?
+														AND ( x.deleted = 0 AND y.deleted=0 AND z.deleted=0 )
+
+												)
+						)
+					AND a.deleted = 0
+					ORDER BY a.time_stamp asc, a.status_id asc
+					';
+		//$query .= $this->getSortSQL( $order );
+
+		$this->rs = $this->db->Execute($query, $ph);
+
+		return $this;
+	}
+
 	function getFirstPunchByUserIDAndEpoch( $user_id, $epoch, $maximum_shift_time = NULL ) {
 		if ( $user_id == '') {
 			return FALSE;
@@ -362,9 +504,11 @@ class PunchListFactory extends PunchFactory implements IteratorAggregate {
 			return FALSE;
 		}
 
-		$maximum_shift_time = $this->getPayPeriodMaximumShiftTime( $user_id, $maximum_shift_time );
+		if ( $maximum_shift_time == '' ) {
+			$maximum_shift_time = $this->getPayPeriodMaximumShiftTime( $user_id, $maximum_shift_time );
+		}
 
-		$user_date_stamp = TTDate::getBeginDayEpoch( $epoch - $maxmimum_shift_time );
+		$user_date_stamp = TTDate::getBeginDayEpoch( $epoch - $maximum_shift_time );
 
 		$udf = new UserDateFactory();
 		$pcf = new PunchControlFactory();
@@ -392,7 +536,6 @@ class PunchListFactory extends PunchFactory implements IteratorAggregate {
 		$this->rs = $this->db->Execute($query, $ph);
 
 		return $this;
-
 	}
 
 	function getPreviousPunchByUserIdAndEpoch($user_id, $epoch, $order = NULL) {
@@ -457,10 +600,6 @@ class PunchListFactory extends PunchFactory implements IteratorAggregate {
 			return FALSE;
 		}
 
-		if ( $maximum_shift_time == '') {
-			return FALSE;
-		}
-
 		$maximum_shift_time = $this->getPayPeriodMaximumShiftTime( $user_id, $maximum_shift_time );
 		$start_time = $epoch - $maximum_shift_time;
 
@@ -585,7 +724,7 @@ class PunchListFactory extends PunchFactory implements IteratorAggregate {
 		$query = '
 					select 	a.*
 					from 	'. $this->getTable() .' as a,
-							'. $pcf->getTable() .' as b
+							'. $pcf->getTable() .' as b,
 							'. $udf->getTable() .' as c
 					where	a.punch_control_id = b.id
 						AND b.user_date_id = c.id
@@ -1155,12 +1294,12 @@ class PunchListFactory extends PunchFactory implements IteratorAggregate {
 		}
 
 		//$additional_order_fields = array('b.name', 'c.name', 'd.name', 'e.name');
-		$additional_order_fields = array();
+		$additional_order_fields = array('first_name', 'last_name', 'date_stamp','time_stamp','type_id','status_id','branch','department','default_branch','default_department','group','title');
 		if ( $order == NULL ) {
 			$order = array( 'c.pay_period_id' => 'asc','c.user_id' => 'asc', 'a.time_stamp' => 'asc', 'a.punch_control_id' => 'asc', 'a.status_id' => 'asc' );
 			$strict = FALSE;
 		} else {
-			$strict = TRUE;
+			$strict = FALSE;
 		}
 		//Debug::Arr($order,'Order Data:', __FILE__, __LINE__, __METHOD__,10);
 		//Debug::Arr($filter_data,'Filter Data:', __FILE__, __LINE__, __METHOD__,10);
@@ -1168,6 +1307,9 @@ class PunchListFactory extends PunchFactory implements IteratorAggregate {
 		if ( isset($filter_data['exclude_user_ids']) ) {
 			$filter_data['exclude_id'] = $filter_data['exclude_user_ids'];
 		}
+		if ( isset($filter_data['user_id']) ) {
+			$filter_data['id'] = $filter_data['user_id'];
+		}
 		if ( isset($filter_data['include_user_ids']) ) {
 			$filter_data['id'] = $filter_data['include_user_ids'];
 		}
@@ -1280,7 +1422,7 @@ class PunchListFactory extends PunchFactory implements IteratorAggregate {
 																		where z.user_id = c.user_id
 																			and z.effective_date <= c.date_stamp
 																			and z.deleted = 0
-																			order by z.effective_date desc limit 1)
+																			order by z.effective_date desc LiMiT 1)
 					';
 		if ( getTTProductEdition() == TT_PRODUCT_PROFESSIONAL ) {
 			$query .= '	LEFT JOIN '. $jf->getTable() .' as x ON b.job_id = x.id';
@@ -1323,6 +1465,12 @@ class PunchListFactory extends PunchFactory implements IteratorAggregate {
 		if ( isset($filter_data['punch_department_id']) AND isset($filter_data['punch_department_id'][0]) AND !in_array(-1, (array)$filter_data['punch_department_id']) ) {
 			$query  .=	' AND b.department_id in ('. $this->getListSQL($filter_data['punch_department_id'], $ph) .') ';
 		}
+		if ( isset($filter_data['punch_status_id']) AND isset($filter_data['punch_status_id'][0]) AND !in_array(-1, (array)$filter_data['punch_status_id']) ) {
+			$query  .=	' AND a.status_id in ('. $this->getListSQL($filter_data['punch_status_id'], $ph) .') ';
+		}
+		if ( isset($filter_data['punch_type_id']) AND isset($filter_data['punch_type_id'][0]) AND !in_array(-1, (array)$filter_data['punch_type_id']) ) {
+			$query  .=	' AND a.type_id in ('. $this->getListSQL($filter_data['punch_type_id'], $ph) .') ';
+		}
 		if ( isset($filter_data['pay_period_ids']) AND isset($filter_data['pay_period_ids'][0]) AND !in_array(-1, (array)$filter_data['pay_period_ids']) ) {
 			$query .= 	' AND c.pay_period_id in ('. $this->getListSQL($filter_data['pay_period_ids'], $ph) .') ';
 		}
