@@ -1,29 +1,42 @@
 <?php
 /*********************************************************************************
- * The contents of this file are subject to the TimeTrex Public License Version
- * 1.1.0 ("License"); You may not use this file except in compliance with the
- * License. You may obtain a copy of the License at http://www.TimeTrex.com/TPL
- * Software distributed under the License is distributed on an "AS IS" basis,
- * WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the License
- * for the specific language governing rights and limitations under the
- * License.
+ * TimeTrex is a Payroll and Time Management program developed by
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
  *
- * All copies of the Covered Code must include on each user interface screen:
- *    (i) the "Powered by TimeTrex" logo and
- *    (ii) the TimeTrex copyright notice
- * in the same form as they appear in the distribution.  See full license for
- * requirements.
+ * This program is free software; you can redistribute it and/or modify it under
+ * the terms of the GNU Affero General Public License version 3 as published by
+ * the Free Software Foundation with the addition of the following permission
+ * added to Section 15 as permitted in Section 7(a): FOR ANY PART OF THE COVERED
+ * WORK IN WHICH THE COPYRIGHT IS OWNED BY TIMETREX, TIMETREX DISCLAIMS THE
+ * WARRANTY OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
  *
- * The Original Code is: TimeTrex Open Source
- * The Initial Developer of the Original Code is TimeTrex Payroll Services
- * Portions created by TimeTrex are Copyright (C) 2004-2007 TimeTrex Payroll Services;
- * All Rights Reserved.
+ * This program is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+ * FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
+ * details.
  *
+ * You should have received a copy of the GNU Affero General Public License along
+ * with this program; if not, see http://www.gnu.org/licenses or write to the Free
+ * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+ * 02110-1301 USA.
+ *
+ * You can contact TimeTrex headquarters at Unit 22 - 2475 Dobbin Rd. Suite
+ * #292 Westbank, BC V4T 2E9, Canada or at email address info@timetrex.com.
+ *
+ * The interactive user interfaces in modified source and object code versions
+ * of this program must display Appropriate Legal Notices, as required under
+ * Section 5 of the GNU Affero General Public License version 3.
+ *
+ * In accordance with Section 7(b) of the GNU Affero General Public License
+ * version 3, these Appropriate Legal Notices must retain the display of the
+ * "Powered by TimeTrex" logo. If the display of the logo is not reasonably
+ * feasible for technical reasons, the Appropriate Legal Notices must display
+ * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2371 $
- * $Id: ScheduleListFactory.class.php 2371 2009-01-21 22:54:00Z ipso $
- * $Date: 2009-01-21 14:54:00 -0800 (Wed, 21 Jan 2009) $
+ * $Revision: 3199 $
+ * $Id: ScheduleListFactory.class.php 3199 2009-12-20 23:37:45Z ipso $
+ * $Date: 2009-12-20 15:37:45 -0800 (Sun, 20 Dec 2009) $
  */
 
 /**
@@ -71,6 +84,9 @@ class ScheduleListFactory extends ScheduleFactory implements IteratorAggregate {
 		return $this;
 	}
 
+	function getByIdAndCompanyId( $id, $company_id ) {
+		return $this->getByCompanyIDAndId($company_id, $id);
+	}
 	function getByCompanyIDAndId($company_id, $id) {
 		if ( $company_id == '' ) {
 			return FALSE;
@@ -213,6 +229,113 @@ class ScheduleListFactory extends ScheduleFactory implements IteratorAggregate {
 		return $this;
 	}
 
+	function getWeekWorkTimeSumByUserIDAndEpochAndStartWeekEpoch( $user_id, $epoch, $week_start_epoch ) {
+		if ( $user_id == '' ) {
+			return FALSE;
+		}
+
+		if ( $epoch == '' ) {
+			return FALSE;
+		}
+
+		if ( $week_start_epoch == '' ) {
+			return FALSE;
+		}
+
+		$udf = new UserDateFactory();
+		$otpf = new OverTimePolicyFactory();
+
+		$ph = array(
+					'user_id' => $user_id,
+					'week_start_epoch' => $this->db->BindDate( $week_start_epoch ),
+					'epoch' =>  $this->db->BindDate( $epoch ),
+					);
+
+		//DO NOT Include paid absences. Only count regular time towards weekly overtime.
+		//And other weekly overtime polices!
+		$query = '
+					select 	sum(a.total_time)
+					from	'. $this->getTable() .' as a
+					LEFT JOIN '. $udf->getTable() .' as b ON a.user_date_id = b.id
+					where
+						b.user_id = ?
+						AND b.date_stamp >= ?
+						AND b.date_stamp < ?
+						AND a.status_id = 10
+						AND a.deleted = 0
+				';
+		$total = $this->db->GetOne($query, $ph);
+
+		if ($total === FALSE ) {
+			$total = 0;
+		}
+		Debug::text('Total: '. $total, __FILE__, __LINE__, __METHOD__, 10);
+
+		return $total;
+	}
+
+	function getByUserIdAndTypeAndDirectionFromDate($user_id, $type_id, $direction, $date, $limit = NULL, $page = NULL, $where = NULL, $order = NULL) {
+		if ( $user_id == '') {
+			return FALSE;
+		}
+
+		if ( $type_id == '') {
+			return FALSE;
+		}
+
+		if ( $direction == '') {
+			return FALSE;
+		}
+
+		if ( $date == '') {
+			return FALSE;
+		}
+
+		if ( strtolower($direction) == 'before' ) {
+			$direction = '<';
+		} elseif ( strtolower($direction) == 'after' ) {
+			$direction = '>';
+		} else {
+			return FALSE;
+		}
+
+		if ( $order == NULL ) {
+			$order = array( 'b.date_stamp' => 'asc' );
+			$strict = FALSE;
+		} else {
+			$strict = TRUE;
+		}
+
+		$udf = new UserDateFactory();
+
+		$ph = array(
+					'date' => $this->db->BindDate( $date ),
+					'type_id' => $type_id,
+					);
+
+		$query = '
+					select 	a.*
+					from	'. $this->getTable() .' as a,
+							'. $udf->getTable() .' as b
+					where 	a.user_date_id = b.id
+						AND b.date_stamp '. $direction .' ?
+						AND a.status_id = ?
+						AND b.user_id in ('. $this->getListSQL( $user_id, $ph ) .')
+						AND ( a.deleted = 0 AND b.deleted = 0 )
+					';
+
+		$query .= $this->getWhereSQL( $where );
+		$query .= $this->getSortSQL( $order, $strict );
+
+		if ($limit == NULL) {
+			$this->rs = $this->db->Execute($query, $ph);
+		} else {
+			$this->rs = $this->db->PageExecute($query, $limit, $page, $ph);
+		}
+
+		return $this;
+	}
+
 	function getByStartDateAndEndDate($start_date, $end_date, $where = NULL, $order = NULL) {
 		if ( $start_date == '') {
 			return FALSE;
@@ -247,7 +370,7 @@ class ScheduleListFactory extends ScheduleFactory implements IteratorAggregate {
 	}
 
 	function getConflictingByUserIdAndStartDateAndEndDate($user_id, $start_date, $end_date, $where = NULL, $order = NULL) {
-		Debug::Text('User Date ID: '. $user_id .' Start Date: '. $start_date .' End Date: '. $end_date, __FILE__, __LINE__, __METHOD__,10);
+		Debug::Text('User ID: '. $user_id .' Start Date: '. $start_date .' End Date: '. $end_date, __FILE__, __LINE__, __METHOD__,10);
 
 		if ( $user_id == '' ) {
 			return FALSE;
@@ -470,16 +593,16 @@ class ScheduleListFactory extends ScheduleFactory implements IteratorAggregate {
 		if ( isset($filter_data['group_ids']) ) {
 			$filter_data['group_id'] = $filter_data['group_ids'];
 		}
-		if ( isset($filter_data['branch_ids']) ) {
-			$filter_data['default_branch_id'] = $filter_data['branch_ids'];
+		if ( isset($filter_data['default_branch_ids']) ) {
+			$filter_data['default_branch_id'] = $filter_data['default_branch_ids'];
 		}
-		if ( isset($filter_data['department_ids']) ) {
-			$filter_data['default_department_id'] = $filter_data['department_ids'];
+		if ( isset($filter_data['default_department_ids']) ) {
+			$filter_data['default_department_id'] = $filter_data['default_department_ids'];
 		}
 		if ( isset($filter_data['schedule_branch_ids']) ) {
 			$filter_data['schedule_branch_id'] = $filter_data['schedule_branch_ids'];
 		}
-		if ( isset($filter_data['punch_department_ids']) ) {
+		if ( isset($filter_data['schedule_department_ids']) ) {
 			$filter_data['schedule_department_id'] = $filter_data['schedule_department_ids'];
 		}
 
@@ -511,6 +634,7 @@ class ScheduleListFactory extends ScheduleFactory implements IteratorAggregate {
 
 		$query = '
 					select
+							a.id as id,
 							a.id as schedule_id,
 							a.status_id as status_id,
 							a.start_time as start_time,
@@ -529,6 +653,10 @@ class ScheduleListFactory extends ScheduleFactory implements IteratorAggregate {
 							c.date_stamp as date_stamp,
 							c.pay_period_id as pay_period_id,
 
+							d.first_name as first_name,
+							d.last_name as last_name,
+							d.created_by as user_created_by,
+
 							z.id as user_wage_id,
 							z.effective_date as user_wage_effective_date ';
 
@@ -626,12 +754,12 @@ class ScheduleListFactory extends ScheduleFactory implements IteratorAggregate {
 
 
 		if ( isset($filter_data['start_date']) AND trim($filter_data['start_date']) != '' ) {
-			$ph[] = $this->db->BindDate($filter_data['start_date']);
+			$ph[] = $this->db->BindTimeStamp($filter_data['start_date']);
 			$query  .=	' AND a.start_time >= ?';
 		}
 		if ( isset($filter_data['end_date']) AND trim($filter_data['end_date']) != '' ) {
-			$ph[] = $this->db->BindDate($filter_data['end_date']);
-			$query  .=	' AND c.start_time <= ?';
+			$ph[] = $this->db->BindTimeStamp($filter_data['end_date']);
+			$query  .=	' AND a.start_time <= ?';
 		}
 
 		$query .= 	'
@@ -640,6 +768,8 @@ class ScheduleListFactory extends ScheduleFactory implements IteratorAggregate {
 		$query .= $this->getWhereSQL( $where );
 		$query .= $this->getSortSQL( $order, $strict, $additional_order_fields );
 
+		Debug::text('Query: '. $query, __FILE__, __LINE__, __METHOD__, 10);
+
 		if ($limit == NULL) {
 			$this->rs = $this->db->Execute($query, $ph);
 		} else {
@@ -824,7 +954,288 @@ class ScheduleListFactory extends ScheduleFactory implements IteratorAggregate {
 		$this->rs = $this->db->Execute($query, $ph);
 
 		return $this;
+	}
 
+	function getAPISearchByCompanyIdAndArrayCriteria( $company_id, $filter_data, $limit = NULL, $page = NULL, $where = NULL, $order = NULL ) {
+		if ( $company_id == '') {
+			return FALSE;
+		}
+
+		if ( !is_array($order) ) {
+			//Use Filter Data ordering if its set.
+			if ( isset($filter_data['sort_column']) AND $filter_data['sort_order']) {
+				$order = array(Misc::trimSortPrefix($filter_data['sort_column']) => $filter_data['sort_order']);
+			}
+		}
+
+		$additional_order_fields = array('schedule_policy_id', 'schedule_policy', 'first_name', 'last_name', 'user_status_id', 'group_id', 'group', 'title_id', 'title', 'default_branch_id', 'default_branch', 'default_department_id', 'default_department', 'total_time', 'date_stamp', 'pay_period_id', );
+		if ( $order == NULL ) {
+			$order = array( 'c.pay_period_id' => 'asc','c.user_id' => 'asc', 'a.start_time' => 'asc' );
+			$strict = FALSE;
+		} else {
+			$strict = TRUE;
+		}
+		//Debug::Arr($order,'Order Data:', __FILE__, __LINE__, __METHOD__,10);
+		//Debug::Arr($filter_data,'Filter Data:', __FILE__, __LINE__, __METHOD__,10);
+
+		if ( isset($filter_data['exclude_user_ids']) ) {
+			$filter_data['exclude_id'] = $filter_data['exclude_user_ids'];
+		}
+		if ( isset($filter_data['include_user_ids']) ) {
+			$filter_data['id'] = $filter_data['include_user_ids'];
+		}
+		if ( isset($filter_data['user_status_ids']) ) {
+			$filter_data['status_id'] = $filter_data['user_status_ids'];
+		}
+		if ( isset($filter_data['user_title_ids']) ) {
+			$filter_data['title_id'] = $filter_data['user_title_ids'];
+		}
+		if ( isset($filter_data['group_ids']) ) {
+			$filter_data['group_id'] = $filter_data['group_ids'];
+		}
+		if ( isset($filter_data['default_branch_ids']) ) {
+			$filter_data['default_branch_id'] = $filter_data['default_branch_ids'];
+		}
+		if ( isset($filter_data['default_department_ids']) ) {
+			$filter_data['default_department_id'] = $filter_data['default_department_ids'];
+		}
+		if ( isset($filter_data['branch_ids']) ) {
+			$filter_data['branch_id'] = $filter_data['branch_ids'];
+		}
+		if ( isset($filter_data['department_ids']) ) {
+			$filter_data['department_id'] = $filter_data['department_ids'];
+		}
+
+		if ( isset($filter_data['exclude_job_ids']) ) {
+			$filter_data['exclude_id'] = $filter_data['exclude_job_ids'];
+		}
+		if ( isset($filter_data['include_job_ids']) ) {
+			$filter_data['include_job_id'] = $filter_data['include_job_ids'];
+		}
+		if ( isset($filter_data['job_group_ids']) ) {
+			$filter_data['job_group_id'] = $filter_data['job_group_ids'];
+		}
+		if ( isset($filter_data['job_item_ids']) ) {
+			$filter_data['job_item_id'] = $filter_data['job_item_ids'];
+		}
+		if ( isset($filter_data['pay_period_ids']) ) {
+			$filter_data['pay_period_id'] = $filter_data['pay_period_ids'];
+		}
+
+		if ( isset($filter_data['start_time']) ) {
+			$filter_data['start_date'] = $filter_data['start_time'];
+		}
+		if ( isset($filter_data['end_time']) ) {
+			$filter_data['end_date'] = $filter_data['end_time'];
+		}
+
+		$spf = new SchedulePolicyFactory();
+		$uf = new UserFactory();
+		$bf = new BranchFactory();
+		$df = new DepartmentFactory();
+		$ugf = new UserGroupFactory();
+		$utf = new UserTitleFactory();
+		$udf = new UserDateFactory();
+		$uwf = new UserWageFactory();
+
+		if ( getTTProductEdition() == TT_PRODUCT_PROFESSIONAL ) {
+			$jf = new JobFactory();
+			$jif = new JobItemFactory();
+		}
+
+		$ph = array(
+					'company_id' => $company_id,
+					);
+
+		$query = '
+					select
+							a.id as id,
+							a.id as schedule_id,
+							a.status_id as status_id,
+							a.start_time as start_time,
+							a.end_time as end_time,
+
+							a.user_date_id as user_date_id,
+							a.branch_id as branch_id,
+							j.name as branch,
+							a.department_id as department_id,
+							k.name as department,
+							a.job_id as job_id,
+							a.job_item_id as job_item_id,
+							a.total_time as total_time,
+							a.schedule_policy_id as schedule_policy_id,
+							a.absence_policy_id as absence_policy_id,
+
+							i.name as schedule_policy,
+
+							c.user_id as user_id,
+							c.date_stamp as date_stamp,
+							c.pay_period_id as pay_period_id,
+
+							d.first_name as first_name,
+							d.last_name as last_name,
+							d.status_id as user_status_id,
+							d.group_id as group_id,
+							g.name as group,
+							d.title_id as title_id,
+							h.name as title,
+							d.default_branch_id as default_branch_id,
+							e.name as default_branch,
+							d.default_department_id as default_department_id,
+							f.name as default_department,
+							d.created_by as user_created_by,
+
+							m.id as user_wage_id,
+							m.effective_date as user_wage_effective_date,
+
+							y.first_name as created_by_first_name,
+							y.middle_name as created_by_middle_name,
+							y.last_name as created_by_last_name,
+							z.first_name as updated_by_first_name,
+							z.middle_name as updated_by_middle_name,
+							z.last_name as updated_by_last_name';
+
+		if ( getTTProductEdition() == TT_PRODUCT_PROFESSIONAL ) {
+			$query .= ',
+						w.name as job_name,
+						w.status_id as job_status_id,
+						w.manual_id as job_manual_id,
+						w.branch_id as job_branch_id,
+						w.department_id as job_department_id,
+						w.group_id as job_group_id';
+		}
+
+		$query .= '
+					from 	'. $this->getTable() .' as a
+							LEFT JOIN '. $spf->getTable() .' as i ON a.schedule_policy_id = i.id
+							LEFT JOIN '. $udf->getTable() .' as c ON a.user_date_id = c.id
+							LEFT JOIN '. $uf->getTable() .' as d ON c.user_id = d.id
+
+							LEFT JOIN '. $bf->getTable() .' as e ON ( d.default_branch_id = e.id AND e.deleted = 0)
+							LEFT JOIN '. $df->getTable() .' as f ON ( d.default_department_id = f.id AND f.deleted = 0)
+							LEFT JOIN '. $ugf->getTable() .' as g ON ( d.group_id = g.id AND g.deleted = 0 )
+							LEFT JOIN '. $utf->getTable() .' as h ON ( d.title_id = h.id AND h.deleted = 0 )
+
+							LEFT JOIN '. $bf->getTable() .' as j ON ( a.branch_id = j.id AND j.deleted = 0)
+							LEFT JOIN '. $df->getTable() .' as k ON ( a.department_id = k.id AND k.deleted = 0)
+
+							LEFT JOIN '. $uwf->getTable() .' as m ON m.id = (select m.id
+																		from '. $uwf->getTable() .' as m
+																		where m.user_id = c.user_id
+																			and m.effective_date <= c.date_stamp
+																			and m.deleted = 0
+																			order by m.effective_date desc limit 1)
+					';
+		if ( getTTProductEdition() == TT_PRODUCT_PROFESSIONAL ) {
+			$query .= '	LEFT JOIN '. $jf->getTable() .' as w ON a.job_id = w.id';
+			$query .= '	LEFT JOIN '. $jif->getTable() .' as x ON a.job_item_id = x.id';
+		}
+
+		$query .= '
+						LEFT JOIN '. $uf->getTable() .' as y ON ( a.created_by = y.id AND y.deleted = 0 )
+						LEFT JOIN '. $uf->getTable() .' as z ON ( a.updated_by = z.id AND z.deleted = 0 )
+					WHERE d.company_id = ?';
+
+		if ( isset($filter_data['permission_children_ids']) AND isset($filter_data['permission_children_ids'][0]) AND !in_array(-1, (array)$filter_data['permission_children_ids']) ) {
+			$query  .=	' AND d.id in ('. $this->getListSQL($filter_data['permission_children_ids'], $ph) .') ';
+		}
+		if ( isset($filter_data['id']) AND isset($filter_data['id'][0]) AND !in_array(-1, (array)$filter_data['id']) ) {
+			$query  .=	' AND a.id in ('. $this->getListSQL($filter_data['id'], $ph) .') ';
+		}
+		if ( isset($filter_data['exclude_id']) AND isset($filter_data['exclude_id'][0]) AND !in_array(-1, (array)$filter_data['exclude_id']) ) {
+			$query  .=	' AND d.id not in ('. $this->getListSQL($filter_data['exclude_id'], $ph) .') ';
+		}
+		if ( isset($filter_data['user_id']) AND isset($filter_data['user_id'][0]) AND !in_array(-1, (array)$filter_data['user_id']) ) {
+			$query  .=	' AND c.user_id in ('. $this->getListSQL($filter_data['user_id'], $ph) .') ';
+		}
+
+		if ( isset($filter_data['user_status_id']) AND isset($filter_data['user_status_id'][0]) AND !in_array(-1, (array)$filter_data['user_status_id']) ) {
+			$query  .=	' AND d.status_id in ('. $this->getListSQL($filter_data['user_status_id'], $ph) .') ';
+		}
+		if ( isset($filter_data['group_id']) AND isset($filter_data['group_id'][0]) AND !in_array(-1, (array)$filter_data['group_id']) ) {
+			if ( isset($filter_data['include_subgroups']) AND (bool)$filter_data['include_subgroups'] == TRUE ) {
+				$uglf = new UserGroupListFactory();
+				$filter_data['group_id'] = $uglf->getByCompanyIdAndGroupIdAndSubGroupsArray( $company_id, $filter_data['group_id'], TRUE);
+			}
+			$query  .=	' AND d.group_id in ('. $this->getListSQL($filter_data['group_id'], $ph) .') ';
+		}
+		if ( isset($filter_data['default_branch_id']) AND isset($filter_data['default_branch_id'][0]) AND !in_array(-1, (array)$filter_data['default_branch_id']) ) {
+			$query  .=	' AND d.default_branch_id in ('. $this->getListSQL($filter_data['default_branch_id'], $ph) .') ';
+		}
+		if ( isset($filter_data['default_department_id']) AND isset($filter_data['default_department_id'][0]) AND !in_array(-1, (array)$filter_data['default_department_id']) ) {
+			$query  .=	' AND d.default_department_id in ('. $this->getListSQL($filter_data['default_department_id'], $ph) .') ';
+		}
+		if ( isset($filter_data['title_id']) AND isset($filter_data['title_id'][0]) AND !in_array(-1, (array)$filter_data['title_id']) ) {
+			$query  .=	' AND d.title_id in ('. $this->getListSQL($filter_data['title_id'], $ph) .') ';
+		}
+		if ( isset($filter_data['branch_id']) AND isset($filter_data['branch_id'][0]) AND !in_array(-1, (array)$filter_data['branch_id']) ) {
+			$query  .=	' AND a.branch_id in ('. $this->getListSQL($filter_data['branch_id'], $ph) .') ';
+		}
+		if ( isset($filter_data['department_id']) AND isset($filter_data['department_id'][0]) AND !in_array(-1, (array)$filter_data['department_id']) ) {
+			$query  .=	' AND a.department_id in ('. $this->getListSQL($filter_data['department_id'], $ph) .') ';
+		}
+		if ( isset($filter_data['status_id']) AND isset($filter_data['status_id'][0]) AND !in_array(-1, (array)$filter_data['status_id']) ) {
+			$query  .=	' AND a.status_id in ('. $this->getListSQL($filter_data['status_id'], $ph) .') ';
+		}
+		if ( isset($filter_data['schedule_policy_id']) AND isset($filter_data['schedule_policy_id'][0]) AND !in_array(-1, (array)$filter_data['schedule_policy_id']) ) {
+			$query  .=	' AND a.schedule_policy_id in ('. $this->getListSQL($filter_data['schedule_policy_id'], $ph) .') ';
+		}
+		if ( isset($filter_data['pay_period_id']) AND isset($filter_data['pay_period_id'][0]) AND !in_array(-1, (array)$filter_data['pay_period_id']) ) {
+			$query .= 	' AND c.pay_period_id in ('. $this->getListSQL($filter_data['pay_period_id'], $ph) .') ';
+		}
+
+
+		//Use the job_id in the schedule table so we can filter by '0' or No Job
+		if ( isset($filter_data['include_job_id']) AND isset($filter_data['include_job_id'][0]) AND !in_array(-1, (array)$filter_data['include_job_id']) ) {
+			$query  .=	' AND a.job_id in ('. $this->getListSQL($filter_data['include_job_id'], $ph) .') ';
+		}
+		if ( isset($filter_data['exclude_job_id']) AND isset($filter_data['exclude_job_id'][0]) AND !in_array(-1, (array)$filter_data['exclude_job_id']) ) {
+			$query  .=	' AND a.job_id not in ('. $this->getListSQL($filter_data['exclude_job_id'], $ph) .') ';
+		}
+		if ( isset($filter_data['job_group_id']) AND isset($filter_data['job_group_id'][0]) AND !in_array(-1, (array)$filter_data['job_group_id']) ) {
+			if ( isset($filter_data['include_job_subgroups']) AND (bool)$filter_data['include_job_subgroups'] == TRUE ) {
+				$uglf = new UserGroupListFactory();
+				$filter_data['job_group_id'] = $uglf->getByCompanyIdAndGroupIdAndjob_subgroupsArray( $company_id, $filter_data['job_group_id'], TRUE);
+			}
+			$query  .=	' AND w.group_id in ('. $this->getListSQL($filter_data['job_group_id'], $ph) .') ';
+		}
+
+		if ( isset($filter_data['job_item_id']) AND isset($filter_data['job_item_id'][0]) AND !in_array(-1, (array)$filter_data['job_item_id']) ) {
+			$query  .=	' AND b.job_item_id in ('. $this->getListSQL($filter_data['job_item_id'], $ph) .') ';
+		}
+
+
+		if ( isset($filter_data['start_date']) AND trim($filter_data['start_date']) != '' ) {
+			$ph[] = $this->db->BindTimeStamp($filter_data['start_date']);
+			$query  .=	' AND a.start_time >= ?';
+		}
+		if ( isset($filter_data['end_date']) AND trim($filter_data['end_date']) != '' ) {
+			$ph[] = $this->db->BindTimeStamp($filter_data['end_date']);
+			$query  .=	' AND a.start_time <= ?';
+		}
+
+		if ( isset($filter_data['created_by']) AND isset($filter_data['created_by'][0]) AND !in_array(-1, (array)$filter_data['created_by']) ) {
+			$query  .=	' AND a.created_by in ('. $this->getListSQL($filter_data['created_by'], $ph) .') ';
+		}
+		if ( isset($filter_data['updated_by']) AND isset($filter_data['updated_by'][0]) AND !in_array(-1, (array)$filter_data['updated_by']) ) {
+			$query  .=	' AND a.updated_by in ('. $this->getListSQL($filter_data['updated_by'], $ph) .') ';
+		}
+
+		$query .= 	'
+						AND (a.deleted = 0 AND c.deleted = 0 AND d.deleted = 0)
+					';
+		$query .= $this->getWhereSQL( $where );
+		$query .= $this->getSortSQL( $order, $strict, $additional_order_fields );
+
+		Debug::text('Query: '. $query, __FILE__, __LINE__, __METHOD__, 10);
+
+		if ($limit == NULL) {
+			$this->rs = $this->db->Execute($query, $ph);
+		} else {
+			$this->rs = $this->db->PageExecute($query, $limit, $page, $ph);
+		}
+
+		return $this;
 	}
 }
 ?>
