@@ -1,29 +1,42 @@
 <?php
 /*********************************************************************************
- * The contents of this file are subject to the TimeTrex Public License Version
- * 1.1.0 ("License"); You may not use this file except in compliance with the
- * License. You may obtain a copy of the License at http://www.TimeTrex.com/TPL
- * Software distributed under the License is distributed on an "AS IS" basis,
- * WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the License
- * for the specific language governing rights and limitations under the
- * License.
+ * TimeTrex is a Payroll and Time Management program developed by
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
  *
- * All copies of the Covered Code must include on each user interface screen:
- *    (i) the "Powered by TimeTrex" logo and
- *    (ii) the TimeTrex copyright notice
- * in the same form as they appear in the distribution.  See full license for
- * requirements.
+ * This program is free software; you can redistribute it and/or modify it under
+ * the terms of the GNU Affero General Public License version 3 as published by
+ * the Free Software Foundation with the addition of the following permission
+ * added to Section 15 as permitted in Section 7(a): FOR ANY PART OF THE COVERED
+ * WORK IN WHICH THE COPYRIGHT IS OWNED BY TIMETREX, TIMETREX DISCLAIMS THE
+ * WARRANTY OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
  *
- * The Original Code is: TimeTrex Open Source
- * The Initial Developer of the Original Code is TimeTrex Payroll Services
- * Portions created by TimeTrex are Copyright (C) 2004-2007 TimeTrex Payroll Services;
- * All Rights Reserved.
+ * This program is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+ * FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
+ * details.
  *
+ * You should have received a copy of the GNU Affero General Public License along
+ * with this program; if not, see http://www.gnu.org/licenses or write to the Free
+ * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+ * 02110-1301 USA.
+ *
+ * You can contact TimeTrex headquarters at Unit 22 - 2475 Dobbin Rd. Suite
+ * #292 Westbank, BC V4T 2E9, Canada or at email address info@timetrex.com.
+ *
+ * The interactive user interfaces in modified source and object code versions
+ * of this program must display Appropriate Legal Notices, as required under
+ * Section 5 of the GNU Affero General Public License version 3.
+ *
+ * In accordance with Section 7(b) of the GNU Affero General Public License
+ * version 3, these Appropriate Legal Notices must retain the display of the
+ * "Powered by TimeTrex" logo. If the display of the logo is not reasonably
+ * feasible for technical reasons, the Appropriate Legal Notices must display
+ * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2426 $
- * $Id: TimeTrexSoapServerUnAuthenticated.class.php 2426 2009-02-18 22:39:19Z ipso $
- * $Date: 2009-02-18 14:39:19 -0800 (Wed, 18 Feb 2009) $
+ * $Revision: 3143 $
+ * $Id: TimeTrexSoapServerUnAuthenticated.class.php 3143 2009-12-02 17:21:41Z ipso $
+ * $Date: 2009-12-02 09:21:41 -0800 (Wed, 02 Dec 2009) $
  */
 
 /**
@@ -279,8 +292,8 @@ class TimeTrexSoapServerUnAuthenticated {
 						'latest_version_schedule' => 3600,
 						'latest_version_schedule_random' => 600,
 						'latest_data_schedule' => 3600,
-						'auto_submit_timeout' => 5,
-						'auto_submit_timeout_increment' => 3,
+						'auto_submit_timeout' => 10,
+						'auto_submit_timeout_increment' => 5,
 						'auto_submit_timeout_max' => 20,
 						'punch_dump_schedule' => 1600,
 						'flap_offline_time' => 1600,
@@ -615,8 +628,23 @@ class TimeTrexSoapServerUnAuthenticated {
 
 			if ( $company_id != FALSE ) {
 				//Gets all users allowed to punch in/out from this station
+				$jlf = new JobListFactory();
+				$job_to_user_map = $jlf->getJobToUserMapByCompanyIdAndStatus( $company_id, 10 );
+				if ( is_array($job_to_user_map) ) {
+					foreach( $job_to_user_map as $key => $arr ) {
+						$list["'$key'"] = array(
+										'job_id' => (int)$arr['job_id'],
+										'user_id' => (int)$arr['user_id'],
+										);
+					}
+
+					if ( isset($list) ) {
+						return $list;
+					}
+				}
+
+				/*
 				$jualf = new JobUserAllowListFactory();
-				//$jlf->getByCompanyIdAndUserIdAndStatus( $company_id,  $current_user->getId(), array(10), TRUE );
 				$jualf->getByCompanyIdAndStatus( $company_id, 10);
 				if ( $jualf->getRecordCount() > 0 ) {
 					$x=0;
@@ -633,6 +661,7 @@ class TimeTrexSoapServerUnAuthenticated {
 						return $list;
 					}
 				}
+				*/
 			}
 
 		}
@@ -710,8 +739,22 @@ class TimeTrexSoapServerUnAuthenticated {
 
 			if ( $company_id != FALSE ) {
 				//Gets all users allowed to punch in/out from this station
+				$jilf = new JobItemListFactory();
+				$job_to_job_item_map = $jilf->getJobToJobItemMapByCompanyIdAndStatus( $company_id, 10 );
+				if ( is_array($job_to_job_item_map) ) {
+					foreach( $job_to_job_item_map as $key => $arr ) {
+						$list["'$key'"] = array(
+										'job_id' => (int)$arr['job_id'],
+										'job_item_id' => (int)$arr['job_item_id'],
+										);
+					}
+
+					if ( isset($list) ) {
+						return $list;
+					}
+				}
+/*
 				$jialf = new JobItemAllowListFactory();
-				//$jlf->getByCompanyIdAndUserIdAndStatus( $company_id,  $current_user->getId(), array(10), TRUE );
 				$jialf->getByCompanyIdAndStatus( $company_id, 10);
 				if ( $jialf->getRecordCount() > 0 ) {
 					$x=0;
@@ -728,6 +771,7 @@ class TimeTrexSoapServerUnAuthenticated {
 						return $list;
 					}
 				}
+*/
 			}
 
 		}
@@ -799,6 +843,7 @@ class TimeTrexSoapServerUnAuthenticated {
 		foreach( $retarr as $station_id => $line_arr) {
 			array_unshift( $line_arr, '---------------- Data Uploaded By: '. $_SERVER['REMOTE_ADDR'] .' At: '. TTDate::getDate('DATE+TIME', $upload_time) .' ----------------'."\n");
 
+			Debug::Text('Station ID: '. $station_id, __FILE__, __LINE__, __METHOD__,10);
 			if ( $station_id != 'no_station_id' ) {
 				//Get Company Short name for station_id
 				$slf = new StationListFactory();
@@ -806,6 +851,8 @@ class TimeTrexSoapServerUnAuthenticated {
 				if ( $slf->getRecordCount() > 0 ) {
 					$s_obj = $slf->getCurrent();
 					$company_name = $s_obj->getCompanyObject()->getShortName();
+
+					//FIXME: Check to make sure the company is still active before proceeding.
 				} else {
 					$company_name = 'no_company';
 				}
@@ -814,7 +861,7 @@ class TimeTrexSoapServerUnAuthenticated {
 				$company_name = 'no_company';
 			}
 
-			$dir = $base_dir . $company_name . DIRECTORY_SEPARATOR;;
+			$dir = $base_dir . preg_replace('/[^a-zA-Z0-9]/', '', escapeshellarg( trim($company_name) ) ) . DIRECTORY_SEPARATOR; //Remove all non-alphanumeric chars.
 
 			if ( !file_exists($dir) ) {
 				mkdir($dir);
@@ -915,7 +962,7 @@ class TimeTrexSoapServerUnAuthenticated {
 						'station_id' => '7D00000023352A81'
 						);
 */
-		Debug::Arr($data, 'offlinePunchDataArr', __FILE__, __LINE__, __METHOD__,10);
+		//Debug::Arr($data, 'offlinePunchDataArr', __FILE__, __LINE__, __METHOD__,10);
 
 
 		//One punch per row
@@ -924,9 +971,9 @@ class TimeTrexSoapServerUnAuthenticated {
 			Debug::Text('--------------------------========================---------------------------', __FILE__, __LINE__, __METHOD__,10);
 			Debug::Text('--------------------------========================---------------------------', __FILE__, __LINE__, __METHOD__,10);
 
-			Debug::Text('Row Key: '. $row_key .' Time: '. $punch_row['time_stamp'], __FILE__, __LINE__, __METHOD__,10);
+			Debug::Text('Row Key: '. $row_key .' Date: '. $punch_row['date_stamp'] .' Time: '. $punch_row['time_stamp'] .' Station ID: '. $punch_row['station_id'], __FILE__, __LINE__, __METHOD__,10);
 
-			if ( isset( $punch_row['station_id']) )  {
+			if ( isset( $punch_row['station_id'] ) )  {
 				$slf = new StationListFactory();
 				$slf->getByStationId( $punch_row['station_id'] );
 				if ( $slf->getRecordCount() > 0 ) {
@@ -959,14 +1006,11 @@ class TimeTrexSoapServerUnAuthenticated {
 				continue;
 			}
 
-			$pcf = new PunchControlFactory();
-			$pf = new PunchFactory();
-			$slf = new ScheduleListFactory();
-
-			//FIXME: If we start trans here, the count is off when a duplicate punch comes in
-			//So the transaction is never committed...
-			//Transactions seem to work fine otherwise though.
-			//$pf->StartTransaction();
+			//Check to make sure the station is allowed.
+			if ( is_object($current_station) AND is_object($current_user) AND $current_station->checkAllowed( $current_user->getId(), $current_station->getStation(), $current_station->getType() ) == FALSE ) {
+				Debug::text('Station NOT allowed: Station ID: '. $current_station->getId() .' User: '. $current_user->getId(), __FILE__, __LINE__, __METHOD__, 10);
+				continue;
+			}
 
 			$punch_full_time_stamp = TTDate::strtotime( $punch_row['date_stamp'].' '.$punch_row['time_stamp'] );
 			//Make sure time stamp converts properly, otherwise skip this punch.
@@ -975,16 +1019,15 @@ class TimeTrexSoapServerUnAuthenticated {
 				continue;
 			}
 
-			/*
-			//As of version 1.5.1 the offset is pre-applied and displayed in the punch window.
-			//It sends the offset in with each punch, but it is ignored.
-			if ( isset($punch_row['offset']) ) {
-				Debug::Text('Date/Time Offset: '. $punch_row['offset'], __FILE__, __LINE__, __METHOD__,10);
-				$punch_full_time_stamp = $punch_full_time_stamp - $punch_row['offset'];
-			}
-			*/
 			Debug::Text('Punch Date/Time: '. $punch_full_time_stamp .' Offset that was already applied: '. $punch_row['offset'], __FILE__, __LINE__, __METHOD__,10);
 
+			$fail_transaction = FALSE;
+
+			$pf = new PunchFactory();
+			$pf->StartTransaction();
+
+			$slf = new ScheduleListFactory();
+
 			//Auto Punch
 			if ( ( isset($punch_row['status_id']) AND $punch_row['status_id'] == 0 )
 					OR ( isset($punch_row['type_id']) AND $punch_row['type_id'] == 0 )
@@ -1029,36 +1072,26 @@ class TimeTrexSoapServerUnAuthenticated {
 					$type_id = $prev_punch_obj->getNextType();
 					$status_id = $prev_punch_obj->getNextStatus();
 
-					//CHeck for meal policy window.
-					$prev_punch_obj->setScheduleID( $punch_full_time_stamp );
-					if ( is_object( $prev_punch_obj->getScheduleObject() )
-							AND is_object($prev_punch_obj->getScheduleObject()->getSchedulePolicyObject() )
-							AND is_object($prev_punch_obj->getScheduleObject()->getSchedulePolicyObject()->getMealPolicyObject() )
-							AND $prev_punch_obj->getType() != 20 ) {
-						Debug::Text(' Found Schedule Meal Policy Object: Start Window: '. $prev_punch_obj->getScheduleObject()->getSchedulePolicyObject()->getMealPolicyObject()->getStartWindow(), __FILE__, __LINE__, __METHOD__,10);
+					$next_type = $prev_punch_obj->getNextType();
 
-						if ( $punch_full_time_stamp >= ($prev_punch_obj->getScheduleObject()->getStartTime() + $prev_punch_obj->getScheduleObject()->getSchedulePolicyObject()->getMealPolicyObject()->getStartWindow() )
-								AND $punch_full_time_stamp <= ($prev_punch_obj->getScheduleObject()->getStartTime() + $prev_punch_obj->getScheduleObject()->getSchedulePolicyObject()->getMealPolicyObject()->getStartWindow() + $prev_punch_obj->getScheduleObject()->getSchedulePolicyObject()->getMealPolicyObject()->getWindowLength() ) ) {
+					//Check for break policy window.
+					if ( $next_type != 30 AND ( $prev_punch_obj->getStatus() != 30 AND $prev_punch_obj->getType() != 30 ) ) {
+						$prev_punch_obj->setUser( $current_user->getId() );
+						$prev_punch_obj->setScheduleID( $prev_punch_obj->findScheduleID( $punch_full_time_stamp ) );
+						if ( $prev_punch_obj->inBreakPolicyWindow( $punch_full_time_stamp, $prev_punch_obj->getTimeStamp() ) == TRUE ) {
+							Debug::Text(' Setting Type to Break: ', __FILE__, __LINE__, __METHOD__,10);
+							$next_type = 30;
+						}
+					}
+
+					//Check for meal policy window.
+					if ( $next_type != 20 AND ( $prev_punch_obj->getStatus() != 20 AND $prev_punch_obj->getType() != 20 ) ) {
+						$prev_punch_obj->setUser( $current_user->getId() );
+						$prev_punch_obj->setScheduleID( $prev_punch_obj->findScheduleID( $punch_full_time_stamp ) );
+						if ( $prev_punch_obj->inMealPolicyWindow( $punch_full_time_stamp, $prev_punch_obj->getTimeStamp() ) == TRUE ) {
 							Debug::Text(' Setting Type to Lunch: ', __FILE__, __LINE__, __METHOD__,10);
-							$type_id = 20;
+							$next_type = 20;
 						}
-					} elseif ( is_object($prev_punch_obj) AND $prev_punch_obj->getType() != 20 ) {
-						//Check NON-scheduled meal policies
-						$mplf = new MealPolicyListFactory();
-						$mplf->getByPolicyGroupUserId( $punch_row['user_id'] );
-						if ( $mplf->getRecordCount() > 0 ) {
-							$mp_obj = $mplf->getCurrent();
-							Debug::Text(' Found NON Schedule Meal Policy start Window: '. $mp_obj->getStartWindow(), __FILE__, __LINE__, __METHOD__,10);
-
-							if ( $punch_full_time_stamp >= ($prev_punch_obj->getTimeStamp() + $mp_obj->getStartWindow())
-									AND $punch_full_time_stamp <= ($prev_punch_obj->getTimeStamp() + $mp_obj->getStartWindow() + $mp_obj->getWindowLength() ) ) {
-								Debug::Text(' Setting Type to Lunch: ', __FILE__, __LINE__, __METHOD__,10);
-								$type_id = 20;
-							}
-						} else {
-							Debug::Text(' DID NOT Find NON Schedule Meal Policy start Window: ', __FILE__, __LINE__, __METHOD__,10);
-						}
-						unset($mplf, $mp_obj);
 					}
 				} else {
 					Debug::Text(' DID NOT Find Previous Punch within Continuous Time from now: ', __FILE__, __LINE__, __METHOD__,10);
@@ -1075,6 +1108,22 @@ class TimeTrexSoapServerUnAuthenticated {
 					} else {
 						$branch_id = $current_user->getDefaultBranch();
 						$department_id = $current_user->getDefaultDepartment();
+
+						//Check station for default/forced settings.
+						if ( is_object($current_station) ) {
+							if ( $current_station->getDefaultBranch() !== FALSE AND $current_station->getDefaultBranch() != 0 ) {
+								$branch_id = $current_station->getDefaultBranch();
+							}
+							if ( $current_station->getDefaultDepartment() !== FALSE AND $current_station->getDefaultDepartment() != 0 ) {
+								$department_id = $current_station->getDefaultDepartment();
+							}
+							if ( $current_station->getDefaultJob() !== FALSE AND $current_station->getDefaultJob() != 0 ) {
+								$job_id = $current_station->getDefaultJob();
+							}
+							if ( $current_station->getDefaultJobItem() !== FALSE AND $current_station->getDefaultJobItem() != 0 ) {
+								$job_item_id = $current_station->getDefaultJobItem();
+							}
+						}
 					}
 
 					$status_id = 10; //In
@@ -1082,42 +1131,42 @@ class TimeTrexSoapServerUnAuthenticated {
 				}
 
 				if ( isset($punch_row['status_id']) AND $punch_row['status_id'] != 0 ) {
-					Debug::Text(' Status ID is NOT AUTO!', __FILE__, __LINE__, __METHOD__,10);
+					Debug::Text(' Status ID is NOT AUTO: '. $punch_row['status_id'], __FILE__, __LINE__, __METHOD__,10);
 					$status_id = $punch_row['status_id'];
 				}
 
 				if ( isset($punch_row['type_id']) AND $punch_row['type_id'] != 0 ) {
-					Debug::Text(' Type ID is NOT AUTO!', __FILE__, __LINE__, __METHOD__,10);
+					Debug::Text(' Type ID is NOT AUTO: '. $punch_row['type_id'], __FILE__, __LINE__, __METHOD__,10);
 					$type_id = $punch_row['type_id'];
 				}
 
 				if ( isset($punch_row['branch_id']) AND $punch_row['branch_id'] != 0 ) {
-					Debug::Text(' Branch ID is NOT AUTO!', __FILE__, __LINE__, __METHOD__,10);
+					Debug::Text(' Branch ID is NOT AUTO: '. $punch_row['branch_id'], __FILE__, __LINE__, __METHOD__,10);
 					$branch_id = $punch_row['branch_id'];
 				}
 
 				if ( isset($punch_row['department_id']) AND $punch_row['department_id'] != 0 ) {
-					Debug::Text(' Department ID is NOT AUTO!', __FILE__, __LINE__, __METHOD__,10);
+					Debug::Text(' Department ID is NOT AUTO: '. $punch_row['department_id'], __FILE__, __LINE__, __METHOD__,10);
 					$department_id = $punch_row['department_id'];
 				}
 
 				if ( isset($punch_row['job_id']) AND $punch_row['job_id'] != 0 ) {
-					Debug::Text(' Job ID is NOT AUTO!', __FILE__, __LINE__, __METHOD__,10);
+					Debug::Text(' Job ID is NOT AUTO: '. $punch_row['job_id'], __FILE__, __LINE__, __METHOD__,10);
 					$job_id = $punch_row['job_id'];
 				}
 
 				if ( isset($punch_row['job_item_id']) AND $punch_row['job_item_id'] != 0 ) {
-					Debug::Text(' Job Item ID is NOT AUTO!', __FILE__, __LINE__, __METHOD__,10);
+					Debug::Text(' Job Item ID is NOT AUTO: '. $punch_row['job_item_id'], __FILE__, __LINE__, __METHOD__,10);
 					$job_item_id = $punch_row['job_item_id'];
 				}
 
 				if ( isset($punch_row['quantity']) ) {
-					Debug::Text(' Quantity is NOT AUTO!', __FILE__, __LINE__, __METHOD__,10);
+					Debug::Text(' Quantity is NOT AUTO: '. $punch_row['quantity'], __FILE__, __LINE__, __METHOD__,10);
 					$quantity = $punch_row['quantity'];
 				}
 
 				if ( isset($punch_row['bad_quantity']) ) {
-					Debug::Text(' Bad Quantity is NOT AUTO!', __FILE__, __LINE__, __METHOD__,10);
+					Debug::Text(' Bad Quantity is NOT AUTO: '. $punch_row['bad_quantity'], __FILE__, __LINE__, __METHOD__,10);
 					$bad_quantity = $punch_row['bad_quantity'];
 				}
 
@@ -1132,154 +1181,127 @@ class TimeTrexSoapServerUnAuthenticated {
 				$bad_quantity = $punch_row['bad_quantity'];
 			}
 
-			//Save Punch Control first
-			if ( isset($status_id) AND $status_id == 20 ) { //Out
-				if ( isset($punch_row['punch_control_id'])
-						AND $punch_row['punch_control_id'] != ''
-						AND $punch_row['punch_control_id'] != 0 ) {
-					Debug::Text(' Using Passed Punch Control ID: '. $punch_row['punch_control_id'], __FILE__, __LINE__, __METHOD__,10);
-					$pcf->setId( $punch_row['punch_control_id'] );
+			//Set User before setTimeStamp so rounding can be done properly.
+			$pf->setUser( $punch_row['user_id'] );
+
+			if ( isset($punch_row['transfer']) AND $punch_row['transfer'] == 1 ) {
+				Debug::Text(' Enabling Transfer!: ', __FILE__, __LINE__, __METHOD__,10);
+				$type_id = 10;
+				$status_id = 10;
+				$pf->setTransfer( TRUE );
+			}
+
+			$pf->setType( $type_id );
+			$pf->setStatus( $status_id );
+			$pf->setTimeStamp( $punch_full_time_stamp, TRUE ); //Make sure we round here.
+
+			if ( isset($status_id) AND $status_id == 20 AND isset( $punch_row['punch_control_id'] ) AND $punch_row['punch_control_id']  != '' AND $punch_row['punch_control_id'] != 0) {
+				$pf->setPunchControlID( $punch_row['punch_control_id'] );
+			} else {
+				$pf->setPunchControlID( $pf->findPunchControlID() );
+			}
+
+			$pf->setStation( $current_station->getId() );
+
+			if ( $pf->isNew() ) {
+				$pf->setActualTimeStamp( $punch_full_time_stamp );
+				$pf->setOriginalTimeStamp( $pf->getTimeStamp() );
+			}
+
+			if ( $pf->isValid() == TRUE ) {
+
+				if ( $pf->Save( FALSE ) == TRUE ) {
+					$pcf = new PunchControlFactory();
+					$pcf->setId( $pf->getPunchControlID() );
+					$pcf->setPunchObject( $pf );
+
+					if ( isset($branch_id) AND $branch_id != '') {
+						$pcf->setBranch( $branch_id );
+					}
+					if ( isset($department_id) AND $department_id != '' ) {
+						$pcf->setDepartment( $department_id );
+					}
+
+					if ( isset($job_id) AND $job_id != '' ) {
+						$pcf->setJob( $job_id );
+					}
+					if ( isset($job_item_id) AND $job_item_id != '') {
+						$pcf->setJobItem( $job_item_id );
+					}
+					if ( isset($quantity) AND $quantity != '' ) {
+						$pcf->setQuantity( $quantity );
+					}
+					if ( isset($bad_quantity) AND $bad_quantity != '' ) {
+						$pcf->setBadQuantity( $bad_quantity );
+					}
+
+					if ( isset($punch_row['note']) AND $punch_row['note'] != '' ) {
+						$pcf->setNote( $punch_row['note'] );
+					}
+
+					if ( isset($punch_row['other_id1']) AND $punch_row['other_id1'] != '' ) {
+						$pcf->setOtherID1( $punch_row['other_id1'] );
+					}
+					if ( isset($punch_row['other_id2']) AND $punch_row['other_id2'] != '' ) {
+						$pcf->setOtherID2( $punch_row['other_id2'] );
+					}
+					if ( isset($punch_row['other_id3']) AND $punch_row['other_id3'] != '' ) {
+						$pcf->setOtherID3( $punch_row['other_id3'] );
+					}
+					if ( isset($punch_row['other_id4']) AND $punch_row['other_id4'] != '' ) {
+						$pcf->setOtherID4( $punch_row['other_id4'] );
+					}
+					if ( isset($punch_row['other_id5']) AND $punch_row['other_id5'] != ''  ) {
+						$pcf->setOtherID5( $punch_row['other_id5'] );
+					}
+
+					$pcf->setEnableStrictJobValidation( TRUE );
+					$pcf->setEnableCalcUserDateID( TRUE );
+					$pcf->setEnableCalcTotalTime( TRUE );
+					$pcf->setEnableCalcSystemTotalTime( TRUE );
+					$pcf->setEnableCalcUserDateTotal( TRUE );
+					$pcf->setEnableCalcException( TRUE );
+					$pcf->setEnablePreMatureException( TRUE ); //Enable pre-mature exceptions at this point.
+
+					if ( $pcf->isValid() == TRUE ) {
+						Debug::Text(' Punch Control is valid, saving...: ', __FILE__, __LINE__, __METHOD__,10);
+
+						if ( $pcf->Save( TRUE, TRUE ) == TRUE ) { //Force isNew() lookup.
+							Debug::text('Saved Punch!', __FILE__, __LINE__, __METHOD__, 10);
+						} else {
+							Debug::text('PCF Save failed... Failing Transaction!', __FILE__, __LINE__, __METHOD__, 10);
+							$fail_transaction = TRUE;
+						}
+					} else {
+						Debug::text('PCF Validate failed... Failing Transaction!', __FILE__, __LINE__, __METHOD__, 10);
+						$fail_transaction = TRUE;
+					}
 				} else {
-					Debug::Text(' Checking for Previous Punch... User ID: '. $punch_row['user_id'] .' TimeStamp: '. $punch_full_time_stamp, __FILE__, __LINE__, __METHOD__,10);
-					$plf = new PunchListFactory();
-					$plf->getPreviousPunchByUserIDAndEpoch( $punch_row['user_id'], $punch_full_time_stamp );
-					if ($plf->getRecordCount() > 0 ) {
-						Debug::Text(' Found Previous Punch within Continuous Time from now: ', __FILE__, __LINE__, __METHOD__,10);
-						$prev_punch_obj = $plf->getCurrent();
-
-						$pcf->setId( $prev_punch_obj->getPunchControlId() );
-
-					} else {
-						Debug::Text(' Did not find previous punch!! BAD!...', __FILE__, __LINE__, __METHOD__,10);
-					}
+					Debug::text('PF Save failed... Failing Transaction!', __FILE__, __LINE__, __METHOD__, 10);
+					$fail_transaction = TRUE;
 				}
 			} else {
-				$status_id = 10; // In
+				Debug::text('PF Validate failed... Failing Transaction!', __FILE__, __LINE__, __METHOD__, 10);
+				$fail_transaction = TRUE;
 			}
 
-			if ( !isset($punch_row['user_date_id'] )
-					OR $punch_row['user_date_id'] == ''
-					OR $punch_row['user_date_id'] == 0 ) {
-				$pcf->findUserDate( $punch_row['user_id'], $punch_full_time_stamp, $status_id );
+			if ( $fail_transaction == FALSE ) {
+				$pf->CommitTransaction();
 			} else {
-				$pcf->setUserDateID( $punch_row['user_date_id'] );
+				$pf->FailTransaction();
 			}
 
-			if ( isset($branch_id) AND $branch_id != '') {
-				$pcf->setBranch( $branch_id );
-			}
-			if ( isset($department_id) AND $department_id != '' ) {
-				$pcf->setDepartment( $department_id );
-			}
-
-			if ( isset($job_id) AND $job_id != '' ) {
-				$pcf->setJob( $job_id );
-			}
-			if ( isset($job_item_id) AND $job_item_id != '') {
-				$pcf->setJobItem( $job_item_id );
-			}
-			if ( isset($quantity) AND $quantity != '' ) {
-				$pcf->setQuantity( $quantity );
-			}
-			if ( isset($bad_quantity) AND $bad_quantity != '' ) {
-				$pcf->setBadQuantity( $bad_quantity );
-			}
-
-			if ( isset($punch_row['note']) AND $punch_row['note'] != '' ) {
-				$pcf->setNote( $punch_row['note'] );
-			}
-
-			if ( isset($punch_row['other_id1']) AND $punch_row['other_id1'] != '' ) {
-				$pcf->setOtherID1( $punch_row['other_id1'] );
-			}
-			if ( isset($punch_row['other_id2']) AND $punch_row['other_id2'] != '' ) {
-				$pcf->setOtherID2( $punch_row['other_id2'] );
-			}
-			if ( isset($punch_row['other_id3']) AND $punch_row['other_id3'] != '' ) {
-				$pcf->setOtherID3( $punch_row['other_id3'] );
-			}
-			if ( isset($punch_row['other_id4']) AND $punch_row['other_id4'] != '' ) {
-				$pcf->setOtherID4( $punch_row['other_id4'] );
-			}
-			if ( isset($punch_row['other_id5']) AND $punch_row['other_id5'] != ''  ) {
-				$pcf->setOtherID5( $punch_row['other_id5'] );
-			}
-
-			if ( $pcf->isValid() ) {
-				$punch_control_id = $pcf->Save();
-
-				//If its an update, not a new insert
-				if ( $punch_control_id === TRUE ) {
-					Debug::Text(' Updating Punch Control Object', __FILE__, __LINE__, __METHOD__,10);
-
-					if ( isset($punch_row['punch_control_id']) AND $punch_row['punch_control_id'] != '' ) {
-						Debug::Text(' Using passed Punch Control ID...', __FILE__, __LINE__, __METHOD__,10);
-						$punch_control_id = $punch_row['punch_control_id'];
-					} elseif ( isset($prev_punch_obj) ) {
-						Debug::Text(' Using last Punch Control ID...', __FILE__, __LINE__, __METHOD__,10);
-						$punch_control_id = $prev_punch_obj->getPunchControlID();
-					} else {
-						Debug::Text(' Not Setting Punch Control ID, BAD!...', __FILE__, __LINE__, __METHOD__,10);
-					}
-				}
-				Debug::Text(' Punch Control ID: '. $punch_control_id, __FILE__, __LINE__, __METHOD__,10);
-
-				if ( isset($punch_row['transfer']) AND $punch_row['transfer'] == 1 ) {
-					Debug::Text(' Enabling Transfer!: ', __FILE__, __LINE__, __METHOD__,10);
-					$pf->setTransfer( TRUE );
-				}
-
-				$pf->setPunchControlID( $punch_control_id );
-
-				$pf->setType( $type_id );
-				$pf->setStatus( $status_id );
-				$pf->setTimeStamp( $punch_full_time_stamp, TRUE ); //Make sure we round here.
-
-				if ( $pf->isNew() ) {
-					Debug::Text(' Setting Actual TimeStamp!: ', __FILE__, __LINE__, __METHOD__,10);
-					$pf->setActualTimeStamp( $punch_full_time_stamp );
-					$pf->setOriginalTimeStamp( $pf->getTimeStamp() );
-				}
-
-				$pf->setStation( $current_station->getId() );
-
-				if ( $pf->isValid() ) {
-					$return_date = $pf->getTimeStamp();
-
-					$pf->setEnableCalcTotalTime( TRUE );
-					$pf->setEnableCalcSystemTotalTime( TRUE );
-					$pf->setEnableCalcUserDateTotal( TRUE );
-					//Because punches can be older then one day, we have to do this
-					//FIXME: queue up which days to calc exceptions on and run that later.
-					$pf->setEnableCalcException( TRUE );
-
-					if ( $pf->Save() == TRUE ) {
-						Debug::text('Saved Punch!', __FILE__, __LINE__, __METHOD__, 10);
-						//$pf->CommitTransaction();
-					} else {
-						Debug::text('Save failed... Failing Transaction!', __FILE__, __LINE__, __METHOD__, 10);
-						///$pf->FailTransaction();
-					}
-
-				} else {
-					Debug::text('Punch is NOT VALID... Failing Transaction ', __FILE__, __LINE__, __METHOD__, 10);
-					//$pf->FailTransaction();
-				}
-
-			} else {
-				Debug::text('bFailing Transaction!', __FILE__, __LINE__, __METHOD__, 10);
-				//$pf->FailTransaction();
-			}
-
-			//Fail all for now.
-			//$pf->FailTransaction();
-
 			unset($punch_full_time_stamp, $current_station, $current_user);
 			//End Foreach
 		}
 
 		return TRUE;
-		//return FALSE;
+	}
+
+	function __call( $name, $arguments ) {
+		Debug::text('ERROR: Attempting to call function that does not exist in this class! Class: '. __CLASS__ .' Function: '. $name, __FILE__, __LINE__, __METHOD__, 10);
+
+		return FALSE;
 	}
 }
 ?>
