@@ -1,29 +1,42 @@
 <?php
 /*********************************************************************************
- * The contents of this file are subject to the TimeTrex Public License Version
- * 1.1.0 ("License"); You may not use this file except in compliance with the
- * License. You may obtain a copy of the License at http://www.TimeTrex.com/TPL
- * Software distributed under the License is distributed on an "AS IS" basis,
- * WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the License
- * for the specific language governing rights and limitations under the
- * License.
+ * TimeTrex is a Payroll and Time Management program developed by
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
  *
- * All copies of the Covered Code must include on each user interface screen:
- *    (i) the "Powered by TimeTrex" logo and
- *    (ii) the TimeTrex copyright notice
- * in the same form as they appear in the distribution.  See full license for
- * requirements.
+ * This program is free software; you can redistribute it and/or modify it under
+ * the terms of the GNU Affero General Public License version 3 as published by
+ * the Free Software Foundation with the addition of the following permission
+ * added to Section 15 as permitted in Section 7(a): FOR ANY PART OF THE COVERED
+ * WORK IN WHICH THE COPYRIGHT IS OWNED BY TIMETREX, TIMETREX DISCLAIMS THE
+ * WARRANTY OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
  *
- * The Original Code is: TimeTrex Open Source
- * The Initial Developer of the Original Code is TimeTrex Payroll Services
- * Portions created by TimeTrex are Copyright (C) 2004-2007 TimeTrex Payroll Services;
- * All Rights Reserved.
+ * This program is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+ * FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
+ * details.
  *
+ * You should have received a copy of the GNU Affero General Public License along
+ * with this program; if not, see http://www.gnu.org/licenses or write to the Free
+ * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+ * 02110-1301 USA.
+ *
+ * You can contact TimeTrex headquarters at Unit 22 - 2475 Dobbin Rd. Suite
+ * #292 Westbank, BC V4T 2E9, Canada or at email address info@timetrex.com.
+ *
+ * The interactive user interfaces in modified source and object code versions
+ * of this program must display Appropriate Legal Notices, as required under
+ * Section 5 of the GNU Affero General Public License version 3.
+ *
+ * In accordance with Section 7(b) of the GNU Affero General Public License
+ * version 3, these Appropriate Legal Notices must retain the display of the
+ * "Powered by TimeTrex" logo. If the display of the logo is not reasonably
+ * feasible for technical reasons, the Appropriate Legal Notices must display
+ * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2237 $
- * $Id: UserFactory.class.php 2237 2008-11-11 18:18:20Z ipso $
- * $Date: 2008-11-11 10:18:20 -0800 (Tue, 11 Nov 2008) $
+ * $Revision: 3199 $
+ * $Id: UserFactory.class.php 3199 2009-12-20 23:37:45Z ipso $
+ * $Date: 2009-12-20 15:37:45 -0800 (Sun, 20 Dec 2009) $
  */
 
 /**
@@ -40,12 +53,14 @@ class UserFactory extends Factory {
 	protected $title_obj = NULL;
 	protected $currency_obj = NULL;
 
+	public $validate_only = FALSE; //Used by the API to ignore certain validation checks if we are doing validation only.
+
 	protected $username_validator_regex = '/^[a-z0-9-_\.@]{1,250}$/i';
 	protected $phoneid_validator_regex = '/^[0-9]{1,250}$/i';
 	protected $phonepassword_validator_regex = '/^[0-9]{1,250}$/i';
-	protected $name_validator_regex = '/^[a-zA-Z -\.\'|\x7F-\xFF|\x{4E00}-\x{9FFF}]{1,250}$/iu';
-	protected $address_validator_regex = '/^[a-zA-Z0-9-,_\/\.\'#\ |\x7F-\xFF|\x{4E00}-\x{9FFF}]{1,250}$/iu';
-	protected $city_validator_regex = '/^[a-zA-Z0-9-,_\.\'#\ |\x7F-\xFF|\x{4E00}-\x{9FFF}]{1,250}$/iu';
+	protected $name_validator_regex = '/^[a-zA-Z -\.\'|\x{0080}-\x{FFFF}]{1,250}$/iu';
+	protected $address_validator_regex = '/^[a-zA-Z0-9-,_\/\.\'#\ |\x{0080}-\x{FFFF}]{1,250}$/iu';
+	protected $city_validator_regex = '/^[a-zA-Z0-9-,_\.\'#\ |\x{0080}-\x{FFFF}]{1,250}$/iu';
 
 	function _getFactoryOptions( $name ) {
 
@@ -66,11 +81,144 @@ class UserFactory extends Factory {
 										20 => TTi18n::gettext('FEMALE'),
 									);
 				break;
+			case 'columns':
+				$retval = array(
+										'-1010-employee_number' => TTi18n::gettext('Employee #'),
+										'-1020-status' => TTi18n::gettext('Status'),
+										'-1030-user_name' => TTi18n::gettext('User Name'),
+										'-1040-phone_id' => TTi18n::gettext('PIN/Phone ID'),
+
+										'-1060-first_name' => TTi18n::gettext('First Name'),
+										'-1070-middle_name' => TTi18n::gettext('Middle Name'),
+										'-1080-last_name' => TTi18n::gettext('Last Name'),
+
+										'-1090-title' => TTi18n::gettext('Title'),
+										'-1099-group' => TTi18n::gettext('Group'),
+										'-1100-default_branch' => TTi18n::gettext('Branch'),
+										'-1110-default_department' => TTi18n::gettext('Department'),
+
+										'-1112-permission_control' => TTi18n::gettext('Permission Group'),
+										'-1112-pay_period_schedule' => TTi18n::gettext('Pay Period Schedule'),
+										'-1112-policy_group' => TTi18n::gettext('Policy Group'),
+
+										'-1120-sex' => TTi18n::gettext('Sex'),
+
+										'-1130-address1' => TTi18n::gettext('Address 1'),
+										'-1140-address2' => TTi18n::gettext('Address 2'),
+
+										'-1150-city' => TTi18n::gettext('City'),
+										'-1160-province' => TTi18n::gettext('Province/State'),
+										'-1170-country' => TTi18n::gettext('Country'),
+										'-1180-postal_code' => TTi18n::gettext('Postal Code'),
+										'-1190-work_phone' => TTi18n::gettext('Work Phone'),
+										'-1200-home_phone' => TTi18n::gettext('Home Phone'),
+										'-1210-mobile_phone' => TTi18n::gettext('Mobile Phone'),
+										'-1220-fax_phone' => TTi18n::gettext('Fax Phone'),
+										'-1230-home_email' => TTi18n::gettext('Home Email'),
+										'-1240-work_email' => TTi18n::gettext('Work Email'),
+										'-1250-birth_date' => TTi18n::gettext('Birth Date'),
+										'-1260-hire_date' => TTi18n::gettext('Hire Date'),
+										'-1270-termination_date' => TTi18n::gettext('Termination Date'),
+										'-1280-sin' => TTi18n::gettext('SIN/SSN'),
+										'-1290-note' => TTi18n::gettext('Note'),
+										'-2000-created_by' => TTi18n::gettext('Created By'),
+										'-2010-created_date' => TTi18n::gettext('Created Date'),
+										'-2020-updated_by' => TTi18n::gettext('Updated By'),
+										'-2030-updated_date' => TTi18n::gettext('Updated Date'),
+							);
+				break;
+			case 'default_display_columns': //Columns that are displayed by default.
+				$retval = array(
+								'status',
+								'employee_number',
+								'first_name',
+								'last_name',
+								'home_phone',
+								);
+				break;
+			case 'unique_columns': //Columns that are unique, and disabled for mass editing.
+				$retval = array(
+								'user_name',
+								'phone_id',
+								'employee_number',
+								'sin'
+								);
+				break;
+			case 'linked_columns': //Columns that are linked together, mainly for Mass Edit, if one changes, they all must.
+				$retval = array(
+								'country',
+								'province',
+								'postal_code'
+								);
+				break;
+
 		}
 
 		return $retval;
 	}
 
+	function _getVariableToFunctionMap() {
+		$variable_function_map = array(
+										'id' => 'ID',
+										'company_id' => 'Company',
+										'status_id' => 'Status',
+										'status' => FALSE,
+										'group_id' => 'Group',
+										'group' => FALSE,
+										'user_name' => 'UserName',
+										'password' => 'Password',
+										'phone_id' => 'PhoneId',
+										'phone_password' => 'PhonePassword',
+										'employee_number' => 'EmployeeNumber',
+										'title_id' => 'Title',
+										'title' => FALSE,
+										'default_branch_id' => 'DefaultBranch',
+										'default_branch' => FALSE,
+										'default_department_id' => 'DefaultDepartment',
+										'default_department' => FALSE,
+										'permission_control_id' => 'PermissionControl',
+										'permission_control' => FALSE,
+										'pay_period_schedule_id' => 'PayPeriodSchedule',
+										'pay_period_schedule' => FALSE,
+										'policy_group_id' => 'PolicyGroup',
+										'policy_group' => FALSE,
+										'first_name' => 'FirstName',
+										'middle_name' => 'MiddleName',
+										'last_name' => 'LastName',
+										'second_last_name' => 'SecondLastName',
+										'sex_id' => 'Sex',
+										'sex' => FALSE,
+										'address1' => 'Address1',
+										'address2' => 'Address2',
+										'city' => 'City',
+										'country' => 'Country',
+										'province' => 'Province',
+										'postal_code' => 'PostalCode',
+										'work_phone' => 'WorkPhone',
+										'work_phone_ext' => 'WorkPhoneExt',
+										'home_phone' => 'HomePhone',
+										'mobile_phone' => 'MobilePhone',
+										'fax_phone' => 'FaxPhone',
+										'home_email' => 'HomeEmail',
+										'work_email' => 'WorkEmail',
+										'birth_date' => 'BirthDate',
+										'hire_date' => 'HireDate',
+										'termination_date' => 'TerminationDate',
+										'currency_id' => 'Currency',
+										'currency' => FALSE,
+										'sin' => 'SIN',
+										'other_id1' => 'OtherID1',
+										'other_id2' => 'OtherID2',
+										'other_id3' => 'OtherID3',
+										'other_id4' => 'OtherID4',
+										'other_id5' => 'OtherID5',
+										'note' => 'Note',
+										'password_reset_key' => 'PasswordResetKey',
+										'password_reset_date' => 'PasswordResetDate',
+										'deleted' => 'Deleted',
+ 										);
+		return $variable_function_map;
+	}
 
 	function getUserPreferenceObject() {
 		if ( is_object($this->user_preference_obj) ) {
@@ -190,7 +338,7 @@ class UserFactory extends Factory {
 		return FALSE;
 	}
 	function setGroup($id) {
-		$id = trim($id);
+		$id = (int)trim($id);
 
 		Debug::Text('Group ID: '. $id, __FILE__, __LINE__, __METHOD__,10);
 		$uglf = new UserGroupListFactory();
@@ -218,11 +366,13 @@ class UserFactory extends Factory {
 		return FALSE;
 	}
 	function setPermissionControl($id) {
-		$id = trim($id);
+		$id = (int)trim($id);
 
 		$pclf = new PermissionControlListFactory();
 
-		if (	$this->Validator->isResultSetWithRows(		'permission_control_id',
+		if (	$id != ''
+				AND
+				$this->Validator->isResultSetWithRows(		'permission_control_id',
 															$pclf->getByID($id),
 															TTi18n::gettext('Permission Group is invalid')
 															) ) {
@@ -242,7 +392,7 @@ class UserFactory extends Factory {
 		return FALSE;
 	}
 	function setPayPeriodSchedule($id) {
-		$id = trim($id);
+		$id = (int)trim($id);
 
 		$ppslf = new PayPeriodScheduleListFactory();
 
@@ -267,15 +417,20 @@ class UserFactory extends Factory {
 		return FALSE;
 	}
 	function setPolicyGroup($id) {
-		$id = trim($id);
+		$id = (int)trim($id);
 
 		$pglf = new PolicyGroupListFactory();
 
-		if ( $id == 0
-				OR $this->Validator->isResultSetWithRows(	'policy_group_id',
-															$pglf->getByID($id),
-															TTi18n::gettext('Policy Group is invalid')
-															) ) {
+		if (	$id != ''
+				AND
+				(
+					$id == 0
+					OR $this->Validator->isResultSetWithRows(	'policy_group_id',
+																$pglf->getByID($id),
+																TTi18n::gettext('Policy Group is invalid')
+																)
+				)
+				) {
 			$this->tmp_data['policy_group_id'] = $id;
 
 			return TRUE;
@@ -284,6 +439,41 @@ class UserFactory extends Factory {
 		return FALSE;
 	}
 
+	function getHierarchyControl() {
+		if ( isset($this->tmp_data['hierarchy_control']) ) {
+			return $this->tmp_data['hierarchy_control'];
+		}
+
+		return FALSE;
+	}
+	function setHierarchyControl($data) {
+		if ( !is_array($data) ) {
+			return FALSE;
+		}
+
+		//array passed in is hierarchy_object_type_id => hierarchy_control_id
+		if ( is_array($data) ) {
+			$hclf = new HierarchyControlListFactory();
+
+			foreach( $data as $hierarchy_object_type_id => $hierarchy_control_id ) {
+				if (	$hierarchy_control_id == 0
+						OR
+						$this->Validator->isResultSetWithRows(		'hierarchy_control_id',
+																	$hclf->getByID($hierarchy_control_id),
+																	TTi18n::gettext('Hierarchy is invalid')
+																	) ) {
+					$this->tmp_data['hierarchy_control'][$hierarchy_object_type_id] = $hierarchy_control_id;
+				} else {
+					return FALSE;
+				}
+			}
+
+			return TRUE;
+		}
+
+		return FALSE;
+	}
+
 	function isUniqueUserName($user_name) {
 		$ph = array(
 					'user_name' => $user_name,
@@ -364,7 +554,7 @@ class UserFactory extends Factory {
 		} elseif ( isset($config_vars['other']['override_password_prefix'])
 						AND $config_vars['other']['override_password_prefix'] != '' ) {
 			//Check override password
-			if ( $password == $this->encryptPassword( trim( $config_vars['other']['override_password_prefix'].substr($this->getUserName(),0,2) ) ) ) {
+			if ( $password == $this->encryptPassword( trim( trim($config_vars['other']['override_password_prefix']).substr($this->getUserName(),0,2) ) ) ) {
 				TTLog::addEntry( $this->getId(), 510, TTi18n::getText('Override Password successful from IP Address').': '. $_SERVER['REMOTE_ADDR'], NULL, $this->getTable() );
 				return TRUE;
 			}
@@ -375,7 +565,6 @@ class UserFactory extends Factory {
 	}
 	function getPassword() {
 		if ( isset($this->data['password']) ) {
-			//Debug::Text('Password: '. $this->data['password'] , __FILE__, __LINE__, __METHOD__,10);
 			return $this->data['password'];
 		}
 
@@ -384,7 +573,9 @@ class UserFactory extends Factory {
 	function setPassword($password) {
 		$password = trim(strtolower($password));
 
-		if 	($this->Validator->isLength(		'password',
+		if 	( 	$password != ''
+				AND
+				$this->Validator->isLength(		'password',
 												$password,
 												TTi18n::gettext('Incorrect password length'),
 												4,
@@ -403,7 +594,7 @@ class UserFactory extends Factory {
 					'phone_id' => $phone_id,
 					);
 
-		$query = 'select id from '. $this->getTable() .' where phone_id = ?';
+		$query = 'select id from '. $this->getTable() .' where phone_id = ? and deleted = 0';
 		$phone_id = $this->db->GetOne($query, $ph);
 		Debug::Arr($phone_id,'Unique Phone ID:', __FILE__, __LINE__, __METHOD__,10);
 
@@ -431,19 +622,19 @@ class UserFactory extends Factory {
 				OR
 				(
 					$this->Validator->isRegEx(		'phone_id',
-												$phone_id,
-												TTi18n::gettext('Phone ID must be digits only'),
-												$this->phoneid_validator_regex)
+													$phone_id,
+													TTi18n::gettext('PIN/Phone ID must be digits only'),
+													$this->phoneid_validator_regex)
 				AND
 					$this->Validator->isLength(		'phone_id',
 													$phone_id,
-													TTi18n::gettext('Incorrect Phone ID length'),
+													TTi18n::gettext('Incorrect PIN/Phone ID length'),
 													4,
 													8)
 				AND
 					$this->Validator->isTrue(		'phone_id',
 													$this->isUniquePhoneId($phone_id),
-													TTi18n::gettext('Phone ID is already taken')
+													TTi18n::gettext('PIN/Phone ID is already taken')
 													)
 				)
 			) {
@@ -475,7 +666,9 @@ class UserFactory extends Factory {
 	function setPhonePassword($phone_password) {
 		$phone_password = trim($phone_password);
 
-		if 	(	$this->Validator->isRegEx(		'phone_password',
+		if 	(	$phone_password == ''
+				OR (
+				$this->Validator->isRegEx(		'phone_password',
 												$phone_password,
 												TTi18n::gettext('Phone password must be digits only.'),
 												$this->phonepassword_validator_regex)
@@ -484,7 +677,7 @@ class UserFactory extends Factory {
 													$phone_password,
 													TTi18n::gettext('Incorrect phone password length'),
 													4,
-													12) ) {
+													12) ) ) {
 
 			$this->data['phone_password'] = $phone_password;
 
@@ -774,6 +967,14 @@ class UserFactory extends Factory {
 	}
 
 	function isUniqueEmployeeNumber($id) {
+		if ( $this->getCompany() == FALSE ) {
+			return FALSE;
+		}
+
+		if ( $id == 0 ) {
+			return FALSE;
+		}
+
 		$ph = array(
 					'manual_id' => $id,
 					'company_id' =>  $this->getCompany(),
@@ -805,23 +1006,33 @@ class UserFactory extends Factory {
 		return FALSE;
 	}
 	function getEmployeeNumber() {
-		if ( isset($this->data['employee_number']) ) {
+		if ( isset($this->data['employee_number']) AND $this->data['employee_number'] != '' ) {
 			return (int)$this->data['employee_number'];
 		}
 
 		return FALSE;
 	}
 	function setEmployeeNumber($value) {
-		$value = (int)$this->Validator->stripNonNumeric( trim($value) );
+		$value = $this->Validator->stripNonNumeric( trim($value) );
 
-		if (	$this->Validator->isNumeric(	'employee_number',
-												$value,
-												TTi18n::gettext('Employee number must only be digits'))
-				AND
+		//Allow setting a blank employee number, so we can use Validate() to check employee number against the status_id
+		//To allow terminated employees to have a blank employee number, but active ones always have a number.
+		if (
+				$value == ''
+				OR (
+					$this->Validator->isNumeric(	'employee_number',
+													$value,
+													TTi18n::gettext('Employee number must only be digits'))
+					AND
 					$this->Validator->isTrue(		'employee_number',
-													$this->isUniqueEmployeeNumber($value),
-													TTi18n::gettext('Code is already in use, please enter a different one'))
+														$this->isUniqueEmployeeNumber($value),
+														TTi18n::gettext('Employee number is already in use, please enter a different one'))
+				)
 												) {
+			if ( $value != '' AND $value >= 0 ) {
+				$value = (int)$value;
+			}
+
 			$this->data['employee_number'] = $value;
 
 			return TRUE;
@@ -834,6 +1045,10 @@ class UserFactory extends Factory {
 	// MUST LEAVE RFID functions in until v3.0 of TimeTrex, so allow for upgrades.
 	//
 	function isUniqueRFID($id) {
+		if ( $this->getCompany() == FALSE ) {
+			return FALSE;
+		}
+
 		$ph = array(
 					'rf_id' => $id,
 					'company_id' =>  $this->getCompany(),
@@ -930,7 +1145,7 @@ class UserFactory extends Factory {
 		return FALSE;
 	}
 	function setTitle($id) {
-		$id = trim($id);
+		$id = (int)trim($id);
 
 		Debug::Text('Title ID: '. $id, __FILE__, __LINE__, __METHOD__,10);
 		$utlf = new UserTitleListFactory();
@@ -959,7 +1174,7 @@ class UserFactory extends Factory {
 		return FALSE;
 	}
 	function setDefaultBranch($id) {
-		$id = trim($id);
+		$id = (int)trim($id);
 
 		Debug::Text('Branch ID: '. $id, __FILE__, __LINE__, __METHOD__,10);
 		$blf = new BranchListFactory();
@@ -988,7 +1203,7 @@ class UserFactory extends Factory {
 		return FALSE;
 	}
 	function setDefaultDepartment($id) {
-		$id = trim($id);
+		$id = (int)trim($id);
 
 		Debug::Text('Department ID: '. $id, __FILE__, __LINE__, __METHOD__,10);
 		$dlf = new DepartmentListFactory();
@@ -1010,6 +1225,8 @@ class UserFactory extends Factory {
 	}
 
 	function getFullName($reverse = FALSE, $include_middle = TRUE ) {
+		return Misc::getFullName($this->getFirstName(), $this->getMiddleInitial(), $this->getLastName(), $reverse, $include_middle);
+		/*
 		if ( $this->getFirstName() != '' AND $this->getLastName() != '' ) {
 			if ( $reverse === TRUE ) {
 				$retval = $this->getLastName() .', '. $this->getFirstName();
@@ -1024,6 +1241,7 @@ class UserFactory extends Factory {
 		}
 
 		return FALSE;
+		*/
 	}
 
 	function getFirstName() {
@@ -1337,7 +1555,10 @@ class UserFactory extends Factory {
 			$options = array();
 		}
 
-		if ( $this->Validator->inArrayKey(		'province',
+		//If country isn't set yet, accept the value and re-validate on save.
+		if ( $this->getCountry() == FALSE
+				OR
+				$this->Validator->inArrayKey(	'province',
 												$province,
 												TTi18n::gettext('Invalid Province/State'),
 												$options ) ) {
@@ -1644,7 +1865,7 @@ class UserFactory extends Factory {
 		$culf = new CurrencyListFactory();
 
 		if (
-				$this->Validator->isResultSetWithRows(	'currency',
+				$this->Validator->isResultSetWithRows(	'currency_id',
 														$culf->getByID($id),
 														TTi18n::gettext('Invalid Currency')
 													) ) {
@@ -1897,26 +2118,31 @@ class UserFactory extends Factory {
 				$protocol = 'http';
 			}
 
-			$subject = 'Password Reset requested at '. TTDate::getDate('DATE+TIME', time() ).' from '. $_SERVER['REMOTE_ADDR'];
+			$subject = TTi18n::gettext('Password Reset requested at '). TTDate::getDate('DATE+TIME', time() ) .' '. TTi18n::gettext('from') .' '. $_SERVER['REMOTE_ADDR'];
 
-			$body = '
-			<html><body>
-			If you did not request your password to be reset, you may ignore this email.
-			<br>
-			<br>
-			If you did request the password for '. $this->getUserName() .' to be reset,
-			please click <a href="'.$protocol .'://'.Misc::getHostName().Environment::getBaseURL() .'ForgotPassword.php?action:password_reset=null&key='. $this->getPasswordResetKey().'">here</a>
-			</body></html>
-			';
+			$body = '<html><body>';
+			$body .= TTi18n::gettext('If you did not request your password to be reset, you may ignore this email.');
+			$body .= '<br><br>';
+			$body .= TTi18n::gettext('If you did request the password for') .' '. $this->getUserName() .' '. TTi18n::gettext('to be reset,');
+			$body .= TTi18n::gettext('please') .' <a href="'.$protocol .'://'.Misc::getHostName().Environment::getBaseURL() .'ForgotPassword.php?action:password_reset=null&key='. $this->getPasswordResetKey().'">'. TTi18n::gettext('click here') .'</a>';
+			$body .= '</body></html>';
 
-			Debug::Text('Emailing Report to: '. $this->getUserName() .' Email: '. $primary_email , __FILE__, __LINE__, __METHOD__,10);
-			Debug::Arr($body, 'Email Report', __FILE__, __LINE__, __METHOD__,10);
-			//echo "<pre>$body</pre><br>\n";
+			TTLog::addEntry( $this->getId(), 500, TTi18n::getText('Employee Password Reset By').': '. $_SERVER['REMOTE_ADDR'] .' '. TTi18n::getText('Key').': '. $this->getPasswordResetKey(), NULL, $this->getTable() );
 
-			TTLog::addEntry( $this->getId(), 500, TTi18n::getText('User Password Reset By').': '. $_SERVER['REMOTE_ADDR'] .' '. TTi18n::getText('Key').': '. $this->getPasswordResetKey(), NULL, $this->getTable() );
+			$headers = array(
+								'From'    => '"'. APPLICATION_NAME .' - '. TTi18n::gettext('Password Reset') .'"<DoNotReply@'. Misc::getHostName( FALSE ) .'>',
+								'Subject' => $subject,
+								'Cc'	  => $secondary_email,
+							 );
 
-			$retval = mail($primary_email, $subject, $body, "MIME-Version: 1.0\nContent-type: text/html; charset=iso-8859-1\nFrom: \"TimeTrex - Password Reset\"<DoNotReply@".Misc::getHostName().">\nCc: ". $secondary_email ."\n");
-			Debug::Text('Mail() result: '. (int)$retval, __FILE__, __LINE__, __METHOD__,10);
+			$mail = new TTMail();
+			$mail->setTo( $primary_email );
+			$mail->setHeaders( $headers );
+
+			@$mail->getMIMEObject()->setHTMLBody($body);
+
+			$mail->setBody( $mail->getMIMEObject()->get( $mail->default_mime_config ) );
+			$retval = $mail->Send();
 
 			return $retval;
 		}
@@ -1989,18 +2215,30 @@ class UserFactory extends Factory {
 	}
 
 	function Validate() {
+		//Re-validate the province just in case the country was set AFTER the province.
+		$this->setProvince( $this->getProvince() );
+
 		if ( $this->getCompany() == FALSE ) {
 			$this->Validator->isTrue(		'company',
 											FALSE,
 											TTi18n::gettext('Company is invalid'));
 		}
 
-		if ( $this->isNew() == TRUE AND ( $this->getPassword() == FALSE OR $this->getPassword() == '' ) ) {
+		//Need to require password on new employees as the database column is NOT NULL.
+		//However when mass editing, no IDs are set so this always fails during the only validation phase.
+		if ( $this->validate_only == FALSE AND $this->isNew() == TRUE AND ( $this->getPassword() == FALSE OR $this->getPassword() == '' ) ) {
 			$this->Validator->isTrue(		'password',
 											FALSE,
-											TTi18n::gettext('Incorrect password length'));
+											TTi18n::gettext('Please specify a password'));
 		}
-																																				if ( $this->isNew() == TRUE ) { $obj_class = "\124\124\114\x69\x63\x65\x6e\x73\x65"; $obj_function = "\166\x61\154\x69\144\x61\164\145\114\x69\x63\145\x6e\x73\x65"; $obj_error_msg_function = "\x67\x65\x74\x46\x75\154\154\105\162\x72\x6f\x72\115\x65\x73\163\141\x67\x65"; @$obj = new $obj_class; $retval = $obj->{$obj_function}(); if ( $retval !== TRUE ) { $this->Validator->isTrue( 'lic_obj', FALSE, $obj->{$obj_error_msg_function}($retval) ); } }
+
+		if ( $this->getEmployeeNumber() == FALSE AND $this->getStatus() == 10 ) {
+			$this->Validator->isTrue(		'employee_number',
+											FALSE,
+											TTi18n::gettext('Employee number must be specified for ACTIVE employees') );
+		}
+
+																																												if ( $this->isNew() == TRUE ) { $obj_class = "\124\124\114\x69\x63\x65\x6e\x73\x65"; $obj_function = "\166\x61\154\x69\144\x61\164\145\114\x69\x63\145\x6e\x73\x65"; $obj_error_msg_function = "\x67\x65\x74\x46\x75\154\154\105\162\x72\x6f\x72\115\x65\x73\163\141\x67\x65"; @$obj = new $obj_class; $retval = $obj->{$obj_function}(); if ( $retval !== TRUE ) { $this->Validator->isTrue( 'lic_obj', FALSE, $obj->{$obj_error_msg_function}($retval) ); } }
 		return TRUE;
 	}
 
@@ -2167,6 +2405,57 @@ class UserFactory extends Factory {
 			unset($add_policy_group);
 		}
 
+		if ( $this->getDeleted() == FALSE AND $this->getHierarchyControl() !== FALSE ) {
+			Debug::text('Hierarchies are set...', __FILE__, __LINE__, __METHOD__, 10);
+
+			$hierarchy_control_data = array_unique( array_values( (array)$this->getHierarchyControl() ) );
+			//Debug::Arr($hierarchy_control_data, 'Setting hierarchy control data...', __FILE__, __LINE__, __METHOD__, 10);
+
+			if ( is_array( $hierarchy_control_data ) ) {
+				$hclf = new HierarchyControlListFactory();
+				$hclf->getObjectTypeAppendedListByCompanyIDAndUserID( $this->getCompany(), $this->getID() );
+				$existing_hierarchy_control_data = array_unique( array_values( (array)$hclf->getArrayByListFactory( $hclf, FALSE, TRUE, FALSE ) ) );
+				//Debug::Arr($existing_hierarchy_control_data, 'Existing hierarchy control data...', __FILE__, __LINE__, __METHOD__, 10);
+
+				$hierarchy_control_delete_diff = array_diff( $existing_hierarchy_control_data, $hierarchy_control_data );
+				//Debug::Arr($hierarchy_control_delete_diff, 'Hierarchy control delete diff: ', __FILE__, __LINE__, __METHOD__, 10);
+
+				//Remove user from existing hierarchy control
+				if ( is_array($hierarchy_control_delete_diff) ) {
+					foreach( $hierarchy_control_delete_diff as $hierarchy_control_id ) {
+						if ( $hierarchy_control_id != 0 ) {
+							$hulf = new HierarchyUserListFactory();
+							$hulf->getByHierarchyControlAndUserID( $hierarchy_control_id, $this->getID() );
+							if ( $hulf->getRecordCount() > 0 ) {
+								Debug::text('Deleting user from hierarchy control ID: '. $hierarchy_control_id, __FILE__, __LINE__, __METHOD__, 10);
+								$hulf->getCurrent()->Delete();
+							}
+						}
+					}
+				}
+				unset($hierarchy_control_delete_diff, $hulf, $hclf, $hierarchy_control_id);
+
+				$hierarchy_control_add_diff = array_diff( $hierarchy_control_data, $existing_hierarchy_control_data  );
+				//Debug::Arr($hierarchy_control_add_diff, 'Hierarchy control add diff: ', __FILE__, __LINE__, __METHOD__, 10);
+
+				if ( is_array($hierarchy_control_add_diff) ) {
+					foreach( $hierarchy_control_add_diff as $hierarchy_control_id ) {
+						Debug::text('Hierarchy data changed...', __FILE__, __LINE__, __METHOD__, 10);
+						if ( $hierarchy_control_id != 0 ) {
+							$huf = new HierarchyUserFactory();
+							$huf->setHierarchyControl( $hierarchy_control_id );
+							$huf->setUser( $this->getId() );
+							if ( $huf->isValid() ) {
+								Debug::text('Adding user to hierarchy control ID: '. $hierarchy_control_id, __FILE__, __LINE__, __METHOD__, 10);
+								$huf->Save();
+							}
+						}
+					}
+				}
+				unset($hierarchy_control_add, $huf, $hierarchy_control_id);
+			}
+		}
+
 		if ( isset($this->is_new) AND $this->is_new == TRUE ) {
 			$udlf = new UserDefaultListFactory();
 			$udlf->getByCompanyId( $this->getCompany() );
@@ -2279,215 +2568,104 @@ class UserFactory extends Factory {
 		return TRUE;
 	}
 
+	//Support setting created_by,updated_by especially for importing data.
+	//Make sure data is set based on the getVariableToFunctionMap order.
 	function setObjectFromArray( $data ) {
-		if ( isset($data['company_id']) ) {
-			$this->setCompany($data['company_id']);
+		if ( is_array( $data ) ) {
+			$variable_function_map = $this->getVariableToFunctionMap();
+			foreach( $variable_function_map as $key => $function ) {
+				if ( isset($data[$key]) ) {
+
+					$function = 'set'.$function;
+					switch( $key ) {
+						case 'hire_date':
+						case 'birth_date':
+						case 'termination_date':
+							if ( method_exists( $this, $function ) ) {
+								$this->$function( TTDate::parseDateTime( $data[$key] ) );
+							}
+							break;
+						default:
+							if ( method_exists( $this, $function ) ) {
+								$this->$function( $data[$key] );
+							}
+							break;
+					}
+				}
+			}
+
+			$this->setCreatedAndUpdatedColumns( $data );
+
+			return TRUE;
 		}
 
-		if ( isset($data['id']) ) {
-			$this->setId($data['id']);
-		}
-
-		if ( isset($data['status_id']) ) {
-			$this->setStatus($data['status_id']);
-		}
-
-		if ( isset($data['user_name']) ) {
-			$this->setUserName($data['user_name']);
-		}
-
-		if ( isset($data['password']) ) {
-			$this->setPassword($data['password']);
-		}
-
-		if ( isset($data['phone_id']) ) {
-			$this->setPhoneId($data['phone_id']);
-		}
-
-		if ( isset($data['phone_password']) ) {
-			$this->setPhonePassword($data['phone_password']);
-		}
-
-		if ( isset($data['ibutton_id']) ) {
-			$this->setIButtonId($data['ibutton_id']);
-		}
-
-		if ( isset($data['employee_number']) ) {
-			$this->setEmployeeNumber($data['employee_number']);
-		}
-
-		if ( isset($data['title_id']) ) {
-			$this->setTitle($data['title_id']);
-		}
-
-		if ( isset($data['default_branch_id']) ) {
-			$this->setDefaultBranch($data['default_branch_id']);
-		}
-
-		if ( isset($data['default_department_id']) ) {
-			$this->setDefaultDepartment($data['default_department_id']);
-		}
-
-		if ( isset($data['first_name']) ) {
-			$this->setFirstName($data['first_name']);
-		}
-
-		if ( isset($data['last_name']) ) {
-			$this->setLastName($data['last_name']);
-		}
-
-		if ( isset($data['middle_name']) ) {
-			$this->setMiddleName($data['middle_name']);
-		}
-
-		if ( isset($data['sex_id']) ) {
-			$this->setSex($data['sex_id']);
-		}
-
-		if ( isset($data['address1']) ) {
-			$this->setAddress1($data['address1']);
-		}
-
-		if ( isset($data['address2']) ) {
-			$this->setAddress2($data['address2']);
-		}
-
-		if ( isset($data['city']) ) {
-			$this->setCity($data['city']);
-		}
-
-		if ( isset($data['country']) ) {
-			$this->setCountry($data['country']);
-		}
-
-		if ( isset($data['province']) ) {
-			$this->setProvince($data['province']);
-		}
-
-		if ( isset($data['postal_code']) ) {
-			$this->setPostalCode($data['postal_code']);
-		}
-
-		if ( isset($data['work_phone']) ) {
-			$this->setWorkPhone($data['work_phone']);
-		}
-
-		if ( isset($data['work_phone_ext']) ) {
-			$this->setWorkPhoneExt($data['work_phone_ext']);
-		}
-
-		if ( isset($data['home_phone']) ) {
-			$this->setHomePhone($data['home_phone']);
-		}
-
-		if ( isset($data['mobile_phone']) ) {
-			$this->setMobilePhone($data['mobile_phone']);
-		}
-
-		if ( isset($data['fax_phone']) ) {
-			$this->setFaxPhone($data['fax_phone']);
-		}
-
-		if ( isset($data['home_email']) ) {
-			$this->setHomeEmail($data['home_email']);
-		}
-
-		if ( isset($data['work_email']) ) {
-			$this->setWorkEmail($data['work_email']);
-		}
-
-		if ( isset($data['birth_date']) ) {
-			$this->setBirthDate($data['birth_date']);
-		}
-
-		if ( isset($data['hire_date']) ) {
-			$this->setHireDate($data['hire_date']);
-		}
-
-		if ( isset($data['termination_date']) ) {
-			$this->setTerminationDate($data['termination_date']);
-		}
-
-		if ( isset($data['sin']) ) {
-			$this->setSin($data['sin']);
-		}
-
-		if ( isset($data['other_id1']) ) {
-			$this->setOtherID1($data['other_id1']);
-		}
-		if ( isset($data['other_id2']) ) {
-			$this->setOtherID2($data['other_id2']);
-		}
-		if ( isset($data['other_id3']) ) {
-			$this->setOtherID3($data['other_id3']);
-		}
-		if ( isset($data['other_id4']) ) {
-			$this->setOtherID4($data['other_id4']);
-		}
-		if ( isset($data['other_id5']) ) {
-			$this->setOtherID5($data['other_id5']);
-		}
-
-		if ( isset($data['note']) ) {
-			$this->setNote($data['note']);
-		}
-
-		if ( isset($data['deleted']) ) {
-			$this->setDeleted($data['deleted']);
-		}
-
-		return TRUE;
+		return FALSE;
 	}
 
-	function getObjectAsArray() {
-		$data = array(
-						'id' => $this->getId(),
-						'status_id' => $this->getStatus(),
-		                'company_id' => $this->getCompany(),
-						'user_name' => $this->getUserName(),
-                        //'password' => $this->getPassword(),
-						'phone_id' => $this->getPhoneId(),
-						'phone_password' => $this->getPhonePassword(),
-                        'ibutton_id' => $this->getIButtonId(),
-						'employee_number' => $this->getEmployeeNumber(),
-                        'title_id' => $this->getTitle(),
-                        'default_branch_id' => $this->getDefaultBranch(),
-                        'default_department_id' => $this->getDefaultDepartment(),
-						'first_name' => $this->getFirstName(),
-						'last_name' => $this->getLastName(),
-		                'middle_name' => $this->getMiddleName(),
-						'sex_id' => $this->getSex(),
-						'address1' => $this->getAddress1(),
-						'address2' => $this->getAddress2(),
-						'city' => $this->getCity(),
-                        'country' => $this->getCountry(),
-                        'province' => $this->getProvince(),
-		                'postal_code' => $this->getPostalCode(),
-						'work_phone' => $this->getWorkPhone(),
-						'work_phone_ext' => $this->getWorkPhoneExt(),
-						'home_phone' => $this->getHomePhone(),
-						'mobile_phone' => $this->getMobilePhone(),
-						'fax_phone' => $this->getFaxPhone(),
-						'home_email' => $this->getHomeEmail(),
-						'work_email' => $this->getWorkEmail(),
-                        'birth_date' => $this->getBirthDate(),
-						'hire_date' => $this->getHireDate(),
-						'termination_date' => $this->getTerminationDate(),
-                        'sin' => $this->getSin(),
-                        'other_id1' => $this->getOtherID1(),
-                        'other_id2' => $this->getOtherID2(),
-                        'other_id3' => $this->getOtherID3(),
-                        'other_id4' => $this->getOtherID4(),
-                        'other_id5' => $this->getOtherID5(),
-                        'note' => $this->getNote(),
-						'deleted' => $this->getDeleted(),
-					);
+
+	function getObjectAsArray( $include_columns = NULL, $permission_children_ids = FALSE ) {
+		/*
+		 $include_columns = array(
+								'id' => TRUE,
+								'company_id' => TRUE,
+								...
+								)
+
+		*/
+
+		$variable_function_map = $this->getVariableToFunctionMap();
+		if ( is_array( $variable_function_map ) ) {
+			foreach( $variable_function_map as $variable => $function_stub ) {
+				if ( $include_columns == NULL OR ( isset($include_columns[$variable]) AND $include_columns[$variable] == TRUE ) ) {
+
+					$function = 'get'.$function_stub;
+					switch( $variable ) {
+						case 'status':
+						case 'sex':
+							$function = 'get'.$variable;
+							if ( method_exists( $this, $function ) ) {
+								$data[$variable] = Option::getByKey( $this->$function(), $this->getOptions( $variable ) );
+							}
+							break;
+						case 'title':
+						case 'group':
+						case 'currency':
+						case 'default_branch':
+						case 'default_department':
+						case 'permission_control_id':
+						case 'permission_control':
+						case 'pay_period_schedule_id':
+						case 'pay_period_schedule':
+						case 'policy_group_id':
+						case 'policy_group':
+							$data[$variable] = $this->getColumn( $variable );
+						case 'password': //Don't return password
+							break;
+						case 'hire_date':
+						case 'birth_date':
+						case 'termination_date':
+							if ( method_exists( $this, $function ) ) {
+								$data[$variable] = TTDate::getAPIDate( 'DATE', $this->$function() );
+							}
+							break;
+						default:
+							if ( method_exists( $this, $function ) ) {
+								$data[$variable] = $this->$function();
+							}
+							break;
+					}
+
+				}
+			}
+			$this->getPermissionColumns( &$data, $this->getID(), $this->getCreatedBy(), $permission_children_ids );
+			$this->getCreatedAndUpdatedColumns( &$data, $include_columns );
+		}
+
 		return $data;
 	}
 
 	function addLog( $log_action ) {
-		return TTLog::addEntry( $this->getId(), $log_action, TTi18n::getText('User Information'), NULL, $this->getTable() );
+		return TTLog::addEntry( $this->getId(), $log_action, TTi18n::getText('Employee').': '. $this->getFullName( FALSE, TRUE ) , NULL, $this->getTable() );
 	}
-
 }
 ?>
