@@ -1,29 +1,42 @@
 <?php
 /*********************************************************************************
- * The contents of this file are subject to the TimeTrex Public License Version
- * 1.1.0 ("License"); You may not use this file except in compliance with the
- * License. You may obtain a copy of the License at http://www.TimeTrex.com/TPL
- * Software distributed under the License is distributed on an "AS IS" basis,
- * WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the License
- * for the specific language governing rights and limitations under the
- * License.
+ * TimeTrex is a Payroll and Time Management program developed by
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
  *
- * All copies of the Covered Code must include on each user interface screen:
- *    (i) the "Powered by TimeTrex" logo and
- *    (ii) the TimeTrex copyright notice
- * in the same form as they appear in the distribution.  See full license for
- * requirements.
+ * This program is free software; you can redistribute it and/or modify it under
+ * the terms of the GNU Affero General Public License version 3 as published by
+ * the Free Software Foundation with the addition of the following permission
+ * added to Section 15 as permitted in Section 7(a): FOR ANY PART OF THE COVERED
+ * WORK IN WHICH THE COPYRIGHT IS OWNED BY TIMETREX, TIMETREX DISCLAIMS THE
+ * WARRANTY OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
  *
- * The Original Code is: TimeTrex Open Source
- * The Initial Developer of the Original Code is TimeTrex Payroll Services
- * Portions created by TimeTrex are Copyright (C) 2004-2007 TimeTrex Payroll Services;
- * All Rights Reserved.
+ * This program is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+ * FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
+ * details.
  *
+ * You should have received a copy of the GNU Affero General Public License along
+ * with this program; if not, see http://www.gnu.org/licenses or write to the Free
+ * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+ * 02110-1301 USA.
+ *
+ * You can contact TimeTrex headquarters at Unit 22 - 2475 Dobbin Rd. Suite
+ * #292 Westbank, BC V4T 2E9, Canada or at email address info@timetrex.com.
+ *
+ * The interactive user interfaces in modified source and object code versions
+ * of this program must display Appropriate Legal Notices, as required under
+ * Section 5 of the GNU Affero General Public License version 3.
+ *
+ * In accordance with Section 7(b) of the GNU Affero General Public License
+ * version 3, these Appropriate Legal Notices must retain the display of the
+ * "Powered by TimeTrex" logo. If the display of the logo is not reasonably
+ * feasible for technical reasons, the Appropriate Legal Notices must display
+ * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2184 $
- * $Id: UserPreferenceFactory.class.php 2184 2008-10-06 17:11:10Z ipso $
- * $Date: 2008-10-06 10:11:10 -0700 (Mon, 06 Oct 2008) $
+ * $Revision: 2862 $
+ * $Id: UserPreferenceFactory.class.php 2862 2009-09-30 19:35:20Z ipso $
+ * $Date: 2009-09-30 12:35:20 -0700 (Wed, 30 Sep 2009) $
  */
 
 /**
@@ -82,7 +95,6 @@ class UserPreferenceFactory extends Factory {
 											'Y-m-d' 	=> '2001-02-25 (yyyy-mm-dd)',
 									);
 				break;
-
 			case 'js_date_format':
 				$retval = array(
 											//http://www.dynarch.com/demos/jscalendar/doc/html/reference.html#node_sec_5
@@ -107,7 +119,29 @@ class UserPreferenceFactory extends Factory {
 											'D, dMY' 	=> '%a, %d%b%Y'
 									);
 				break;
-
+			case 'flex_date_format':
+				$retval = array(
+											'd-M-y'		=> 'DD-MMM-YY',
+											'd-M-Y'		=> 'DD-MMM-YYYY',
+											'dMY'		=> 'DDMMMYYYY',
+											'd/m/Y'		=> 'DD/MM/YYYY',
+											'd/m/y'		=> 'DD/MM/YY',
+											'd-m-y'		=> 'DD-MM-YY',
+											'd-m-Y'		=> 'DD-MM-YYYY',
+											'm/d/y'		=> 'MM/DD/YY',
+											'm/d/Y'		=> 'MM/DD/YYYY',
+											'm-d-y'		=> 'MM-DD-YY',
+											'm-d-Y'     => 'MM-DD-YYYY',
+											'Y-m-d'		=> 'YYYY-MM-DD',
+											'M-d-y'		=> 'MMM-DD-yy',
+											'M-d-Y' 	=> 'MMM-DD-YYYY',
+											'l, F d Y'  => 'EEEE,MMMM DD YYYY',
+											'D, F d Y'  => 'EEE,MMMM DD YYYY',
+											'D, M d Y'  => 'EEE,MMM DD YYYY',
+											'D, d-M-Y'  => 'EEE,DD-MMM-YYYY',
+											'D, dMY'	=> 'EEE,DDMMMYYYY'
+									);
+				break;
 			case 'time_format':
 				$retval = array(
 											//'g:i:s A' 	=> TTi18n::gettext('8:09:11 PM'),
@@ -120,7 +154,6 @@ class UserPreferenceFactory extends Factory {
 											'G:i T' => TTi18n::gettext('20:09 GMT')
 									);
 				break;
-
 			case 'js_time_format':
 				$retval = array(
 											'g:i A' 	=> '%l:%M %p', //  8:09 PM
@@ -130,7 +163,15 @@ class UserPreferenceFactory extends Factory {
 											'G:i T' => '%k:%M' //20:09 PM GMT
 									);
 				break;
-
+			case 'flex_time_format':
+				$retval = array(
+											'g:i A' 	=> 'L:NN A', //  8:09 PM
+											'g:i a' 	=> 'L:NN a', //8:09 pm
+											'G:i' 		=> 'JJ:NN', //20:09
+											'g:i A T' => 'L:NN A T', //8:09 PM GMT
+											'G:i T' => 'JJ:NN T' //20:09 PM GMT
+									);
+				break;
 			case 'time_unit_format':
 				$retval = array(
 											10 	=> TTi18n::gettext('hh:mm (2:15)'),
@@ -756,12 +797,67 @@ class UserPreferenceFactory extends Factory {
 											6 	=> TTi18n::gettext('Saturday'),
 									);
 				break;
+			case 'columns':
+				$retval = array(
+										'-1000-first_name' => TTi18n::gettext('First Name'),
+										'-1010-last_name' => TTi18n::gettext('Last Name'),
+										'-1020-language_display' => TTi18n::gettext('Language'),
+										'-1030-date_format' => TTi18n::gettext('Date Format'),
+										'-1040-time_format' => TTi18n::gettext('Time Format'),
+										'-1050-time_zone' => TTi18n::gettext('TimeZone'),
+										'-1060-time_unit_format' => TTi18n::gettext('Time Unit Format'),
+										'-1070-items_per_page' => TTi18n::gettext('Items Per Page'),
+										'-1080-timesheet_view' => TTi18n::gettext('TimeSheet View'),
+										'-1090-start_week_day' => TTi18n::gettext('Start Weekday'),
+										//'-1100-enable_email_notification_exception' => TTi18n::gettext('Email Notification Exception'),
+										//'-1110-enable_email_notification_message' => TTi18n::gettext('Email Notification Message'),
+										//'-1120-enable_email_notification_home' => TTi18n::gettext('Email Notification Home'),
 
+										'-2000-created_by' => TTi18n::gettext('Created By'),
+										'-2010-created_date' => TTi18n::gettext('Created Date'),
+										'-2020-updated_by' => TTi18n::gettext('Updated By'),
+										'-2030-updated_date' => TTi18n::gettext('Updated Date'),
+							);
+				break;
+			case 'default_display_columns': //Columns that are displayed by default.
+				$retval = array(
+								'first_name',
+								'last_name',
+								'date_format',
+								'time_format',
+								'time_unit_format',
+								'time_zone',
+								'created_by',
+								'created_date',
+								'updated_by',
+								'updated_date',
+								);
+				break;
 		}
 
 		return $retval;
 	}
 
+	function _getVariableToFunctionMap() {
+		$variable_function_map = array(
+										'id' => 'ID',
+										'user_id' => 'User',
+										'language' => 'Language',
+										'date_format' => 'DateFormat',
+										'time_format' => 'TimeFormat',
+										'time_zone' => 'TimeZone',
+										'time_unit_format' => 'TimeUnitFormat',
+										'items_per_page' => 'ItemsPerPage',
+										'timesheet_view' => 'TimeSheetView',
+										'start_week_day' => 'StartWeekDay',
+										'enable_email_notification_exception' => 'EnableEmailNotificationException',
+										'enable_email_notification_message' => 'EnableEmailNotificationMessage',
+										'enable_email_notification_home' => 'EnableEmailNotificationHome',
+										'deleted' => 'Deleted',
+										);
+		return $variable_function_map;
+	}
+
 	function getUserObject() {
 		if ( is_object($this->user_obj) ) {
 			return $this->user_obj;
@@ -1001,7 +1097,7 @@ class UserPreferenceFactory extends Factory {
 	function setItemsPerPage($items_per_page) {
 		$items_per_page = trim($items_per_page);
 
-		if 	($items_per_page != '' AND $items_per_page >= 1 AND $items_per_page <= 1000) {
+		if 	($items_per_page != '' AND $items_per_page >= 5 AND $items_per_page <= 2000) {
 
 			$this->data['items_per_page'] = $items_per_page;
 
@@ -1010,7 +1106,7 @@ class UserPreferenceFactory extends Factory {
 
 			$this->Validator->isTrue(		'items_per_page',
 											FALSE,
-											TTi18n::gettext('Items per page must be between 10 and 200'));
+											TTi18n::gettext('Items per page must be between 5 and 2000'));
 		}
 
 		return FALSE;
@@ -1146,8 +1242,85 @@ class UserPreferenceFactory extends Factory {
 		return TRUE;
 	}
 
+	function preSave() {
+		//Check the locale, if its not english, we need to make sure the selected dateformat is correct for the language, or else force it.
+		if ( $this->getLanguage() != 'en' ) {
+			if ( Option::getByValue( $this->getDateFormat(), $this->getOptions('other_date_format') ) == FALSE ) {
+				//Force a change of date format
+				$this->setDateFormat('d/m/Y');
+				Debug::text('Language changed and date format doesnt match any longer, forcing it to: d/m/Y', __FILE__, __LINE__, __METHOD__, 10);
+			} else {
+				Debug::text('Date format doesnt need fixing...', __FILE__, __LINE__, __METHOD__, 10);
+			}
+		}
+
+		return TRUE;
+	}
+
 	function postSave() {
 		$this->removeCache( $this->getUser() );
+
+		return TRUE;
+	}
+
+	//Support setting created_by,updated_by especially for importing data.
+	//Make sure data is set based on the getVariableToFunctionMap order.
+	function setObjectFromArray( $data ) {
+		if ( is_array( $data ) ) {
+			$variable_function_map = $this->getVariableToFunctionMap();
+			foreach( $variable_function_map as $key => $function ) {
+				if ( isset($data[$key]) ) {
+
+					$function = 'set'.$function;
+					switch( $key ) {
+						default:
+							if ( method_exists( $this, $function ) ) {
+								$this->$function( $data[$key] );
+							}
+							break;
+					}
+				}
+			}
+
+			$this->setCreatedAndUpdatedColumns( $data );
+
+			return TRUE;
+		}
+
+		return FALSE;
+	}
+
+
+	function getObjectAsArray( $include_columns = NULL ) {
+		$variable_function_map = $this->getVariableToFunctionMap();
+		if ( is_array( $variable_function_map ) ) {
+			foreach( $variable_function_map as $variable => $function_stub ) {
+				if ( $include_columns == NULL OR ( isset($include_columns[$variable]) AND $include_columns[$variable] == TRUE ) ) {
+
+					$function = 'get'.$function_stub;
+					switch( $variable ) {
+						case 'language':
+						case 'date_format':
+						case 'time_format':
+						case 'time_zone':
+						case 'time_unit_format':
+						case 'timesheet_view':
+						case 'start_week_day':
+							if ( method_exists( $this, $function ) ) {
+								$data[$variable.'_display'] = Option::getByKey( $this->$function(), $this->getOptions( $variable ) );
+							}
+						default:
+							if ( method_exists( $this, $function ) ) {
+								$data[$variable] = $this->$function();
+							}
+							break;
+					}
+				}
+			}
+			$this->getCreatedAndUpdatedColumns( &$data, $include_columns );
+		}
+
+		return $data;
 	}
 
 	function addLog( $log_action ) {
