@@ -1,29 +1,42 @@
 <?php
 /*********************************************************************************
- * The contents of this file are subject to the TimeTrex Public License Version
- * 1.1.0 ("License"); You may not use this file except in compliance with the
- * License. You may obtain a copy of the License at http://www.TimeTrex.com/TPL
- * Software distributed under the License is distributed on an "AS IS" basis,
- * WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the License
- * for the specific language governing rights and limitations under the
- * License.
+ * TimeTrex is a Payroll and Time Management program developed by
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
  *
- * All copies of the Covered Code must include on each user interface screen:
- *    (i) the "Powered by TimeTrex" logo and
- *    (ii) the TimeTrex copyright notice
- * in the same form as they appear in the distribution.  See full license for
- * requirements.
+ * This program is free software; you can redistribute it and/or modify it under
+ * the terms of the GNU Affero General Public License version 3 as published by
+ * the Free Software Foundation with the addition of the following permission
+ * added to Section 15 as permitted in Section 7(a): FOR ANY PART OF THE COVERED
+ * WORK IN WHICH THE COPYRIGHT IS OWNED BY TIMETREX, TIMETREX DISCLAIMS THE
+ * WARRANTY OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
  *
- * The Original Code is: TimeTrex Open Source
- * The Initial Developer of the Original Code is TimeTrex Payroll Services
- * Portions created by TimeTrex are Copyright (C) 2004-2007 TimeTrex Payroll Services;
- * All Rights Reserved.
+ * This program is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+ * FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
+ * details.
  *
+ * You should have received a copy of the GNU Affero General Public License along
+ * with this program; if not, see http://www.gnu.org/licenses or write to the Free
+ * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+ * 02110-1301 USA.
+ *
+ * You can contact TimeTrex headquarters at Unit 22 - 2475 Dobbin Rd. Suite
+ * #292 Westbank, BC V4T 2E9, Canada or at email address info@timetrex.com.
+ *
+ * The interactive user interfaces in modified source and object code versions
+ * of this program must display Appropriate Legal Notices, as required under
+ * Section 5 of the GNU Affero General Public License version 3.
+ *
+ * In accordance with Section 7(b) of the GNU Affero General Public License
+ * version 3, these Appropriate Legal Notices must retain the display of the
+ * "Powered by TimeTrex" logo. If the display of the logo is not reasonably
+ * feasible for technical reasons, the Appropriate Legal Notices must display
+ * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2453 $
- * $Id: Data.class.php 2453 2009-03-20 16:34:04Z ipso $
- * $Date: 2009-03-20 09:34:04 -0700 (Fri, 20 Mar 2009) $
+ * $Revision: 3199 $
+ * $Id: Data.class.php 3199 2009-12-20 23:37:45Z ipso $
+ * $Date: 2009-12-20 15:37:45 -0800 (Sun, 20 Dec 2009) $
  */
 
 /**
@@ -44,6 +57,22 @@ class PayrollDeduction_CA_Data extends PayrollDeduction_Base {
 	*/
 
 	var $basic_claim_code_options = array(
+							1262332800 => array( //01-Jan-2010
+										'CA' => 10382, //Federal
+										'BC' => 11000,
+										'AB' => 16825,
+										'SK' => 13348,
+										'MB' => 8134,
+										'QC' => 0,
+										'ON' => 8943,
+										'NL' => 7833,
+										'NB' => 8777,
+										'NS' => 8231,
+										'PE' => 7708,
+										'NT' => 12740,
+										'YT' => 10382,
+										'NU' => 11714,
+										),
 							1238569200 => array( //01-Apr-09
 										'CA' => 10375, //Federal
 										'BC' => 9373,
@@ -52,12 +81,12 @@ class PayrollDeduction_CA_Data extends PayrollDeduction_Base {
 										'MB' => 8134,
 										'QC' => 0,
 										'ON' => 8881,
-										'NF' => 7778,
+										'NL' => 7778,
 										'NB' => 8134,
 										'NS' => 7981,
 										'PE' => 7708,
 										'NT' => 12664,
-										'YU' => 10375,
+										'YT' => 10375,
 										'NU' => 11644,
 										),
 							1230796800 => array( //01-Jan-09
@@ -68,12 +97,12 @@ class PayrollDeduction_CA_Data extends PayrollDeduction_Base {
 										'MB' => 8134,
 										'QC' => 0,
 										'ON' => 8881,
-										'NF' => 7778,
+										'NL' => 7778,
 										'NB' => 8134,
 										'NS' => 7981,
 										'PE' => 7708,
 										'NT' => 12664,
-										'YU' => 10100,
+										'YT' => 10100,
 										'NU' => 11644,
 										),
 							1199174400 => array( //01-Jan-08
@@ -84,12 +113,12 @@ class PayrollDeduction_CA_Data extends PayrollDeduction_Base {
 										'MB' => 8034,
 										'QC' => 0,
 										'ON' => 8681,
-										'NF' => 7566,
+										'NL' => 7566,
 										'NB' => 8395,
 										'NS' => 7731,
 										'PE' => 7708,
 										'NT' => 12355,
-										'YU' => 9600,
+										'YT' => 9600,
 										'NU' => 11360,
 										),
 							1183273200 => array( //01-Jul-07
@@ -100,12 +129,12 @@ class PayrollDeduction_CA_Data extends PayrollDeduction_Base {
 										'MB' => 7834,
 										'QC' => 0,
 										'ON' => 8553,
-										'NF' => 7558,
+										'NL' => 7558,
 										'NB' => 8239,
 										'NS' => 7481,
 										'PE' => 7708,
 										'NT' => 12125,
-										'YU' => 8929,
+										'YT' => 8929,
 										'NU' => 11149,
 										),
 							1167638400 => array( //01-Jan-07
@@ -116,12 +145,12 @@ class PayrollDeduction_CA_Data extends PayrollDeduction_Base {
 										'MB' => 7834,
 										'QC' => 0,
 										'ON' => 8553,
-										'NF' => 7410,
+										'NL' => 7410,
 										'NB' => 8239,
 										'NS' => 7481,
 										'PE' => 7412,
 										'NT' => 12125,
-										'YU' => 8929,
+										'YT' => 8929,
 										'NU' => 11149,
 										),
 							1151737200 => array( //01-Jul-06
@@ -132,12 +161,12 @@ class PayrollDeduction_CA_Data extends PayrollDeduction_Base {
 										'MB' => 7734,
 										'QC' => 0,
 										'ON' => 8377,
-										'NF' => 7410,
+										'NL' => 7410,
 										'NB' => 8061,
 										'NS' => 7231,
 										'PE' => 7412,
 										'NT' => 11864,
-										'YU' => 8328,
+										'YT' => 8328,
 										'NU' => 10909,
 										),
 							1136102400 => array( //01-Jan-06
@@ -148,12 +177,12 @@ class PayrollDeduction_CA_Data extends PayrollDeduction_Base {
 										'MB' => 7734,
 										'QC' => 0,
 										'ON' => 8377,
-										'NF' => 7410,
+										'NL' => 7410,
 										'NB' => 8061,
 										'NS' => 7231,
 										'PE' => 7412,
 										'NT' => 11864,
-										'YU' => 8328,
+										'YT' => 8328,
 										'NU' => 10909,
 										),
 									);
@@ -162,6 +191,12 @@ class PayrollDeduction_CA_Data extends PayrollDeduction_Base {
 		CPP settings
 	*/
 	var $cpp_options = array(
+							1262332800 => array( //2010
+										'maximum_pensionable_earnings' => 47200,
+										'basic_exemption' => 3500,
+										'employee_rate' => 0.0495,
+										'employee_maximum_contribution' => 2163.15
+										),
 							1230796800 => array( //2009
 										'maximum_pensionable_earnings' => 46300,
 										'basic_exemption' => 3500,
@@ -204,6 +239,12 @@ class PayrollDeduction_CA_Data extends PayrollDeduction_Base {
 		EI settings
 	*/
 	var $ei_options = array(
+							1262332800 => array( //2010
+										'maximum_insurable_earnings' => 43200,
+										'employee_rate' => 0.0173,
+										'employee_maximum_contribution' => 747.36,
+										'employer_rate' => 1.4
+										),
 							1230796800 => array( //2009
 										'maximum_insurable_earnings' => 42300,
 										'employee_rate' => 0.0173,
