@@ -1,79 +1,90 @@
 <?php
 /*********************************************************************************
- * The contents of this file are subject to the TimeTrex Public License Version
- * 1.1.0 ("License"); You may not use this file except in compliance with the
- * License. You may obtain a copy of the License at http://www.TimeTrex.com/TPL
- * Software distributed under the License is distributed on an "AS IS" basis,
- * WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the License
- * for the specific language governing rights and limitations under the
- * License.
+ * TimeTrex is a Payroll and Time Management program developed by
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
  *
- * All copies of the Covered Code must include on each user interface screen:
- *    (i) the "Powered by TimeTrex" logo and
- *    (ii) the TimeTrex copyright notice
- * in the same form as they appear in the distribution.  See full license for
- * requirements.
+ * This program is free software; you can redistribute it and/or modify it under
+ * the terms of the GNU Affero General Public License version 3 as published by
+ * the Free Software Foundation with the addition of the following permission
+ * added to Section 15 as permitted in Section 7(a): FOR ANY PART OF THE COVERED
+ * WORK IN WHICH THE COPYRIGHT IS OWNED BY TIMETREX, TIMETREX DISCLAIMS THE
+ * WARRANTY OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
  *
- * The Original Code is: TimeTrex Open Source
- * The Initial Developer of the Original Code is TimeTrex Payroll Services
- * Portions created by TimeTrex are Copyright (C) 2004-2007 TimeTrex Payroll Services;
- * All Rights Reserved.
+ * This program is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+ * FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
+ * details.
  *
+ * You should have received a copy of the GNU Affero General Public License along
+ * with this program; if not, see http://www.gnu.org/licenses or write to the Free
+ * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+ * 02110-1301 USA.
+ *
+ * You can contact TimeTrex headquarters at Unit 22 - 2475 Dobbin Rd. Suite
+ * #292 Westbank, BC V4T 2E9, Canada or at email address info@timetrex.com.
+ *
+ * The interactive user interfaces in modified source and object code versions
+ * of this program must display Appropriate Legal Notices, as required under
+ * Section 5 of the GNU Affero General Public License version 3.
+ *
+ * In accordance with Section 7(b) of the GNU Affero General Public License
+ * version 3, these Appropriate Legal Notices must retain the display of the
+ * "Powered by TimeTrex" logo. If the display of the logo is not reasonably
+ * feasible for technical reasons, the Appropriate Legal Notices must display
+ * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2453 $
- * $Id: Data.class.php 2453 2009-03-20 16:34:04Z ipso $
- * $Date: 2009-03-20 09:34:04 -0700 (Fri, 20 Mar 2009) $
+ * $Revision: 3199 $
+ * $Id: Data.class.php 3199 2009-12-20 23:37:45Z ipso $
+ * $Date: 2009-12-20 15:37:45 -0800 (Sun, 20 Dec 2009) $
  */
 
 /*
 Site with good Tax news on updates: http://www.sageabra.com/hr-news/
  - http://www.sageabra.com/hr-news/payroll_news.aspx?item={fe86cf98-8789-3d13-aabc-0dff4bf8cc13}
-DONE-	Federal          		- Google: Notice 1036 http://www.irs.gov/pub/irs-pdf/n1036.pdf
 
-**************************8- Kansas/Maryland/Puerto Rico tax table updates from May.
-
-NOCHANGE-	'AL' => 'Alabama' 		- http://www.ador.state.al.us/Withholding/index.html
-NOCHANGE-	'AZ' => 'Arizona',		- http://www.azdor.gov/Withholding/menu.htm
-NOCHANGE-	'AR' => 'Arkansas'		- http://www.arkansas.gov/dfa/income_tax/tax_wh_forms.html
-DONE-	'CA' => 'California' 	- http://www.edd.ca.gov/taxrep/taxrte9x.htm#Withhold
-DONE- (no change)	'CO' => 'Colorado',		- http://www.revenue.state.co.us/taxstatutesregs/withholdingindex/WHtablesgeninfo.html
-DONE-	'CT' => 'Connecticut'	- http://www.ct.gov/drs/cwp/view.asp?a=1479&q=269984
-NOCHANGE-	'DE' => 'Delaware',		- http://www.state.de.us/revenue/services/Business_Tax/WH_FAQS.shtml
-DONE-	'DC' => 'D.C.', 		- http://otr.cfo.dc.gov/otr/cwp/view.asp?a=1330&Q=593946
-NOCHANGE-	'GA' => 'Georgia',		- http://www.dot.state.ga.us/topps/admin/7153-6.htm
-NOCHANGE-	'HI' => 'Hawaii',		- http://www.state.hi.us/tax/a1_b1_5whhold.htm
-DONE-	'ID' => 'Idaho',		- http://tax.idaho.gov/publications.htm
-NOCHANGE-	'IL' => 'Illinois',		- http://www.revenue.state.il.us/Businesses/TaxInformation/Payroll/index.htm
-NOCHANGE-	'IN' => 'Indiana',		- http://www.in.gov/dor/taxforms/s-wforms.html
-NOCHANGE-	'IA' => 'Iowa',			- http://www.state.ia.us/tax/forms/withhold.html
-NOCHANGE-	'KS' => 'Kansas',		- http://www.ksrevenue.org/forms-btwh.htm
-DONE-	'KY' => 'Kentucky', 	- http://revenue.ky.gov/business/whtax.htm
-NOCHANGE-until July	'LA' => 'Louisiana',	- http://www.revenue.louisiana.gov/sections/publications/tm.asp
-DONE-	'ME' => 'Maine',		- http://www.state.me.us/revenue/forms/with/2009.htm -- Check each year.
-DONE-	'MD' => 'Maryland',		- http://www.oregon.gov/DOR/BUS/withholding.shtml - http://business.marylandtaxes.com/taxinfo/withholding/default.asp
-NOCHANGE-	'MA' => 'Massachusetts' - http://www.mass.gov/?pageID=dorterminal&L=3&L0=Home&L1=Businesses&L2=Current+Tax+Year+Information&sid=Ador&b=terminalcontent&f=dor_business_buspubs&csid=Ador
-DONE-	'MI' => 'Michigan',		- http://www.michigan.gov/documents/treasury/446_2007_176836_7.pdf
-DONE-	'MN' => 'Minnesota',	- http://www.taxes.state.mn.us/taxes/withholding/index.shtml
-NOCHANGE-	'MS' => 'Mississippi',	- http://www.mstc.state.ms.us/taxareas/withhold/main.htm
-NOCHANGE-	'MO' => 'Missouri',		- http://www.dor.mo.gov/tax/business/withhold/
-NOCHANGE-	'MT' => 'Montana',		- http://mt.gov/revenue/formsandresources/forms.asp
-NOCHANGE-	'NE' => 'Nebraska',		- http://www.revenue.state.ne.us/tax/current/current.htm#inc
-DONE-	'NM' => 'New Mexico', 	- http://www.tax.state.nm.us/trd_pubs.htm
-NOCHANGE-	'NJ' => 'New Jersey',	- http://www.state.nj.us/treasury/taxation/index.html?njit30.htm~mainFrame
-NOCHANGE-	'NY' => 'New York',		- http://www.tax.state.ny.us/forms/withholding_cur_forms.htm
-DONE- (just knocked off the last bracket of each status)	'NC' => 'North Carolina'- http://www.dornc.com/taxes/wh_tax/index.html
-DONE-	'ND' => 'North Dakota', - http://www.nd.gov/tax/indwithhold/pubs/guide/index.html
-DONE-	'OH' => 'Ohio',			- http://tax.ohio.gov/divisions/employer_withholding/index.stm
-DONE-	'OK' => 'Oklahoma',		- http://www.tax.ok.gov/btforms.html
-DONE-	'OR' => 'Oregon',		- http://www.oregon.gov/DOR/BUS/withholding.shtml
-NOCHANGE-	'PA' => 'Pennsylvania', - http://www.revenue.state.pa.us/revenue/cwp/view.asp?A=2&Q=205810
-DONE-	'RI' => 'Rhode Island', - http://www.tax.state.ri.us/
-NOCHANGE-	'SC' => 'South Carolina'- http://www.sctax.org/Publications/default.htm
-DONE-	'UT' => 'Utah',			- http://www.tax.utah.gov/forms/ (PUB-14)
-DONE-	'VT' => 'Vermont',		- http://www.state.vt.us/tax/businesswithholding.shtml
-NOCHANGE- 'VA' => 'Virginia',		- http://www.tax.virginia.gov/site.cfm?alias=WithholdingTax
-NOCHANGE-	'WI' => 'Wisconsin',	- http://www.revenue.wi.gov/ise/with/index.html
+C:16-Dec-09-			Federal          		- Google: Notice 1036 http://www.irs.gov/pub/irs-pdf/n1036.pdf
+C:16-Dec-09-			'AL' => 'Alabama' 		- http://www.ador.state.al.us/Withholding/index.html *Withholding Tax Tables and Instructions
+C:16-Dec-09:NOCHANGE-	'AZ' => 'Arizona',		- http://www.azdor.gov/Forms/Withholding.aspx *Employer chooses percent of federal tax.
+C:16-Dec-09:NOCHANGE-	'AR' => 'Arkansas'		- http://www.dfa.arkansas.gov/offices/incomeTax/withholding/Pages/withholdingForms.aspx *Witholding Tax Formula
+C:16-Dec-09-			'CA' => 'California' 	- http://www.edd.ca.gov/Payroll_Taxes/Rates_and_Withholding.htm *PIT Withholding schedules
+****C:16-Dec-09-		'CO' => 'Colorado',		- http://www.colorado.gov/cs/Satellite?c=Page&cid=1214992372268&pagename=Revenue%2FREVXLayout *Form: DR 1098
+****C:16-Dec-09-		'CT' => 'Connecticut'	- http://www.ct.gov/drs/cwp/view.asp?a=1509&q=306182&drsPNavCtr=|42845|#42889  *Withholding Forms and Withholding Tables
+C:16-Dec-09-			'DE' => 'Delaware',		- http://revenue.delaware.gov/services/WITBk.shtml *http://revenue.delaware.gov/services/wit_folder/section17.shtml
+C:16-Dec-09:NOCHANGE-	'DC' => 'D.C.', 		- http://otr.cfo.dc.gov/otr/cwp/view.asp?a=1330&Q=593946
+C:16-Dec-09:NOCHANGE-	'GA' => 'Georgia',		- https://etax.dor.ga.gov/inctax/withholding/whgeninfo.aspx *Employers Tax Guide
+C:16-Dec-09-			'HI' => 'Hawaii',		- http://www.state.hi.us/tax/a1_b1_5whhold.htm * Employers Tax Guide (Booklet A)
+C:16-Dec-09:NOCHANGE-	'ID' => 'Idaho',		- http://tax.idaho.gov/s-results-pub.cfm?doc=EPB00006&pkey=bus
+C:16-Dec-09:NOCHANGE-	'IL' => 'Illinois',		- http://www.revenue.state.il.us/Businesses/TaxInformation/Payroll/index.htm *Booklet IL-700-T
+C:16-Dec-09:NOCHANGE-	'IN' => 'Indiana',		- http://www.in.gov/dor/4006.htm#withholding *Departmental Notice #1 DN01
+C:01-Jan-10:NOCHANGE-	'IA' => 'Iowa',			- http://www.state.ia.us/tax/forms/withhold.html
+C:01-Jan-10:NOCHANGE-	'KS' => 'Kansas',		- http://www.ksrevenue.org/forms-btwh.htm
+C:16-Dec-09:NOCHANGE-	'KY' => 'Kentucky', 	- http://revenue.ky.gov/business/whtax.htm
+C:16-Dec-09:NOCHANGE-	'LA' => 'Louisiana',	- http://www.revenue.louisiana.gov/sections/publications/tm.asp
+C:16-Dec-09-			'ME' => 'Maine',		- http://www.state.me.us/revenue/forms/with/2010.htm -- Check each year on the right of the page.
+C:16-Dec-09-			'MD' => 'Maryland',		- http://business.marylandtaxes.com/taxinfo/withholding/default.asp - Use non-residents tables, minus 1.25%, manually calculate each bracket. FIX county taxes...
+C:16-Dec-09-			'MA' => 'Massachusetts' - http://www.mass.gov/?pageID=dorterminal&L=3&L0=Home&L1=Businesses&L2=Current+Tax+Year+Information&sid=Ador&b=terminalcontent&f=dor_business_buspubs&csid=Ador
+C:16-Dec-09:NOCHANGE-	'MI' => 'Michigan',		- http://www.michigan.gov/documents/treasury/446_2007_176836_7.pdf *Michigan Income Tax Withholding Guide
+C:16-Dec-09-			'MN' => 'Minnesota',	- http://www.taxes.state.mn.us/taxes/withholding/index.shtml *2010 Computer Formula
+C:16-Dec-09:NOCHANGE-	'MS' => 'Mississippi',	- http://www.mstc.state.ms.us/taxareas/withhold/main.html *Pub 89-350
+C:16-Dec-09:NOCHANGE-	'MO' => 'Missouri',		- http://www.dor.mo.gov/tax/business/withhold/ *Employers Tax Guide
+C:16-Dec-09:NOCHANGE-	'MT' => 'Montana',		- http://mt.gov/revenue/formsandresources/forms.asp *Montana Witholding Tax Guide
+C:16-Dec-09:NOCHANGE-	'NE' => 'Nebraska',		- http://www.revenue.state.ne.us/tax/current/current.htm#inc *Withholding Forms
+C:16-Dec-09:NOCHANGE-	'NM' => 'New Mexico', 	- http://www.tax.state.nm.us/pubs/withholding_taxrates.htm *FYI-104
+C:16-Dec-09:NOCHANGE-	'NJ' => 'New Jersey',	- http://www.state.nj.us/treasury/taxation/freqqite.shtml *Withholding Rate Tables
+C:16-Dec-09-			'NY' => 'New York',		- http://www.tax.state.ny.us/forms/withholding_cur_forms.htm *NYS-50-T.1
+C:16-Dec-09:NOCHANGE-	'NC' => 'North Carolina'- http://www.dornc.com/taxes/wh_tax/index.html *Income Tax Withholding Tables & Instructions for Employers, NC30
+C:16-Dec-09-			'ND' => 'North Dakota', - http://www.nd.gov/tax/indwithhold/pubs/guide/index.html *Withholding Rates and Instructions for Wages Paid in 2010
+C:16-Dec-09:NOCHANGE-	'OH' => 'Ohio',			- http://tax.ohio.gov/divisions/employer_withholding/index.stm *Income Tax Withholding Instructions
+C:16-Dec-09-			'OK' => 'Oklahoma',		- http://www.tax.ok.gov/btforms.html *OW-2, Oklahoma Income Tax Withholding Tables
+C:16-Dec-09:NOCHANGE-	'OR' => 'Oregon',		- http://www.oregon.gov/DOR/BUS/withholding.shtml
+C:16-Dec-09:NOCHANGE-	'PA' => 'Pennsylvania', - http://www.revenue.state.pa.us/portal/server.pt/community/employer_withholding/14495 *Rev 415
+C:16-Dec-09-			'RI' => 'Rhode Island', - http://www.tax.state.ri.us/misc/software_developers.php *Withholding Tables
+C:16-Dec-09:NOCHANGE-	'SC' => 'South Carolina'- http://www.sctax.org/Publications/default.htm *Withholding, 09Withholding.pdf
+C:16-Dec-09:NOCHANGE-	'UT' => 'Utah',			- http://www.tax.utah.gov/forms/ *PUB 14
+C:16-Dec-09-	'VT' => 'Vermont',		- http://www.state.vt.us/tax/businesswithholding.shtml *Vermont Percentage Method Withholding Tables
+C:16-Dec-09:NOCHANGE- 'VA' => 'Virginia',		- http://www.tax.virginia.gov/site.cfm?alias=WithholdingTax, http://www.tax.virginia.gov/site.cfm?alias=busforms&selOtherForm=10&CFID=6568377&CFTOKEN=b5c365f14d473a0e-A35BD51E-0E04-BFC5-09FA7EDF84E52AA5#displayedAfterSubmit *Employer Withholding Instructions
+C:16-Dec-09-	'WI' => 'Wisconsin',	- http://www.revenue.wi.gov/forms/with/index.html *Pub W-166, Method "B" calculation
 
 	'AK' => 'Alaska',		- NO STATE TAXES
 	'FL' => 'Florida',		- NO STATE TAXES
@@ -98,6 +109,7 @@ class PayrollDeduction_US_Data extends PayrollDeduction_Base {
 	var $country_primary_currency = 'USD';
 
 	var $federal_allowance = array(
+									//01-Jan-10 - No Change
 									1230796800 => 3650.00, //01-Jan-09
 									1199174400 => 3500.00, //01-Jan-08
 									1167638400 => 3400.00, //01-Jan-07
@@ -106,6 +118,7 @@ class PayrollDeduction_US_Data extends PayrollDeduction_Base {
 
 	//http://www.ssa.gov/pressoffice/factsheets/colafacts2007.htm
 	var $social_security_options = array(
+									//2010a - No Change.
 									1230796800 => array( //2009a
 														'maximum_earnings' => 106800,
 														'rate' => 6.2,
@@ -154,6 +167,23 @@ class PayrollDeduction_US_Data extends PayrollDeduction_Base {
 
 	*/
 	var $eic_options = array(
+								1262332800 => array( //01-Jan-10
+													10 => array(
+																array( 'income' => 8970,  'calculation_type' => 10, 'percent' => 20.40 ),
+																array( 'income' => 16450, 'calculation_type' => 20, 'amount' => 1830 ),
+																array( 'income' => 16450, 'calculation_type' => 30, 'amount' => 1830, 'percent' => 9.588  ),
+																),
+													20 => array(
+																array( 'income' => 8970,  'calculation_type' => 10, 'percent' => 20.40 ),
+																array( 'income' => 21460, 'calculation_type' => 20, 'amount' => 1830 ),
+																array( 'income' => 21460, 'calculation_type' => 30, 'amount' => 1830, 'percent' => 9.588  ),
+																),
+													30 => array(
+																array( 'income' => 4485,  'calculation_type' => 10, 'percent' => 20.40 ),
+																array( 'income' => 10730, 'calculation_type' => 20, 'amount' => 915 ),
+																array( 'income' => 10730, 'calculation_type' => 30, 'amount' => 915, 'percent' => 9.588  ),
+																),
+													),
 								1238569200 => array( //01-Apr-09
 													10 => array(
 																array( 'income' => 8950,  'calculation_type' => 10, 'percent' => 20.40 ),
@@ -221,7 +251,7 @@ class PayrollDeduction_US_Data extends PayrollDeduction_Base {
 			$epoch = TTDate::getTime();
 		}
 
-		Debug::text('bUsing ('. $state .'/'. $district .') values from: '. TTDate::getDate('DATE+TIME', $epoch) , __FILE__, __LINE__, __METHOD__,10);
+		Debug::text('Using ('. $state .'/'. $district .') values from: '. TTDate::getDate('DATE+TIME', $epoch) , __FILE__, __LINE__, __METHOD__,10);
 
 		$cache_id = $country.$state.$district.$epoch.$federal_status.$state_status.$district_status;
 
@@ -300,8 +330,9 @@ class PayrollDeduction_US_Data extends PayrollDeduction_Base {
 			$prev_income = 0;
 			$prev_rate = 0;
 			$prev_constant = 0;
+			$prev_type = NULL;
 			foreach($rows as $key => $arr) {
-				if ( $arr['district'] != NULL ) {
+				if ( $arr['district'] != NULL) {
 					$type = 'district';
 				} elseif ( $arr['state'] != NULL ) {
 					$type = 'state';
@@ -309,6 +340,13 @@ class PayrollDeduction_US_Data extends PayrollDeduction_Base {
 					$type = 'federal';
 				}
 
+				//Tax brackets can get carried over from Federal to State, to District if we don't clear them out each time the type changes.
+				if ( $type != $prev_type ) {
+					$prev_income = 0;
+					$prev_rate = 0;
+					$prev_constant = 0;
+				}
+
 				$this->income_tax_rates[$type][] = array(	'prev_income' => trim($prev_income),
 															'income' => trim($arr['income']),
 															'prev_rate' => ( bcdiv( trim($prev_rate), 100 ) ),
@@ -316,6 +354,7 @@ class PayrollDeduction_US_Data extends PayrollDeduction_Base {
 															'prev_constant' => trim($prev_constant),
 															'constant' => trim($arr['constant']) );
 
+				$prev_type = $type;
 				$prev_income = $arr['income'];
 				$prev_rate = $arr['rate'];
 				$prev_constant = $arr['constant'];
@@ -346,9 +385,11 @@ class PayrollDeduction_US_Data extends PayrollDeduction_Base {
 				}
 			}
 
+			/*
 			if ( isset($arr) ) {
-				Debug::text('bUsing values from: '. TTDate::getDate('DATE+TIME', $arr['effective_date']) , __FILE__, __LINE__, __METHOD__,10);
+				Debug::text('Using values from: '. TTDate::getDate('DATE+TIME', $arr['effective_date']) , __FILE__, __LINE__, __METHOD__,10);
 			}
+			*/
 
 			//var_dump($this->income_tax_rates);
 			$cache->save(serialize($this->income_tax_rates), $cache_id, $this->table );
