@@ -1,37 +1,43 @@
 <?php
 /*********************************************************************************
- * The contents of this file are subject to the TimeTrex Public License Version
- * 1.1.0 ("License"); You may not use this file except in compliance with the
- * License. You may obtain a copy of the License at http://www.TimeTrex.com/TPL
- * Software distributed under the License is distributed on an "AS IS" basis,
- * WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the License
- * for the specific language governing rights and limitations under the
- * License.
+ * TimeTrex is a Payroll and Time Management program developed by
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
  *
- * All copies of the Covered Code must include on each user interface screen:
- *    (i) the "Powered by TimeTrex" logo and
- *    (ii) the TimeTrex copyright notice
- * in the same form as they appear in the distribution.  See full license for
- * requirements.
+ * This program is free software; you can redistribute it and/or modify it under
+ * the terms of the GNU Affero General Public License version 3 as published by
+ * the Free Software Foundation with the addition of the following permission
+ * added to Section 15 as permitted in Section 7(a): FOR ANY PART OF THE COVERED
+ * WORK IN WHICH THE COPYRIGHT IS OWNED BY TIMETREX, TIMETREX DISCLAIMS THE
+ * WARRANTY OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
  *
- * The Original Code is: TimeTrex Open Source
- * The Initial Developer of the Original Code is TimeTrex Payroll Services
- * Portions created by TimeTrex are Copyright (C) 2004-2007 TimeTrex Payroll Services;
- * All Rights Reserved.
+ * This program is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+ * FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
+ * details.
  *
+ * You should have received a copy of the GNU Affero General Public License along
+ * with this program; if not, see http://www.gnu.org/licenses or write to the Free
+ * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+ * 02110-1301 USA.
+ *
+ * You can contact TimeTrex headquarters at Unit 22 - 2475 Dobbin Rd. Suite
+ * #292 Westbank, BC V4T 2E9, Canada or at email address info@timetrex.com.
+ *
+ * The interactive user interfaces in modified source and object code versions
+ * of this program must display Appropriate Legal Notices, as required under
+ * Section 5 of the GNU Affero General Public License version 3.
+ *
+ * In accordance with Section 7(b) of the GNU Affero General Public License
+ * version 3, these Appropriate Legal Notices must retain the display of the
+ * "Powered by TimeTrex" logo. If the display of the logo is not reasonably
+ * feasible for technical reasons, the Appropriate Legal Notices must display
+ * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2341 $
- * $Id: Interface.inc.php 2341 2009-01-15 00:00:38Z ipso $
- * $Date: 2009-01-14 16:00:38 -0800 (Wed, 14 Jan 2009) $
+ * $Revision: 3219 $
+ * $Id: Interface.inc.php 3219 2009-12-24 18:01:51Z ipso $
+ * $Date: 2009-12-24 10:01:51 -0800 (Thu, 24 Dec 2009) $
  */
-
-/* Use these lines to run scripts from the command line... for debugging.
-  $_COOKIE['SessionID'] = '07bc520b3e90835ab586f0c585c4dd8f';
-  $_SERVER['REMOTE_ADDR'] = '192.168.1.100';
-*/
-
-
 if ( !isset($disable_cache_control) ) {
 	//Turn caching off.
 	header('Expires: Mon, 26 Jul 1997 05:00:00 GMT');
@@ -51,6 +57,22 @@ if ( !isset($enable_wap) ) {
 	header('Content-Type: text/html; charset=UTF-8');
 }
 
+//Skip this step if disable_database_connection is enabled or the user is going through the installer still
+if ( ( !isset($disable_database_connection) OR ( isset($disable_database_connection) AND $disable_database_connection != TRUE ) )
+		AND ( !isset($config_vars['other']['installer_enabled']) OR ( isset($config_vars['other']['installer_enabled']) AND $config_vars['other']['installer_enabled'] != TRUE ) )) {
+	//Get all system settings, so they can be used even if the user isn't logged in, such as the login page.
+	$sslf = new SystemSettingListFactory();
+	$system_settings = $sslf->getAllArray();
+	unset($sslf);
+
+	//Get primary company data needs to be used when user isn't logged in as well.
+	$clf = new CompanyListFactory();
+	$clf->getByID( PRIMARY_COMPANY_ID );
+	if ( $clf->getRecordCount() == 1 ) {
+		$primary_company = $clf->getCurrent();
+	}
+}
+
 $permission = new Permission();
 
 $authentication = new Authentication();
@@ -73,14 +95,16 @@ if ( isset($authenticate) AND $authenticate === FALSE ) {
 		$current_user = $authentication->getObject();
 		Debug::text('User Authenticated: '. $current_user->getUserName() .' Created Date: '. $authentication->getCreatedDate(), __FILE__, __LINE__, __METHOD__, 10);
 
-		$clf = new CompanyListFactory();
-		$current_company = $clf->getByID( $current_user->getCompany() )->getCurrent();
-		unset($clf);
+		if ( PRIMARY_COMPANY_ID == $current_user->getCompany() ) {
+			$current_company = $primary_company;
+		} else {
+			$current_company = $clf->getByID( $current_user->getCompany() )->getCurrent();
+		}
 
 		//Check to make sure the logged in user's information is all up to date.
 		//Make sure they also have permissions to edit information, otherwise don't redirect them.
 		if ( $current_user->isInformationComplete() == FALSE
-				AND ( !stristr( $_SERVER['SCRIPT_NAME'], 'permissiondenied') AND !stristr( $_SERVER['SCRIPT_NAME'], 'logout') AND !stristr( $_SERVER['SCRIPT_NAME'], 'about') AND !stristr( $_SERVER['SCRIPT_NAME'], 'punch.php') AND !stristr( $_SERVER['SCRIPT_NAME'], 'ajax_server') AND !stristr( $_SERVER['SCRIPT_NAME'], 'global.js') AND !stristr( $_SERVER['SCRIPT_NAME'], 'menu.js') )
+				AND ( !stristr( $_SERVER['SCRIPT_NAME'], 'permissiondenied') AND !stristr( $_SERVER['SCRIPT_NAME'], 'logout') AND !stristr( $_SERVER['SCRIPT_NAME'], 'about') AND !stristr( $_SERVER['SCRIPT_NAME'], 'punch.php') AND !stristr( $_SERVER['SCRIPT_NAME'], 'ajax_server') AND !stristr( $_SERVER['SCRIPT_NAME'], 'global.js') AND !stristr( $_SERVER['SCRIPT_NAME'], 'menu.js') AND !stristr( $_SERVER['SCRIPT_NAME'], 'embeddeddocument') )
 				AND !isset($_GET['incomplete']) AND !isset($_POST['incomplete'])
 				AND ($permission->Check('user','enabled') AND ( $permission->Check('user','edit') OR $permission->Check('user','edit_own') OR $permission->Check('user','edit_child')) ) ) {
 			Redirect::Page( URLBuilder::getURL( array('id' => $current_user->getID(), 'incomplete' => 1 ), Environment::GetBaseURL().'users/EditUser.php') );
@@ -136,11 +160,6 @@ if ( isset($authenticate) AND $authenticate === FALSE ) {
 			Redirect::Page( URLBuilder::getURL( array('incomplete' => 1 ), Environment::GetBaseURL().'users/EditUserPreference.php') );
 		}
 
-		//Get all system settings, so they can be used even if the user isn't logged in, such as the login page.
-		$sslf = new SystemSettingListFactory();
-		$system_settings = $sslf->getAllArray();
-		unset($sslf);
-
 		//Handle station functionality
 		if ( isset( $_COOKIE['StationID'] ) ) {
 			Debug::text('Station ID Cookie found! '. $_COOKIE['StationID'], __FILE__, __LINE__, __METHOD__, 10);
@@ -188,6 +207,7 @@ if ( isset($authenticate) AND $authenticate === FALSE ) {
 		//exit;
 	}
 }
+unset($clf);
 
 require_once( Environment::getBasePath() .'classes'. DIRECTORY_SEPARATOR .'smarty'. DIRECTORY_SEPARATOR .'libs'. DIRECTORY_SEPARATOR .'Smarty.class.php');
 
@@ -227,6 +247,9 @@ if ( isset($system_settings) ) {
 if ( isset($current_company) ) {
 	$smarty->assign_by_ref('current_company', $current_company );
 }
+if ( isset($primary_company) ) {
+	$smarty->assign_by_ref('primary_company', $primary_company );
+}
 
 if ( isset($config_vars) ) {
 	$smarty->assign_by_ref('config_vars', $config_vars );
