@@ -1,29 +1,42 @@
 <?php
 /*********************************************************************************
- * The contents of this file are subject to the TimeTrex Public License Version
- * 1.1.0 ("License"); You may not use this file except in compliance with the
- * License. You may obtain a copy of the License at http://www.TimeTrex.com/TPL
- * Software distributed under the License is distributed on an "AS IS" basis,
- * WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the License
- * for the specific language governing rights and limitations under the
- * License.
+ * TimeTrex is a Payroll and Time Management program developed by
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
  *
- * All copies of the Covered Code must include on each user interface screen:
- *    (i) the "Powered by TimeTrex" logo and
- *    (ii) the TimeTrex copyright notice
- * in the same form as they appear in the distribution.  See full license for
- * requirements.
+ * This program is free software; you can redistribute it and/or modify it under
+ * the terms of the GNU Affero General Public License version 3 as published by
+ * the Free Software Foundation with the addition of the following permission
+ * added to Section 15 as permitted in Section 7(a): FOR ANY PART OF THE COVERED
+ * WORK IN WHICH THE COPYRIGHT IS OWNED BY TIMETREX, TIMETREX DISCLAIMS THE
+ * WARRANTY OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
  *
- * The Original Code is: TimeTrex Open Source
- * The Initial Developer of the Original Code is TimeTrex Payroll Services
- * Portions created by TimeTrex are Copyright (C) 2004-2007 TimeTrex Payroll Services;
- * All Rights Reserved.
+ * This program is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+ * FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
+ * details.
  *
+ * You should have received a copy of the GNU Affero General Public License along
+ * with this program; if not, see http://www.gnu.org/licenses or write to the Free
+ * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+ * 02110-1301 USA.
+ *
+ * You can contact TimeTrex headquarters at Unit 22 - 2475 Dobbin Rd. Suite
+ * #292 Westbank, BC V4T 2E9, Canada or at email address info@timetrex.com.
+ *
+ * The interactive user interfaces in modified source and object code versions
+ * of this program must display Appropriate Legal Notices, as required under
+ * Section 5 of the GNU Affero General Public License version 3.
+ *
+ * In accordance with Section 7(b) of the GNU Affero General Public License
+ * version 3, these Appropriate Legal Notices must retain the display of the
+ * "Powered by TimeTrex" logo. If the display of the logo is not reasonably
+ * feasible for technical reasons, the Appropriate Legal Notices must display
+ * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2468 $
- * $Id: AuthorizationList.php 2468 2009-04-08 19:47:03Z ipso $
- * $Date: 2009-04-08 12:47:03 -0700 (Wed, 08 Apr 2009) $
+ * $Revision: 3091 $
+ * $Id: AuthorizationList.php 3091 2009-11-18 18:00:31Z ipso $
+ * $Date: 2009-11-18 10:00:31 -0800 (Wed, 18 Nov 2009) $
  */
 require_once('../../includes/global.inc.php');
 require_once(Environment::getBasePath() .'includes/Interface.inc.php');
@@ -52,46 +65,54 @@ extract	(FormVariables::GetVariables(
 												'selected_levels'
 												) ) );
 
+URLBuilder::setURL($_SERVER['SCRIPT_NAME'],
+											array(
+													'sort_column' => $sort_column,
+													'sort_order' => $sort_order,
+													'page' => $page
+												) );
+
 switch ($action) {
 	case 'submit':
 		Debug::Text('Submit!', __FILE__, __LINE__, __METHOD__,10);
 
 	default:
+		$sort_array = NULL;
+		if ( $sort_column != '' ) {
+			$sort_array = array(Misc::trimSortPrefix($sort_column) => $sort_order);
+		}
+
 		$ulf = new UserListFactory();
 		$hlf = new HierarchyListFactory();
+		$hllf = new HierarchyLevelListFactory();
 		$hotlf = new HierarchyObjectTypeListFactory();
 
 		if ( $permission->Check('request','authorize') ) {
 			//Debug::Text('Request: Selected Level: '. $selected_levels['request'], __FILE__, __LINE__, __METHOD__,10);
+			$request_levels = $hllf->getLevelsByUserIdAndObjectTypeID( $current_user->getId(), 50 );
+			Debug::Arr( $request_levels, 'Request Levels', __FILE__, __LINE__, __METHOD__,10);
 
-			//Get Hierarchy Control ID
-			$request_hierarchy_id = $hotlf->getByCompanyIdAndObjectTypeId( $current_company->getId(), 50 )->getCurrent()->getHierarchyControl();
-			Debug::Text('Request Hierarchy ID: '. $request_hierarchy_id, __FILE__, __LINE__, __METHOD__,10);
-
-			//Get all levels below us.
-			$request_levels = $hlf->getLevelsByHierarchyControlIdAndUserId( $request_hierarchy_id, $current_user->getId() );
-			//Debug::Arr( $request_levels, 'Request Levels', __FILE__, __LINE__, __METHOD__,10);
-
-			if ( isset($selected_levels['request']) AND in_array( $selected_levels['request'], array_keys($request_levels) ) ) {
-				$request_selected_level = $selected_levels['request'];
+			if ( isset($selected_levels['request']) AND isset($request_levels[$selected_levels['request']]) ) {
+				$request_selected_level = $request_levels[$selected_levels['request']];
 				Debug::Text(' Switching Levels to Level: '. $request_selected_level, __FILE__, __LINE__, __METHOD__,10);
+			} elseif ( isset($request_levels[1]) ) {
+				$request_selected_level = $request_levels[1];
 			} else {
+				Debug::Text( 'No Request Levels... Not in hierarchy?', __FILE__, __LINE__, __METHOD__,10);
 				$request_selected_level = 0;
 			}
 			Debug::Text( 'Request Selected Level: '. $request_selected_level, __FILE__, __LINE__, __METHOD__,10);
 
 			//Get all relevant hierarchy ids
-			$request_hierarchy_user_ids = $hlf->getByHierarchyControlIdAndUserIdAndLevel( $request_hierarchy_id, $current_user->getId(), (int)$request_selected_level );
-			//Debug::Arr( $request_hierarchy_user_ids, 'Request Hierarchy Ids', __FILE__, __LINE__, __METHOD__,10);
+			$request_hierarchy_user_ids = $hlf->getByUserIdAndObjectTypeIDAndLevel( $current_user->getId(), 50, (int)$request_selected_level );
 
 			if ( is_array($request_hierarchy_user_ids)
 					AND isset($request_hierarchy_user_ids['child_level'])
 					AND isset($request_hierarchy_user_ids['parent_level'])
 					AND isset($request_hierarchy_user_ids['current_level']) ) {
-
+				Debug::Text( 'Hierarchy information found...', __FILE__, __LINE__, __METHOD__,10);
 				$rlf = new RequestListFactory();
-				//$rlf->getByUserIdListAndStatusAndNotAuthorized($request_child_level_user_ids, 30, $request_parent_level_user_ids, $request_current_level_user_ids );
-				$rlf->getByUserIdListAndStatusAndNotAuthorized($request_hierarchy_user_ids['child_level'], 30, $request_hierarchy_user_ids['parent_level'], $request_hierarchy_user_ids['current_level'] );
+				$rlf->getByUserIdListAndStatusAndLevelAndMaxLevelAndNotAuthorized( $request_hierarchy_user_ids['child_level'], 30, (int)$request_selected_level, (int)end($request_levels), NULL, NULL, NULL, $sort_array );
 
 				$status_options = $rlf->getOptions('status');
 				$type_options = $rlf->getOptions('type');
@@ -108,7 +129,7 @@ switch ($action) {
 											'type' => $type_options[$r_obj->getType()],
 											'status_id' => $r_obj->getStatus(),
 											'status' => $status_options[$r_obj->getStatus()]
-														);
+										);
 				}
 				$smarty->assign_by_ref('requests', $requests);
 
@@ -116,31 +137,31 @@ switch ($action) {
 					$smarty->assign_by_ref('request_levels', $request_levels );
 					$smarty->assign_by_ref('selected_request_level', $request_selected_level);
 				}
+			} else {
+				Debug::Text( 'No hierarchy information found...', __FILE__, __LINE__, __METHOD__,10);
 			}
 		}
 
 		if ( $permission->Check('punch','authorize') ) {
 			//Debug::Text('TimeSheet: Selected Level: '. $selected_levels['timesheet'], __FILE__, __LINE__, __METHOD__,10);
 
-			//Get Hierarchy Control ID
-			$timesheet_hierarchy_id = $hotlf->getByCompanyIdAndObjectTypeId( $current_company->getId(), 90 )->getCurrent()->getHierarchyControl();
-			Debug::Text('TimeSheet Hierarchy ID: '. $timesheet_hierarchy_id, __FILE__, __LINE__, __METHOD__,10);
+			$timesheet_levels = $hllf->getLevelsByUserIdAndObjectTypeID( $current_user->getId(), 90 );
+			Debug::Arr( $timesheet_levels , 'TimeSheet Levels', __FILE__, __LINE__, __METHOD__,10);
 
-			//Get all levels below us.
-			$timesheet_levels = $hlf->getLevelsByHierarchyControlIdAndUserId( $timesheet_hierarchy_id,  $current_user->getId() );
-			Debug::Arr( $timesheet_levels, 'TimeSheet Levels', __FILE__, __LINE__, __METHOD__,10);
-
-			if ( isset($selected_levels['timesheet']) AND in_array( $selected_levels['timesheet'], array_keys($timesheet_levels) ) ) {
-				$timesheet_selected_level = $selected_levels['timesheet'];
+			if ( isset($selected_levels['timesheet']) AND isset($timesheet_levels[$selected_levels['timesheet']]) ) {
+				$timesheet_selected_level = $timesheet_levels[$selected_levels['timesheet']];
 				Debug::Text(' Switching Levels to Level: '. $timesheet_selected_level, __FILE__, __LINE__, __METHOD__,10);
+			} elseif ( isset($timesheet_levels[1]) ) {
+				$timesheet_selected_level = $request_levels[1];
 			} else {
+				Debug::Text( 'No TimeSheet Levels... Not in hierarchy?', __FILE__, __LINE__, __METHOD__,10);
 				$timesheet_selected_level = 0;
 			}
 			Debug::Text( 'TimeSheet Selected Level: '. $timesheet_selected_level, __FILE__, __LINE__, __METHOD__,10);
 
 			//Get all relevant hierarchy ids
-			$timesheet_hierarchy_user_ids = $hlf->getByHierarchyControlIdAndUserIdAndLevel( $timesheet_hierarchy_id, $current_user->getId(), (int)$timesheet_selected_level );
-			//Debug::Arr( $timesheet_hierarchy_user_ids, 'TimeSheet Hierarchy Ids', __FILE__, __LINE__, __METHOD__,10);
+			$timesheet_hierarchy_user_ids = $hlf->getByUserIdAndObjectTypeIDAndLevel( $current_user->getId(), 90, (int)$timesheet_selected_level );
+			//Debug::Arr( $request_hierarchy_user_ids, 'Request Hierarchy Ids', __FILE__, __LINE__, __METHOD__,10);
 
 			if ( is_array($timesheet_hierarchy_user_ids)
 					AND isset($timesheet_hierarchy_user_ids['child_level'])
@@ -148,7 +169,7 @@ switch ($action) {
 					AND isset($timesheet_hierarchy_user_ids['current_level']) ) {
 
 				$pptsvlf = new PayPeriodTimeSheetVerifyListFactory();
-				$pptsvlf->getByUserIdListAndStatusAndNotAuthorized($timesheet_hierarchy_user_ids['child_level'], 30, $timesheet_hierarchy_user_ids['parent_level'], $timesheet_hierarchy_user_ids['current_level']  );
+				$pptsvlf->getByUserIdListAndStatusAndLevelAndMaxLevelAndNotAuthorized( $timesheet_hierarchy_user_ids['child_level'], 30, (int)$timesheet_selected_level, (int)end($timesheet_levels), NULL, NULL, NULL, $sort_array  );
 
 				$status_options = $pptsvlf->getOptions('status');
 
@@ -171,6 +192,8 @@ switch ($action) {
 					$smarty->assign_by_ref('timesheet_levels', $timesheet_levels );
 					$smarty->assign_by_ref('selected_timesheet_level', $timesheet_selected_level );
 				}
+			} else {
+				Debug::Text( 'No hierarchy information found...', __FILE__, __LINE__, __METHOD__,10);
 			}
 		}
 
