@@ -1,38 +1,50 @@
 <?php
 /*********************************************************************************
- * The contents of this file are subject to the TimeTrex Public License Version
- * 1.1.0 ("License"); You may not use this file except in compliance with the
- * License. You may obtain a copy of the License at http://www.TimeTrex.com/TPL
- * Software distributed under the License is distributed on an "AS IS" basis,
- * WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the License
- * for the specific language governing rights and limitations under the
- * License.
+ * TimeTrex is a Payroll and Time Management program developed by
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
  *
- * All copies of the Covered Code must include on each user interface screen:
- *    (i) the "Powered by TimeTrex" logo and
- *    (ii) the TimeTrex copyright notice
- * in the same form as they appear in the distribution.  See full license for
- * requirements.
+ * This program is free software; you can redistribute it and/or modify it under
+ * the terms of the GNU Affero General Public License version 3 as published by
+ * the Free Software Foundation with the addition of the following permission
+ * added to Section 15 as permitted in Section 7(a): FOR ANY PART OF THE COVERED
+ * WORK IN WHICH THE COPYRIGHT IS OWNED BY TIMETREX, TIMETREX DISCLAIMS THE
+ * WARRANTY OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
  *
- * The Original Code is: TimeTrex Open Source
- * The Initial Developer of the Original Code is TimeTrex Payroll Services
- * Portions created by TimeTrex are Copyright (C) 2004-2007 TimeTrex Payroll Services;
- * All Rights Reserved.
+ * This program is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+ * FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
+ * details.
  *
+ * You should have received a copy of the GNU Affero General Public License along
+ * with this program; if not, see http://www.gnu.org/licenses or write to the Free
+ * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+ * 02110-1301 USA.
+ *
+ * You can contact TimeTrex headquarters at Unit 22 - 2475 Dobbin Rd. Suite
+ * #292 Westbank, BC V4T 2E9, Canada or at email address info@timetrex.com.
+ *
+ * The interactive user interfaces in modified source and object code versions
+ * of this program must display Appropriate Legal Notices, as required under
+ * Section 5 of the GNU Affero General Public License version 3.
+ *
+ * In accordance with Section 7(b) of the GNU Affero General Public License
+ * version 3, these Appropriate Legal Notices must retain the display of the
+ * "Powered by TimeTrex" logo. If the display of the logo is not reasonably
+ * feasible for technical reasons, the Appropriate Legal Notices must display
+ * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2426 $
- * $Id: global.js.php 2426 2009-02-18 22:39:19Z ipso $
- * $Date: 2009-02-18 14:39:19 -0800 (Wed, 18 Feb 2009) $
+ * $Revision: 3199 $
+ * $Id: global.js.php 3199 2009-12-20 23:37:45Z ipso $
+ * $Date: 2009-12-20 15:37:45 -0800 (Sun, 20 Dec 2009) $
  */
 $disable_cache_control = TRUE;
 require_once('..'. DIRECTORY_SEPARATOR .'includes'. DIRECTORY_SEPARATOR.'global.inc.php');
 
-//When going through the installer the user isnt logged in, so we still
+//When going through the installer or using quickpunch the user isnt logged in, so we still
 //need to be able to load this file.
-if ( isset($config_vars['other']['installer_enabled'])
-		AND $config_vars['other']['installer_enabled'] == 1 ) {
-	//if ( isset($_GET['authenticate']) AND $_GET['authenticate'] == 0 ) {
+if ( ( isset($config_vars['other']['installer_enabled']) AND $config_vars['other']['installer_enabled'] == 1 )
+		OR ( isset($_SERVER['HTTP_REFERER']) AND stristr( $_SERVER['HTTP_REFERER'], 'quick_punch') ) ) {
 	//FIXME: Remove the authenticate flag from sm_header and installer.
 	$authenticate = FALSE;
 }
@@ -493,12 +505,12 @@ function keyhandler(e) {
     }
 
     if ( code == 27 ) { //Esc
-        hideQuickHelpWindow()
+        //hideQuickHelpWindow()
     }
 
     if ( code == 96 ) { //`= 96
-        placeQuickHelpWindow();
-        showQuickHelpWindow()
+        //placeQuickHelpWindow();
+        //showQuickHelpWindow()
     }
 
     if ( code == 94 || code == 126 ) { //^ = 94 ~ == 126
@@ -950,6 +962,7 @@ function firstElementFocus() {
     for(i=0; i < 10; i++) {
         //alert('Object: '+document.forms[0].elements[i]);
         if ( document.forms != 'undefined'
+			&& document.forms.length > 0
             && document.forms[0].elements[i] != 'undefined'
             && document.forms[0].elements[i] != null
             && document.forms[0].elements[i].type == 'text' ) {
@@ -1432,6 +1445,15 @@ function resizeWindowToFit( contentObj, type, offset ) {
 		final_w = final_w+offset;
 		final_h = final_h+offset;
 	}
+
+	//Don't make window larger than screen size
+	if ( final_w > screen.availWidth ) {
+		final_w = screen.availWidth;
+	}
+
+	if ( final_h > screen.availHeight ) {
+		final_h = screen.availHeight;
+	}
 	//alert('Content Width: '+ final_w +' Height: '+ final_h );
 
 	x.resizeTo( final_w, final_h );
