@@ -1,33 +1,45 @@
 <?php
 /*********************************************************************************
- * The contents of this file are subject to the TimeTrex Public License Version
- * 1.1.0 ("License"); You may not use this file except in compliance with the
- * License. You may obtain a copy of the License at http://www.TimeTrex.com/TPL
- * Software distributed under the License is distributed on an "AS IS" basis,
- * WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the License
- * for the specific language governing rights and limitations under the
- * License.
+ * TimeTrex is a Payroll and Time Management program developed by
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
  *
- * All copies of the Covered Code must include on each user interface screen:
- *    (i) the "Powered by TimeTrex" logo and
- *    (ii) the TimeTrex copyright notice
- * in the same form as they appear in the distribution.  See full license for
- * requirements.
+ * This program is free software; you can redistribute it and/or modify it under
+ * the terms of the GNU Affero General Public License version 3 as published by
+ * the Free Software Foundation with the addition of the following permission
+ * added to Section 15 as permitted in Section 7(a): FOR ANY PART OF THE COVERED
+ * WORK IN WHICH THE COPYRIGHT IS OWNED BY TIMETREX, TIMETREX DISCLAIMS THE
+ * WARRANTY OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
  *
- * The Original Code is: TimeTrex Open Source
- * The Initial Developer of the Original Code is TimeTrex Payroll Services
- * Portions created by TimeTrex are Copyright (C) 2004-2007 TimeTrex Payroll Services;
- * All Rights Reserved.
+ * This program is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+ * FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
+ * details.
  *
+ * You should have received a copy of the GNU Affero General Public License along
+ * with this program; if not, see http://www.gnu.org/licenses or write to the Free
+ * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+ * 02110-1301 USA.
+ *
+ * You can contact TimeTrex headquarters at Unit 22 - 2475 Dobbin Rd. Suite
+ * #292 Westbank, BC V4T 2E9, Canada or at email address info@timetrex.com.
+ *
+ * The interactive user interfaces in modified source and object code versions
+ * of this program must display Appropriate Legal Notices, as required under
+ * Section 5 of the GNU Affero General Public License version 3.
+ *
+ * In accordance with Section 7(b) of the GNU Affero General Public License
+ * version 3, these Appropriate Legal Notices must retain the display of the
+ * "Powered by TimeTrex" logo. If the display of the logo is not reasonably
+ * feasible for technical reasons, the Appropriate Legal Notices must display
+ * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2357 $
- * $Id: Form940.php 2357 2009-01-19 23:39:58Z ipso $
- * $Date: 2009-01-19 15:39:58 -0800 (Mon, 19 Jan 2009) $
+ * $Revision: 2868 $
+ * $Id: Form940.php 2868 2009-10-02 22:48:14Z ipso $
+ * $Date: 2009-10-02 15:48:14 -0700 (Fri, 02 Oct 2009) $
  */
 require_once('../../includes/global.inc.php');
 require_once(Environment::getBasePath() .'includes/Interface.inc.php');
-require(Environment::getBasePath() .'/classes/fpdi/fpdi.php');
 
 if ( !$permission->Check('report','enabled')
 		OR !$permission->Check('report','view_form940') ) {
@@ -112,8 +124,8 @@ switch ($action) {
 			$ugdf->setID( $ugdlf->getCurrent()->getID() );
 		}
 		$ugdf->setCompany( $current_company->getId() );
-		$ugdf->setName( $title );
 		$ugdf->setScript( $_SERVER['SCRIPT_NAME'] );
+		$ugdf->setName( $title );
 		$ugdf->setData( $setup_data );
 		$ugdf->setDefault( TRUE );
 		if ( $ugdf->isValid() ) {
@@ -135,6 +147,16 @@ switch ($action) {
 					$pseal_obj = $pseallf->getCurrent();
 				}
 
+				require_once( Environment::getBasePath() .'/classes/fpdi/fpdi.php');
+				require_once( Environment::getBasePath() .'/classes/tcpdf/tcpdf.php');
+				require_once( Environment::getBasePath() .'/classes/GovernmentForms/GovernmentForms.class.php');
+
+				$gf = new GovernmentForms();
+
+				$f940 = $gf->getFormObject( '940', 'US' );
+				//$f940->setDebug(FALSE);
+				$f940->setShowBackground( $show_background );
+
 				//
 				//Get all data for the form.
 				//
@@ -151,7 +173,7 @@ switch ($action) {
 					}
 
 					if ( isset($pay_period_ids) ) {
-						$payments_over_cutoff = 7000;
+						$payments_over_cutoff = $f940->payment_cutoff_amount;
 
 						//PS Account Amounts...
 						//Get employees who have recieved pay stubs.
@@ -211,7 +233,7 @@ switch ($action) {
 								$user_total_lines_arr[$user_id]['p2_4'] += $user_quarter_lines_arr[$user_id]['p2_4'];
 								$user_total_lines_arr[$user_id]['total_payment'] += $tmp_quarter_user_payment;
 
-								//If we the user exceeds the cutoff, simply minus the cutoff
+								//If the user exceeds the cutoff, simply minus the cutoff
 								if ( $user_total_lines_arr[$user_id]['total_payment'] > $payments_over_cutoff ) {
 									Debug::Text('User ID: '. $user_id .' Over Cutoff...', __FILE__, __LINE__, __METHOD__,10);
 
@@ -233,8 +255,8 @@ switch ($action) {
 
 							$lines_arr[$quarter_id]['p2_6'] = $lines_arr[$quarter_id]['p2_4'] + $lines_arr[$quarter_id]['p2_5'];
 							$lines_arr[$quarter_id]['p2_7'] = $lines_arr[$quarter_id]['p2_3'] - $lines_arr[$quarter_id]['p2_6'];
-							$lines_arr[$quarter_id]['p2_8'] = $lines_arr[$quarter_id]['p2_7'] * 0.008;
-							$lines_arr[$quarter_id]['p3_9'] = $lines_arr[$quarter_id]['p2_7'] * 0.054;
+							$lines_arr[$quarter_id]['p2_8'] = $lines_arr[$quarter_id]['p2_7'] * $f940->futa_tax_before_adjustment_rate;
+							$lines_arr[$quarter_id]['p3_9'] = $lines_arr[$quarter_id]['p2_7'] * $f940->futa_tax_rate;
 							$lines_arr[$quarter_id]['p4_12'] = $lines_arr[$quarter_id]['p2_8'] + $lines_arr[$quarter_id]['p3_9'];
 						}
 						unset($user_id);
@@ -250,368 +272,93 @@ switch ($action) {
 					Debug::Arr($lines_arr, 'Lines Array: ', __FILE__, __LINE__, __METHOD__,10);
 				}
 
-				if  ( isset($lines_arr['total']['p4_12']) ) {
-					//P4 - Line14
-					$lines_arr['total']['p4_14'] = $lines_arr['total']['p4_12'];
-				}
-
-				$border = 0;
-
-				$adjust_x = 0;
-				$adjust_y = 0;
-
-				$pdf = new fpdi();
-
-				if ( $show_background == TRUE ) {
-					//Import original Gov't supplied PDF.
-					$pagecount = $pdf->setSourceFile(Environment::getBasePath().'interface'. DIRECTORY_SEPARATOR .'forms'. DIRECTORY_SEPARATOR .'us'. DIRECTORY_SEPARATOR .'tax'. DIRECTORY_SEPARATOR .'f940.pdf');
-					$tplidx[1] = $pdf->ImportPage(1);
-					$tplidx[2] = $pdf->ImportPage(2);
-					$tplidx[3] = $pdf->ImportPage(3);
-					$tplidx[4] = $pdf->ImportPage(4);
-				}
-
-				$pdf->setMargins(0,0,0,0);
-				$pdf->SetAutoPageBreak(FALSE);
-				$pdf->SetFont('freeserif','', 10);
-
-				$pdf->AddPage();
-				if ( isset($tplidx) ) {
-					$pdf->useTemplate($tplidx[1],0,0);
-				}
-
-				//Form year
-				if ( $show_background == TRUE ) {
-					//Form number and year
-					$pdf->SetFont('freeserif','B', 18);
-					$pdf->setFillColor( 255,255,255 );
-					$pdf->setXY( Misc::AdjustXY(19, $adjust_x), Misc::AdjustXY(10, $adjust_y) );
-					$pdf->Cell(35,10,'940 for '. $filter_data['year'], $border, 0, 'C', 1);
-
-					//Year in type of return
-					$pdf->SetFont('freeserif','', 9);
-					$pdf->setFillColor( 245,245,245 ); //Gray background.
-					$pdf->setXY( Misc::AdjustXY(162, $adjust_x), Misc::AdjustXY(54, $adjust_y) );
-					$pdf->Cell(7,3,$filter_data['year'], $border, 0, 'C', 1);
-
-					//Form revision at bottom right of 1st page
-					$pdf->SetFont('freeserif','', 7);
-					$pdf->setFillColor( 255,255,255 );
-					$pdf->setXY( Misc::AdjustXY(195, $adjust_x), Misc::AdjustXY(265, $adjust_y) );
-					$pdf->Cell(9, 4, '('. $filter_data['year'] .')', $border, 0, 'C', 1);
-
-					//Form year in black bars
-					$pdf->SetFont('freeserif','B', 10);
-					$pdf->setTextColor( 255,255,255 );
-					$pdf->setFillColor( 0,0,0 );
-					$pdf->setXY( Misc::AdjustXY(103, $adjust_x), Misc::AdjustXY(106.8, $adjust_y) );
-					$pdf->Cell(9, 3.5, $filter_data['year'], $border, 0, 'C', 1);
-					$pdf->setXY( Misc::AdjustXY(124, $adjust_x), Misc::AdjustXY(204.5, $adjust_y) );
-					$pdf->Cell(9, 3.5, $filter_data['year'], $border, 0, 'C', 1);
-					$pdf->setTextColor( 0,0,0 );
-
-					$pdf->SetFont('freeserif','', 10);
-					$pdf->setFillColor( 245,245,245 );
-					$pdf->setXY( Misc::AdjustXY(80, $adjust_x), Misc::AdjustXY(237.72, $adjust_y) );
-					$pdf->Cell(8, 3.5, $filter_data['year'], $border, 0, 'C', 1);
-
-					$pdf->setFillColor( 255,255,255 );
-					$pdf->SetFont('freeserif','', 10);
-				}
-
-				//EIN
-				$ein = str_replace(array('-', ' '), '', $current_company->getBusinessNumber() );
-				if ( isset($ein) AND strlen($ein) > 5 ) {
-					$pdf->setXY( Misc::AdjustXY(54, $adjust_x), Misc::AdjustXY(24, $adjust_y) );
-					$pdf->Cell(7,7,$ein[0], $border, 0, 'C');
-
-					$pdf->setXY( Misc::AdjustXY(63, $adjust_x), Misc::AdjustXY(24, $adjust_y) );
-					$pdf->Cell(7,7,$ein[1], $border, 0, 'C');
-
-					$pdf->setXY( Misc::AdjustXY(77, $adjust_x), Misc::AdjustXY(24, $adjust_y) );
-					$pdf->Cell(7,7,$ein[2], $border, 0, 'C');
-
-					$pdf->setXY( Misc::AdjustXY(85, $adjust_x), Misc::AdjustXY(24, $adjust_y) );
-					$pdf->Cell(7,7,$ein[3], $border, 0, 'C');
-
-					$pdf->setXY( Misc::AdjustXY(94, $adjust_x), Misc::AdjustXY(24, $adjust_y) );
-					$pdf->Cell(7,7,$ein[4], $border, 0, 'C');
-
-					$pdf->setXY( Misc::AdjustXY(103, $adjust_x), Misc::AdjustXY(24, $adjust_y) );
-					$pdf->Cell(7,7,$ein[5], $border, 0, 'C');
-
-					$pdf->setXY( Misc::AdjustXY(112, $adjust_x), Misc::AdjustXY(24, $adjust_y) );
-					$pdf->Cell(7,7,$ein[6], $border, 0, 'C');
-
-					$pdf->setXY( Misc::AdjustXY(121, $adjust_x), Misc::AdjustXY(24, $adjust_y) );
-					$pdf->Cell(7,7,$ein[7], $border, 0, 'C');
-
-					$pdf->setXY( Misc::AdjustXY(130, $adjust_x), Misc::AdjustXY(24, $adjust_y) );
-					$pdf->Cell(7,7,$ein[8], $border, 0, 'C');
-				}
-
-				//Name
-				if ( $setup_data['name'] != '' ) {
-					$pdf->setXY( Misc::AdjustXY(49, $adjust_x), Misc::AdjustXY(33, $adjust_y) );
-					$pdf->Cell(90,6,$setup_data['name'], $border, 0, 'L');
-				}
-
-				//Trade name
-				$pdf->setXY( Misc::AdjustXY(41, $adjust_x), Misc::AdjustXY(42, $adjust_y) );
-				$pdf->Cell(90,6,$current_company->getName(), $border, 0, 'L');
-
-				$pdf->setXY( Misc::AdjustXY(28, $adjust_x), Misc::AdjustXY(50, $adjust_y) );
-				$pdf->Cell(100,6,$current_company->getAddress1() .' '. $current_company->getAddress2(), $border, 0, 'L');
-
-				$pdf->setXY( Misc::AdjustXY(28, $adjust_x), Misc::AdjustXY(59, $adjust_y) );
-				$pdf->Cell(65,6,$current_company->getCity(), $border, 0, 'L');
-
-				$pdf->setXY( Misc::AdjustXY(96, $adjust_x), Misc::AdjustXY(59, $adjust_y) );
-				$pdf->Cell(12,6,$current_company->getProvince(), $border, 0, 'C');
-
-				$pdf->setXY( Misc::AdjustXY(111, $adjust_x), Misc::AdjustXY(59, $adjust_y) );
-				$pdf->Cell(23,6,$current_company->getPostalCode(), $border, 0, 'C');
+				$f940->year = $filter_data['year'];
+				$f940->ein = $current_company->getBusinessNumber();
+				$f940->name = $setup_data['name'];
+				$f940->trade_name = $current_company->getName();
+				$f940->address = $current_company->getAddress1() .' '. $current_company->getAddress2();
+				$f940->city = $current_company->getCity();
+				$f940->state = $current_company->getProvince();
+				$f940->zip_code = $current_company->getPostalCode();
 
 				if ( isset($setup_data['return_type']) AND is_array($setup_data['return_type']) ) {
 					foreach( $setup_data['return_type'] as $return_type ) {
 						switch ( $return_type ) {
 							case 10: //Amended
-								$pdf->setXY( Misc::AdjustXY(149, $adjust_x), Misc::AdjustXY(36, $adjust_y) );
-								$pdf->Cell(5,5,'X', $border, 0, 'C');
+								$return_type_arr[] = 'a';
 								break;
 							case 20: //Successor
-								$pdf->setXY( Misc::AdjustXY(149, $adjust_x), Misc::AdjustXY(43, $adjust_y) );
-								$pdf->Cell(5,5,'X', $border, 0, 'C');
+								$return_type_arr[] = 'b';
 								break;
 							case 30: //No Payments
-								$pdf->setXY( Misc::AdjustXY(149, $adjust_x), Misc::AdjustXY(49, $adjust_y) );
-								$pdf->Cell(5,5,'X', $border, 0, 'C');
+								$return_type_arr[] = 'c';
 								break;
 							case 40: //Final
-								$pdf->setXY( Misc::AdjustXY(149, $adjust_x), Misc::AdjustXY(55, $adjust_y) );
-								$pdf->Cell(5,5,'X', $border, 0, 'C');
+								$return_type_arr[] = 'd';
 								break;
 						}
 					}
-				}
 
-				//Multi-state company
+					$f940->return_type = $return_type_arr;
+				}
+/*
 				if ( count($state_options) > 1 ) {
 					//2006 form doesn't support this yet.
+					$f940->l1b = TRUE;
 				} else {
 					$state = trim( array_shift($state_options) );
-
 					if ( strlen($state) == 2 ) {
-						//Line 1a
-						$pdf->setXY( Misc::AdjustXY(111, $adjust_x), Misc::AdjustXY(83, $adjust_y) );
-						$pdf->Cell(5,5,$state[0], $border, 0, 'C');
-						$pdf->setXY( Misc::AdjustXY(121, $adjust_x), Misc::AdjustXY(83, $adjust_y) );
-						$pdf->Cell(5,5,$state[1], $border, 0, 'C');
+						$f940->l1a = $state;
 					}
 				}
-
+*/
 				//Exempt payment check boxes
 				if ( isset($setup_data['exempt_payment']) AND is_array($setup_data['exempt_payment']) ) {
 					foreach( $setup_data['exempt_payment'] as $return_type ) {
 						switch ( $return_type ) {
 							case 10: //Fringe
-								$pdf->setXY( Misc::AdjustXY(55, $adjust_x), Misc::AdjustXY(130, $adjust_y) );
-								$pdf->Cell(5,5,'X', $border, 0, 'C');
+								$f940->l4a = TRUE;
 								break;
 							case 20: //Group life insurance
-								$pdf->setXY( Misc::AdjustXY(55, $adjust_x), Misc::AdjustXY(134, $adjust_y) );
-								$pdf->Cell(5,5,'X', $border, 0, 'C');
+								$f940->l4b = TRUE;
 								break;
 							case 30: //Retirement/Pension
-								$pdf->setXY( Misc::AdjustXY(101, $adjust_x), Misc::AdjustXY(130, $adjust_y) );
-								$pdf->Cell(5,5,'X', $border, 0, 'C');
+								$f940->l4c = TRUE;
 								break;
 							case 40: //Dependant care
-								$pdf->setXY( Misc::AdjustXY(101, $adjust_x), Misc::AdjustXY(134, $adjust_y) );
-								$pdf->Cell(5,5,'X', $border, 0, 'C');
+								$f940->l4d = TRUE;
 								break;
 							case 50: //Other
-								$pdf->setXY( Misc::AdjustXY(139, $adjust_x), Misc::AdjustXY(130, $adjust_y) );
-								$pdf->Cell(5,5,'X', $border, 0, 'C');
+								$f940->l4e = TRUE;
 								break;
 						}
 					}
 				}
 
-				if ( isset($lines_arr) ) {
-					//
-					// Part 2
-					//
+				$f940->l3 = $lines_arr['total']['p2_3'];
+				$f940->l4 = $lines_arr['total']['p2_4'];
+				$f940->l5 = $lines_arr['total']['p2_5'];
 
-					//Line 3
-					$pdf->setXY( Misc::AdjustXY(159, $adjust_x), Misc::AdjustXY(114, $adjust_y) );
-					$pdf->Cell(35,6, Misc::getBeforeDecimal( Misc::MoneyFormat( $lines_arr['total']['p2_3'], FALSE) ), $border, 0, 'R');
-					$pdf->Cell(8,6, Misc::getAfterDecimal( Misc::MoneyFormat( $lines_arr['total']['p2_3'], FALSE) ), $border, 0, 'R');
+				$f940->l13 = $setup_data['tax_deposited'];
 
-					//Line 4
-					$pdf->setXY( Misc::AdjustXY(108, $adjust_x), Misc::AdjustXY(123, $adjust_y) );
-					$pdf->Cell(35,6, Misc::getBeforeDecimal( Misc::MoneyFormat( $lines_arr['total']['p2_4'], FALSE) ), $border, 0, 'R');
-					$pdf->Cell(8,6, Misc::getAfterDecimal( Misc::MoneyFormat( $lines_arr['total']['p2_4'], FALSE) ), $border, 0, 'R');
+				$f940->l15b = TRUE;
 
-					//Line 5
-					$pdf->setXY( Misc::AdjustXY(108, $adjust_x), Misc::AdjustXY(142, $adjust_y) );
-					$pdf->Cell(35,6, Misc::getBeforeDecimal( Misc::MoneyFormat( $lines_arr['total']['p2_5'], FALSE) ), $border, 0, 'R');
-					$pdf->Cell(8,6, Misc::getAfterDecimal( Misc::MoneyFormat( $lines_arr['total']['p2_5'], FALSE) ), $border, 0, 'R');
-
-					//Line 6
-					$pdf->setXY( Misc::AdjustXY(159, $adjust_x), Misc::AdjustXY(150, $adjust_y) );
-					$pdf->Cell(35,6, Misc::getBeforeDecimal( Misc::MoneyFormat( $lines_arr['total']['p2_6'], FALSE) ), $border, 0, 'R');
-					$pdf->Cell(8,6, Misc::getAfterDecimal( Misc::MoneyFormat( $lines_arr['total']['p2_6'], FALSE) ), $border, 0, 'R');
-
-					//Line 7
-					$pdf->setXY( Misc::AdjustXY(159, $adjust_x), Misc::AdjustXY(158, $adjust_y) );
-					$pdf->Cell(35,6, Misc::getBeforeDecimal( Misc::MoneyFormat( $lines_arr['total']['p2_7'], FALSE) ), $border, 0, 'R');
-					$pdf->Cell(8,6, Misc::getAfterDecimal( Misc::MoneyFormat( $lines_arr['total']['p2_7'], FALSE) ), $border, 0, 'R');
-
-					//Line 8
-					$pdf->setXY( Misc::AdjustXY(159, $adjust_x), Misc::AdjustXY(166, $adjust_y) );
-					$pdf->Cell(35,6, Misc::getBeforeDecimal( Misc::MoneyFormat( $lines_arr['total']['p2_8'], FALSE) ), $border, 0, 'R');
-					$pdf->Cell(8,6, Misc::getAfterDecimal( Misc::MoneyFormat( $lines_arr['total']['p2_8'], FALSE) ), $border, 0, 'R');
-
-					//
-					//Part 3
-					//
-
-					//Line 9
-					$pdf->setXY( Misc::AdjustXY(159, $adjust_x), Misc::AdjustXY(179, $adjust_y) );
-					$pdf->Cell(35,6, Misc::getBeforeDecimal( Misc::MoneyFormat( $lines_arr['total']['p3_9'], FALSE) ), $border, 0, 'R');
-					$pdf->Cell(8,6, Misc::getAfterDecimal( Misc::MoneyFormat( $lines_arr['total']['p3_9'], FALSE) ), $border, 0, 'R');
-
-					//
-					//Part 4
-					//
-
-					//Line 12
-					$pdf->setXY( Misc::AdjustXY(159, $adjust_x), Misc::AdjustXY(212, $adjust_y) );
-					$pdf->Cell(35,6, Misc::getBeforeDecimal( Misc::MoneyFormat( $lines_arr['total']['p4_12'], FALSE) ), $border, 0, 'R');
-					$pdf->Cell(8,6, Misc::getAfterDecimal( Misc::MoneyFormat( $lines_arr['total']['p4_12'], FALSE) ), $border, 0, 'R');
-
-					//Line 14
-					$pdf->setXY( Misc::AdjustXY(159, $adjust_x), Misc::AdjustXY(235, $adjust_y) );
-					$pdf->Cell(35,6, Misc::getBeforeDecimal( Misc::MoneyFormat( $lines_arr['total']['p4_12'], FALSE) ), $border, 0, 'R');
-					$pdf->Cell(8,6, Misc::getAfterDecimal( Misc::MoneyFormat( $lines_arr['total']['p4_12'], FALSE) ), $border, 0, 'R');
-
-					$pdf->AddPage();
-					if ( isset($tplidx) ) {
-						$pdf->useTemplate($tplidx[2],0,0);
-					}
-
-					//Form year
-					if ( $show_background == TRUE ) {
-						//Form revision at bottom right of 2nd page
-						$pdf->SetFont('freeserif','', 7);
-						$pdf->setFillColor( 255,255,255 );
-						$pdf->setXY( Misc::AdjustXY(195, $adjust_x), Misc::AdjustXY(246, $adjust_y) );
-						$pdf->Cell(9, 4, '('. $filter_data['year'] .')', $border, 0, 'C', 1);
-
-						$pdf->SetFont('freeserif','', 10);
-					}
-
-					//Company
-					$pdf->setXY(Misc::AdjustXY(14, $adjust_x), Misc::AdjustXY(23, $adjust_y));
-					$pdf->Cell(90,6,$current_company->getName(), $border, 0, 'L');
-
-					//EIN
-					$pdf->setXY(Misc::AdjustXY(141, $adjust_x), Misc::AdjustXY(23, $adjust_y));
-					$pdf->Cell(50,6,$current_company->getBusinessNumber(), $border, 0, 'L');
-
-					//
-					//Part 5
-					//
-
-					if ( $lines_arr['total']['p4_12'] > 500 ) {
-						//Line 16a
-						if ( isset($lines_arr[1]['p4_12']) AND $lines_arr[1]['p4_12'] > 0 ) {
-							$pdf->setXY( Misc::AdjustXY(121, $adjust_x), Misc::AdjustXY(46, $adjust_y) );
-							$pdf->Cell(35,6, Misc::getBeforeDecimal( Misc::MoneyFormat( $lines_arr[1]['p4_12'], FALSE) ), $border, 0, 'R');
-							$pdf->Cell(8,6, Misc::getAfterDecimal( Misc::MoneyFormat( $lines_arr[1]['p4_12'], FALSE) ), $border, 0, 'R');
-						}
-
-						//Line 16b
-						if ( isset($lines_arr[2]['p4_12']) AND $lines_arr[2]['p4_12'] > 0 ) {
-							$pdf->setXY( Misc::AdjustXY(121, $adjust_x), Misc::AdjustXY(55, $adjust_y) );
-							$pdf->Cell(35,6, Misc::getBeforeDecimal( Misc::MoneyFormat( $lines_arr[2]['p4_12'], FALSE) ), $border, 0, 'R');
-							$pdf->Cell(8,6, Misc::getAfterDecimal( Misc::MoneyFormat( $lines_arr[2]['p4_12'], FALSE) ), $border, 0, 'R');
-						}
-
-						//Line 16c
-						if ( isset($lines_arr[3]['p4_12']) AND $lines_arr[3]['p4_12'] > 0 ) {
-							$pdf->setXY( Misc::AdjustXY(121, $adjust_x), Misc::AdjustXY(63, $adjust_y) );
-							$pdf->Cell(35,6, Misc::getBeforeDecimal( Misc::MoneyFormat( $lines_arr[3]['p4_12'], FALSE) ), $border, 0, 'R');
-							$pdf->Cell(8,6, Misc::getAfterDecimal( Misc::MoneyFormat( $lines_arr[3]['p4_12'], FALSE) ), $border, 0, 'R');
-						}
-
-						//Line 16c
-						if ( isset($lines_arr[4]['p4_12']) AND $lines_arr[4]['p4_12'] > 0 ) {
-							$pdf->setXY( Misc::AdjustXY(121, $adjust_x), Misc::AdjustXY(72, $adjust_y) );
-							$pdf->Cell(35,6, Misc::getBeforeDecimal( Misc::MoneyFormat( $lines_arr[4]['p4_12'], FALSE) ), $border, 0, 'R');
-							$pdf->Cell(8,6, Misc::getAfterDecimal( Misc::MoneyFormat( $lines_arr[4]['p4_12'], FALSE) ), $border, 0, 'R');
-						}
-
-						//Line 17
-						$pdf->setXY( Misc::AdjustXY(121, $adjust_x), Misc::AdjustXY(80, $adjust_y) );
-						$pdf->Cell(35,6, Misc::getBeforeDecimal( Misc::MoneyFormat( $lines_arr['total']['p4_12'], FALSE) ), $border, 0, 'R');
-						$pdf->Cell(8,6, Misc::getAfterDecimal( Misc::MoneyFormat( $lines_arr['total']['p4_12'], FALSE) ), $border, 0, 'R');
-					}
-
-					//Add Vochure page.
-					$pdf->AddPage();
-					if ( isset($tplidx) ) {
-						$pdf->useTemplate($tplidx[3],0,0);
-					}
-
-					//Form year
-					if ( $show_background == TRUE ) {
-						$pdf->SetFont('freeserif','B', 24);
-						$pdf->setFillColor( 255,255,255 );
-						$pdf->setXY( Misc::AdjustXY(185, $adjust_x), Misc::AdjustXY(209, $adjust_y) );
-						$pdf->Cell(10,7, substr( $filter_data['year'], 2, 2) , $border, 0, 'C', 1);
-
-						//Form year in instructions
-						$pdf->SetFont('freeserif','', 10);
-						$pdf->setXY( Misc::AdjustXY(89, $adjust_x), Misc::AdjustXY(51.8, $adjust_y) );
-						$pdf->Cell(8, 4, $filter_data['year'], $border, 0, 'C', 1);
-						$pdf->setXY( Misc::AdjustXY(120, $adjust_x), Misc::AdjustXY(69, $adjust_y) );
-						$pdf->Cell(9, 4, $filter_data['year'].'.', $border, 0, 'C', 1);
-						$pdf->setXY( Misc::AdjustXY(131, $adjust_x), Misc::AdjustXY(84.8, $adjust_y) );
-						$pdf->Cell(9, 4, $filter_data['year'], $border, 0, 'C', 1);
-						$pdf->setXY( Misc::AdjustXY(185, $adjust_x), Misc::AdjustXY(88.5, $adjust_y) );
-						$pdf->Cell(9, 4, $filter_data['year'], $border, 0, 'C', 1);
-
-						$pdf->SetFont('freeserif','', 10);
-					}
-
-					$ein = str_replace(array('-', ' '), '', $current_company->getBusinessNumber() );
-					if ( isset($ein) AND strlen($ein) > 5 ) {
-						$pdf->setXY( Misc::AdjustXY(20, $adjust_x), Misc::AdjustXY(224, $adjust_y) );
-						$pdf->Cell(10,7,$ein[0].$ein[1], $border, 0, 'C');
-
-						$pdf->setXY( Misc::AdjustXY(33, $adjust_x), Misc::AdjustXY(224, $adjust_y) );
-						$pdf->Cell(25,7,$ein[2].$ein[3].$ein[4].$ein[5].$ein[6].$ein[7].$ein[8], $border, 0, 'L');
-					}
-
-					$pdf->setXY( Misc::AdjustXY(153, $adjust_x), Misc::AdjustXY(224, $adjust_y) );
-					$pdf->Cell(35,6, Misc::getBeforeDecimal( Misc::MoneyFormat( $lines_arr['total']['p4_12'], FALSE) ), $border, 0, 'R');
-					$pdf->Cell(8,6, Misc::getAfterDecimal( Misc::MoneyFormat( $lines_arr['total']['p4_12'], FALSE) ), $border, 0, 'R');
-
-					//Trade name
-					$pdf->setXY( Misc::AdjustXY(80, $adjust_x), Misc::AdjustXY(233, $adjust_y) );
-					$pdf->Cell(90,6,$current_company->getName(), $border, 0, 'L');
-
-					$pdf->setXY( Misc::AdjustXY(80, $adjust_x), Misc::AdjustXY(241, $adjust_y) );
-					$pdf->Cell(100,6,$current_company->getAddress1() .' '. $current_company->getAddress2(), $border, 0, 'L');
-
-					$pdf->setXY( Misc::AdjustXY(80, $adjust_x), Misc::AdjustXY(250, $adjust_y) );
-					$pdf->Cell(100,6,$current_company->getCity().', '.$current_company->getProvince().' '.$current_company->getPostalCode() , $border, 0, 'L');
+				if ( isset($lines_arr[1]['p4_12']) ) {
+					$f940->l16a = $lines_arr[1]['p4_12'];
+				}
+				if ( isset($lines_arr[2]['p4_12']) ) {
+					$f940->l16b = $lines_arr[2]['p4_12'];
+				}
+				if ( isset($lines_arr[3]['p4_12']) ) {
+					$f940->l16c = $lines_arr[3]['p4_12'];
+				}
+				if ( isset($lines_arr[4]['p4_12']) ) {
+					$f940->l16d = $lines_arr[4]['p4_12'];
 				}
 
-				//Finish off PDF
-				$output = $pdf->Output('','S');
+				$gf->addForm( $f940 );
+
+				$output = $gf->output( 'PDF' );
 
 				if ( Debug::getVerbosity() == 11 ) {
 					Debug::Display();
