@@ -1,29 +1,42 @@
 <?php
 /*********************************************************************************
- * The contents of this file are subject to the TimeTrex Public License Version
- * 1.1.0 ("License"); You may not use this file except in compliance with the
- * License. You may obtain a copy of the License at http://www.TimeTrex.com/TPL
- * Software distributed under the License is distributed on an "AS IS" basis,
- * WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the License
- * for the specific language governing rights and limitations under the
- * License.
+ * TimeTrex is a Payroll and Time Management program developed by
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
  *
- * All copies of the Covered Code must include on each user interface screen:
- *    (i) the "Powered by TimeTrex" logo and
- *    (ii) the TimeTrex copyright notice
- * in the same form as they appear in the distribution.  See full license for
- * requirements.
+ * This program is free software; you can redistribute it and/or modify it under
+ * the terms of the GNU Affero General Public License version 3 as published by
+ * the Free Software Foundation with the addition of the following permission
+ * added to Section 15 as permitted in Section 7(a): FOR ANY PART OF THE COVERED
+ * WORK IN WHICH THE COPYRIGHT IS OWNED BY TIMETREX, TIMETREX DISCLAIMS THE
+ * WARRANTY OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
  *
- * The Original Code is: TimeTrex Open Source
- * The Initial Developer of the Original Code is TimeTrex Payroll Services
- * Portions created by TimeTrex are Copyright (C) 2004-2007 TimeTrex Payroll Services;
- * All Rights Reserved.
+ * This program is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+ * FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
+ * details.
  *
+ * You should have received a copy of the GNU Affero General Public License along
+ * with this program; if not, see http://www.gnu.org/licenses or write to the Free
+ * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+ * 02110-1301 USA.
+ *
+ * You can contact TimeTrex headquarters at Unit 22 - 2475 Dobbin Rd. Suite
+ * #292 Westbank, BC V4T 2E9, Canada or at email address info@timetrex.com.
+ *
+ * The interactive user interfaces in modified source and object code versions
+ * of this program must display Appropriate Legal Notices, as required under
+ * Section 5 of the GNU Affero General Public License version 3.
+ *
+ * In accordance with Section 7(b) of the GNU Affero General Public License
+ * version 3, these Appropriate Legal Notices must retain the display of the
+ * "Powered by TimeTrex" logo. If the display of the logo is not reasonably
+ * feasible for technical reasons, the Appropriate Legal Notices must display
+ * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2237 $
- * $Id: FormW2.php 2237 2008-11-11 18:18:20Z ipso $
- * $Date: 2008-11-11 10:18:20 -0800 (Tue, 11 Nov 2008) $
+ * $Revision: 2882 $
+ * $Id: FormW2.php 2882 2009-10-07 23:10:54Z ipso $
+ * $Date: 2009-10-07 16:10:54 -0700 (Wed, 07 Oct 2009) $
  */
 require_once('../../includes/global.inc.php');
 require_once(Environment::getBasePath() .'includes/Interface.inc.php');
@@ -71,11 +84,20 @@ $non_static_columns = array(
 											'-1150-medicare_tax' => TTi18n::gettext('Medicare Tax (6)'),
 											'-1160-ss_tips' => TTi18n::gettext('Social Security Tips (7)'),
 											'-1170-allocated_tips' => TTi18n::gettext('Allocated Tips (8)'),
-											'-1180-advance_eic' => TTi18n::gettext('Allocated Tips (9)'),
-											'-1190-state_wage_1' => TTi18n::gettext('1- State Wages, Tips, Other (16)'),
-											'-1200-state_tax_1' => TTi18n::gettext('1- State Income Tax (17)'),
-											'-1210-district_wage_1' => TTi18n::gettext('1- Locality Wages, Tips, Other (18)'),
-											'-1220-district_tax_1' => TTi18n::gettext('1- Locality Income Tax (19)'),
+											'-1180-advance_eic' => TTi18n::gettext('Advance EIC Payment (9)'),
+											'-1190-dependent_care_benefit' => TTi18n::gettext('Dependent Care Benefits (10)'),
+											'-1200-nonqualified_plan' => TTi18n::gettext('Nonqualified Plans (11)'),
+											'-1210-box_12a' => TTi18n::gettext('Box 12a'),
+											'-1220-box_12b' => TTi18n::gettext('Box 12b'),
+											'-1230-box_12c' => TTi18n::gettext('Box 12c'),
+											'-1240-box_12d' => TTi18n::gettext('Box 12d'),
+											'-1250-box_14a' => TTi18n::gettext('Other Box 14(a)'),
+											'-1260-box_14b' => TTi18n::gettext('Other Box 14(b)'),
+											'-1260-box_14c' => TTi18n::gettext('Other Box 14(c)'),
+											'-1500-state_wage_1' => TTi18n::gettext('1- State Wages, Tips, Other (16)'),
+											'-1510-state_tax_1' => TTi18n::gettext('1- State Income Tax (17)'),
+											'-1600-district_wage_1' => TTi18n::gettext('1- Locality Wages, Tips, Other (18)'),
+											'-1610-district_tax_1' => TTi18n::gettext('1- Locality Income Tax (19)'),
 											);
 
 $pseallf = new PayStubEntryAccountLinkListFactory();
@@ -96,6 +118,15 @@ $column_ps_entry_name_map = array(
 								'ss_tips' => @$setup_data['7_psea_ids'],
 								'allocated_tips' => @$setup_data['8_psea_ids'],
 								'advance_eic' => @$setup_data['9_psea_ids'],
+								'dependent_care_benefit' => @$setup_data['10_psea_ids'],
+								'nonqualified_plan' => @$setup_data['11_psea_ids'],
+								'box_12a' => @$setup_data['12a_psea_ids'],
+								'box_12b' => @$setup_data['12b_psea_ids'],
+								'box_12c' => @$setup_data['12c_psea_ids'],
+								'box_12d' => @$setup_data['12d_psea_ids'],
+								'box_14a' => @$setup_data['14a_psea_ids'],
+								'box_14b' => @$setup_data['14b_psea_ids'],
+								'box_14c' => @$setup_data['14c_psea_ids'],
 								);
 
 $pplf = new PayPeriodListFactory();
@@ -128,8 +159,8 @@ switch ($action) {
 			$ugdf->setID( $ugdlf->getCurrent()->getID() );
 		}
 		$ugdf->setCompany( $current_company->getId() );
-		$ugdf->setName( $title );
 		$ugdf->setScript( $_SERVER['SCRIPT_NAME'] );
+		$ugdf->setName( $title );
 		$ugdf->setData( $setup_data );
 		$ugdf->setDefault( TRUE );
 		if ( $ugdf->isValid() ) {
@@ -412,10 +443,20 @@ switch ($action) {
 						$pdf->Cell(40,5, $rows[$last_row]['allocated_tips'] , $border, 0, 'R');
 					}
 					//Box 9
-					if ($rows[$last_row]['advance_eic'] > 0) {
+					if ($rows[$last_row]['advance_eic'] != 0) {
 						$pdf->setXY(106,61);
 						$pdf->Cell(40,5, abs($rows[$last_row]['advance_eic']) , $border, 0, 'R'); //Should always be positive.
 					}
+					//Box 10
+					if ($rows[$last_row]['dependent_care_benefit'] != 0) {
+						$pdf->setXY(161,61);
+						$pdf->Cell(40,5, $rows[$last_row]['dependent_care_benefit'] , $border, 0, 'R');
+					}
+					//Box 11
+					if ($rows[$last_row]['nonqualified_plan'] != 0) {
+						$pdf->setXY(106,69);
+						$pdf->Cell(40,5, $rows[$last_row]['nonqualified_plan'] , $border, 0, 'R');
+					}
 
 
 					//If more then one state is being report, Box 15 must be "X" and NO state ID.
@@ -586,11 +627,68 @@ switch ($action) {
 							$pdf->Cell(40,5, $row['allocated_tips'] , $border, 0, 'R');
 						}
 						//Box 9
-						if ( isset($row['advance_eic']) AND $row['advance_eic'] > 0) {
+						if ( isset($row['advance_eic']) AND $row['advance_eic'] != 0) {
 							$pdf->setXY(116,61);
 							$pdf->Cell(40,5, abs($row['advance_eic']) , $border, 0, 'R'); //Should always be positive.
 						}
 
+						//Box 10
+						if ( isset($row['dependent_care_benefit']) AND $row['dependent_care_benefit'] > 0) {
+							$pdf->setXY(161,61);
+							$pdf->Cell(40,5, $row['dependent_care_benefit'] , $border, 0, 'R');
+						}
+						//Box 11
+						if ( isset($row['nonqualified_plan']) AND $row['nonqualified_plan'] > 0) {
+							$pdf->setXY(116,69);
+							$pdf->Cell(40,5, $row['nonqualified_plan'] , $border, 0, 'R');
+						}
+
+
+						//Box 12a
+						if ( isset($row['box_12a']) AND $row['box_12a'] > 0) {
+							$pdf->setXY(161,69);
+							$pdf->Cell(10,5, $setup_data['12a_code'] , $border, 0, 'R');
+							$pdf->Cell(30,5, $row['box_12a'] , $border, 0, 'R');
+						}
+						//Box 12b
+						if ( isset($row['box_12b']) AND $row['box_12b'] > 0) {
+							$pdf->setXY(161,77);
+							$pdf->Cell(10,5, $setup_data['12b_code'] , $border, 0, 'R');
+							$pdf->Cell(30,5, $row['box_12b'] , $border, 0, 'R');
+						}
+						//Box 12c
+						if ( isset($row['box_12c']) AND $row['box_12c'] > 0) {
+							$pdf->setXY(161,86);
+							$pdf->Cell(10,5, $setup_data['12c_code'] , $border, 0, 'R');
+							$pdf->Cell(30,5, $row['box_12c'] , $border, 0, 'R');
+						}
+						//Box 12d
+						if ( isset($row['box_12d']) AND $row['box_12d'] > 0) {
+							$pdf->setXY(161,94);
+							$pdf->Cell(10,5, $setup_data['12d_code'] , $border, 0, 'R');
+							$pdf->Cell(30,5, $row['box_12d'] , $border, 0, 'R');
+						}
+
+
+						//Box 14a
+						if ( isset($row['box_14a']) AND $row['box_14a'] > 0) {
+							$pdf->setXY(117,86);
+							$pdf->Cell(21,5, $setup_data['14a_name'].':' , $border, 0, 'L');
+							$pdf->Cell(21,5, $row['box_14a'] , $border, 0, 'R');
+						}
+						//Box 14b
+						if ( isset($row['box_14b']) AND $row['box_14b'] > 0) {
+							$pdf->setXY(117,91);
+							$pdf->Cell(21,5, $setup_data['14b_name'].':' , $border, 0, 'L');
+							$pdf->Cell(21,5, $row['box_14b'] , $border, 0, 'R');
+						}
+						//Box 14c
+						if ( isset($row['box_14c']) AND $row['box_14c'] > 0) {
+							$pdf->setXY(117,96);
+							$pdf->Cell(21,5, $setup_data['14c_name'].':' , $border, 0, 'L');
+							$pdf->Cell(21,5, $row['box_14c'] , $border, 0, 'R');
+						}
+
 
 						if ( isset($row['state_1']) ) {
 							//1- State
