@@ -1,29 +1,42 @@
 <?php
 /*********************************************************************************
- * The contents of this file are subject to the TimeTrex Public License Version
- * 1.1.0 ("License"); You may not use this file except in compliance with the
- * License. You may obtain a copy of the License at http://www.TimeTrex.com/TPL
- * Software distributed under the License is distributed on an "AS IS" basis,
- * WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the License
- * for the specific language governing rights and limitations under the
- * License.
+ * TimeTrex is a Payroll and Time Management program developed by
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
  *
- * All copies of the Covered Code must include on each user interface screen:
- *    (i) the "Powered by TimeTrex" logo and
- *    (ii) the TimeTrex copyright notice
- * in the same form as they appear in the distribution.  See full license for
- * requirements.
+ * This program is free software; you can redistribute it and/or modify it under
+ * the terms of the GNU Affero General Public License version 3 as published by
+ * the Free Software Foundation with the addition of the following permission
+ * added to Section 15 as permitted in Section 7(a): FOR ANY PART OF THE COVERED
+ * WORK IN WHICH THE COPYRIGHT IS OWNED BY TIMETREX, TIMETREX DISCLAIMS THE
+ * WARRANTY OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
  *
- * The Original Code is: TimeTrex Open Source
- * The Initial Developer of the Original Code is TimeTrex Payroll Services
- * Portions created by TimeTrex are Copyright (C) 2004-2007 TimeTrex Payroll Services;
- * All Rights Reserved.
+ * This program is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+ * FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
+ * details.
  *
+ * You should have received a copy of the GNU Affero General Public License along
+ * with this program; if not, see http://www.gnu.org/licenses or write to the Free
+ * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+ * 02110-1301 USA.
+ *
+ * You can contact TimeTrex headquarters at Unit 22 - 2475 Dobbin Rd. Suite
+ * #292 Westbank, BC V4T 2E9, Canada or at email address info@timetrex.com.
+ *
+ * The interactive user interfaces in modified source and object code versions
+ * of this program must display Appropriate Legal Notices, as required under
+ * Section 5 of the GNU Affero General Public License version 3.
+ *
+ * In accordance with Section 7(b) of the GNU Affero General Public License
+ * version 3, these Appropriate Legal Notices must retain the display of the
+ * "Powered by TimeTrex" logo. If the display of the logo is not reasonably
+ * feasible for technical reasons, the Appropriate Legal Notices must display
+ * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2338 $
- * $Id: PayStubSummary.php 2338 2009-01-14 21:32:59Z ipso $
- * $Date: 2009-01-14 13:32:59 -0800 (Wed, 14 Jan 2009) $
+ * $Revision: 2838 $
+ * $Id: PayStubSummary.php 2838 2009-09-18 20:57:41Z ipso $
+ * $Date: 2009-09-18 13:57:41 -0700 (Fri, 18 Sep 2009) $
  */
 require_once('../../includes/global.inc.php');
 require_once(Environment::getBasePath() .'includes/Interface.inc.php');
@@ -71,6 +84,9 @@ $static_columns = array(
 							'-1070-hire_date' => TTi18n::gettext('Hire Date'),
 							'-1080-since_hire_date' => TTi18n::gettext('Since Hired'),
 							'-1085-termination_date' => TTi18n::gettext('Termination Date'),
+							'-1086-institution' => TTi18n::gettext('Bank Institution'),
+							'-1087-transit' => TTi18n::gettext('Bank Transit/Routing'),
+							'-1089-account' => TTi18n::gettext('Bank Account'),
 							'-1090-pay_period' => TTi18n::gettext('Pay Period'),
 							'-1100-pay_stub_start_date' => TTi18n::gettext('Start Date'),
 							'-1110-pay_stub_end_date' => TTi18n::gettext('End Date'),
@@ -224,6 +240,7 @@ switch ($action) {
 					//Get column headers
 					$report_columns = array();
 
+					//Strip off Employee Deduction, Earnings, etc from names so they don't clutter reports.
 					$psealf->getByCompanyId( $current_company->getId() );
 					foreach($psealf as $psea_obj) {
 						//$report_columns[$psen_obj->getId()] = $psen_obj->getDescription();
@@ -234,32 +251,32 @@ switch ($action) {
 					$report_columns = Misc::prependArray( $static_columns, $report_columns);
 
 					$pself = new PayStubEntryListFactory();
-					//$pself->getReportByCompanyIdAndUserIdAndPayPeriodId( $current_company->getId(), $filter_data['user_ids'], $filter_data['pay_period_ids'] );
 					$pself->getReportByCompanyIdAndArrayCriteria( $current_company->getId(), $filter_data );
+					if ( $pself->getRecordCount() > 0 ) {
+						//Prepare data for regular report.
+						foreach( $pself as $pse_obj ) {
+							$user_id = $pse_obj->getColumn('user_id');
+							$pay_stub_id = $pse_obj->getColumn('pay_stub_id');
+							$currency_id = $pse_obj->getColumn('currency_id');
+							$currency_rate = $pse_obj->getColumn('currency_rate');
+							//$pay_period_id = $pse_obj->getColumn('pay_period_id');
+							//$pay_stub_transaction_date = $pse_obj->getColumn('pay_stub_transaction_date');
+							$pay_stub_entry_name_id = $pse_obj->getColumn('pay_stub_entry_name_id');
 
-					//Prepare data for regular report.
-					foreach( $pself as $pse_obj ) {
-						$user_id = $pse_obj->getColumn('user_id');
-						$pay_stub_id = $pse_obj->getColumn('pay_stub_id');
-						$currency_id = $pse_obj->getColumn('currency_id');
-						$currency_rate = $pse_obj->getColumn('currency_rate');
-						//$pay_period_id = $pse_obj->getColumn('pay_period_id');
-						//$pay_stub_transaction_date = $pse_obj->getColumn('pay_stub_transaction_date');
-						$pay_stub_entry_name_id = $pse_obj->getColumn('pay_stub_entry_name_id');
+							//$raw_rows[$user_id][$pay_p][$pay_stub_entry_name_id] = $pse_obj->getColumn('amount');
 
-						//$raw_rows[$user_id][$pay_p][$pay_stub_entry_name_id] = $pse_obj->getColumn('amount');
-
-						if ( !isset($raw_rows[$user_id][$pay_stub_id]) ) {
-							$raw_rows[$user_id][$pay_stub_id]['pay_period_id'] = $pse_obj->getColumn('pay_period_id');
-							$raw_rows[$user_id][$pay_stub_id]['pay_stub_start_date'] = TTDate::strtotime( $pse_obj->getColumn('pay_stub_start_date') );
-							$raw_rows[$user_id][$pay_stub_id]['pay_stub_end_date'] = TTDate::strtotime( $pse_obj->getColumn('pay_stub_end_date') );
-							$raw_rows[$user_id][$pay_stub_id]['pay_stub_transaction_date'] = TTDate::strtotime( $pse_obj->getColumn('pay_stub_transaction_date') );
-							$raw_rows[$user_id][$pay_stub_id]['currency_id'] = $pse_obj->getColumn('currency_id');
-							$raw_rows[$user_id][$pay_stub_id]['currency_rate'] = $pse_obj->getColumn('currency_rate');
+							if ( !isset($raw_rows[$user_id][$pay_stub_id]) ) {
+								$raw_rows[$user_id][$pay_stub_id]['pay_period_id'] = $pse_obj->getColumn('pay_period_id');
+								$raw_rows[$user_id][$pay_stub_id]['pay_stub_start_date'] = TTDate::strtotime( $pse_obj->getColumn('pay_stub_start_date') );
+								$raw_rows[$user_id][$pay_stub_id]['pay_stub_end_date'] = TTDate::strtotime( $pse_obj->getColumn('pay_stub_end_date') );
+								$raw_rows[$user_id][$pay_stub_id]['pay_stub_transaction_date'] = TTDate::strtotime( $pse_obj->getColumn('pay_stub_transaction_date') );
+								$raw_rows[$user_id][$pay_stub_id]['currency_id'] = $pse_obj->getColumn('currency_id');
+								$raw_rows[$user_id][$pay_stub_id]['currency_rate'] = $pse_obj->getColumn('currency_rate');
+							}
+							$raw_rows[$user_id][$pay_stub_id]['pay_stub_entry_name'][$pay_stub_entry_name_id] = $pse_obj->getColumn('amount');
 						}
-						$raw_rows[$user_id][$pay_stub_id]['pay_stub_entry_name'][$pay_stub_entry_name_id] = $pse_obj->getColumn('amount');
+						unset($user_id, $pay_stub_id, $currency_id, $currency_rate, $pay_stub_entry_name_id);
 					}
-					unset($user_id, $pay_stub_id, $currency_id, $currency_rate, $pay_stub_entry_name_id);
 					//var_dump($raw_rows);
 
 					if ( isset($raw_rows) ) {
@@ -293,9 +310,15 @@ switch ($action) {
 							$currency_convert_to_base = TRUE;
 						}
 
+						$balf = new BankAccountListFactory();
+
 						$x=0;
 						foreach($raw_rows as $user_id => $data_b) {
 							$user_obj = $ulf->getById( $user_id )->getCurrent();
+							$balf->getUserAccountByCompanyIdAndUserId( $user_obj->getCompany(), $user_obj->getID() );
+							if ( $balf->getRecordCount() == 1 ) {
+								$ba_obj = $balf->getCurrent();
+							}
 
 							foreach($data_b as $pay_stub_id => $raw_row) {
 								$tmp_rows[$x]['user_id'] = $user_id;
@@ -344,6 +367,16 @@ switch ($action) {
 								$tmp_rows[$x]['termination_date_order'] = $user_obj->getTerminationDate();
 								$tmp_rows[$x]['termination_date'] = TTDate::getDate('DATE', $user_obj->getTerminationDate() );
 
+								if ( isset($ba_obj ) ) {
+									$tmp_rows[$x]['institution'] = $ba_obj->getInstitution();
+									$tmp_rows[$x]['transit'] = $ba_obj->getTransit();
+									$tmp_rows[$x]['account'] = $ba_obj->getAccount();
+								} else {
+									$tmp_rows[$x]['institution'] = NULL;
+									$tmp_rows[$x]['transit'] = NULL;
+									$tmp_rows[$x]['account'] = NULL;
+								}
+
 								$tmp_rows[$x]['currency'] = $tmp_rows[$x]['current_currency'] = Option::getByKey( $raw_row['currency_id'], $currency_options );
 								if ( $currency_convert_to_base == TRUE ) {
 									$tmp_rows[$x]['current_currency'] = Option::getByKey( $base_currency_obj->getId(), $currency_options );
@@ -357,6 +390,7 @@ switch ($action) {
 
 								$x++;
 							}
+							unset($ba_obj);
 						}
 					}
 					//var_dump($rows);
