@@ -1,24 +1,37 @@
 <?php
 /*********************************************************************************
- * The contents of this file are subject to the TimeTrex Public License Version
- * 1.1.0 ("License"); You may not use this file except in compliance with the
- * License. You may obtain a copy of the License at http://www.TimeTrex.com/TPL
- * Software distributed under the License is distributed on an "AS IS" basis,
- * WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the License
- * for the specific language governing rights and limitations under the
- * License.
+ * TimeTrex is a Payroll and Time Management program developed by
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
  *
- * All copies of the Covered Code must include on each user interface screen:
- *    (i) the "Powered by TimeTrex" logo and
- *    (ii) the TimeTrex copyright notice
- * in the same form as they appear in the distribution.  See full license for
- * requirements.
+ * This program is free software; you can redistribute it and/or modify it under
+ * the terms of the GNU Affero General Public License version 3 as published by
+ * the Free Software Foundation with the addition of the following permission
+ * added to Section 15 as permitted in Section 7(a): FOR ANY PART OF THE COVERED
+ * WORK IN WHICH THE COPYRIGHT IS OWNED BY TIMETREX, TIMETREX DISCLAIMS THE
+ * WARRANTY OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
  *
- * The Original Code is: TimeTrex Open Source
- * The Initial Developer of the Original Code is TimeTrex Payroll Services
- * Portions created by TimeTrex are Copyright (C) 2004-2007 TimeTrex Payroll Services;
- * All Rights Reserved.
+ * This program is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+ * FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
+ * details.
  *
+ * You should have received a copy of the GNU Affero General Public License along
+ * with this program; if not, see http://www.gnu.org/licenses or write to the Free
+ * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+ * 02110-1301 USA.
+ *
+ * You can contact TimeTrex headquarters at Unit 22 - 2475 Dobbin Rd. Suite
+ * #292 Westbank, BC V4T 2E9, Canada or at email address info@timetrex.com.
+ *
+ * The interactive user interfaces in modified source and object code versions
+ * of this program must display Appropriate Legal Notices, as required under
+ * Section 5 of the GNU Affero General Public License version 3.
+ *
+ * In accordance with Section 7(b) of the GNU Affero General Public License
+ * version 3, these Appropriate Legal Notices must retain the display of the
+ * "Powered by TimeTrex" logo. If the display of the logo is not reasonably
+ * feasible for technical reasons, the Appropriate Legal Notices must display
+ * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
  * $Revision: 1564 $
@@ -163,8 +176,8 @@ switch ($action) {
 			$ugdf->setID( $ugdlf->getCurrent()->getID() );
 		}
 		$ugdf->setCompany( $current_company->getId() );
-		$ugdf->setName( $title );
 		$ugdf->setScript( $_SERVER['SCRIPT_NAME'] );
+		$ugdf->setName( $title );
 		$ugdf->setData( $setup_data );
 		$ugdf->setDefault( TRUE );
 		if ( $ugdf->isValid() ) {
@@ -271,16 +284,12 @@ switch ($action) {
 
 				//Debug::Text('Column: '. $column .' Status ID: '. $status_id .' Type ID: '. $type_id , __FILE__, __LINE__, __METHOD__,10);
 
-				if ( $column == 'worked_time' ) {
-					//Handle actual time diff/wage here.
-					//$tmp_rows[$user_id][$pay_period_id][$column] = $udt_obj->getColumn('total_time');
+				if ( $column != NULL ) {
 					if ( isset($tmp_rows[$user_id][$pay_period_id][$column]) ) {
 						$tmp_rows[$user_id][$pay_period_id][$column] += (int)$udt_obj->getColumn('total_time');
 					} else {
 						$tmp_rows[$user_id][$pay_period_id][$column] = (int)$udt_obj->getColumn('total_time');
 					}
-				} else {
-					$tmp_rows[$user_id][$pay_period_id][$column] = $udt_obj->getColumn('total_time');
 				}
 			}
 			//print_r($tmp_rows);
@@ -431,7 +440,7 @@ switch ($action) {
 
 						break;
 					case 'paychex_preview': //Paychex Preview export format.
-						$file_name = $setup_data['paychex_preview']['client_number'] .'_TA.csv';
+						$file_name = $setup_data['paychex_preview']['client_number'] .'_TA.txt';
 
 						ksort($setup_data['paychex_preview']['columns']);
 						$setup_data['paychex_preview']['columns'] = Misc::trimSortPrefix( $setup_data['paychex_preview']['columns'] );
@@ -439,7 +448,7 @@ switch ($action) {
 						$data = NULL;
 						foreach($rows as $row) {
 							foreach( $setup_data['paychex_preview']['columns'] as $column_id => $column_data ) {
-								if ( isset( $row[$column_id] ) AND $column_data['hour_code'] != '' ) {
+								if ( isset( $row[$column_id] ) AND trim($column_data['hour_code']) != '' ) {
 									$data .= str_pad($row['employee_number'], 6, ' ', STR_PAD_LEFT);
 									$data .= str_pad('E'. str_pad( $column_data['hour_code'], 2, 0, STR_PAD_LEFT) , 47, ' ', STR_PAD_LEFT);
 									$data .= str_pad( str_pad( TTDate::getTimeUnit( $row[$column_id], 20 ), 8, 0, STR_PAD_LEFT) , 17, ' ', STR_PAD_LEFT)."\n";
@@ -458,7 +467,7 @@ switch ($action) {
 													'hour_code' => '', 'value' => '', 'distribution' => '', 'rate' => '', 'premium' => '', 'day' => '', 'pay_period' => '');
 						foreach($rows as $row) {
 							foreach( $setup_data['ceridian_insync']['columns'] as $column_id => $column_data ) {
-								if ( isset( $row[$column_id] ) AND $column_data['hour_code'] != '' ) {
+								if ( isset( $row[$column_id] ) AND trim($column_data['hour_code']) != '' ) {
 									$tmp_rows[] = array(
 														'employee_number' => $row['employee_number'],
 														'import_type_id' => 'COSTING',
@@ -491,7 +500,7 @@ switch ($action) {
 						$export_column_map = array('employee_number' => '', 'transaction_code' => '', 'hour_code' => '', 'hours' => '');
 						foreach($rows as $row) {
 							foreach( $setup_data['millenium']['columns'] as $column_id => $column_data ) {
-								if ( isset( $row[$column_id] ) AND $column_data['hour_code'] != '' ) {
+								if ( isset( $row[$column_id] ) AND trim($column_data['hour_code']) != '' ) {
 									$tmp_rows[] = array(
 														'employee_number' => $row['employee_number'],
 														'transaction_code' => 'E',
@@ -523,7 +532,7 @@ switch ($action) {
 
 						foreach($rows as $row) {
 							foreach( $setup_data['quickbooks']['columns'] as $column_id => $column_data ) {
-								if ( isset( $row[$column_id] ) AND $column_data['hour_code'] != '' ) {
+								if ( isset( $row[$column_id] ) AND trim($column_data['hour_code']) != '' ) {
 									$data .= 'TIMEACT	'. date('n/j/y', $row['pay_period_end_date']).'		'. $row['first_name'].'  '. $row['last_name'].'		'. trim($column_data['hour_code']) .'	'.  TTDate::getTimeUnit( $row[$column_id], 10 ) .'			Y	0'."\n";
 								}
 							}
@@ -550,7 +559,7 @@ switch ($action) {
 						foreach($rows as $row) {
 							foreach( $setup_data['surepayroll']['columns'] as $column_id => $column_data ) {
 
-								if ( isset( $row[$column_id] ) AND $column_data['hour_code'] != '' ) {
+								if ( isset( $row[$column_id] ) AND trim($column_data['hour_code']) != '' ) {
 									Debug::Arr($column_data,'Output2', __FILE__, __LINE__, __METHOD__,10);
 									$tmp_rows[] = array(
 														'pay_period_end_date' => date('m/d/Y', $row['pay_period_end_date']),
