@@ -1,29 +1,42 @@
 <?php
 /*********************************************************************************
- * The contents of this file are subject to the TimeTrex Public License Version
- * 1.1.0 ("License"); You may not use this file except in compliance with the
- * License. You may obtain a copy of the License at http://www.TimeTrex.com/TPL
- * Software distributed under the License is distributed on an "AS IS" basis,
- * WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the License
- * for the specific language governing rights and limitations under the
- * License.
+ * TimeTrex is a Payroll and Time Management program developed by
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
  *
- * All copies of the Covered Code must include on each user interface screen:
- *    (i) the "Powered by TimeTrex" logo and
- *    (ii) the TimeTrex copyright notice
- * in the same form as they appear in the distribution.  See full license for
- * requirements.
+ * This program is free software; you can redistribute it and/or modify it under
+ * the terms of the GNU Affero General Public License version 3 as published by
+ * the Free Software Foundation with the addition of the following permission
+ * added to Section 15 as permitted in Section 7(a): FOR ANY PART OF THE COVERED
+ * WORK IN WHICH THE COPYRIGHT IS OWNED BY TIMETREX, TIMETREX DISCLAIMS THE
+ * WARRANTY OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
  *
- * The Original Code is: TimeTrex Open Source
- * The Initial Developer of the Original Code is TimeTrex Payroll Services
- * Portions created by TimeTrex are Copyright (C) 2004-2007 TimeTrex Payroll Services;
- * All Rights Reserved.
+ * This program is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+ * FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
+ * details.
  *
+ * You should have received a copy of the GNU Affero General Public License along
+ * with this program; if not, see http://www.gnu.org/licenses or write to the Free
+ * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+ * 02110-1301 USA.
+ *
+ * You can contact TimeTrex headquarters at Unit 22 - 2475 Dobbin Rd. Suite
+ * #292 Westbank, BC V4T 2E9, Canada or at email address info@timetrex.com.
+ *
+ * The interactive user interfaces in modified source and object code versions
+ * of this program must display Appropriate Legal Notices, as required under
+ * Section 5 of the GNU Affero General Public License version 3.
+ *
+ * In accordance with Section 7(b) of the GNU Affero General Public License
+ * version 3, these Appropriate Legal Notices must retain the display of the
+ * "Powered by TimeTrex" logo. If the display of the logo is not reasonably
+ * feasible for technical reasons, the Appropriate Legal Notices must display
+ * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2073 $
- * $Id: PunchSummary.php 2073 2008-08-22 18:41:21Z ipso $
- * $Date: 2008-08-22 11:41:21 -0700 (Fri, 22 Aug 2008) $
+ * $Revision: 3199 $
+ * $Id: PunchSummary.php 3199 2009-12-20 23:37:45Z ipso $
+ * $Date: 2009-12-20 15:37:45 -0800 (Sun, 20 Dec 2009) $
  */
 require_once('../../includes/global.inc.php');
 require_once(Environment::getBasePath() .'includes/Interface.inc.php');
@@ -81,6 +94,7 @@ $static_columns = array(			'-1000-full_name' => TTi18n::gettext('Full Name'),
 									'-1039-group' => TTi18n::gettext('Group'),
 									'-1040-default_branch' => TTi18n::gettext('Default Branch'),
 									'-1050-default_department' => TTi18n::gettext('Default Department'),
+									'-1090-date_stamp' => TTi18n::gettext('Date'),
 									'-1100-in_time_stamp' => TTi18n::gettext('In Punch'),
 									'-1101-in_type' => TTi18n::gettext('In Type'),
 									'-1110-out_time_stamp' => TTi18n::gettext('Out Punch'),
@@ -219,10 +233,9 @@ switch ($action) {
 			}
 
 			foreach( $ulf as $u_obj ) {
-				$filter_data['user_ids'][] = $u_obj->getId();
+				$filter_data['include_user_ids'][] = $u_obj->getId();
 			}
 
-
 			if ( isset($filter_data['pay_period_ids']) ) {
 				//Trim sort prefix from selected pay periods.
 				$tmp_filter_pay_period_ids = $filter_data['pay_period_ids'];
@@ -261,7 +274,6 @@ switch ($action) {
 				$filter_data['job_item_ids'] = array( -1 );
 			}
 
-
 			//$plf->getReportByStartDateAndEndDateAndUserIdListAndBranchIdAndDepartmentIdAndJobIdListAndJobItemIdList( $filter_data['start_date'], $filter_data['end_date'], $filter_data['user_ids'], $filter_data['punch_branch_ids'], $filter_data['punch_department_ids'], $filter_data['job_ids'], $filter_data['job_item_ids'] );
 			$plf->getSearchByCompanyIdAndArrayCriteria( $current_company->getId(), $filter_data );
 			foreach ($plf as $p_obj ) {
@@ -304,6 +316,7 @@ switch ($action) {
 						'other_id3' => $p_obj->getColumn('other_id3'),
 						'other_id4' => $p_obj->getColumn('other_id4'),
 						'other_id5' => $p_obj->getColumn('other_id5'),
+						'date_stamp' => TTDate::strtotime( $p_obj->getColumn('date_stamp') ),
 						'in_time_stamp' => NULL,
 						'in_actual_time_stamp' => NULL,
 						'in_type' => NULL,
@@ -402,6 +415,9 @@ switch ($action) {
 							$rows[$x]['title'] = Option::getByKey($user_obj->getTitle(), $title_options, NULL );
 							$rows[$x]['default_branch'] =  Option::getByKey($user_obj->getDefaultBranch(), $branch_options, NULL );
 							$rows[$x]['default_department'] = Option::getByKey($user_obj->getDefaultDepartment(), $department_options, NULL );
+							$rows[$x]['group'] = Option::getByKey($user_obj->getGroup(), $group_options, NULL );
+
+							$rows[$x]['date_stamp'] = (string)$data_c['date_stamp'];
 
 							$rows[$x]['in_station_type'] = Option::getByKey($data_c['in_station_type_id'], $station_type_options, NULL );
 							$rows[$x]['in_station_station_id'] = (string)$data_c['in_station_station_id'];
@@ -413,7 +429,6 @@ switch ($action) {
 							$rows[$x]['out_station_source'] = (string)$data_c['out_station_source'];
 							$rows[$x]['out_station_description'] = (string)$data_c['out_station_description'];
 
-							$rows[$x]['group'] = Option::getByKey($data_c['group_id'], $group_options, NULL );
 							$rows[$x]['branch'] =  Option::getByKey($data_c['branch_id'], $branch_options, NULL );
 							$rows[$x]['department'] = Option::getByKey($data_c['department_id'], $department_options, NULL );
 
@@ -486,13 +501,20 @@ switch ($action) {
 				$filter_data['column_ids'] = array_diff( $filter_data['column_ids'], $ignore_elements );
 
 				//Add the group by element back in
+				if ( isset($filter_data['quaternary_group_by']) AND $filter_data['quaternary_group_by'] != 0 ) {
+					array_unshift( $filter_data['column_ids'], $filter_data['quaternary_group_by'] );
+				}
+				if ( isset($filter_data['tertiary_group_by']) AND $filter_data['tertiary_group_by'] != 0 ) {
+					array_unshift( $filter_data['column_ids'], $filter_data['tertiary_group_by'] );
+				}
 				if ( isset($filter_data['secondary_group_by']) AND $filter_data['secondary_group_by'] != 0 ) {
-					array_unshift( $filter_data['column_ids'], $filter_data['primary_group_by'], $filter_data['secondary_group_by'] );
-				} else {
+					array_unshift( $filter_data['column_ids'], $filter_data['secondary_group_by'] );
+				}
+				if ( isset($filter_data['primary_group_by']) AND $filter_data['primary_group_by'] != 0 ) {
 					array_unshift( $filter_data['column_ids'], $filter_data['primary_group_by'] );
 				}
 
-				$rows = Misc::ArrayGroupBy( $rows, array(Misc::trimSortPrefix($filter_data['primary_group_by']),Misc::trimSortPrefix($filter_data['secondary_group_by'])), Misc::trimSortPrefix($ignore_elements) );
+				$rows = Misc::ArrayGroupBy( $rows, array(Misc::trimSortPrefix($filter_data['primary_group_by']), Misc::trimSortPrefix($filter_data['secondary_group_by']), Misc::trimSortPrefix($filter_data['tertiary_group_by']), Misc::trimSortPrefix($filter_data['quaternary_group_by'])), Misc::trimSortPrefix($ignore_elements) );
 			}
 
 			if ( isset($rows) ) {
@@ -532,6 +554,8 @@ switch ($action) {
 							if ( $column_data == '' ) {
 								$column_data = NULL;
 							}
+						} elseif ( $column == 'date_stamp' ) {
+							$column_data = TTDate::getDate( 'DATE', $column_data );
 						}
 
 						$row_columns[$column] = $column_data;
