@@ -1,29 +1,42 @@
 <?php
 /*********************************************************************************
- * The contents of this file are subject to the TimeTrex Public License Version
- * 1.1.0 ("License"); You may not use this file except in compliance with the
- * License. You may obtain a copy of the License at http://www.TimeTrex.com/TPL
- * Software distributed under the License is distributed on an "AS IS" basis,
- * WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the License
- * for the specific language governing rights and limitations under the
- * License.
+ * TimeTrex is a Payroll and Time Management program developed by
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
  *
- * All copies of the Covered Code must include on each user interface screen:
- *    (i) the "Powered by TimeTrex" logo and
- *    (ii) the TimeTrex copyright notice
- * in the same form as they appear in the distribution.  See full license for
- * requirements.
+ * This program is free software; you can redistribute it and/or modify it under
+ * the terms of the GNU Affero General Public License version 3 as published by
+ * the Free Software Foundation with the addition of the following permission
+ * added to Section 15 as permitted in Section 7(a): FOR ANY PART OF THE COVERED
+ * WORK IN WHICH THE COPYRIGHT IS OWNED BY TIMETREX, TIMETREX DISCLAIMS THE
+ * WARRANTY OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
  *
- * The Original Code is: TimeTrex Open Source
- * The Initial Developer of the Original Code is TimeTrex Payroll Services
- * Portions created by TimeTrex are Copyright (C) 2004-2007 TimeTrex Payroll Services;
- * All Rights Reserved.
+ * This program is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+ * FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
+ * details.
  *
+ * You should have received a copy of the GNU Affero General Public License along
+ * with this program; if not, see http://www.gnu.org/licenses or write to the Free
+ * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+ * 02110-1301 USA.
+ *
+ * You can contact TimeTrex headquarters at Unit 22 - 2475 Dobbin Rd. Suite
+ * #292 Westbank, BC V4T 2E9, Canada or at email address info@timetrex.com.
+ *
+ * The interactive user interfaces in modified source and object code versions
+ * of this program must display Appropriate Legal Notices, as required under
+ * Section 5 of the GNU Affero General Public License version 3.
+ *
+ * In accordance with Section 7(b) of the GNU Affero General Public License
+ * version 3, these Appropriate Legal Notices must retain the display of the
+ * "Powered by TimeTrex" logo. If the display of the logo is not reasonably
+ * feasible for technical reasons, the Appropriate Legal Notices must display
+ * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2426 $
- * $Id: T4Summary.php 2426 2009-02-18 22:39:19Z ipso $
- * $Date: 2009-02-18 14:39:19 -0800 (Wed, 18 Feb 2009) $
+ * $Revision: 2906 $
+ * $Id: T4Summary.php 2906 2009-10-16 21:41:04Z ipso $
+ * $Date: 2009-10-16 14:41:04 -0700 (Fri, 16 Oct 2009) $
  */
 require_once('../../includes/global.inc.php');
 require_once(Environment::getBasePath() .'includes/Interface.inc.php');
@@ -137,8 +150,8 @@ switch ($action) {
 			$ugdf->setID( $ugdlf->getCurrent()->getID() );
 		}
 		$ugdf->setCompany( $current_company->getId() );
-		$ugdf->setName( $title );
 		$ugdf->setScript( $_SERVER['SCRIPT_NAME'] );
+		$ugdf->setName( $title );
 		$ugdf->setData( $setup_data );
 		$ugdf->setDefault( TRUE );
 		if ( $ugdf->isValid() ) {
@@ -330,18 +343,22 @@ switch ($action) {
 
 				//Get User Tax / Deductions by Pay Stub Account.
 				$udlf = new UserDeductionListFactory();
-				$udlf->getByUserIdAndPayStubEntryAccountID( $user_obj->getId(), $setup_data['employee_cpp_psea_id'] );
-				if ( $setup_data['employee_cpp_psea_id'] != 0
-						AND $udlf->getRecordCount() == 0 ) {
-					Debug::Text('CPP Exempt!', __FILE__, __LINE__, __METHOD__,10);
-					$t4ee->setExemptCPP( TRUE );
+				if ( isset($setup_data['employee_cpp_psea_id']) ) {
+					$udlf->getByUserIdAndPayStubEntryAccountID( $user_obj->getId(), $setup_data['employee_cpp_psea_id'] );
+					if ( $setup_data['employee_cpp_psea_id'] != 0
+							AND $udlf->getRecordCount() == 0 ) {
+						Debug::Text('CPP Exempt!', __FILE__, __LINE__, __METHOD__,10);
+						$t4ee->setExemptCPP( TRUE );
+					}
 				}
 
-				$udlf->getByUserIdAndPayStubEntryAccountID( $user_obj->getId(), $setup_data['employee_ei_psea_id'] );
-				if ( $setup_data['employee_ei_psea_id'] != 0
-						AND $udlf->getRecordCount() == 0 ) {
-					Debug::Text('EI Exempt!', __FILE__, __LINE__, __METHOD__,10);
-					$t4ee->setExemptEI( TRUE );
+				if ( isset($setup_data['employee_ei_psea_id'] ) ) {
+					$udlf->getByUserIdAndPayStubEntryAccountID( $user_obj->getId(), $setup_data['employee_ei_psea_id'] );
+					if ( $setup_data['employee_ei_psea_id'] != 0
+							AND $udlf->getRecordCount() == 0 ) {
+						Debug::Text('EI Exempt!', __FILE__, __LINE__, __METHOD__,10);
+						$t4ee->setExemptEI( TRUE );
+					}
 				}
 
 				$t4ee->setEmploymentIncome( $row['income'] );
