@@ -1,29 +1,42 @@
 <?php
 /*********************************************************************************
- * The contents of this file are subject to the TimeTrex Public License Version
- * 1.1.0 ("License"); You may not use this file except in compliance with the
- * License. You may obtain a copy of the License at http://www.TimeTrex.com/TPL
- * Software distributed under the License is distributed on an "AS IS" basis,
- * WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the License
- * for the specific language governing rights and limitations under the
- * License.
+ * TimeTrex is a Payroll and Time Management program developed by
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
  *
- * All copies of the Covered Code must include on each user interface screen:
- *    (i) the "Powered by TimeTrex" logo and
- *    (ii) the TimeTrex copyright notice
- * in the same form as they appear in the distribution.  See full license for
- * requirements.
+ * This program is free software; you can redistribute it and/or modify it under
+ * the terms of the GNU Affero General Public License version 3 as published by
+ * the Free Software Foundation with the addition of the following permission
+ * added to Section 15 as permitted in Section 7(a): FOR ANY PART OF THE COVERED
+ * WORK IN WHICH THE COPYRIGHT IS OWNED BY TIMETREX, TIMETREX DISCLAIMS THE
+ * WARRANTY OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
  *
- * The Original Code is: TimeTrex Open Source
- * The Initial Developer of the Original Code is TimeTrex Payroll Services
- * Portions created by TimeTrex are Copyright (C) 2004-2007 TimeTrex Payroll Services;
- * All Rights Reserved.
+ * This program is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+ * FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
+ * details.
  *
+ * You should have received a copy of the GNU Affero General Public License along
+ * with this program; if not, see http://www.gnu.org/licenses or write to the Free
+ * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+ * 02110-1301 USA.
+ *
+ * You can contact TimeTrex headquarters at Unit 22 - 2475 Dobbin Rd. Suite
+ * #292 Westbank, BC V4T 2E9, Canada or at email address info@timetrex.com.
+ *
+ * The interactive user interfaces in modified source and object code versions
+ * of this program must display Appropriate Legal Notices, as required under
+ * Section 5 of the GNU Affero General Public License version 3.
+ *
+ * In accordance with Section 7(b) of the GNU Affero General Public License
+ * version 3, these Appropriate Legal Notices must retain the display of the
+ * "Powered by TimeTrex" logo. If the display of the logo is not reasonably
+ * feasible for technical reasons, the Appropriate Legal Notices must display
+ * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2570 $
- * $Id: TimesheetDetail.php 2570 2009-05-28 21:29:33Z ipso $
- * $Date: 2009-05-28 14:29:33 -0700 (Thu, 28 May 2009) $
+ * $Revision: 2906 $
+ * $Id: TimesheetDetail.php 2906 2009-10-16 21:41:04Z ipso $
+ * $Date: 2009-10-16 14:41:04 -0700 (Fri, 16 Oct 2009) $
  */
 require_once('../../includes/global.inc.php');
 require_once(Environment::getBasePath() .'includes/Interface.inc.php');
@@ -460,7 +473,10 @@ switch ($action) {
 				$pptsvlf->getByPayPeriodIdAndCompanyId( $filter_data['pay_period_ids'][0], $current_company->getId() );
 				if ( $pptsvlf->getRecordCount() > 0 ) {
 					foreach( $pptsvlf as $pptsv_obj ) {
-						$verified_time_sheets[$pptsv_obj->getUser()][$pptsv_obj->getPayPeriod()] = $pptsv_obj->getStatus();
+						$verified_time_sheets[$pptsv_obj->getUser()][$pptsv_obj->getPayPeriod()] = array(
+																										 'status_id' => $pptsv_obj->getStatus(),
+																										 'created_date' => $pptsv_obj->getCreatedDate(),
+																										);
 					}
 				}
 			}
@@ -490,10 +506,12 @@ switch ($action) {
 						$rows[$i]['default_branch'] =  Option::getByKey($user_obj->getDefaultBranch(), $branch_options, NULL );
 						$rows[$i]['default_department'] = Option::getByKey($user_obj->getDefaultDepartment(), $department_options, NULL );
 
+						$rows[$i]['verified_time_sheet_date'] = FALSE;
 						if ( $verified_time_sheets !== NULL AND isset($verified_time_sheets[$user_id][$pay_period_id]) ) {
-							if ( $verified_time_sheets[$user_id][$pay_period_id] == 50 ) {
+							if ( $verified_time_sheets[$user_id][$pay_period_id]['status_id'] == 50 ) {
 								$rows[$i]['verified_time_sheet'] = TTi18n::gettext('Yes');
-							} elseif ( $verified_time_sheets[$user_id][$pay_period_id] == 30 ) {
+								$rows[$i]['verified_time_sheet_date'] = $verified_time_sheets[$user_id][$pay_period_id]['created_date'];
+							} elseif ( $verified_time_sheets[$user_id][$pay_period_id]['status_id'] == 30 ) {
 								$rows[$i]['verified_time_sheet'] = TTi18n::gettext('Pending');
 							} else {
 								$rows[$i]['verified_time_sheet'] = TTi18n::gettext('Declined');
@@ -695,16 +713,16 @@ switch ($action) {
 
 								$pdf->SetFont('','B',10);
 								$pdf->setFillColor(220,220,220);
-								$pdf->MultiCell( $column_widths['line'], $line_h, '#' , 1, 'C', 1, 0, $cell_h_min, $cell_h_max);
-								$pdf->MultiCell( $column_widths['date_stamp'], $line_h, TTi18n::gettext('Date') , 1, 'C', 1, 0, $cell_h_min, $cell_h_max);
-								$pdf->MultiCell( $column_widths['dow'], $line_h, TTi18n::gettext('DoW') , 1, 'C', 1, 0, $cell_h_min, $cell_h_max);
-								$pdf->MultiCell( $column_widths['min_punch_time_stamp'], $line_h, TTi18n::gettext('First In') , 1, 'C', 1, 0, $cell_h_min, $cell_h_max);
-								$pdf->MultiCell( $column_widths['max_punch_time_stamp'], $line_h, TTi18n::gettext('Last Out') , 1, 'C', 1, 0, $cell_h_min, $cell_h_max);
-								$pdf->MultiCell( $column_widths['worked_time'], $line_h, TTi18n::gettext('Worked Time') , 1, 'C', 1, 0, $cell_h_min, $cell_h_max);
-								$pdf->MultiCell( $column_widths['regular_time'], $line_h, TTi18n::gettext('Regular Time') , 1, 'C', 1, 0, $cell_h_min, $cell_h_max);
-								$pdf->MultiCell( $column_widths['over_time'], $line_h, TTi18n::gettext('Over Time') , 1, 'C', 1, 0, $cell_h_min, $cell_h_max);
-								$pdf->MultiCell( $column_widths['paid_time'], $line_h, TTi18n::gettext('Paid Time') , 1, 'C', 1, 0, $cell_h_min, $cell_h_max);
-								$pdf->MultiCell( $column_widths['absence_time'], $line_h, TTi18n::gettext('Absence Time') , 1, 'C', 1, 0, $cell_h_min, $cell_h_max);
+								$pdf->MultiCell( $column_widths['line'], $line_h, '#' , 1, 'C', 1, 0);
+								$pdf->MultiCell( $column_widths['date_stamp'], $line_h, TTi18n::gettext('Date') , 1, 'C', 1, 0);
+								$pdf->MultiCell( $column_widths['dow'], $line_h, TTi18n::gettext('DoW') , 1, 'C', 1, 0);
+								$pdf->MultiCell( $column_widths['min_punch_time_stamp'], $line_h, TTi18n::gettext('First In') , 1, 'C', 1, 0);
+								$pdf->MultiCell( $column_widths['max_punch_time_stamp'], $line_h, TTi18n::gettext('Last Out') , 1, 'C', 1, 0);
+								$pdf->MultiCell( $column_widths['worked_time'], $line_h, TTi18n::gettext('Worked Time') , 1, 'C', 1, 0);
+								$pdf->MultiCell( $column_widths['regular_time'], $line_h, TTi18n::gettext('Regular Time') , 1, 'C', 1, 0);
+								$pdf->MultiCell( $column_widths['over_time'], $line_h, TTi18n::gettext('Over Time') , 1, 'C', 1, 0);
+								$pdf->MultiCell( $column_widths['paid_time'], $line_h, TTi18n::gettext('Paid Time') , 1, 'C', 1, 0);
+								$pdf->MultiCell( $column_widths['absence_time'], $line_h, TTi18n::gettext('Absence Time') , 1, 'C', 1, 0);
 								$pdf->Ln();
 							}
 
@@ -816,6 +834,13 @@ switch ($action) {
 					$pdf->Cell(140,5, '', $border, 0, 'R');
 					$pdf->Cell(60,5, TTi18n::gettext('(print name)'), $border, 0, 'C');
 
+					if ( $user_data['verified_time_sheet_date'] != FALSE ) {
+						$pdf->Ln();
+						$pdf->SetFont('','B',10);
+						$pdf->Cell(200,5, TTi18n::gettext('TimeSheet electronically signed by').' '. $user_data['first_name'] .' '. $user_data['last_name'] .' '. TTi18n::gettext('on') .' '. TTDate::getDate('DATE+TIME', $user_data['verified_time_sheet_date'] ), $border, 0, 'C');
+						$pdf->SetFont('','',10);
+					}
+
 
 					//Add generated date/time at the bottom.
 					$pdf->SetFont('','I',8);
@@ -955,16 +980,16 @@ switch ($action) {
 
 								$pdf->SetFont('','B',10);
 								$pdf->setFillColor(220,220,220);
-								$pdf->MultiCell( $column_widths['line'], $line_h, '#' , 1, 'C', 1, 0, $cell_h_min, $cell_h_max);
-								$pdf->MultiCell( $column_widths['date_stamp'], $line_h, TTi18n::gettext('Date') , 1, 'C', 1, 0, $cell_h_min, $cell_h_max);
-								$pdf->MultiCell( $column_widths['dow'], $line_h, TTi18n::gettext('DoW') , 1, 'C', 1, 0, $cell_h_min, $cell_h_max);
-								$pdf->MultiCell( $column_widths['in_punch_time_stamp'], $line_h, TTi18n::gettext('In') , 1, 'C', 1, 0, $cell_h_min, $cell_h_max);
-								$pdf->MultiCell( $column_widths['out_punch_time_stamp'], $line_h, TTi18n::gettext('Out') , 1, 'C', 1, 0, $cell_h_min, $cell_h_max);
-								$pdf->MultiCell( $column_widths['worked_time'], $line_h, TTi18n::gettext('Worked Time') , 1, 'C', 1, 0, $cell_h_min, $cell_h_max);
-								$pdf->MultiCell( $column_widths['paid_time'], $line_h, TTi18n::gettext('Paid Time') , 1, 'C', 1, 0, $cell_h_min, $cell_h_max);
-								$pdf->MultiCell( $column_widths['regular_time'], $line_h, TTi18n::gettext('Regular Time') , 1, 'C', 1, 0, $cell_h_min, $cell_h_max);
-								$pdf->MultiCell( $column_widths['over_time'], $line_h, TTi18n::gettext('Over Time') , 1, 'C', 1, 0, $cell_h_min, $cell_h_max);
-								$pdf->MultiCell( $column_widths['absence_time'], $line_h, TTi18n::gettext('Absence Time') , 1, 'C', 1, 0, $cell_h_min, $cell_h_max);
+								$pdf->MultiCell( $column_widths['line'], $line_h, '#' , 1, 'C', 1, 0);
+								$pdf->MultiCell( $column_widths['date_stamp'], $line_h, TTi18n::gettext('Date') , 1, 'C', 1, 0);
+								$pdf->MultiCell( $column_widths['dow'], $line_h, TTi18n::gettext('DoW') , 1, 'C', 1, 0);
+								$pdf->MultiCell( $column_widths['in_punch_time_stamp'], $line_h, TTi18n::gettext('In') , 1, 'C', 1, 0);
+								$pdf->MultiCell( $column_widths['out_punch_time_stamp'], $line_h, TTi18n::gettext('Out') , 1, 'C', 1, 0);
+								$pdf->MultiCell( $column_widths['worked_time'], $line_h, TTi18n::gettext('Worked Time') , 1, 'C', 1, 0);
+								$pdf->MultiCell( $column_widths['paid_time'], $line_h, TTi18n::gettext('Paid Time') , 1, 'C', 1, 0);
+								$pdf->MultiCell( $column_widths['regular_time'], $line_h, TTi18n::gettext('Regular Time') , 1, 'C', 1, 0);
+								$pdf->MultiCell( $column_widths['over_time'], $line_h, TTi18n::gettext('Over Time') , 1, 'C', 1, 0);
+								$pdf->MultiCell( $column_widths['absence_time'], $line_h, TTi18n::gettext('Absence Time') , 1, 'C', 1, 0);
 								$pdf->Ln();
 							}
 
@@ -1006,7 +1031,7 @@ switch ($action) {
 								$max_rows = $total_rows_arr[0];
 								$line_h = $default_line_h*$max_rows;
 
-								$pdf->SetFont('','',10);
+								$pdf->SetFont('','',9);
 								$pdf->Cell( $column_widths['line'], $line_h, $x , 1, 0, 'C', 1);
 								$pdf->Cell( $column_widths['date_stamp'], $line_h, TTDate::getDate('DATE', $data['date_stamp'] ), 1, 0, 'C', 1);
 								$pdf->Cell( $column_widths['dow'], $line_h, date('D', $data['date_stamp']) , 1, 0, 'C', 1);
@@ -1044,7 +1069,7 @@ switch ($action) {
 
 									$pdf->setXY( $punch_x, $pre_punch_y);
 
-									$pdf->SetFont('','',10);
+									$pdf->SetFont('','',9);
 								} else {
 									$pdf->Cell( $column_widths['in_punch_time_stamp'], $line_h, '', 1, 0, 'C', 1);
 									$pdf->Cell( $column_widths['out_punch_time_stamp'], $line_h, '', 1, 0, 'C', 1);
@@ -1068,7 +1093,7 @@ switch ($action) {
 									}
 									$pdf->setXY( $over_time_x+$column_widths['over_time'], $pre_punch_y);
 
-									$pdf->SetFont('','',10);
+									$pdf->SetFont('','',9);
 								} else {
 									$pdf->Cell( $column_widths['over_time'], $line_h, TTDate::getTimeUnit( $data['over_time'] ), 1, 0, 'C', 1);
 								}
@@ -1086,7 +1111,7 @@ switch ($action) {
 
 									$pdf->setY( $pdf->getY()-($line_h/$total_absence_rows));
 
-									$pdf->SetFont('','',10);
+									$pdf->SetFont('','',9);
 								} else {
 									$pdf->Cell( $column_widths['absence_time'], $line_h, TTDate::getTimeUnit( $data['absence_time'] ), 1, 0, 'C', 1);
 								}
@@ -1111,7 +1136,7 @@ switch ($action) {
 							if ( $x % 7 == 0 OR $i == $max_i ) {
 								//Show Week Total.
 								$total_cell_width = $column_widths['line']+$column_widths['date_stamp']+$column_widths['dow']+$column_widths['in_punch_time_stamp']+$column_widths['out_punch_time_stamp'];
-								$pdf->SetFont('','B',10);
+								$pdf->SetFont('','B',9);
 								$pdf->Cell( $total_cell_width, 6, TTi18n::gettext('Week Total:').' ', 0, 0, 'R', 0);
 								$pdf->Cell( $column_widths['worked_time'], 6, TTDate::getTimeUnit( $week_totals['worked_time'] ) , 0, 0, 'C', 0);
 								$pdf->Cell( $column_widths['paid_time'], 6,  TTDate::getTimeUnit( $week_totals['paid_time'] ), 0, 0, 'C', 0);
@@ -1143,7 +1168,7 @@ switch ($action) {
 						//Display overall totals.
 						$pdf->Ln(4);
 						$total_cell_width = $column_widths['line']+$column_widths['date_stamp']+$column_widths['dow']+$column_widths['in_punch_time_stamp'];
-						$pdf->SetFont('','B',10);
+						$pdf->SetFont('','B',9);
 						$pdf->Cell( $total_cell_width, 6, '' , 0, 0, 'R', 0);
 						$pdf->Cell( $column_widths['out_punch_time_stamp'], 6, TTi18n::gettext('Overall Total:').' ', 'T', 0, 'R', 0);
 						$pdf->Cell( $column_widths['worked_time'], 6, TTDate::getTimeUnit( $totals['worked_time'] ) , 'T', 0, 'C', 0);
@@ -1181,6 +1206,13 @@ switch ($action) {
 					$pdf->Cell(140,5, '', $border, 0, 'R');
 					$pdf->Cell(60,5, TTi18n::gettext('(print name)'), $border, 0, 'C');
 
+					if ( $user_data['verified_time_sheet_date'] != FALSE ) {
+						$pdf->Ln();
+						$pdf->SetFont('','B',10);
+						$pdf->Cell(200,5, TTi18n::gettext('TimeSheet electronically signed by').' '. $user_data['first_name'] .' '. $user_data['last_name'] .' '. TTi18n::gettext('on') .' '. TTDate::getDate('DATE+TIME', $user_data['verified_time_sheet_date'] ), $border, 0, 'C');
+						$pdf->SetFont('','',10);
+					}
+
 
 					//Add generated date/time at the bottom.
 					$pdf->SetFont('','I',8);
