@@ -1,29 +1,42 @@
 <?php
 /*********************************************************************************
- * The contents of this file are subject to the TimeTrex Public License Version
- * 1.1.0 ("License"); You may not use this file except in compliance with the
- * License. You may obtain a copy of the License at http://www.TimeTrex.com/TPL
- * Software distributed under the License is distributed on an "AS IS" basis,
- * WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the License
- * for the specific language governing rights and limitations under the
- * License.
+ * TimeTrex is a Payroll and Time Management program developed by
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
  *
- * All copies of the Covered Code must include on each user interface screen:
- *    (i) the "Powered by TimeTrex" logo and
- *    (ii) the TimeTrex copyright notice
- * in the same form as they appear in the distribution.  See full license for
- * requirements.
+ * This program is free software; you can redistribute it and/or modify it under
+ * the terms of the GNU Affero General Public License version 3 as published by
+ * the Free Software Foundation with the addition of the following permission
+ * added to Section 15 as permitted in Section 7(a): FOR ANY PART OF THE COVERED
+ * WORK IN WHICH THE COPYRIGHT IS OWNED BY TIMETREX, TIMETREX DISCLAIMS THE
+ * WARRANTY OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
  *
- * The Original Code is: TimeTrex Open Source
- * The Initial Developer of the Original Code is TimeTrex Payroll Services
- * Portions created by TimeTrex are Copyright (C) 2004-2007 TimeTrex Payroll Services;
- * All Rights Reserved.
+ * This program is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+ * FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
+ * details.
  *
+ * You should have received a copy of the GNU Affero General Public License along
+ * with this program; if not, see http://www.gnu.org/licenses or write to the Free
+ * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+ * 02110-1301 USA.
+ *
+ * You can contact TimeTrex headquarters at Unit 22 - 2475 Dobbin Rd. Suite
+ * #292 Westbank, BC V4T 2E9, Canada or at email address info@timetrex.com.
+ *
+ * The interactive user interfaces in modified source and object code versions
+ * of this program must display Appropriate Legal Notices, as required under
+ * Section 5 of the GNU Affero General Public License version 3.
+ *
+ * In accordance with Section 7(b) of the GNU Affero General Public License
+ * version 3, these Appropriate Legal Notices must retain the display of the
+ * "Powered by TimeTrex" logo. If the display of the logo is not reasonably
+ * feasible for technical reasons, the Appropriate Legal Notices must display
+ * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2371 $
- * $Id: EditStation.php 2371 2009-01-21 22:54:00Z ipso $
- * $Date: 2009-01-21 14:54:00 -0800 (Wed, 21 Jan 2009) $
+ * $Revision: 2904 $
+ * $Id: EditStation.php 2904 2009-10-16 18:04:09Z ipso $
+ * $Date: 2009-10-16 11:04:09 -0700 (Fri, 16 Oct 2009) $
  */
 require_once('../../includes/global.inc.php');
 require_once(Environment::getBasePath() .'includes/Interface.inc.php');
@@ -93,9 +106,6 @@ switch ($action) {
 			if ( isset($data['mode_flag']) ) {
 				$sf->setModeFlag($data['mode_flag']);
 			}
-			if ( isset($data['work_code_definition']) ) {
-				$sf->setWorkCodeDefinition($data['work_code_definition']);
-			}
 		}
 
 		if ( isset($data['branch_id']) ) {
@@ -104,6 +114,13 @@ switch ($action) {
 		if ( isset($data['department_id']) ) {
 			$sf->setDefaultDepartment($data['department_id']);
 		}
+		if ( isset($data['job_id']) ) {
+			$sf->setDefaultJob($data['job_id']);
+		}
+		if ( isset($data['job_item_id']) ) {
+			$sf->setDefaultJobItem($data['job_item_id']);
+		}
+
 		if ( isset($data['time_zone_id']) ) {
 			$sf->setTimeZone($data['time_zone_id']);
 		}
@@ -226,7 +243,7 @@ switch ($action) {
 					}
 					break;
 				case 'delete_data':
-					if ( isset($s_obj) AND $tc->DeleteAllData( $s_obj) == TRUE ) {
+					if ( isset($s_obj) AND $tc->DeleteAllData( $s_obj ) == TRUE ) {
 						$result_str = TTi18n::gettext('Delete Data Succeeded!');
 						if ( $s_obj->isValid() ) {
 							$s_obj->Save(FALSE);
@@ -299,7 +316,6 @@ switch ($action) {
 
 									'enable_auto_punch_status' => $s_obj->getEnableAutoPunchStatus(),
 									'mode_flag' => $s_obj->getModeFlag(),
-									'work_code_definition' => $s_obj->getWorkCodeDefinition(),
 
 									'last_punch_time_stamp' => $s_obj->getLastPunchTimeStamp(),
 									'last_poll_date' => $s_obj->getLastPollDate(),
@@ -308,6 +324,8 @@ switch ($action) {
 
 									'branch_id' => $s_obj->getDefaultBranch(),
 									'department_id' => $s_obj->getDefaultDepartment(),
+									'job_id' => $s_obj->getDefaultJob(),
+									'job_item_id' => $s_obj->getDefaultJobItem(),
 									'time_zone_id' => $s_obj->getTimeZone(),
 
 									'group_selection_type_id' => $s_obj->getGroupSelectionType(),
@@ -331,19 +349,13 @@ switch ($action) {
 								);
 			}
 		} elseif ( $action != 'submit' AND $action != 'time_clock_command' ) {
-			if ( $current_company->getProductEdition() == 20 ) {
-				$work_code_definition = array('branch' => 1, 'department' => 1, 'job' => 5, 'task' => 2) ;
-			} else {
-				$work_code_definition = array('branch' => 4, 'department' => 5 );
-			}
 
 			$data = array(	'status' => 20,
 							'port' => 80,
 							'password' => 0,
 							'poll_frequency' => 600,
 							'push_frequency' => 86400,
-							'partial_push_frequency' => 3600,
-							'work_code_definition' => $work_code_definition); //Default to enable.
+							'partial_push_frequency' => 3600 );
 		}
 
 		$data = Misc::preSetArrayValues( $data, array('branch_ids', 'department_ids', 'group_ids', 'include_user_ids', 'exclude_user_ids'), NULL);
@@ -356,6 +368,16 @@ switch ($action) {
 		$data['time_clock_command_options'] = $sf->getOptions('time_clock_command');
 		$data['mode_flag_options'] = $sf->getOptions('mode_flag');
 
+		if ( $current_company->getProductEdition() == 20 ) {
+			$jlf = new JobListFactory();
+			$jlf->getByCompanyId( $current_company->getId() );
+			$data['job_options'] = Misc::prependArray( array(0 => '-- None --'), $jlf->getArrayByListFactory( $jlf, FALSE, TRUE ) );
+
+			$jilf = new JobItemListFactory();
+			$jilf->getByCompanyIdAndStatus( $current_company->getId(), 10 );
+			$data['job_item_options'] = Misc::prependArray( array(0 => '-- None --'), $jilf->getArrayByListFactory( $jilf, TRUE, FALSE ) );
+		}
+
 		//Get branches
 		$blf = new BranchListFactory();
 		$blf->getByCompanyId( $current_company->getId() );
