@@ -1,29 +1,42 @@
 <?php
 /*********************************************************************************
- * The contents of this file are subject to the TimeTrex Public License Version
- * 1.1.0 ("License"); You may not use this file except in compliance with the
- * License. You may obtain a copy of the License at http://www.TimeTrex.com/TPL
- * Software distributed under the License is distributed on an "AS IS" basis,
- * WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the License
- * for the specific language governing rights and limitations under the
- * License.
+ * TimeTrex is a Payroll and Time Management program developed by
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
  *
- * All copies of the Covered Code must include on each user interface screen:
- *    (i) the "Powered by TimeTrex" logo and
- *    (ii) the TimeTrex copyright notice
- * in the same form as they appear in the distribution.  See full license for
- * requirements.
+ * This program is free software; you can redistribute it and/or modify it under
+ * the terms of the GNU Affero General Public License version 3 as published by
+ * the Free Software Foundation with the addition of the following permission
+ * added to Section 15 as permitted in Section 7(a): FOR ANY PART OF THE COVERED
+ * WORK IN WHICH THE COPYRIGHT IS OWNED BY TIMETREX, TIMETREX DISCLAIMS THE
+ * WARRANTY OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
  *
- * The Original Code is: TimeTrex Open Source
- * The Initial Developer of the Original Code is TimeTrex Payroll Services
- * Portions created by TimeTrex are Copyright (C) 2004-2007 TimeTrex Payroll Services;
- * All Rights Reserved.
+ * This program is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+ * FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
+ * details.
  *
+ * You should have received a copy of the GNU Affero General Public License along
+ * with this program; if not, see http://www.gnu.org/licenses or write to the Free
+ * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+ * 02110-1301 USA.
+ *
+ * You can contact TimeTrex headquarters at Unit 22 - 2475 Dobbin Rd. Suite
+ * #292 Westbank, BC V4T 2E9, Canada or at email address info@timetrex.com.
+ *
+ * The interactive user interfaces in modified source and object code versions
+ * of this program must display Appropriate Legal Notices, as required under
+ * Section 5 of the GNU Affero General Public License version 3.
+ *
+ * In accordance with Section 7(b) of the GNU Affero General Public License
+ * version 3, these Appropriate Legal Notices must retain the display of the
+ * "Powered by TimeTrex" logo. If the display of the logo is not reasonably
+ * feasible for technical reasons, the Appropriate Legal Notices must display
+ * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2396 $
- * $Id: ViewUserTimeSheet.php 2396 2009-01-27 19:04:45Z ipso $
- * $Date: 2009-01-27 11:04:45 -0800 (Tue, 27 Jan 2009) $
+ * $Revision: 3199 $
+ * $Id: ViewUserTimeSheet.php 3199 2009-12-20 23:37:45Z ipso $
+ * $Date: 2009-12-20 15:37:45 -0800 (Sun, 20 Dec 2009) $
  */
 require_once('../../includes/global.inc.php');
 require_once(Environment::getBasePath() .'includes/Interface.inc.php');
@@ -105,7 +118,7 @@ $smarty->assign('title', TTi18n::gettext($title = 'My Timesheet')); // See index
 extract	(FormVariables::GetVariables(
 										array	(
 												'action',
-												'override_action',
+												'action_option',
 												'filter_data',
 												'prev_week',
 												'next_week',
@@ -249,13 +262,14 @@ if ( $filter_data['date'] == '' OR $filter_data['date'] <= 0 ) {
 //Save current filter settings, so when we come back to the timesheet they are loaded.
 $ugdf = new UserGenericDataFactory();
 if ( isset($generic_data) AND $generic_data['id'] != '' AND $generic_data['id'] != 0 ) {
+	Debug::text('Passed ID: ', __FILE__, __LINE__, __METHOD__,10);
 	$ugdf->setID( $generic_data['id'] );
 }
 
-$ugdf->setName( 'Default' );
 $ugdf->setCompany( $current_company->getId() );
 $ugdf->setUser( $current_user->getId() );
 $ugdf->setScript( $_SERVER['SCRIPT_NAME'] );
+$ugdf->setName( 'Default' ); //This has to go after company,user and script are already set.
 $ugdf->setData( $filter_data );
 $ugdf->setDefault( TRUE );
 
@@ -302,12 +316,12 @@ URLBuilder::setURL($_SERVER['SCRIPT_NAME'],
 													'filter_data' => $filter_data,
 												) );
 
-if ( isset($override_action) AND $override_action != '') {
-	$action = $override_action;
+$action = Misc::findSubmitButton();
+Debug::Text('Action: '. $action .' Action Option: '. $action_option, __FILE__, __LINE__, __METHOD__,10);
+//If submit is pressed, use $action_option from the dropdown box as the action instead.
+if ( $action == 'submit' AND $action_option != '' ) {
+	$action = $action_option;
 }
-
-$action = strtolower(trim($action));
-Debug::Text('Action: '. $action , __FILE__, __LINE__, __METHOD__,10);
 switch ($action) {
 	case 'authorize':
 	case 'decline':
@@ -328,16 +342,10 @@ switch ($action) {
 		$pptsvf->setUser( $user_id );
 		$pptsvf->setPayPeriod( $pay_period_id );
 
-		//Check if we are final authorization level or not.
-		$af = new AuthorizationFactory();
-		$af->setObjectType('timesheet');
-		if ( $af->isFinalAuthorization() === TRUE ) {
-			$pptsvf->setStatus(50); //Authorized
-			$pptsvf->setAuthorized( TRUE );
-		} else {
-			$pptsvf->setStatus(30); //Pending Auth
-			$pptsvf->setAuthorized( FALSE );
-		}
+		//With the new hierarchy system there will never be a case where the timesheet verification can be immiedately authorized
+		//as we can only determine hierarchies based on subordinates now.
+		$pptsvf->setStatus(30); //Pending Auth
+		$pptsvf->setAuthorized( FALSE );
 
 		if ( $pptsvf->isValid() ) {
 			$pptsvf->Save();
@@ -346,7 +354,7 @@ switch ($action) {
 		Redirect::Page( URLBuilder::getURL( NULL, '../timesheet/ViewUserTimeSheet.php') );
 
 		break;
-	case 'recalculate pay stub':
+	case 'recalculate_pay_stub':
 		//Debug::setVerbosity(11);
 
 		//Find out if a pay stub is already generated for the pay period we are currently in.
@@ -390,7 +398,7 @@ switch ($action) {
 		Redirect::Page( URLBuilder::getURL( array('filter_pay_period_id' => $pay_period_id, 'filter_user_id' => $filter_data['user_id'] ), '../pay_stub/PayStubList.php') );
 
 		break;
-	case 'calculate adjustment':
+	case 'calculate_adjustment':
 		//Debug::setVerbosity(11);
 
 		TTLog::addEntry( $filter_data['user_id'], 'Notice', TTi18n::gettext('Calculating Employee Pay Stub Adjustment for Pay Period:').' '. $pay_period_id, $current_user->getID(), 'pay_stub' );
@@ -408,14 +416,14 @@ switch ($action) {
 		Redirect::Page( URLBuilder::getURL( array('user_id' => $filter_data['user_id'] ), '../pay_stub_amendment/PayStubAmendmentList.php') );
 
 		break;
-	case 'recalculate company':
+	case 'recalculate_company':
 		Debug::Text('Recalculating company timesheet!', __FILE__, __LINE__, __METHOD__,10);
 
 		//Redirect::Page( URLBuilder::getURL( array('action' => 'recalculate_company', 'pay_period_ids' => $pay_period_id, 'next_page' => urlencode( URLBuilder::getURL( array('filter_date' => $filter_date ), '../timesheet/ViewUserTimeSheet.php') ) ), '../progress_bar/ProgressBarControl.php') );
 		Redirect::Page( URLBuilder::getURL( array('action' => 'recalculate_company', 'pay_period_ids' => $pay_period_id, 'next_page' => urlencode( URLBuilder::getURL( NULL, '../timesheet/ViewUserTimeSheet.php') ) ), '../progress_bar/ProgressBarControl.php'), FALSE );
 
 		break;
-	case 'recalculate employee':
+	case 'recalculate_employee':
 		Debug::Text('Recalculating employee timesheet!', __FILE__, __LINE__, __METHOD__,10);
 
 		Redirect::Page( URLBuilder::getURL( array('action' => 'recalculate_employee', 'pay_period_ids' => $pay_period_id, 'filter_user_id' => $filter_data['user_id'], 'next_page' => urlencode( URLBuilder::getURL( NULL, '../timesheet/ViewUserTimeSheet.php') ) ), '../progress_bar/ProgressBarControl.php'), FALSE );
@@ -663,7 +671,7 @@ switch ($action) {
 			foreach($udtlf as $udt_obj) {
 				$user_date_stamp = TTDate::strtotime( $udt_obj->getColumn('user_date_stamp') );
 
-				if ( $udt_obj->getMealPolicyID() !== FALSE ) {
+				if ( $udt_obj->getMealPolicyID() !== FALSE AND isset($meal_policy_options[$udt_obj->getmealPolicyID()]) ) {
 					$meal_policy = $meal_policy_options[$udt_obj->getmealPolicyID()];
 				} else {
 					$meal_policy = TTi18n::gettext('No Meal Policy');
@@ -706,8 +714,64 @@ switch ($action) {
 			$date_total_meal_ids = array_unique($date_total_meal_ids);
 			sort($date_total_meal_ids);
 
-			$date_meal_total_rows = TimeSheetFormatArrayByDate( $date_meal_total_group, $date_total_meal_ids, $calendar_array, 'meal_policy');
-			//var_dump($date_meal_total_rows);
+			$date_meal_policy_total_rows = TimeSheetFormatArrayByDate( $date_meal_total_group, $date_total_meal_ids, $calendar_array, 'meal_policy');
+			//var_dump($date_meal_policy_total_rows);
+		}
+
+
+		$bplf = new BreakPolicyListFactory();
+		$break_policy_options = $bplf->getByCompanyIdArray( $current_company->getId() );
+		unset($bplf);
+
+		$udtlf->getByCompanyIDAndUserIdAndStatusAndTypeAndStartDateAndEndDate( $current_company->getId(), $user_id, 10, 110, $start_date, $end_date);
+		if ( $udtlf->getRecordCount() > 0 ) {
+			foreach($udtlf as $udt_obj) {
+				$user_date_stamp = TTDate::strtotime( $udt_obj->getColumn('user_date_stamp') );
+
+				if ( $udt_obj->getBreakPolicyID() !== FALSE AND isset($break_policy_options[$udt_obj->getBreakPolicyID()]) ) {
+					$break_policy = $break_policy_options[$udt_obj->getBreakPolicyID()];
+				} else {
+					$break_policy = TTi18n::gettext('No Break Policy');
+				}
+
+				$date_break_policy_totals[$user_date_stamp][] = array(
+												'date_stamp' => $udt_obj->getColumn('user_date_stamp'),
+												'id' => $udt_obj->getId(),
+												'user_date_id' => $udt_obj->getUserDateId(),
+												'status_id' => $udt_obj->getStatus(),
+												'type_id' => $udt_obj->getType(),
+												'over_time_policy_id' => $udt_obj->getOverTimePolicyID(),
+												'break_policy_id' => $udt_obj->getbreakPolicyID(),
+												'break_policy' => $break_policy,
+												'department_id' => $udt_obj->getDepartment(),
+												'total_time' => $udt_obj->getTotalTime(),
+												'total_time_display' => abs($udt_obj->getTotalTime()),
+												//'name' => $udt_obj->getName(),
+												'override' => $udt_obj->getOverride()
+												);
+
+				$date_break_policy_total_policy_ids[] = (int)$udt_obj->getBreakPolicyID();
+				$date_total_break_policy_ids[] = (int)$udt_obj->getBreakPolicyID();
+			}
+		}
+
+		if ( isset($date_break_policy_totals) ) {
+			foreach( $date_break_policy_totals as $user_date_stamp => $date_rows ) {
+				foreach($date_rows as $date_data) {
+					$prev_total_time = 0;
+					if ( isset($date_break_policy_total_group[$user_date_stamp][$date_data['break_policy_id']]) ) {
+						$prev_total_time = $date_break_policy_total_group[$user_date_stamp][$date_data['break_policy_id']]['total_time'];
+					}
+
+					$date_data['total_time'] = $date_data['total_time'] + $prev_total_time;
+					$date_break_policy_total_group[$user_date_stamp][$date_data['break_policy_id']] = $date_data;
+				}
+			}
+
+			$date_total_break_policy_ids = array_unique($date_total_break_policy_ids);
+			sort($date_total_break_policy_ids);
+
+			$date_break_policy_total_rows = TimeSheetFormatArrayByDate( $date_break_policy_total_group, $date_total_break_policy_ids, $calendar_array, 'break_policy');
 		}
 
 		//Get only system totals.
@@ -1323,7 +1387,8 @@ switch ($action) {
 		$smarty->assign_by_ref('calendar_array', $calendar_array);
 		$smarty->assign_by_ref('rows', $rows);
 		$smarty->assign_by_ref('date_break_total_rows', $date_break_total_rows);
-		$smarty->assign_by_ref('date_meal_total_rows', $date_meal_total_rows);
+		$smarty->assign_by_ref('date_break_policy_total_rows', $date_break_policy_total_rows);
+		$smarty->assign_by_ref('date_meal_policy_total_rows', $date_meal_policy_total_rows);
 		$smarty->assign_by_ref('date_total_rows', $date_total_rows);
 		$smarty->assign_by_ref('date_branch_total_rows', $date_branch_total_rows);
 		$smarty->assign_by_ref('date_department_total_rows', $date_department_total_rows);
@@ -1355,6 +1420,8 @@ switch ($action) {
 			$smarty->assign('pay_period_id', $pay_period_obj->getId() );
 			$smarty->assign('pay_period_start_date', $pay_period_obj->getStartDate() );
 			$smarty->assign('pay_period_end_date', $pay_period_obj->getEndDate() );
+			$smarty->assign('pay_period_verify_window_start_date', $pay_period_obj->getTimeSheetVerifyWindowStartDate() );
+			$smarty->assign('pay_period_verify_window_end_date', $pay_period_obj->getTimeSheetVerifyWindowEndDate() );
 			$smarty->assign('pay_period_transaction_date', $pay_period_obj->getTransactionDate() );
 			$smarty->assign('pay_period_is_locked', $pay_period_obj->getIsLocked() );
 			$smarty->assign('pay_period_status_id', $pay_period_obj->getStatus() );
@@ -1373,18 +1440,18 @@ switch ($action) {
 
 		$action_options = array(
 							'0' => TTi18n::gettext('-- Select Action --'),
-							'recalculate employee' => 	TTi18n::gettext('Recalculate Employee'),
-							'recalculate company' => 	TTi18n::gettext('Recalculate Company') );
+							'recalculate_employee' => 	TTi18n::gettext('Recalculate Employee'),
+							'recalculate_company' => 	TTi18n::gettext('Recalculate Company') );
 
 		if ( $permission->Check('pay_period_schedule','enabled') AND ( $permission->Check('pay_period_schedule','edit') OR $permission->Check('pay_period_schedule','edit_own') ) ) {
-			$action_options['recalculate pay stub'] = TTi18n::gettext('Recalculate Pay Stub');
+			$action_options['recalculate_pay_stub'] = TTi18n::gettext('Recalculate Pay Stub');
 		}
 
 		if ( isset($pay_period_obj) AND is_object($pay_period_obj) AND $pay_period_obj->getStatus() == 30 ) {
 			//Add a spacer so its less likely for someone to accidently hit "Recalc Pay Stub"
 			//instead of calculate adjustment.
 			$action_options['-1'] = '---';
-			$action_options['calculate adjustment']  = 'Calculate PS Adjustment';
+			$action_options['calculate_adjustment']  = TTi18n::gettext('Calculate PS Adjustment');
 		}
 
 		$all_array_option = array('-1' => TTi18n::gettext('-- All --'));
