@@ -1,29 +1,42 @@
 <?php
 /*********************************************************************************
- * The contents of this file are subject to the TimeTrex Public License Version
- * 1.1.0 ("License"); You may not use this file except in compliance with the
- * License. You may obtain a copy of the License at http://www.TimeTrex.com/TPL
- * Software distributed under the License is distributed on an "AS IS" basis,
- * WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the License
- * for the specific language governing rights and limitations under the
- * License.
+ * TimeTrex is a Payroll and Time Management program developed by
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
  *
- * All copies of the Covered Code must include on each user interface screen:
- *    (i) the "Powered by TimeTrex" logo and
- *    (ii) the TimeTrex copyright notice
- * in the same form as they appear in the distribution.  See full license for
- * requirements.
+ * This program is free software; you can redistribute it and/or modify it under
+ * the terms of the GNU Affero General Public License version 3 as published by
+ * the Free Software Foundation with the addition of the following permission
+ * added to Section 15 as permitted in Section 7(a): FOR ANY PART OF THE COVERED
+ * WORK IN WHICH THE COPYRIGHT IS OWNED BY TIMETREX, TIMETREX DISCLAIMS THE
+ * WARRANTY OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
  *
- * The Original Code is: TimeTrex Open Source
- * The Initial Developer of the Original Code is TimeTrex Payroll Services
- * Portions created by TimeTrex are Copyright (C) 2004-2007 TimeTrex Payroll Services;
- * All Rights Reserved.
+ * This program is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+ * FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
+ * details.
  *
+ * You should have received a copy of the GNU Affero General Public License along
+ * with this program; if not, see http://www.gnu.org/licenses or write to the Free
+ * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+ * 02110-1301 USA.
+ *
+ * You can contact TimeTrex headquarters at Unit 22 - 2475 Dobbin Rd. Suite
+ * #292 Westbank, BC V4T 2E9, Canada or at email address info@timetrex.com.
+ *
+ * The interactive user interfaces in modified source and object code versions
+ * of this program must display Appropriate Legal Notices, as required under
+ * Section 5 of the GNU Affero General Public License version 3.
+ *
+ * In accordance with Section 7(b) of the GNU Affero General Public License
+ * version 3, these Appropriate Legal Notices must retain the display of the
+ * "Powered by TimeTrex" logo. If the display of the logo is not reasonably
+ * feasible for technical reasons, the Appropriate Legal Notices must display
+ * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2426 $
- * $Id: EditUser.php 2426 2009-02-18 22:39:19Z ipso $
- * $Date: 2009-02-18 14:39:19 -0800 (Wed, 18 Feb 2009) $
+ * $Revision: 2684 $
+ * $Id: EditUser.php 2684 2009-07-24 22:47:23Z ipso $
+ * $Date: 2009-07-24 15:47:23 -0700 (Fri, 24 Jul 2009) $
  */
 require_once('../../includes/global.inc.php');
 require_once(Environment::getBasePath() .'includes/Interface.inc.php');
@@ -179,7 +192,7 @@ switch ($action) {
 					if ( $user_data['phone_password'] == $user_data['phone_password2'] ) {
 						$uf->setPhonePassword($user_data['phone_password']);
 					} else {
-						$uf->Validator->isTrue( 'password',
+						$uf->Validator->isTrue( 'phone_password',
 												FALSE,
 												TTi18n::gettext('Passwords don\'t match') );
 					}
@@ -327,6 +340,10 @@ switch ($action) {
             $uf->setPolicyGroup( $udf_obj->getPolicyGroup() );
         }
 
+		if ( isset($user_data['hierarchy_control']) AND ( $permission->Check('hierarchy','edit') OR $permission->Check('user','edit_hierarchy') ) ) {
+			$uf->setHierarchyControl( $user_data['hierarchy_control'] );
+		}
+
 		if ( isset($user_data['currency_id']) ) {
 			$uf->setCurrency( $user_data['currency_id'] );
 		} elseif ( isset($udf_obj) AND is_object($udf_obj) AND $uf->isNew() == TRUE ) {
@@ -499,6 +516,11 @@ switch ($action) {
 					if ( $pglf->getRecordCount() > 0 ) {
 						$user_data['policy_group_id'] = $pglf->getCurrent()->getId();
 					}
+
+					$hclf = new HierarchyControlListFactory();
+					$hclf->getObjectTypeAppendedListByCompanyIDAndUserID( $user->getCompany(), $user->getID() );
+					$user_data['hierarchy_control'] = $hclf->getArrayByListFactory( $hclf, FALSE, TRUE, FALSE );
+					unset($hclf);
 				} else {
 					$permission->Redirect( FALSE ); //Redirect
 				}
@@ -628,6 +650,13 @@ switch ($action) {
         $culf->getByCompanyId( $company_id );
 		$currency_options = $culf->getArrayByListFactory( $culf, FALSE, TRUE );
 
+		$hotf = new HierarchyObjectTypeFactory();
+		$hierarchy_object_type_options = $hotf->getOptions('object_type');
+
+		$hclf = new HierarchyControlListFactory();
+		$hclf->getObjectTypeAppendedListByCompanyID( $company_id );
+		$hierarchy_control_options = $hclf->getArrayByListFactory( $hclf, TRUE, TRUE );
+
 		//Select box options;
 		$user_data['branch_options'] = $branch_options;
 		$user_data['department_options'] = $department_options;
@@ -665,6 +694,9 @@ switch ($action) {
 		$oflf = new OtherFieldListFactory();
 		$user_data['other_field_names'] = $oflf->getByCompanyIdAndTypeIdArray( $company_id, 10 );
 
+		$user_data['hierarchy_object_type_options'] = $hierarchy_object_type_options;
+		$user_data['hierarchy_control_options'] = $hierarchy_control_options;
+
 		//Company list.
 		if ( $permission->Check('company','view') ) {
 			$user_data['company_options'] = CompanyListFactory::getAllArray();
