@@ -1,29 +1,42 @@
 <?php
 /*********************************************************************************
- * The contents of this file are subject to the TimeTrex Public License Version
- * 1.1.0 ("License"); You may not use this file except in compliance with the
- * License. You may obtain a copy of the License at http://www.TimeTrex.com/TPL
- * Software distributed under the License is distributed on an "AS IS" basis,
- * WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the License
- * for the specific language governing rights and limitations under the
- * License.
+ * TimeTrex is a Payroll and Time Management program developed by
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
  *
- * All copies of the Covered Code must include on each user interface screen:
- *    (i) the "Powered by TimeTrex" logo and
- *    (ii) the TimeTrex copyright notice
- * in the same form as they appear in the distribution.  See full license for
- * requirements.
+ * This program is free software; you can redistribute it and/or modify it under
+ * the terms of the GNU Affero General Public License version 3 as published by
+ * the Free Software Foundation with the addition of the following permission
+ * added to Section 15 as permitted in Section 7(a): FOR ANY PART OF THE COVERED
+ * WORK IN WHICH THE COPYRIGHT IS OWNED BY TIMETREX, TIMETREX DISCLAIMS THE
+ * WARRANTY OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
  *
- * The Original Code is: TimeTrex Open Source
- * The Initial Developer of the Original Code is TimeTrex Payroll Services
- * Portions created by TimeTrex are Copyright (C) 2004-2007 TimeTrex Payroll Services;
- * All Rights Reserved.
+ * This program is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+ * FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
+ * details.
  *
+ * You should have received a copy of the GNU Affero General Public License along
+ * with this program; if not, see http://www.gnu.org/licenses or write to the Free
+ * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+ * 02110-1301 USA.
+ *
+ * You can contact TimeTrex headquarters at Unit 22 - 2475 Dobbin Rd. Suite
+ * #292 Westbank, BC V4T 2E9, Canada or at email address info@timetrex.com.
+ *
+ * The interactive user interfaces in modified source and object code versions
+ * of this program must display Appropriate Legal Notices, as required under
+ * Section 5 of the GNU Affero General Public License version 3.
+ *
+ * In accordance with Section 7(b) of the GNU Affero General Public License
+ * version 3, these Appropriate Legal Notices must retain the display of the
+ * "Powered by TimeTrex" logo. If the display of the logo is not reasonably
+ * feasible for technical reasons, the Appropriate Legal Notices must display
+ * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2371 $
- * $Id: AddRecurringScheduleShift.php 2371 2009-01-21 22:54:00Z ipso $
- * $Date: 2009-01-21 14:54:00 -0800 (Wed, 21 Jan 2009) $
+ * $Revision: 2894 $
+ * $Id: AddRecurringScheduleShift.php 2894 2009-10-13 18:35:51Z ipso $
+ * $Date: 2009-10-13 11:35:51 -0700 (Tue, 13 Oct 2009) $
  */
 require_once( dirname(__FILE__) . DIRECTORY_SEPARATOR .'..'. DIRECTORY_SEPARATOR .'includes'. DIRECTORY_SEPARATOR .'global.inc.php');
 require_once( dirname(__FILE__) . DIRECTORY_SEPARATOR .'..'. DIRECTORY_SEPARATOR .'includes'. DIRECTORY_SEPARATOR .'CLI.inc.php');
@@ -53,7 +66,7 @@ if ( $clf->getRecordCount() > 0 ) {
 				Debug::text('Recurring Schedule Control List Record Count: '. $rsclf->getRecordCount() , __FILE__, __LINE__, __METHOD__, 10);
 
 				foreach( $rsclf as $rsc_obj ) {
-					$rsclf->StartTransaction();
+					//$rsclf->StartTransaction(); Wrap each individual schedule in its own transaction instead.
 
 					Debug::text('Recurring Schedule ID: '. $rsc_obj->getID() , __FILE__, __LINE__, __METHOD__, 10);
 					//Debug::Arr($rsc_obj->getUser(), 'Users assigned to Schedule', __FILE__, __LINE__, __METHOD__, 10);
@@ -89,6 +102,14 @@ if ( $clf->getRecordCount() > 0 ) {
 							$end_date = $current_epoch + $add_shift_offset;
 							Debug::text('Start Date: '. TTDate::getDate('DATE+TIME', $start_date ) .' End Date: '. TTDate::getDate('DATE+TIME', $end_date ) , __FILE__, __LINE__, __METHOD__, 10);
 
+							//Make sure employee is employed in this time frame.
+							if ( ( $user_obj->getHireDate() != '' AND $start_date <= $user_obj->getHireDate() )
+									OR ( $user_obj->getTerminationDate() != '' AND $start_date > $user_obj->getTerminationDate() )
+									) {
+								Debug::text('Skipping User due to hire/termination date...'. $user_id, __FILE__, __LINE__, __METHOD__, 10);
+								continue; //Skip user.
+							}
+							
 							//Set the timezone before getting the recurring schedule shifts
 							//so we prevent timezone issues and DST issues from arising.
 							$recurring_schedule_days = $rsc_obj->getShiftsByStartDateAndEndDate( $start_date, $end_date );
@@ -141,6 +162,9 @@ if ( $clf->getRecordCount() > 0 ) {
 											//And that no schedule shifts overlap this one.
 											//Use the isValid() function for this
 											$sf = new ScheduleFactory();
+
+											$sf->StartTransaction();
+
 											$sf->findUserDate( $user_id, $recurring_schedule_shift_start_time );
 											$sf->setStatus( $status_id ); //Working
 											$sf->setStartTime( $recurring_schedule_shift_start_time );
@@ -192,79 +216,134 @@ if ( $clf->getRecordCount() > 0 ) {
 													$sf->setEnableReCalculateDay(FALSE); //Don't need to re-calc right now?
 												}
 
+												$schedule_result = $sf->Save();
+												$sf->CommitTransaction();
+
 												$profiler->startTimer( "Add Punch");
 
 												Debug::text('Schedule Checks out, saving: '. TTDate::getDate('DATE+TIME', $recurring_schedule_shift_start_time ), __FILE__, __LINE__, __METHOD__, 10);
-												if ( $sf->Save() == TRUE
+												if ( $schedule_result == TRUE
 														AND $rsc_obj->getAutoFill() == TRUE
 														AND $status_id == 10 ) { //Make sure they are working for Auto-fill to kickin.
 													Debug::text('Schedule has AutoFill enabled!', __FILE__, __LINE__, __METHOD__, 10);
 
-													//Could wrap this in its own transaction
-													//But the entire RSC obj is already wrapped, so without sub-trans
-													//Its not going to help.
-													$pcf = new PunchControlFactory();
-													$pcf->findUserDate( $user_id, $recurring_schedule_shift_start_time );
+													$commit_punch_transaction = FALSE;
 
-													if ( $recurring_schedule_shift['branch_id'] == -1 ) {
-														$pcf->setBranch( $user_obj->getDefaultBranch() );
+													Debug::text('Punch In: '. TTDate::getDate('DATE+TIME', $recurring_schedule_shift_start_time ), __FILE__, __LINE__, __METHOD__, 10);
+													$pf_in = new PunchFactory();
+
+													$pf_in->StartTransaction();
+
+													$pf_in->setUser( $user_id );
+													$pf_in->setType( 10 ); //Normal
+													$pf_in->setStatus( 10 ); //In
+													$pf_in->setTimeStamp( $recurring_schedule_shift_start_time, TRUE  );
+													$pf_in->setPunchControlID( $pf_in->findPunchControlID() );
+													$pf_in->setActualTimeStamp( $pf_in->getTimeStamp() );
+													$pf_in->setOriginalTimeStamp( $pf_in->getTimeStamp() );
+
+													if ( $pf_in->isValid() ) {
+														Debug::text('Punch In: Valid!', __FILE__, __LINE__, __METHOD__, 10);
+														$pf_in->setEnableCalcTotalTime( FALSE );
+														$pf_in->setEnableCalcSystemTotalTime( FALSE );
+														$pf_in->setEnableCalcUserDateTotal( FALSE );
+														$pf_in->setEnableCalcException( FALSE );
+
+														$pf_in->Save( FALSE );
 													} else {
-														$pcf->setBranch( $recurring_schedule_shift['branch_id'] );
+														Debug::text('Punch In: InValid!', __FILE__, __LINE__, __METHOD__, 10);
 													}
 
-													if ( $recurring_schedule_shift['department_id'] == -1 ) {
-														$pcf->setDepartment( $user_obj->getDefaultDepartment() );
+													Debug::text('Punch Out: '. TTDate::getDate('DATE+TIME', $recurring_schedule_shift_end_time ), __FILE__, __LINE__, __METHOD__, 10);
+													$pf_out = new PunchFactory();
+													$pf_out->setUser( $user_id );
+													$pf_out->setType( 10 ); //Normal
+													$pf_out->setStatus( 20 ); //Out
+													$pf_out->setTimeStamp( $recurring_schedule_shift_end_time, TRUE  );
+													$pf_out->setPunchControlID( $pf_in->findPunchControlID() ); //Use the In punch object to find the punch_control_id.
+													$pf_out->setActualTimeStamp( $pf_out->getTimeStamp() );
+													$pf_out->setOriginalTimeStamp( $pf_out->getTimeStamp() );
+
+													if ( $pf_out->isValid() ) {
+														Debug::text('Punch Out: Valid!', __FILE__, __LINE__, __METHOD__, 10);
+														$pf_out->setEnableCalcTotalTime( TRUE );
+														$pf_out->setEnableCalcSystemTotalTime( TRUE );
+														$pf_out->setEnableCalcUserDateTotal( TRUE );
+														$pf_out->setEnableCalcException( TRUE );
+
+														$pf_out->Save( FALSE );
 													} else {
-														$pcf->setDepartment( $recurring_schedule_shift['department_id'] );
+														Debug::text('Punch Out: InValid!', __FILE__, __LINE__, __METHOD__, 10);
 													}
 
-													if ( isset($recurring_schedule_shift['job_id']) ) {
-														$pcf->setJob( $recurring_schedule_shift['job_id'] );
-													}
+													if ( $pf_in->isValid() == TRUE OR $pf_out->isValid() == TRUE ) {
+														Debug::text('Punch In and Out succeeded, saving punch control!', __FILE__, __LINE__, __METHOD__, 10);
 
-													if ( isset($recurring_schedule_shift['job_item_id']) ) {
-														$pcf->setJobItem( $recurring_schedule_shift['job_item_id'] );
-													}
+														$pcf = new PunchControlFactory();
+														$pcf->setId( $pf_in->getPunchControlID() );
 
-													if ( $pcf->isValid() ) {
-														$punch_control_id = $pcf->Save();
-
-														//Debug::Text(' Punch Control ID: '. $punch_control_id, __FILE__, __LINE__, __METHOD__,10);
-														Debug::Text(' AutoFill Punch In: '. TTDate::getDate('DATE+TIME', $recurring_schedule_shift_start_time ), __FILE__, __LINE__, __METHOD__,10);
-														$pf = new PunchFactory();
-														$pf->setPunchControlID( $punch_control_id );
-														$pf->setType( 10 ); //Normal
-														$pf->setStatus( 10 ); //In
-														$pf->setTimeStamp( $recurring_schedule_shift_start_time, TRUE );
-														$pf->setActualTimeStamp( $recurring_schedule_shift_start_time );
-														$pf->setOriginalTimeStamp( $pf->getTimeStamp() );
-														//Won't save this punch if it overlaps already signed in punch.
-														if ( $pf->isValid() ) {
-															$pf->Save();
+														if ( $pf_in->isValid() == TRUE ) {
+															$pcf->setPunchObject( $pf_in );
+														} elseif ( $pf_out->isValid() == TRUE ) {
+															$pcf->setPunchObject( $pf_out );
 														}
 
-														Debug::Text(' AutoFill Punch Out: '. TTDate::getDate('DATE+TIME', $recurring_schedule_shift_end_time ), __FILE__, __LINE__, __METHOD__,10);
-														$pf = new PunchFactory();
-														$pf->setPunchControlID( $punch_control_id );
-														$pf->setType( 10 ); //Normal
-														$pf->setStatus( 20 ); //Out
-														$pf->setTimeStamp( $recurring_schedule_shift_end_time, TRUE );
-														$pf->setActualTimeStamp( $recurring_schedule_shift_end_time );
-														$pf->setOriginalTimeStamp( $pf->getTimeStamp() );
-														//Won't save this punch if it overlaps already signed in punch.
-														if ( $pf->isValid() ) {
-															$pf->setEnableCalcTotalTime( TRUE );
-															$pf->setEnableCalcSystemTotalTime( TRUE );
-															$pf->setEnableCalcWeeklySystemTotalTime( TRUE );
-															$pf->setEnableCalcUserDateTotal( TRUE );
-															$pf->setEnableCalcException( TRUE );
-
-															$pf->Save();
+														if ( $recurring_schedule_shift['branch_id'] == -1 ) {
+															$pcf->setBranch( $user_obj->getDefaultBranch() );
+														} else {
+															$pcf->setBranch( $recurring_schedule_shift['branch_id'] );
 														}
+
+														if ( $recurring_schedule_shift['department_id'] == -1 ) {
+															$pcf->setDepartment( $user_obj->getDefaultDepartment() );
+														} else {
+															$pcf->setDepartment( $recurring_schedule_shift['department_id'] );
+														}
+
+														if ( getTTProductEdition() == TT_PRODUCT_PROFESSIONAL ) {
+															if ( isset($recurring_schedule_shift['job_id']) ) {
+																$pcf->setJob( $recurring_schedule_shift['job_id'] );
+															}
+
+															if ( isset($recurring_schedule_shift['job_item_id']) ) {
+																$pcf->setJobItem( $recurring_schedule_shift['job_item_id'] );
+															}
+														}
+
+														$pcf->setEnableStrictJobValidation( TRUE );
+														$pcf->setEnableCalcUserDateID( TRUE );
+														$pcf->setEnableCalcTotalTime( TRUE );
+														$pcf->setEnableCalcSystemTotalTime( TRUE );
+														$pcf->setEnableCalcUserDateTotal( TRUE );
+														$pcf->setEnableCalcException( TRUE );
+														$pcf->setEnablePreMatureException( FALSE ); //Disable pre-mature exceptions at this point.
+
+														if ( $pcf->isValid() ) {
+															$pcf->Save( TRUE, TRUE );
+
+															$commit_punch_transaction = TRUE;
+														} else {
+														}
+													} else {
+														Debug::text('Punch In and Out failed, not saving punch control!', __FILE__, __LINE__, __METHOD__, 10);
 													}
+
+													if ( $commit_punch_transaction == TRUE ) {
+														Debug::text('Committing Punch Transaction!', __FILE__, __LINE__, __METHOD__, 10);
+														$pf_in->CommitTransaction();
+													} else {
+														Debug::text('Rolling Back Punch Transaction!', __FILE__, __LINE__, __METHOD__, 10);
+														$pf_in->FailTransaction();
+														$pf_in->CommitTransaction();
+													}
+
+													unset($pf_in, $pf_out, $pcf);
 												}
+
 												$profiler->stopTimer( "Add Punch");
 											} else {
+												$sf->FailTransaction();
+												$sf->CommitTransaction();
 												Debug::text('Bad or conflicting Schedule: '. TTDate::getDate('DATE+TIME', $recurring_schedule_shift_start_time ), __FILE__, __LINE__, __METHOD__, 10);
 											}
 
@@ -290,7 +369,7 @@ if ( $clf->getRecordCount() > 0 ) {
 						}
 					}
 					//$rsclf->FailTransaction();
-					$rsclf->CommitTransaction();
+					//$rsclf->CommitTransaction();
 				}
 			}
 		} else {
