@@ -1,29 +1,42 @@
 <?php
 /*********************************************************************************
- * The contents of this file are subject to the TimeTrex Public License Version
- * 1.1.0 ("License"); You may not use this file except in compliance with the
- * License. You may obtain a copy of the License at http://www.TimeTrex.com/TPL
- * Software distributed under the License is distributed on an "AS IS" basis,
- * WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the License
- * for the specific language governing rights and limitations under the
- * License.
+ * TimeTrex is a Payroll and Time Management program developed by
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
  *
- * All copies of the Covered Code must include on each user interface screen:
- *    (i) the "Powered by TimeTrex" logo and
- *    (ii) the TimeTrex copyright notice
- * in the same form as they appear in the distribution.  See full license for
- * requirements.
+ * This program is free software; you can redistribute it and/or modify it under
+ * the terms of the GNU Affero General Public License version 3 as published by
+ * the Free Software Foundation with the addition of the following permission
+ * added to Section 15 as permitted in Section 7(a): FOR ANY PART OF THE COVERED
+ * WORK IN WHICH THE COPYRIGHT IS OWNED BY TIMETREX, TIMETREX DISCLAIMS THE
+ * WARRANTY OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
  *
- * The Original Code is: TimeTrex Open Source
- * The Initial Developer of the Original Code is TimeTrex Payroll Services
- * Portions created by TimeTrex are Copyright (C) 2004-2007 TimeTrex Payroll Services;
- * All Rights Reserved.
+ * This program is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+ * FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
+ * details.
  *
+ * You should have received a copy of the GNU Affero General Public License along
+ * with this program; if not, see http://www.gnu.org/licenses or write to the Free
+ * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+ * 02110-1301 USA.
+ *
+ * You can contact TimeTrex headquarters at Unit 22 - 2475 Dobbin Rd. Suite
+ * #292 Westbank, BC V4T 2E9, Canada or at email address info@timetrex.com.
+ *
+ * The interactive user interfaces in modified source and object code versions
+ * of this program must display Appropriate Legal Notices, as required under
+ * Section 5 of the GNU Affero General Public License version 3.
+ *
+ * In accordance with Section 7(b) of the GNU Affero General Public License
+ * version 3, these Appropriate Legal Notices must retain the display of the
+ * "Powered by TimeTrex" logo. If the display of the logo is not reasonably
+ * feasible for technical reasons, the Appropriate Legal Notices must display
+ * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 1277 $
- * $Id: import_punches.php 1277 2007-09-27 21:08:52Z ipso $
- * $Date: 2007-09-27 14:08:52 -0700 (Thu, 27 Sep 2007) $
+ * $Revision: 2845 $
+ * $Id: import_punches.php 2845 2009-09-21 23:18:43Z ipso $
+ * $Date: 2009-09-21 16:18:43 -0700 (Mon, 21 Sep 2009) $
  */
 require_once( dirname(__FILE__) . DIRECTORY_SEPARATOR .'..'. DIRECTORY_SEPARATOR .'..'. DIRECTORY_SEPARATOR .'includes'. DIRECTORY_SEPARATOR .'global.inc.php');
 require_once( dirname(__FILE__) . DIRECTORY_SEPARATOR .'..'. DIRECTORY_SEPARATOR .'..'. DIRECTORY_SEPARATOR .'includes'. DIRECTORY_SEPARATOR .'CLI.inc.php');
@@ -300,10 +313,6 @@ if ( $argc < 3 OR in_array ($argv[1], array('--help', '-help', '-h', '-?') ) ) {
 					unset($jilf);
 				}
 
-				$pcf = new PunchControlFactory();
-
-				$status_id = Misc::importCallInputParseFunction( 'status_id', $mapped_row['status_id'], $filtered_import_map['status_id']['default_value'], $filtered_import_map['status_id']['parse_hint'] );
-
 				if ( isset($mapped_row['time_stamp']) AND $mapped_row['time_stamp'] != '' ) {
 					$time_stamp_epoch = Misc::importCallInputParseFunction( 'time_stamp', $mapped_row['time_stamp'], $filtered_import_map['time_stamp']['default_value'], $filtered_import_map['time_stamp']['parse_hint'] );
 				} else {
@@ -313,18 +322,218 @@ if ( $argc < 3 OR in_array ($argv[1], array('--help', '-help', '-h', '-?') ) ) {
 						$time_stamp_epoch = NULL;
 					}
 				}
-				//echo "  Time Stamp: $i. ". TTDate::getDate('DATE+TIME', $time_stamp_epoch) ." (".$time_stamp_epoch.")\n";
+				echo "  Time Stamp: $i. ". TTDate::getDate('DATE+TIME', $time_stamp_epoch) ." (".$time_stamp_epoch.")\n";
 
-				$pcf->findUserDate( $u_obj->getId(), $time_stamp_epoch, $status_id );
-				//echo "User Date ID: ". $pcf->getUserDateId() ."\n";
+				$status_id = Misc::importCallInputParseFunction( 'status_id', $mapped_row['status_id'], $filtered_import_map['status_id']['default_value'], $filtered_import_map['status_id']['parse_hint'] );
 
-				//Try to find a punch_control_id we can attach to safely.
-				$pclf = new PunchControlListFactory();
-				$tmp_punch_control_id = $pclf->getInCompletePunchControlIdByUserDateIdAndEpoch( $pcf->getUserDateId(), $time_stamp_epoch, $status_id );
-				if ( $tmp_punch_control_id !== FALSE ) {
-					$pcf->setId( $tmp_punch_control_id );
+				if ( !isset($mapped_row['time_stamp']) OR $mapped_row['time_stamp'] == '' ) {
+					//Two punches per row
+					if ( isset($mapped_row['start_time_stamp']) AND $mapped_row['start_time_stamp'] != '' ) {
+						//
+						// Start Punch
+						//
+						$pf = new PunchFactory();
+						$pf->setUser( $u_obj->getId() );
+
+						if ( isset($mapped_row['start_type_id']) AND $mapped_row['start_type_id'] != '' ) {
+							$pf->setType( Misc::importCallInputParseFunction( 'start_type_id', $mapped_row['start_type_id'], $filtered_import_map['start_type_id']['default_value'], $filtered_import_map['start_type_id']['parse_hint'] ) );
+						} else {
+							$pf->setType(10); //Normal
+						}
+
+						$pf->setStatus(10); //In
+
+						if ( isset($mapped_row['disable_rounding']) AND $mapped_row['disable_rounding'] != '' ) {
+							$disable_rounding = (bool)$mapped_row['disable_rounding'];
+						}
+						//Reverse boolean.
+						if ( isset($disable_rounding) AND $disable_rounding == TRUE ) {
+							$enable_rounding = FALSE;
+						} else {
+							$enable_rounding = TRUE;
+						}
+						//echo "First Punch: ". TTDate::getDate('DATE+TIME', $time_stamp_epoch) ."\n";
+						$pf->setTimeStamp( $time_stamp_epoch, $enable_rounding );
+
+						$pf->setPunchControlID( $pf->findPunchControlID() );
+
+						$pf->setActualTimeStamp( $time_stamp_epoch );
+						$pf->setOriginalTimeStamp( $time_stamp_epoch );
+
+						if ( $pf->isValid() ) {
+							$pf->setEnableCalcTotalTime( TRUE );
+							$pf->setEnableCalcSystemTotalTime( TRUE );
+							$pf->setEnableCalcUserDateTotal( TRUE );
+							$pf->setEnableCalcException( TRUE );
+
+							if ( $pf->Save( FALSE ) == TRUE ) {
+								$punch_control_id = $pf->getPunchControlID();
+								echo " \t\t\t1. Success!";
+							} else {
+								echo " \t\t\t1. Failed!";
+								$commit_trans = FALSE;
+								$e++;
+
+								$errors = $pf->Validator->getErrorsArray();
+								if ( is_array($errors) ) {
+									foreach( $errors as $error_arr ) {
+										echo "      ERROR: ". $error_arr[0] ."\n";
+									}
+								}
+							}
+						} else {
+							echo " \t\t\t1. Failed!\n";
+							$commit_trans = FALSE;
+							$e++;
+
+
+							$errors = $pf->Validator->getErrorsArray();
+							if ( is_array($errors) ) {
+								foreach( $errors as $error_arr ) {
+									echo "      ERROR: ". $error_arr[0] ."\n";
+								}
+							}
+						}
+					} else {
+						echo " \t\t\t1. Failed!\n";
+						//$commit_trans = FALSE;
+						$e++;
+
+						echo "      ERROR: No punch In timestamp...\n";
+					}
+
+					if ( isset($mapped_row['end_time_stamp']) AND $mapped_row['end_time_stamp'] != '' AND isset($pf) AND is_object($pf) ) {
+						//
+						// End Punch
+						//
+						$pf_b = new PunchFactory();
+						$pf_b->setUser( $u_obj->getId() );
+
+						if ( isset($mapped_row['end_type_id']) AND $mapped_row['end_type_id'] != '' ) {
+							$pf_b->setType( Misc::importCallInputParseFunction( 'end_type_id', $mapped_row['end_type_id'], $filtered_import_map['end_type_id']['default_value'], $filtered_import_map['end_type_id']['parse_hint'] ) );
+						} else {
+							$pf_b->setType(10); //Normal
+						}
+
+						$pf_b->setStatus(20); //Out
+
+						if ( isset($mapped_row['disable_rounding']) AND $mapped_row['disable_rounding'] != '' ) {
+							$disable_rounding = (bool)$mapped_row['disable_rounding'];
+						}
+						//Reverse boolean.
+						if ( isset($disable_rounding) AND $disable_rounding == TRUE ) {
+							$enable_rounding = FALSE;
+						} else {
+							$enable_rounding = TRUE;
+						}
+
+						$end_time_stamp_epoch = Misc::importCallInputParseFunction( 'time_stamp', $mapped_row['end_time_stamp'], $filtered_import_map['end_time_stamp']['default_value'], $filtered_import_map['end_time_stamp']['parse_hint'] );
+
+						//echo "Second Punch: ". TTDate::getDate('DATE+TIME', $end_time_stamp_epoch) ."\n";
+						$pf_b->setTimeStamp( $end_time_stamp_epoch, $enable_rounding );
+
+						$pf_b->setPunchControlID( $pf->findPunchControlID() );
+
+						$pf_b->setActualTimeStamp( $end_time_stamp_epoch );
+						$pf_b->setOriginalTimeStamp( $end_time_stamp_epoch );
+
+						if ( $pf_b->isValid() ) {
+							if ( $pf_b->Save() == TRUE ) {
+								echo " 2. Success!\n";
+							} else {
+								echo " 2. Failed!\n";
+								$commit_trans = FALSE;
+								$e++;
+
+								$errors = $pf_b->Validator->getErrorsArray();
+								if ( is_array($errors) ) {
+									foreach( $errors as $error_arr ) {
+										echo "      ERROR: ". $error_arr[0] ."\n";
+									}
+								}
+							}
+						} else {
+							echo " 2. Failed!\n";
+							$commit_trans = FALSE;
+							$e++;
+
+							$errors = $pf_b->Validator->getErrorsArray();
+							if ( is_array($errors) ) {
+								foreach( $errors as $error_arr ) {
+									echo "      ERROR: ". $error_arr[0] ."\n";
+								}
+							}
+						}
+					} else {
+						echo " 2. Failed!\n";
+						//$commit_trans = FALSE;
+						$e++;
+
+						echo "      ERROR: No punch Out timestamp...\n";
+					}
+				} else {
+					//Single punch per row
+					$pf = new PunchFactory();
+					$pf->setUser( $u_obj->getId() );
+
+					if ( isset($mapped_row['type_id']) AND $mapped_row['type_id'] != '' ) {
+						$pf->setType( Misc::importCallInputParseFunction( 'type_id', $mapped_row['type_id'], $filtered_import_map['type_id']['default_value'], $filtered_import_map['type_id']['parse_hint'] ) );
+					}
+
+					if ( isset($mapped_row['status_id']) AND $mapped_row['status_id'] != '' ) {
+						$pf->setStatus( $status_id );
+					}
+
+					if ( isset($mapped_row['disable_rounding']) AND $mapped_row['disable_rounding'] != '' ) {
+						$disable_rounding = (bool)$mapped_row['disable_rounding'];
+					}
+					//Reverse boolean.
+					if ( isset($disable_rounding) AND $disable_rounding == TRUE ) {
+						$enable_rounding = FALSE;
+					} else {
+						$enable_rounding = TRUE;
+					}
+
+					$pf->setTimeStamp( $time_stamp_epoch, $enable_rounding );
+
+					$pf->setPunchControlID( $pf->findPunchControlID() );
+
+					$pf->setActualTimeStamp( $time_stamp_epoch );
+					$pf->setOriginalTimeStamp( $time_stamp_epoch );
+
+					if ( $pf->isValid() ) {
+						if ( $pf->Save( FALSE ) == TRUE ) {
+							echo " \t\t\tSuccess!\n";
+						} else {
+							echo " \t\t\tFailed!\n";
+							$commit_trans = FALSE;
+							$e++;
+
+							$errors = $pf->Validator->getErrorsArray();
+							if ( is_array($errors) ) {
+								foreach( $errors as $error_arr ) {
+									echo "      ERROR: ". $error_arr[0] ."\n";
+								}
+							}
+						}
+					} else {
+						echo " \t\t\tFailed!\n";
+						$commit_trans = FALSE;
+						$e++;
+
+						$errors = $pf->Validator->getErrorsArray();
+						if ( is_array($errors) ) {
+							foreach( $errors as $error_arr ) {
+								echo "      ERROR: ". $error_arr[0] ."\n";
+							}
+						}
+					}
 				}
 
+				$pcf = new PunchControlFactory();
+				$pcf->setId( $pf->getPunchControlID() );
+				$pcf->setPunchObject( $pf );
+
 				if ( isset($mapped_row['branch_id']) AND $mapped_row['branch_id'] != '' ) {
 					$pcf->setBranch( Misc::importCallInputParseFunction( 'branch_id', $mapped_row['branch_id'], $filtered_import_map['branch_id']['default_value'], $filtered_import_map['branch_id']['parse_hint'] ) );
 				}
@@ -350,258 +559,27 @@ if ( $argc < 3 OR in_array ($argv[1], array('--help', '-help', '-h', '-?') ) ) {
 					}
 				}
 
+				$pcf->setEnableStrictJobValidation( TRUE );
+				$pcf->setEnableCalcUserDateID( TRUE );
+				$pcf->setEnableCalcTotalTime( TRUE );
+				$pcf->setEnableCalcSystemTotalTime( TRUE );
+				$pcf->setEnableCalcWeeklySystemTotalTime( TRUE );
+				$pcf->setEnableCalcUserDateTotal( TRUE );
+				$pcf->setEnableCalcException( TRUE );
+
 				if ( $pcf->isValid() ) {
-					$punch_control_id = $pcf->Save();
-
-					if ( !isset($mapped_row['time_stamp']) OR $mapped_row['time_stamp'] == '' ) {
-						//Two punches per row
-						if ( isset($mapped_row['start_time_stamp']) AND $mapped_row['start_time_stamp'] != '' ) {
-							//
-							// Start Punch
-							//
-							$pf = new PunchFactory();
-							if ( isset($tmp_punch_control_id) AND $tmp_punch_control_id != '' ) {
-								//echo "aPunch Control ID: ". $tmp_punch_control_id ."\n";
-								$pf->setPunchControlID( $tmp_punch_control_id );
-							} elseif ( is_numeric( $punch_control_id ) ) {
-								//echo "bPunch Control ID: ". $punch_control_id ."\n";
-								$pf->setPunchControlID( $punch_control_id );
-							}
-
-							if ( isset($mapped_row['start_type_id']) AND $mapped_row['start_type_id'] != '' ) {
-								$pf->setType( Misc::importCallInputParseFunction( 'start_type_id', $mapped_row['start_type_id'], $filtered_import_map['start_type_id']['default_value'], $filtered_import_map['start_type_id']['parse_hint'] ) );
-							} else {
-								$pf->setType(10); //Normal
-							}
-
-							$pf->setStatus(10); //In
-
-							if ( isset($mapped_row['disable_rounding']) AND $mapped_row['disable_rounding'] != '' ) {
-								$disable_rounding = (bool)$mapped_row['disable_rounding'];
-							}
-							//Reverse boolean.
-							if ( isset($disable_rounding) AND $disable_rounding == TRUE ) {
-								$enable_rounding = FALSE;
-							} else {
-								$enable_rounding = TRUE;
-							}
-							//echo "First Punch: ". TTDate::getDate('DATE+TIME', $time_stamp_epoch) ."\n";
-							$pf->setTimeStamp( $time_stamp_epoch, $enable_rounding );
-
-							$pf->setActualTimeStamp( $time_stamp_epoch );
-							$pf->setOriginalTimeStamp( $time_stamp_epoch );
-
-							if ( $pf->isValid() ) {
-								$pf->setEnableCalcTotalTime( TRUE );
-								$pf->setEnableCalcSystemTotalTime( TRUE );
-								$pf->setEnableCalcUserDateTotal( TRUE );
-								$pf->setEnableCalcException( TRUE );
-
-								if ( $pf->Save() == TRUE ) {
-									echo " \t\t\t1. Success!";
-								} else {
-									echo " \t\t\t1. Failed!";
-									$commit_trans = FALSE;
-									$e++;
-
-
-									$errors = $pf->Validator->getErrorsArray();
-									if ( is_array($errors) ) {
-										foreach( $errors as $error_arr ) {
-											echo "      ERROR: ". $error_arr[0] ."\n";
-										}
-									}
-
-								}
-							} else {
-								echo " \t\t\t1. Failed!\n";
-								$commit_trans = FALSE;
-								$e++;
-
-
-								$errors = $pf->Validator->getErrorsArray();
-								if ( is_array($errors) ) {
-									foreach( $errors as $error_arr ) {
-										echo "      ERROR: ". $error_arr[0] ."\n";
-									}
-								}
-
-							}
-						} else {
-							echo " \t\t\t1. Failed!\n";
-							//$commit_trans = FALSE;
-							$e++;
-
-							echo "      ERROR: No punch In timestamp...\n";
-						}
-
-						if ( isset($mapped_row['end_time_stamp']) AND $mapped_row['end_time_stamp'] != '' ) {
-							//
-							// End Punch
-							//
-							$pf = new PunchFactory();
-							if ( isset($tmp_punch_control_id) AND $tmp_punch_control_id != '' ) {
-								//echo "aPunch Control ID: ". $tmp_punch_control_id ."\n";
-								$pf->setPunchControlID( $tmp_punch_control_id );
-							} elseif ( is_numeric( $punch_control_id ) ) {
-								//echo "bPunch Control ID: ". $punch_control_id ."\n";
-								$pf->setPunchControlID( $punch_control_id );
-							}
-
-							if ( isset($mapped_row['end_type_id']) AND $mapped_row['end_type_id'] != '' ) {
-								$pf->setType( Misc::importCallInputParseFunction( 'end_type_id', $mapped_row['end_type_id'], $filtered_import_map['end_type_id']['default_value'], $filtered_import_map['end_type_id']['parse_hint'] ) );
-							} else {
-								$pf->setType(10); //Normal
-							}
-
-							$pf->setStatus(20); //Out
-
-							if ( isset($mapped_row['disable_rounding']) AND $mapped_row['disable_rounding'] != '' ) {
-								$disable_rounding = (bool)$mapped_row['disable_rounding'];
-							}
-							//Reverse boolean.
-							if ( isset($disable_rounding) AND $disable_rounding == TRUE ) {
-								$enable_rounding = FALSE;
-							} else {
-								$enable_rounding = TRUE;
-							}
-
-							$end_time_stamp_epoch = Misc::importCallInputParseFunction( 'time_stamp', $mapped_row['end_time_stamp'], $filtered_import_map['end_time_stamp']['default_value'], $filtered_import_map['end_time_stamp']['parse_hint'] );
-
-							//echo "Second Punch: ". TTDate::getDate('DATE+TIME', $end_time_stamp_epoch) ."\n";
-							$pf->setTimeStamp( $end_time_stamp_epoch, $enable_rounding );
-
-							$pf->setActualTimeStamp( $end_time_stamp_epoch );
-							$pf->setOriginalTimeStamp( $end_time_stamp_epoch );
-
-							if ( $pf->isValid() ) {
-								$pf->setEnableCalcTotalTime( TRUE );
-								$pf->setEnableCalcSystemTotalTime( TRUE );
-								$pf->setEnableCalcUserDateTotal( TRUE );
-								$pf->setEnableCalcException( TRUE );
-
-								if ( $pf->Save() == TRUE ) {
-									echo " 2. Success!\n";
-								} else {
-									echo " 2. Failed!\n";
-									$commit_trans = FALSE;
-									$e++;
-
-
-									$errors = $pf->Validator->getErrorsArray();
-									if ( is_array($errors) ) {
-										foreach( $errors as $error_arr ) {
-											echo "      ERROR: ". $error_arr[0] ."\n";
-										}
-									}
-
-								}
-							} else {
-								echo " 2. Failed!\n";
-								$commit_trans = FALSE;
-								$e++;
-
-
-								$errors = $pf->Validator->getErrorsArray();
-								if ( is_array($errors) ) {
-									foreach( $errors as $error_arr ) {
-										echo "      ERROR: ". $error_arr[0] ."\n";
-									}
-								}
-
-							}
-						} else {
-							echo " 2. Failed!\n";
-							//$commit_trans = FALSE;
-							$e++;
-
-							echo "      ERROR: No punch Out timestamp...\n";
-						}
-					} else {
-						//Single punch per row
-						$pf = new PunchFactory();
-						if ( isset($tmp_punch_control_id) AND $tmp_punch_control_id != '' ) {
-							//echo "aPunch Control ID: ". $tmp_punch_control_id ."\n";
-							$pf->setPunchControlID( $tmp_punch_control_id );
-						} elseif ( is_numeric( $punch_control_id ) ) {
-							//echo "bPunch Control ID: ". $punch_control_id ."\n";
-							$pf->setPunchControlID( $punch_control_id );
-						}
-
-						if ( isset($mapped_row['type_id']) AND $mapped_row['type_id'] != '' ) {
-							$pf->setType( Misc::importCallInputParseFunction( 'type_id', $mapped_row['type_id'], $filtered_import_map['type_id']['default_value'], $filtered_import_map['type_id']['parse_hint'] ) );
-						}
-
-						if ( isset($mapped_row['status_id']) AND $mapped_row['status_id'] != '' ) {
-							$pf->setStatus( $status_id );
-						}
-
-						if ( isset($mapped_row['disable_rounding']) AND $mapped_row['disable_rounding'] != '' ) {
-							$disable_rounding = (bool)$mapped_row['disable_rounding'];
-						}
-						//Reverse boolean.
-						if ( isset($disable_rounding) AND $disable_rounding == TRUE ) {
-							$enable_rounding = FALSE;
-						} else {
-							$enable_rounding = TRUE;
-						}
-						$pf->setTimeStamp( $time_stamp_epoch, $enable_rounding );
-
-						$pf->setActualTimeStamp( $time_stamp_epoch );
-						$pf->setOriginalTimeStamp( $time_stamp_epoch );
-
-						if ( $pf->isValid() ) {
-							$pf->setEnableCalcTotalTime( TRUE );
-							$pf->setEnableCalcSystemTotalTime( TRUE );
-							$pf->setEnableCalcUserDateTotal( TRUE );
-							$pf->setEnableCalcException( TRUE );
-
-							if ( $pf->Save() == TRUE ) {
-								echo " \t\t\tSuccess!\n";
-							} else {
-								echo " \t\t\tFailed!\n";
-								$commit_trans = FALSE;
-								$e++;
-
-
-								$errors = $pf->Validator->getErrorsArray();
-								if ( is_array($errors) ) {
-									foreach( $errors as $error_arr ) {
-										echo "      ERROR: ". $error_arr[0] ."\n";
-									}
-								}
-
-							}
-						} else {
-							echo " \t\t\tFailed!\n";
-							$commit_trans = FALSE;
-							$e++;
-
-
-							$errors = $pf->Validator->getErrorsArray();
-							if ( is_array($errors) ) {
-								foreach( $errors as $error_arr ) {
-									echo "      ERROR: ". $error_arr[0] ."\n";
-								}
-							}
-
-						}
-
-					}
-
+					$punch_control_id = $pcf->Save( TRUE, TRUE );
 				} else {
 					echo " \t\t\tFailed!\n";
 					$commit_trans = FALSE;
 					$e++;
 
-
 					$errors = $pcf->Validator->getErrorsArray();
 					if ( is_array($errors) ) {
 						foreach( $errors as $error_arr ) {
 							echo "      ERROR: ". $error_arr[0] ."\n";
 						}
 					}
-
 				}
 
 			} else {
@@ -633,5 +611,5 @@ if ( $argc < 3 OR in_array ($argv[1], array('--help', '-help', '-h', '-?') ) ) {
 }
 
 echo "WARNING: Clear TimeTrex cache after running this.\n";
-//Debug::Display();
+Debug::Display();
 ?>
\ No newline at end of file
