@@ -1,29 +1,42 @@
 <?php
 /*********************************************************************************
- * The contents of this file are subject to the TimeTrex Public License Version
- * 1.1.0 ("License"); You may not use this file except in compliance with the
- * License. You may obtain a copy of the License at http://www.TimeTrex.com/TPL
- * Software distributed under the License is distributed on an "AS IS" basis,
- * WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the License
- * for the specific language governing rights and limitations under the
- * License.
+ * TimeTrex is a Payroll and Time Management program developed by
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
  *
- * All copies of the Covered Code must include on each user interface screen:
- *    (i) the "Powered by TimeTrex" logo and
- *    (ii) the TimeTrex copyright notice
- * in the same form as they appear in the distribution.  See full license for
- * requirements.
+ * This program is free software; you can redistribute it and/or modify it under
+ * the terms of the GNU Affero General Public License version 3 as published by
+ * the Free Software Foundation with the addition of the following permission
+ * added to Section 15 as permitted in Section 7(a): FOR ANY PART OF THE COVERED
+ * WORK IN WHICH THE COPYRIGHT IS OWNED BY TIMETREX, TIMETREX DISCLAIMS THE
+ * WARRANTY OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
  *
- * The Original Code is: TimeTrex Open Source
- * The Initial Developer of the Original Code is TimeTrex Payroll Services
- * Portions created by TimeTrex are Copyright (C) 2004-2007 TimeTrex Payroll Services;
- * All Rights Reserved.
+ * This program is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+ * FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
+ * details.
  *
+ * You should have received a copy of the GNU Affero General Public License along
+ * with this program; if not, see http://www.gnu.org/licenses or write to the Free
+ * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+ * 02110-1301 USA.
+ *
+ * You can contact TimeTrex headquarters at Unit 22 - 2475 Dobbin Rd. Suite
+ * #292 Westbank, BC V4T 2E9, Canada or at email address info@timetrex.com.
+ *
+ * The interactive user interfaces in modified source and object code versions
+ * of this program must display Appropriate Legal Notices, as required under
+ * Section 5 of the GNU Affero General Public License version 3.
+ *
+ * In accordance with Section 7(b) of the GNU Affero General Public License
+ * version 3, these Appropriate Legal Notices must retain the display of the
+ * "Powered by TimeTrex" logo. If the display of the logo is not reasonably
+ * feasible for technical reasons, the Appropriate Legal Notices must display
+ * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2158 $
- * $Id: DateTimeTest.php 2158 2008-09-15 23:26:15Z ipso $
- * $Date: 2008-09-15 16:26:15 -0700 (Mon, 15 Sep 2008) $
+ * $Revision: 3041 $
+ * $Id: DateTimeTest.php 3041 2009-11-12 19:34:13Z ipso $
+ * $Date: 2009-11-12 11:34:13 -0800 (Thu, 12 Nov 2009) $
  */
 require_once('PHPUnit/Framework/TestCase.php');
 
@@ -395,5 +408,212 @@ class DateTimeTest extends PHPUnit_Framework_TestCase {
 		$this->assertEquals( (int)TTDate::graceTime( strtotime('15-Apr-07 7:58 AM'), (60*5), strtotime('15-Apr-07 8:00 AM') ), strtotime('15-Apr-07 8:00 AM') );
 		$this->assertEquals( (int)TTDate::graceTime( strtotime('15-Apr-07 7:58:23 AM'), (60*5), strtotime('15-Apr-07 8:00 AM') ), strtotime('15-Apr-07 8:00 AM') );
 	}
+
+	function test_calculateTimeOnEachDayBetweenRange() {
+		$test1_result = TTDate::calculateTimeOnEachDayBetweenRange( strtotime('01-Jan-09 8:00AM'), strtotime('01-Jan-09 11:30PM') );
+		$this->assertEquals( count($test1_result), 1 );
+		$this->assertEquals( $test1_result[1230796800], 55800 );
+
+		$test2_result = TTDate::calculateTimeOnEachDayBetweenRange( strtotime('01-Jan-09 4:00PM'), strtotime('02-Jan-09 8:00AM') );
+		$this->assertEquals( count($test2_result), 2 );
+		$this->assertEquals( $test2_result[1230796800], 28800 );
+		$this->assertEquals( $test2_result[1230883200], 28800 );
+
+		$test3_result = TTDate::calculateTimeOnEachDayBetweenRange( strtotime('01-Jan-09 4:00PM'), strtotime('03-Jan-09 8:00AM') );
+		$this->assertEquals( count($test3_result), 3 );
+		$this->assertEquals( $test3_result[1230796800], 28800 );
+		$this->assertEquals( $test3_result[1230883200], 86400 );
+		$this->assertEquals( $test3_result[1230969600], 28800 );
+
+		$test4_result = TTDate::calculateTimeOnEachDayBetweenRange( strtotime('01-Jan-09 4:00PM'), strtotime('9-Jan-09 8:00AM') );
+		$this->assertEquals( count($test4_result), 9 );
+		$this->assertEquals( $test4_result[1230796800], 28800 );
+		$this->assertEquals( $test4_result[1230883200], 86400 );
+		$this->assertEquals( $test4_result[1230969600], 86400 );
+		$this->assertEquals( $test4_result[1231056000], 86400 );
+		$this->assertEquals( $test4_result[1231142400], 86400 );
+		$this->assertEquals( $test4_result[1231228800], 86400 );
+		$this->assertEquals( $test4_result[1231315200], 86400 );
+		$this->assertEquals( $test4_result[1231401600], 86400 );
+		$this->assertEquals( $test4_result[1231488000], 28800 );
+
+		$test5_result = TTDate::calculateTimeOnEachDayBetweenRange( strtotime('01-Jan-09 12:00AM'), strtotime('01-Jan-09 12:59:59PM') );
+		$this->assertEquals( count($test5_result), 1 );
+		$this->assertEquals( $test5_result[1230796800], 46799 );
+
+		$test5_result = TTDate::calculateTimeOnEachDayBetweenRange( strtotime('01-Jan-09 12:00AM'), strtotime('02-Jan-09 12:00AM') );
+		$this->assertEquals( count($test5_result), 1 );
+		$this->assertEquals( $test5_result[1230796800], 86400 );
+
+		$test5_result = TTDate::calculateTimeOnEachDayBetweenRange( strtotime('01-Jan-09 12:01AM'), strtotime('02-Jan-09 12:01AM') );
+		$this->assertEquals( count($test5_result), 2 );
+		$this->assertEquals( $test5_result[1230796800], 86340);
+		$this->assertEquals( $test5_result[1230883200], 60);
+
+		$test5_result = TTDate::calculateTimeOnEachDayBetweenRange( strtotime('01-Jan-09 1:53PM'), strtotime('03-Jan-09 6:12AM') );
+		$this->assertEquals( count($test5_result), 3 );
+		$this->assertEquals( $test5_result[1230796800], 36420);
+		$this->assertEquals( $test5_result[1230883200], 86400);
+		$this->assertEquals( $test5_result[1230969600], 22320);
+	}
+
+	function test_getWeek() {
+		//Match up with PHP's function
+		$date1 = strtotime('01-Nov-09 12:00PM');
+		$this->assertEquals( date('W', $date1 ), 44 );
+		$this->assertEquals( TTDate::getWeek( $date1, 1), 44 );
+
+		$date1 = strtotime('02-Nov-09 12:00PM');
+		$this->assertEquals( date('W', $date1 ), 45 );
+		$this->assertEquals( TTDate::getWeek( $date1, 1), 45 );
+
+		$date1 = strtotime('03-Nov-09 12:00PM');
+		$this->assertEquals( date('W', $date1 ), 45 );
+		$this->assertEquals( TTDate::getWeek( $date1, 1), 45 );
+
+		$date1 = strtotime('04-Nov-09 12:00PM');
+		$this->assertEquals( date('W', $date1 ), 45 );
+		$this->assertEquals( TTDate::getWeek( $date1, 1), 45 );
+
+		$date1 = strtotime('05-Nov-09 12:00PM');
+		$this->assertEquals( date('W', $date1 ), 45 );
+		$this->assertEquals( TTDate::getWeek( $date1, 1), 45 );
+
+		$date1 = strtotime('06-Nov-09 12:00PM');
+		$this->assertEquals( date('W', $date1 ), 45 );
+		$this->assertEquals( TTDate::getWeek( $date1, 1), 45 );
+
+		$date1 = strtotime('07-Nov-09 12:00PM');
+		$this->assertEquals( date('W', $date1 ), 45 );
+		$this->assertEquals( TTDate::getWeek( $date1, 1), 45 );
+
+		$date1 = strtotime('08-Nov-09 12:00PM');
+		$this->assertEquals( date('W', $date1 ), 45 );
+		$this->assertEquals( TTDate::getWeek( $date1, 1), 45 );
+
+		$date1 = strtotime('09-Nov-09 12:00PM');
+		$this->assertEquals( date('W', $date1 ), 46 );
+		$this->assertEquals( TTDate::getWeek( $date1, 1), 46 );
+
+		//Test with Sunday as start day of week.
+		$date1 = strtotime('01-Nov-09 12:00PM');
+		$this->assertEquals( TTDate::getWeek( $date1, 0), 45 );
+
+		$date1 = strtotime('02-Nov-09 12:00PM');
+		$this->assertEquals( TTDate::getWeek( $date1, 0), 45 );
+
+		$date1 = strtotime('03-Nov-09 12:00PM');
+		$this->assertEquals( TTDate::getWeek( $date1, 0), 45 );
+
+		$date1 = strtotime('04-Nov-09 12:00PM');
+		$this->assertEquals( TTDate::getWeek( $date1, 0), 45 );
+
+		$date1 = strtotime('05-Nov-09 12:00PM');
+		$this->assertEquals( TTDate::getWeek( $date1, 0), 45 );
+
+		$date1 = strtotime('06-Nov-09 12:00PM');
+		$this->assertEquals( TTDate::getWeek( $date1, 0), 45 );
+
+		$date1 = strtotime('07-Nov-09 12:00PM');
+		$this->assertEquals( TTDate::getWeek( $date1, 0), 45 );
+
+		$date1 = strtotime('08-Nov-09 12:00PM');
+		$this->assertEquals( TTDate::getWeek( $date1, 0), 46 );
+
+		$date1 = strtotime('09-Nov-09 12:00PM');
+		$this->assertEquals( TTDate::getWeek( $date1, 0), 46 );
+
+
+		//Test with Tuesday as start day of week.
+		$date1 = strtotime('01-Nov-09 12:00PM');
+		$this->assertEquals( TTDate::getWeek( $date1, 2), 44 );
+
+		$date1 = strtotime('02-Nov-09 12:00PM');
+		$this->assertEquals( TTDate::getWeek( $date1, 2), 44 );
+
+		$date1 = strtotime('03-Nov-09 12:00PM');
+		$this->assertEquals( TTDate::getWeek( $date1, 2), 45 );
+
+		$date1 = strtotime('04-Nov-09 12:00PM');
+		$this->assertEquals( TTDate::getWeek( $date1, 2), 45 );
+
+		$date1 = strtotime('05-Nov-09 12:00PM');
+		$this->assertEquals( TTDate::getWeek( $date1, 2), 45 );
+
+		$date1 = strtotime('06-Nov-09 12:00PM');
+		$this->assertEquals( TTDate::getWeek( $date1, 2), 45 );
+
+		$date1 = strtotime('07-Nov-09 12:00PM');
+		$this->assertEquals( TTDate::getWeek( $date1, 2), 45 );
+
+		$date1 = strtotime('08-Nov-09 12:00PM');
+		$this->assertEquals( TTDate::getWeek( $date1, 2), 45 );
+
+		$date1 = strtotime('09-Nov-09 12:00PM');
+		$this->assertEquals( TTDate::getWeek( $date1, 2), 45 );
+
+		$date1 = strtotime('10-Nov-09 12:00PM');
+		$this->assertEquals( TTDate::getWeek( $date1, 2), 46 );
+
+		$date1 = strtotime('11-Nov-09 12:00PM');
+		$this->assertEquals( TTDate::getWeek( $date1, 2), 46 );
+
+
+		//Test with Wed as start day of week.
+		$date1 = strtotime('03-Nov-09 12:00PM');
+		$this->assertEquals( TTDate::getWeek( $date1, 3), 44 );
+
+		$date1 = strtotime('04-Nov-09 12:00PM');
+		$this->assertEquals( TTDate::getWeek( $date1, 3), 45 );
+
+		$date1 = strtotime('05-Nov-09 12:00PM');
+		$this->assertEquals( TTDate::getWeek( $date1, 3), 45 );
+
+		//Test with Thu as start day of week.
+		$date1 = strtotime('04-Nov-09 12:00PM');
+		$this->assertEquals( TTDate::getWeek( $date1, 4), 44 );
+
+		$date1 = strtotime('05-Nov-09 12:00PM');
+		$this->assertEquals( TTDate::getWeek( $date1, 4), 45 );
+
+		$date1 = strtotime('06-Nov-09 12:00PM');
+		$this->assertEquals( TTDate::getWeek( $date1, 4), 45 );
+
+		//Test with Fri as start day of week.
+		$date1 = strtotime('05-Nov-09 12:00PM');
+		$this->assertEquals( TTDate::getWeek( $date1, 5), 44 );
+
+		$date1 = strtotime('06-Nov-09 12:00PM');
+		$this->assertEquals( TTDate::getWeek( $date1, 5), 45 );
+
+		$date1 = strtotime('07-Nov-09 12:00PM');
+		$this->assertEquals( TTDate::getWeek( $date1, 5), 45 );
+
+		//Test with Sat as start day of week.
+		$date1 = strtotime('06-Nov-09 12:00PM');
+		$this->assertEquals( TTDate::getWeek( $date1, 6), 44 );
+
+		$date1 = strtotime('07-Nov-09 12:00PM');
+		$this->assertEquals( TTDate::getWeek( $date1, 6), 45 );
+
+		$date1 = strtotime('08-Nov-09 12:00PM');
+		$this->assertEquals( TTDate::getWeek( $date1, 6), 45 );
+
+		//Test with different years
+		$date1 = strtotime('31-Dec-09 12:00PM');
+		$this->assertEquals( TTDate::getWeek( $date1, 1), 53 );
+
+		$date1 = strtotime('01-Jan-10 12:00PM');
+		$this->assertEquals( TTDate::getWeek( $date1, 1), 53 );
+
+		$date1 = strtotime('04-Jan-10 12:00PM');
+		$this->assertEquals( TTDate::getWeek( $date1, 1), 1 );
+
+		$date1 = strtotime('03-Jan-10 12:00PM');
+		$this->assertEquals( TTDate::getWeek( $date1, 0), 1 );
+
+		$date1 = strtotime('09-Jan-10 12:00PM');
+		$this->assertEquals( TTDate::getWeek( $date1, 6), 1 );
+	}
 }
 ?>
\ No newline at end of file
