@@ -1,29 +1,42 @@
 <?php
 /*********************************************************************************
- * The contents of this file are subject to the TimeTrex Public License Version
- * 1.1.0 ("License"); You may not use this file except in compliance with the
- * License. You may obtain a copy of the License at http://www.TimeTrex.com/TPL
- * Software distributed under the License is distributed on an "AS IS" basis,
- * WITHOUT WARRANTY OF ANY KIND, either express or implied.  See the License
- * for the specific language governing rights and limitations under the
- * License.
+ * TimeTrex is a Payroll and Time Management program developed by
+ * TimeTrex Payroll Services Copyright (C) 2003 - 2010 TimeTrex Payroll Services.
  *
- * All copies of the Covered Code must include on each user interface screen:
- *    (i) the "Powered by TimeTrex" logo and
- *    (ii) the TimeTrex copyright notice
- * in the same form as they appear in the distribution.  See full license for
- * requirements.
+ * This program is free software; you can redistribute it and/or modify it under
+ * the terms of the GNU Affero General Public License version 3 as published by
+ * the Free Software Foundation with the addition of the following permission
+ * added to Section 15 as permitted in Section 7(a): FOR ANY PART OF THE COVERED
+ * WORK IN WHICH THE COPYRIGHT IS OWNED BY TIMETREX, TIMETREX DISCLAIMS THE
+ * WARRANTY OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
  *
- * The Original Code is: TimeTrex Open Source
- * The Initial Developer of the Original Code is TimeTrex Payroll Services
- * Portions created by TimeTrex are Copyright (C) 2004-2007 TimeTrex Payroll Services;
- * All Rights Reserved.
+ * This program is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+ * FOR A PARTICULAR PURPOSE.  See the GNU Affero General Public License for more
+ * details.
  *
+ * You should have received a copy of the GNU Affero General Public License along
+ * with this program; if not, see http://www.gnu.org/licenses or write to the Free
+ * Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+ * 02110-1301 USA.
+ *
+ * You can contact TimeTrex headquarters at Unit 22 - 2475 Dobbin Rd. Suite
+ * #292 Westbank, BC V4T 2E9, Canada or at email address info@timetrex.com.
+ *
+ * The interactive user interfaces in modified source and object code versions
+ * of this program must display Appropriate Legal Notices, as required under
+ * Section 5 of the GNU Affero General Public License version 3.
+ *
+ * In accordance with Section 7(b) of the GNU Affero General Public License
+ * version 3, these Appropriate Legal Notices must retain the display of the
+ * "Powered by TimeTrex" logo. If the display of the logo is not reasonably
+ * feasible for technical reasons, the Appropriate Legal Notices must display
+ * the words "Powered by TimeTrex".
  ********************************************************************************/
 /*
- * $Revision: 2453 $
- * $Id: PayStubCalculationTest.php 2453 2009-03-20 16:34:04Z ipso $
- * $Date: 2009-03-20 09:34:04 -0700 (Fri, 20 Mar 2009) $
+ * $Revision: 3143 $
+ * $Id: PayStubCalculationTest.php 3143 2009-12-02 17:21:41Z ipso $
+ * $Date: 2009-12-02 09:21:41 -0800 (Wed, 02 Dec 2009) $
  */
 require_once('PHPUnit/Framework/TestCase.php');
 
@@ -55,7 +68,7 @@ class PayStubCalculationTest extends PHPUnit_Framework_TestCase {
         Debug::text('Running setUp(): ', __FILE__, __LINE__, __METHOD__,10);
 
 		$dd = new DemoData();
-		$dd->setUserNamePostFix( rand(1000,9999) );
+		$dd->setUserNamePostFix( rand(1000,99999) );
 		$this->company_id = $dd->createCompany();
 		Debug::text('Company ID: '. $this->company_id, __FILE__, __LINE__, __METHOD__,10);
 
@@ -154,6 +167,29 @@ class PayStubCalculationTest extends PHPUnit_Framework_TestCase {
 			$pseaf->Save();
 		}
 
+		Debug::text('Saving.... Employee Deduction - Advanced Percent 1', __FILE__, __LINE__, __METHOD__, 10);
+		$pseaf = new PayStubEntryAccountFactory();
+		$pseaf->setCompany( $this->company_id );
+		$pseaf->setStatus(10);
+		$pseaf->setType(20);
+		$pseaf->setName('Advanced Percent 1');
+		$pseaf->setOrder(291);
+
+		if ( $pseaf->isValid() ) {
+			$pseaf->Save();
+		}
+		Debug::text('Saving.... Employee Deduction - Advanced Percent 2', __FILE__, __LINE__, __METHOD__, 10);
+		$pseaf = new PayStubEntryAccountFactory();
+		$pseaf->setCompany( $this->company_id );
+		$pseaf->setStatus(10);
+		$pseaf->setType(20);
+		$pseaf->setName('Advanced Percent 2');
+		$pseaf->setOrder(291);
+
+		if ( $pseaf->isValid() ) {
+			$pseaf->Save();
+		}
+
 		Debug::text('Saving.... Employee Deduction - EI', __FILE__, __LINE__, __METHOD__, 10);
 		$pseaf = new PayStubEntryAccountFactory();
 		$pseaf->setCompany( $this->company_id );
@@ -239,6 +275,49 @@ class PayStubCalculationTest extends PHPUnit_Framework_TestCase {
 			}
 		}
 
+		//Test Advanced Percent Calculation maximum amount.
+		$cdf = new CompanyDeductionFactory();
+		$cdf->setCompany( $this->company_id );
+		$cdf->setStatus( 10 ); //Enabled
+		$cdf->setType( 10 ); //Tax
+		$cdf->setName( 'Test Advanced Percent 1' );
+		$cdf->setCalculation( 15 );
+		$cdf->setCalculationOrder( 90 );
+		$cdf->setPayStubEntryAccount( CompanyDeductionFactory::getPayStubEntryAccountByCompanyIDAndTypeAndFuzzyName($this->company_id, 20, 'Advanced Percent 1') );
+		$cdf->setUserValue1( 1 ); //1%
+		$cdf->setUserValue2( 2000 ); //Wage Base
+
+		if ( $cdf->isValid() ) {
+			$cdf->Save(FALSE);
+
+			$cdf->setIncludePayStubEntryAccount( array( $this->pay_stub_account_link_arr['regular_time'] ) );
+
+			if ( $cdf->isValid() ) {
+				$cdf->Save();
+			}
+		}
+		//Test Advanced Percent Calculation maximum amount.
+		$cdf = new CompanyDeductionFactory();
+		$cdf->setCompany( $this->company_id );
+		$cdf->setStatus( 10 ); //Enabled
+		$cdf->setType( 10 ); //Tax
+		$cdf->setName( 'Test Advanced Percent 2' );
+		$cdf->setCalculation( 15 );
+		$cdf->setCalculationOrder( 90 );
+		$cdf->setPayStubEntryAccount( CompanyDeductionFactory::getPayStubEntryAccountByCompanyIDAndTypeAndFuzzyName($this->company_id, 20, 'Advanced Percent 2') );
+		$cdf->setUserValue1( 1 ); //1%
+		$cdf->setUserValue2( 2500 ); //Wage Base
+
+		if ( $cdf->isValid() ) {
+			$cdf->Save(FALSE);
+
+			$cdf->setIncludePayStubEntryAccount( array( $this->pay_stub_account_link_arr['regular_time'] ) );
+
+			if ( $cdf->isValid() ) {
+				$cdf->Save();
+			}
+		}
+
 		$cdf = new CompanyDeductionFactory();
 		$cdf->setCompany( $this->company_id );
 		$cdf->setStatus( 10 ); //Enabled
@@ -599,7 +678,8 @@ class PayStubCalculationTest extends PHPUnit_Framework_TestCase {
 		$psaf->setStatus( 50 ); //Active
 
 		$psaf->setType( 10 );
-		$psaf->setAmount( 0.09 );
+		//$psaf->setAmount( 0.09 );
+		$psaf->setAmount( 1000 ); //Increase this so Union Dues are closer to the maximum earnings and are calculated to be less.
 		$psaf->setYTDAdjustment(TRUE);
 
 		$psaf->setDescription('Test YTD (2) PS Amendment');
@@ -670,9 +750,28 @@ class PayStubCalculationTest extends PHPUnit_Framework_TestCase {
 
 		//
 		// Add EARNING PS amendments for a pay period that has no Punch hours.
-		//
+		// Include a regular time adjustment so we can test Wage Base amounts for some tax/deductions.
 
-		//Regular FIXED PS amendment
+		//Regular FIXED PS amendment as regular time.
+		$psaf = new PayStubAmendmentFactory();
+		$psaf->setUser( $this->user_id );
+		$psaf->setPayStubEntryNameId( CompanyDeductionFactory::getPayStubEntryAccountByCompanyIDAndTypeAndFuzzyName($this->company_id, 10, 'Regular Time') );
+		$psaf->setStatus( 50 ); //Active
+
+		$psaf->setType( 10 );
+		$psaf->setRate( 33.33 );
+		$psaf->setUnits( 3 );
+
+		$psaf->setDescription('Test Fixed PS Amendment (1)');
+
+		$psaf->setEffectiveDate( $this->pay_period_objs[1]->getEndDate() );
+
+		$psaf->setAuthorized(TRUE);
+		if ( $psaf->isValid() ) {
+			$psaf->Save();
+		}
+
+		//Regular FIXED PS amendment as Bonus
 		$psaf = new PayStubAmendmentFactory();
 		$psaf->setUser( $this->user_id );
 		$psaf->setPayStubEntryNameId( CompanyDeductionFactory::getPayStubEntryAccountByCompanyIDAndTypeAndFuzzyName($this->company_id, 10, 'Bonus') );
@@ -682,7 +781,7 @@ class PayStubCalculationTest extends PHPUnit_Framework_TestCase {
 		$psaf->setRate( 10 );
 		$psaf->setUnits( 30 );
 
-		$psaf->setDescription('Test Fixed PS Amendment');
+		$psaf->setDescription('Test Fixed PS Amendment (2)');
 
 		$psaf->setEffectiveDate( $this->pay_period_objs[1]->getEndDate() );
 
@@ -738,6 +837,8 @@ class PayStubCalculationTest extends PHPUnit_Framework_TestCase {
 							'state_disability' => CompanyDeductionFactory::getPayStubEntryAccountByCompanyIDAndTypeAndFuzzyName($this->company_id, 20, 'State Disability Ins.'),
 							'medicare' => CompanyDeductionFactory::getPayStubEntryAccountByCompanyIDAndTypeAndFuzzyName($this->company_id, 20, 'Medicare'),
 							'union_dues' => CompanyDeductionFactory::getPayStubEntryAccountByCompanyIDAndTypeAndFuzzyName($this->company_id, 20, 'Union Dues'),
+							'advanced_percent_1' => CompanyDeductionFactory::getPayStubEntryAccountByCompanyIDAndTypeAndFuzzyName($this->company_id, 20, 'Advanced Percent 1'),
+							'advanced_percent_2' => CompanyDeductionFactory::getPayStubEntryAccountByCompanyIDAndTypeAndFuzzyName($this->company_id, 20, 'Advanced Percent 2'),
 							'deduction_other' => CompanyDeductionFactory::getPayStubEntryAccountByCompanyIDAndTypeAndFuzzyName($this->company_id, 20, 'Other'),
 							'ei' => CompanyDeductionFactory::getPayStubEntryAccountByCompanyIDAndTypeAndFuzzyName($this->company_id, 20, 'ei'),
 							'cpp' => CompanyDeductionFactory::getPayStubEntryAccountByCompanyIDAndTypeAndFuzzyName($this->company_id, 20, 'cpp'),
@@ -770,8 +871,8 @@ class PayStubCalculationTest extends PHPUnit_Framework_TestCase {
 		$this->assertEquals( $pse_arr[$pse_accounts['other']][0]['amount'], '240.80' );
 		$this->assertEquals( $pse_arr[$pse_accounts['other']][0]['ytd_amount'], '0.00' );
 		//Fixed amount PS amendment
-		$this->assertEquals( $pse_arr[$pse_accounts['other']][1]['amount'], '0.09' );
-		$this->assertEquals( $pse_arr[$pse_accounts['other']][1]['ytd_amount'], '240.89' );
+		$this->assertEquals( $pse_arr[$pse_accounts['other']][1]['amount'], '1000.00' );
+		$this->assertEquals( $pse_arr[$pse_accounts['other']][1]['ytd_amount'], '1240.80' );
 
 		$this->assertEquals( $pse_arr[$pse_accounts['premium_2']][0]['amount'], '10.00' );
 		$this->assertEquals( $pse_arr[$pse_accounts['premium_2']][0]['ytd_amount'], '0.00' );
@@ -802,19 +903,19 @@ class PayStubCalculationTest extends PHPUnit_Framework_TestCase {
 		$this->assertEquals( $pse_arr[$pse_accounts['vacation_accrual']][2]['amount'], '-114.67' );
 		$this->assertEquals( $pse_arr[$pse_accounts['vacation_accrual']][2]['ytd_amount'], '114.67' );
 
-		//Union Dues - Wage Base Amount
-		//$this->assertEquals( $pse_arr[$pse_accounts['union_dues']][0]['amount'], '8.69' );
-		//$this->assertEquals( $pse_arr[$pse_accounts['union_dues']][0]['ytd_amount'], '8.69' );
+		//Union Dues - Should be 19.98 due to getting close to hitting Wage Base, because a YTD adjustment for Total Gross exists for around 1001.99.
+		$this->assertEquals( $pse_arr[$pse_accounts['union_dues']][0]['amount'], '19.98' );
+		$this->assertEquals( $pse_arr[$pse_accounts['union_dues']][0]['ytd_amount'], '19.98' );
 
-		$this->assertEquals( $pse_arr[$pse_accounts['union_dues']][0]['amount'], '30.00' );
-		$this->assertEquals( $pse_arr[$pse_accounts['union_dues']][0]['ytd_amount'], '30.00' ); //Due to hitting Wage Base
+		//Advanced Percent
+		$this->assertEquals( $pse_arr[$pse_accounts['advanced_percent_1']][0]['amount'], '20.00' );
+		$this->assertEquals( $pse_arr[$pse_accounts['advanced_percent_1']][0]['ytd_amount'], '20.00' ); //Exceeds Wage Base
 
-		//Other Deduction - Wage Excempt amount.
-		//$this->assertEquals( $pse_arr[$pse_accounts['deduction_other']][0]['amount'], '31.32' );
-		//$this->assertEquals( $pse_arr[$pse_accounts['deduction_other']][0]['ytd_amount'], '31.32' );
+		$this->assertEquals( $pse_arr[$pse_accounts['advanced_percent_2']][0]['amount'], '24.08' );
+		$this->assertEquals( $pse_arr[$pse_accounts['advanced_percent_2']][0]['ytd_amount'], '24.08' ); //Not close to Wage Base.
 
-		$this->assertEquals( $pse_arr[$pse_accounts['deduction_other']][0]['amount'], '37.28' );
-		$this->assertEquals( $pse_arr[$pse_accounts['deduction_other']][0]['ytd_amount'], '37.28' );
+		$this->assertEquals( $pse_arr[$pse_accounts['deduction_other']][0]['amount'], '37.29' );
+		$this->assertEquals( $pse_arr[$pse_accounts['deduction_other']][0]['ytd_amount'], '37.29' );
 
 		//EI
 		$this->assertEquals( $pse_arr[$pse_accounts['ei']][0]['amount'], '700.00' );
@@ -879,14 +980,14 @@ class PayStubCalculationTest extends PHPUnit_Framework_TestCase {
 
 		if ( $pse_arr[$this->pay_stub_account_link_arr['total_gross']][0]['amount'] >= 3250
 				AND $pse_arr[$this->pay_stub_account_link_arr['total_gross']][0]['amount'] <= 3400
-				AND ($pse_arr[$this->pay_stub_account_link_arr['total_gross']][0]['amount']+2.08) == $pse_arr[$this->pay_stub_account_link_arr['total_gross']][0]['ytd_amount'] ) {
+				AND ( $pse_arr[$this->pay_stub_account_link_arr['total_gross']][0]['amount']+(1000+1.99) ) == $pse_arr[$this->pay_stub_account_link_arr['total_gross']][0]['ytd_amount'] ) {
 			$this->assertTrue( TRUE );
 		} else {
 			$this->assertTrue( FALSE, 'Total Gross not within range!' );
 		}
 
-		if ( $pse_arr[$this->pay_stub_account_link_arr['total_deductions']][0]['amount'] >= 900
-				AND $pse_arr[$this->pay_stub_account_link_arr['total_deductions']][0]['amount'] <= 1300
+		if ( $pse_arr[$this->pay_stub_account_link_arr['total_deductions']][0]['amount'] >= 1100
+				AND $pse_arr[$this->pay_stub_account_link_arr['total_deductions']][0]['amount'] <= 1400
 				AND ( bcadd($pse_arr[$this->pay_stub_account_link_arr['total_deductions']][0]['amount'],2600)) == $pse_arr[$this->pay_stub_account_link_arr['total_deductions']][0]['ytd_amount'] ) {
 			$this->assertTrue( TRUE );
 		} else {
@@ -895,7 +996,7 @@ class PayStubCalculationTest extends PHPUnit_Framework_TestCase {
 
 		if ( $pse_arr[$this->pay_stub_account_link_arr['net_pay']][0]['amount'] >= 1900
 				AND $pse_arr[$this->pay_stub_account_link_arr['net_pay']][0]['amount'] <= 2300
-				AND bcsub($pse_arr[$this->pay_stub_account_link_arr['net_pay']][0]['amount'],2597.92) == $pse_arr[$this->pay_stub_account_link_arr['net_pay']][0]['ytd_amount'] ) {
+				AND bcsub($pse_arr[$this->pay_stub_account_link_arr['net_pay']][0]['amount'], 1598.01) == $pse_arr[$this->pay_stub_account_link_arr['net_pay']][0]['ytd_amount'] ) {
 			$this->assertTrue( TRUE );
 		} else {
 			$this->assertTrue( FALSE, 'NET PAY not within range!');
@@ -918,6 +1019,8 @@ class PayStubCalculationTest extends PHPUnit_Framework_TestCase {
 							'state_disability' => CompanyDeductionFactory::getPayStubEntryAccountByCompanyIDAndTypeAndFuzzyName($this->company_id, 20, 'State Disability Ins.'),
 							'medicare' => CompanyDeductionFactory::getPayStubEntryAccountByCompanyIDAndTypeAndFuzzyName($this->company_id, 20, 'Medicare'),
 							'union_dues' => CompanyDeductionFactory::getPayStubEntryAccountByCompanyIDAndTypeAndFuzzyName($this->company_id, 20, 'Union Dues'),
+							'advanced_percent_1' => CompanyDeductionFactory::getPayStubEntryAccountByCompanyIDAndTypeAndFuzzyName($this->company_id, 20, 'Advanced Percent 1'),
+							'advanced_percent_2' => CompanyDeductionFactory::getPayStubEntryAccountByCompanyIDAndTypeAndFuzzyName($this->company_id, 20, 'Advanced Percent 2'),
 							'deduction_other' => CompanyDeductionFactory::getPayStubEntryAccountByCompanyIDAndTypeAndFuzzyName($this->company_id, 20, 'Other'),
 							'ei' => CompanyDeductionFactory::getPayStubEntryAccountByCompanyIDAndTypeAndFuzzyName($this->company_id, 20, 'ei'),
 							'cpp' => CompanyDeductionFactory::getPayStubEntryAccountByCompanyIDAndTypeAndFuzzyName($this->company_id, 20, 'cpp'),
@@ -932,32 +1035,39 @@ class PayStubCalculationTest extends PHPUnit_Framework_TestCase {
 		//var_dump($pse_arr);
 
 
+		$this->assertEquals( $pse_arr[$pse_accounts['regular_time']][0]['rate'], '33.33' );
+		$this->assertEquals( $pse_arr[$pse_accounts['regular_time']][0]['units'], '3.00' );
+		$this->assertEquals( $pse_arr[$pse_accounts['regular_time']][0]['amount'], '99.99' );
+		$this->assertEquals( $pse_arr[$pse_accounts['regular_time']][0]['ytd_amount'], '2507.99' );
+
 		$this->assertEquals( $pse_arr[$pse_accounts['bonus']][0]['rate'], '10.00' );
 		$this->assertEquals( $pse_arr[$pse_accounts['bonus']][0]['units'], '30.00' );
 		$this->assertEquals( $pse_arr[$pse_accounts['bonus']][0]['amount'], '300.00' );
 		$this->assertEquals( $pse_arr[$pse_accounts['bonus']][0]['ytd_amount'], '400.00' );
 
-		$this->assertEquals( $pse_arr[$this->pay_stub_account_link_arr['total_gross']][0]['amount'], '300' );
+		$this->assertEquals( $pse_arr[$pse_accounts['union_dues']][0]['amount'], '0.00' );
+		$this->assertEquals( $pse_arr[$pse_accounts['union_dues']][0]['ytd_amount'], '19.98' );
 
-		//if ( $pse_arr[$this->pay_stub_account_link_arr['total_gross']][0]['amount'] >= 3250
-		//		AND $pse_arr[$this->pay_stub_account_link_arr['total_gross']][0]['amount'] <= 3400
-		//		AND ($pse_arr[$this->pay_stub_account_link_arr['total_gross']][0]['amount']+2.08) == $pse_arr[$this->pay_stub_account_link_arr['total_gross']][0]['ytd_amount'] ) {
-		//	$this->assertTrue( TRUE );
-		//} else {
-		//	$this->assertTrue( FALSE, 'Total Gross not within range!' );
-		//}
+		$this->assertEquals( $pse_arr[$this->pay_stub_account_link_arr['total_gross']][0]['amount'], '399.99' );
 
-		if ( $pse_arr[$this->pay_stub_account_link_arr['total_deductions']][0]['amount'] >= 25
-				AND $pse_arr[$this->pay_stub_account_link_arr['total_deductions']][0]['amount'] <= 75
-				AND ( bcadd($pse_arr[$this->pay_stub_account_link_arr['total_deductions']][0]['amount'], 3847.85)) == $pse_arr[$this->pay_stub_account_link_arr['total_deductions']][0]['ytd_amount'] ) {
+		//Check deductions.
+		$this->assertEquals( $pse_arr[$pse_accounts['advanced_percent_1']][0]['amount'], '0.00' ); //Already Exceeded Wage Base, this should be 0!!
+		$this->assertEquals( $pse_arr[$pse_accounts['advanced_percent_1']][0]['ytd_amount'], '20.00' );
+		$this->assertEquals( $pse_arr[$pse_accounts['advanced_percent_2']][0]['amount'], '0.92' ); //Nearing Wage Base, this should be less than 1!!
+		$this->assertEquals( $pse_arr[$pse_accounts['advanced_percent_2']][0]['ytd_amount'], '25.00' );
+
+
+		if ( $pse_arr[$this->pay_stub_account_link_arr['total_deductions']][0]['amount'] >= 45
+				AND $pse_arr[$this->pay_stub_account_link_arr['total_deductions']][0]['amount'] <= 65
+				AND ( bcadd($pse_arr[$this->pay_stub_account_link_arr['total_deductions']][0]['amount'], 3881.92)) == $pse_arr[$this->pay_stub_account_link_arr['total_deductions']][0]['ytd_amount'] ) {
 			$this->assertTrue( TRUE );
 		} else {
 			$this->assertTrue( FALSE, 'Total Deductions not within range! Total Deductions: '. $pse_arr[$this->pay_stub_account_link_arr['total_deductions']][0]['amount'] .' YTD Amount: '. $pse_arr[$this->pay_stub_account_link_arr['total_deductions']][0]['ytd_amount'] );
 		}
 
-		if ( $pse_arr[$this->pay_stub_account_link_arr['net_pay']][0]['amount'] >= 230
-				AND $pse_arr[$this->pay_stub_account_link_arr['net_pay']][0]['amount'] <= 270
-				AND bcsub($pse_arr[$this->pay_stub_account_link_arr['net_pay']][0]['amount'],472.92) == $pse_arr[$this->pay_stub_account_link_arr['net_pay']][0]['ytd_amount'] ) {
+		if ( $pse_arr[$this->pay_stub_account_link_arr['net_pay']][0]['amount'] >= 335
+				AND $pse_arr[$this->pay_stub_account_link_arr['net_pay']][0]['amount'] <= 355
+				AND bcadd($pse_arr[$this->pay_stub_account_link_arr['net_pay']][0]['amount'],492.92) == $pse_arr[$this->pay_stub_account_link_arr['net_pay']][0]['ytd_amount'] ) {
 			$this->assertTrue( TRUE );
 		} else {
 			$this->assertTrue( FALSE, 'NET PAY not within range! Net Pay: '. $pse_arr[$this->pay_stub_account_link_arr['net_pay']][0]['amount'] .' YTD Amount: '. $pse_arr[$this->pay_stub_account_link_arr['net_pay']][0]['ytd_amount']);
